#include <stdint.h>
#include <stdlib.h>
#include <stdio.h>
#include <string>

template<typename T>
class Array {

  private:

    int size1, size2, size3;
    T *elems;

  public:

    Array() : size1(0), size2(0), size3(0), elems(0) {}
    ~Array() { deallocate_(); }

    void dim(int sz1, int sz2 = 1, int sz3 = 1) {
        deallocate_();
        elems = new T [sz1 * sz2 * sz3] ();
        size1 = sz1;
        size2 = sz2;
        size3 = sz3;
    }

    T & operator() (int i1) {
        return elems[i1];
    }

    T & operator() (int i1, int i2) {
        return elems[i1 * size2 + i2];
    }

    T & operator() (int i1, int i2, int i3) {
        return elems[(i1 * size2 + i2) * size3 + i3];
    }

  private:

    void deallocate_() {
      delete[] elems;
      elems = 0;
    }
};
struct ListElement {
    struct ListElement *next;
    struct ListElement *prev;
    /* element data starts here */
};
class LinkedList {
  public:
    struct ListElement *root;
    struct ListElement *current;
    struct ListElement *last;
    int length;
    int index;
    LinkedList() : root(0), current(0), last(0), length(0), index(-1) {};
    virtual struct ListElement *alloc_elem() = 0;
    virtual void del_elem(struct ListElement *elem) = 0;
};
template <typename T>
class TypedList : public LinkedList {
  public:
    static T empty_T;
    struct ListElement *alloc_elem() {
        char *space = new char [sizeof(struct ListElement) + sizeof(T)];
        T *elem = new (space + sizeof(struct ListElement)) T(empty_T);
        return reinterpret_cast<struct ListElement *>(space);
    }
    void del_elem(struct ListElement *elem) {
        T *realelem = reinterpret_cast<T *> (elem + 1);
        realelem->~T();
        delete[] reinterpret_cast<char *>(elem);
    }
};
template <typename T>
T TypedList<T>::empty_T;
#define LIST_CURRENT(list,type) (* (type *) ((list)->current + 1))
enum label { NOLABEL, Lv_again, Lv_geladen, Lv_nach_zauber};
struct st_az {
	int16_t f_nr;
	int16_t f_staerke;
	int16_t f_dauer;
	int16_t f_source;
	st_az() : f_nr(), f_staerke(), f_dauer(), f_source() {};
};
struct st_carta {
	int16_t f_feld[151];
	st_carta() : f_feld() {};
};
struct st_character_data {
	int8_t f_status;
	std::string f_verifikation;
	int16_t f_level;
	int16_t f_maxlevel;
	int16_t f_maennchen;
	int16_t f_lifepoints;
	int16_t f_maxlifepoints;
	int16_t f_lifegain;
	int16_t f_mana;
	int16_t f_maxmana;
	int16_t f_managain;
	int16_t f_attack;
	int16_t f_dexterity;
	int16_t f_strength;
	int16_t f_maxspeed;
	int16_t f_speed;
	int16_t f_perception;
	int16_t f_luck_score;
	int16_t f_power_score;
	int16_t f_circle;
	int16_t f_magieresistenz;
	int16_t f_spellweaving;
	int16_t f_style;
	int16_t f_light;
	int16_t f_hunger;
	int16_t f_durst;
	int16_t f_weisheit;
	int16_t f_schleichen;
	int16_t f_mks;
	int16_t f_fluch;
	int16_t f_fluchdauer;
	int16_t f_krankheit;
	int16_t f_krankheitdauer;
	int16_t f_gift;
	int16_t f_giftdauer;
	int16_t f_verhungern;
	int16_t f_verdursten;
	int16_t f_betrunken;
	int16_t f_lifepointgegenstand;
	int16_t f_managegenstand;
	int16_t f_staerkegegenstand;
	int16_t f_zugweitegegenstand;
	int16_t f_dexteritygegenstand;
	int16_t f_gluecksgegenstand;
	int16_t f_bogentreffergegenstand;
	int16_t f_bogenschadengegenstand;
	int16_t f_powergegenstand;
	int16_t f_perceptiongegenstand;
	int16_t f_attackgegenstand;
	int16_t f_stealthgegenstand;
	int16_t f_damagegegenstand;
	int16_t f_lichtgegenstand;
	int16_t f_diebstahlgegenstand;
	int16_t f_goblinlehre;
	int16_t f_spinnenlehre;
	int16_t f_untotenlehre;
	int16_t f_pflanzenlehre;
	int16_t f_tierkunde;
	int16_t f_fallenlehre;
	int16_t f_giftlehre;
	int16_t f_pos_zaubermenue;
	int16_t f_dumm;
	int16_t f_face;
	int16_t f_hinterhalt;
	int16_t f_portal;
	int16_t f_teleport;
	int16_t f_nexus;
	int16_t f_stehlen;
	int16_t f_schriftrolle;
	int16_t f_zauberbuch;
	int16_t f_kessel;
	int16_t f_udjat_ben;
	int16_t f_armageddon;
	int16_t f_pestilence;
	int16_t f_drachenform;
	int16_t f_macht;
	int16_t f_magic_apple;
	int16_t f_refresh;
	int16_t f_heal;
	int16_t f_akt_zauber;
	std::string f_schule;
	int16_t f_lehrer;
	int16_t f_stabteile;
	int16_t f_moves;
	int16_t f_anker_x;
	int16_t f_anker_y;
	int16_t f_anker_level;
	int16_t f_old_pos_x;
	int16_t f_old_pos_y;
	int16_t f_old_lp;
	int16_t f_old_max_lp;
	int16_t f_old_mp;
	int16_t f_old_max_mp;
	std::string f_sterbegrund[4];
	int16_t f_character_x;
	int16_t f_character_y;
	int8_t f_creature_typ;
	int16_t f_creature_lifepoints;
	int16_t f_creature_attack;
	int16_t f_creature_schaden_min;
	int16_t f_creature_schaden_max;
	int16_t f_creature_speed;
	int16_t f_creature_maxspeed;
	int16_t f_creature_x;
	int16_t f_creature_y;
	int16_t f_creature_heading;
	st_character_data() : f_status(), f_verifikation(), f_level(), f_maxlevel(), f_maennchen(), f_lifepoints(), f_maxlifepoints(), f_lifegain(), f_mana(), f_maxmana(), f_managain(), f_attack(), f_dexterity(), f_strength(), f_maxspeed(), f_speed(), f_perception(), f_luck_score(), f_power_score(), f_circle(), f_magieresistenz(), f_spellweaving(), f_style(), f_light(), f_hunger(), f_durst(), f_weisheit(), f_schleichen(), f_mks(), f_fluch(), f_fluchdauer(), f_krankheit(), f_krankheitdauer(), f_gift(), f_giftdauer(), f_verhungern(), f_verdursten(), f_betrunken(), f_lifepointgegenstand(), f_managegenstand(), f_staerkegegenstand(), f_zugweitegegenstand(), f_dexteritygegenstand(), f_gluecksgegenstand(), f_bogentreffergegenstand(), f_bogenschadengegenstand(), f_powergegenstand(), f_perceptiongegenstand(), f_attackgegenstand(), f_stealthgegenstand(), f_damagegegenstand(), f_lichtgegenstand(), f_diebstahlgegenstand(), f_goblinlehre(), f_spinnenlehre(), f_untotenlehre(), f_pflanzenlehre(), f_tierkunde(), f_fallenlehre(), f_giftlehre(), f_pos_zaubermenue(), f_dumm(), f_face(), f_hinterhalt(), f_portal(), f_teleport(), f_nexus(), f_stehlen(), f_schriftrolle(), f_zauberbuch(), f_kessel(), f_udjat_ben(), f_armageddon(), f_pestilence(), f_drachenform(), f_macht(), f_magic_apple(), f_refresh(), f_heal(), f_akt_zauber(), f_schule(), f_lehrer(), f_stabteile(), f_moves(), f_anker_x(), f_anker_y(), f_anker_level(), f_old_pos_x(), f_old_pos_y(), f_old_lp(), f_old_max_lp(), f_old_mp(), f_old_max_mp(), f_sterbegrund(), f_character_x(), f_character_y(), f_creature_typ(), f_creature_lifepoints(), f_creature_attack(), f_creature_schaden_min(), f_creature_schaden_max(), f_creature_speed(), f_creature_maxspeed(), f_creature_x(), f_creature_y(), f_creature_heading() {};
};
struct st_credit {
	std::string f_text;
	int32_t f_max;
	int32_t f_div;
	float f_sinstart;
	int32_t f_fade;
	int32_t f_y;
	st_credit() : f_text(), f_max(), f_div(), f_sinstart(), f_fade(), f_y() {};
};
struct st_egal {
	std::string f_version;
	std::string f_name;
	int16_t f_level;
	int16_t f_gold;
	int16_t f_mks;
	int16_t f_punkte;
	int16_t f_maennchen;
	int16_t f_maxlifepoints;
	int16_t f_maxmana;
	int16_t f_attack;
	int16_t f_dexterity;
	int16_t f_strength;
	int16_t f_maxspeed;
	int16_t f_perception;
	int16_t f_luck_score;
	int16_t f_power_score;
	int16_t f_circle;
	std::string f_anfangszeit;
	std::string f_endezeit;
	int16_t f_stabteile;
	int16_t f_moves;
	std::string f_sterbegrund[4];
	int16_t f_skills[31];
	st_egal() : f_version(), f_name(), f_level(), f_gold(), f_mks(), f_punkte(), f_maennchen(), f_maxlifepoints(), f_maxmana(), f_attack(), f_dexterity(), f_strength(), f_maxspeed(), f_perception(), f_luck_score(), f_power_score(), f_circle(), f_anfangszeit(), f_endezeit(), f_stabteile(), f_moves(), f_sterbegrund(), f_skills() {};
};
struct st_gs {
	std::string f_name[4];
	std::string f_info[4];
	int16_t f_art;
	int16_t f_klasse;
	int16_t f_magisch;
	int16_t f_qualitaet;
	int16_t f_einkauf;
	int16_t f_verkauf;
	int16_t f_gewicht;
	int16_t f_attri1;
	int16_t f_attri2;
	int16_t f_attri3;
	int16_t f_attri4;
	st_gs() : f_name(), f_info(), f_art(), f_klasse(), f_magisch(), f_qualitaet(), f_einkauf(), f_verkauf(), f_gewicht(), f_attri1(), f_attri2(), f_attri3(), f_attri4() {};
};
struct st_inv {
	int16_t f_name;
	int16_t f_art;
	int16_t f_benutzt;
	int16_t f_anzahl;
	int16_t f_status;
	int16_t f_attri1;
	int16_t f_attri2;
	int16_t f_attri3;
	int16_t f_attri4;
	int16_t f_attri5;
	st_inv() : f_name(), f_art(), f_benutzt(), f_anzahl(), f_status(), f_attri1(), f_attri2(), f_attri3(), f_attri4(), f_attri5() {};
};
struct st_item2 {
	int16_t f_name[151];
	int16_t f_anzahl[151];
	int16_t f_status[151];
	st_item2() : f_name(), f_anzahl(), f_status() {};
};
struct st_kriatura {
	int16_t f_creature_lifepoints;
	int16_t f_creature_attack;
	int16_t f_creature_schaden_min;
	int16_t f_creature_schaden_max;
	int16_t f_creature_maxspeed;
	st_kriatura() : f_creature_lifepoints(), f_creature_attack(), f_creature_schaden_min(), f_creature_schaden_max(), f_creature_maxspeed() {};
};
struct st_laby {
	int16_t f_feld[151];
	int16_t f_lebenspunkte[151];
	int16_t f_objekt[151];
	int16_t f_status[151];
	st_laby() : f_feld(), f_lebenspunkte(), f_objekt(), f_status() {};
};
struct st_lock {
	int16_t f_name;
	int16_t f_locked;
	st_lock() : f_name(), f_locked() {};
};
struct st_mes {
	int16_t f_farbe;
	std::string f_nachricht;
	st_mes() : f_farbe(), f_nachricht() {};
};
struct st_misch {
	int16_t f_trank1;
	int16_t f_trank2;
	int16_t f_trank3;
	st_misch() : f_trank1(), f_trank2(), f_trank3() {};
};
struct st_monster2 {
	int16_t f_name[151];
	int16_t f_graphic[151];
	int16_t f_lifepoints[151];
	int16_t f_status[151];
	int16_t f_duration[151];
	st_monster2() : f_name(), f_graphic(), f_lifepoints(), f_status(), f_duration() {};
};
struct st_monsterstruct {
	std::string f_name[4];
	int16_t f_nr;
	int8_t f_art;
	int16_t f_lebenspunkte;
	int8_t f_angriff;
	int8_t f_abwehr;
	int8_t f_staerke;
	int8_t f_ruestung;
	int8_t f_zauberkraft;
	int8_t f_zauber;
	int8_t f_reichweite;
	int16_t f_minlevel;
	int16_t f_sound;
	int8_t f_eigenschaft1;
	int8_t f_eigenschaft2;
	int8_t f_eigenschaft3;
	int8_t f_eigenschaft4;
	int8_t f_eigenschaft5;
	int8_t f_eigenschaft6;
	int8_t f_eigenschaft7;
	int8_t f_eigenschaft8;
	int8_t f_eigenschaft9;
	int8_t f_eigenschaft10;
	st_monsterstruct() : f_name(), f_nr(), f_art(), f_lebenspunkte(), f_angriff(), f_abwehr(), f_staerke(), f_ruestung(), f_zauberkraft(), f_zauber(), f_reichweite(), f_minlevel(), f_sound(), f_eigenschaft1(), f_eigenschaft2(), f_eigenschaft3(), f_eigenschaft4(), f_eigenschaft5(), f_eigenschaft6(), f_eigenschaft7(), f_eigenschaft8(), f_eigenschaft9(), f_eigenschaft10() {};
};
struct st_pi {
	int16_t f_nr;
	std::string f_wirkung[4];
	st_pi() : f_nr(), f_wirkung() {};
};
struct st_skill {
	std::string f_name[4];
	int16_t f_nummer;
	int16_t f_kosten;
	std::string f_beschreibung_1[4];
	std::string f_beschreibung_2[4];
	int16_t f_gruppe;
	int16_t f_gewaehlt;
	int16_t f_gelocked;
	st_skill() : f_name(), f_nummer(), f_kosten(), f_beschreibung_1(), f_beschreibung_2(), f_gruppe(), f_gewaehlt(), f_gelocked() {};
};
struct st_spell {
	std::string f_name[4];
	int16_t f_level;
	int16_t f_kosten;
	int16_t f_dauer;
	int16_t f_chance;
	int16_t f_anhaltend;
	int16_t f_erlernt;
	std::string f_art;
	std::string f_besch_1[4];
	std::string f_besch_2[4];
	st_spell() : f_name(), f_level(), f_kosten(), f_dauer(), f_chance(), f_anhaltend(), f_erlernt(), f_art(), f_besch_1(), f_besch_2() {};
};
struct st_sprache {
	int32_t f_id;
	int32_t f_buttonpos;
	st_sprache() : f_id(), f_buttonpos() {};
};
struct st_zl {
	std::string f_name[4];
	st_zl() : f_name() {};
};
static Array<int32_t> a_addelay;
static Array<int32_t> a_addelaymax;
static Array<struct st_az> a_aktive;
static Array<int16_t> a_ausgangx;
static Array<int16_t> a_ausgangy;
static Array<struct st_carta> a_automap;
static Array<struct st_kriatura> a_creature;
static Array<struct st_credit> a_credits;
static Array<int16_t> a_eingangx;
static Array<int16_t> a_eingangy;
static Array<int16_t> a_fluss;
static Array<int32_t> a_fsprites;
static Array<struct st_gs> a_gegenstand;
static Array<int16_t> a_goblinkoenig;
static Array<int16_t> a_groesse;
static Array<int16_t> a_haendler_objekte;
static Array<int16_t> a_haendler_schriftrolle;
static Array<int16_t> a_haendler_staerke;
static Array<int16_t> a_high_skill;
static Array<struct st_egal> a_hscores;
static Array<int16_t> a_inhalt;
static Array<struct st_inv> a_inventory;
static Array<struct st_item2> a_laby_item;
static Array<struct st_item2> a_laby_item2;
static Array<struct st_monster2> a_laby_monster;
static Array<struct st_monster2> a_laby_monster2;
static Array<struct st_laby> a_labyrinth;
static Array<struct st_laby> a_labyrinth2;
static Array<int16_t> a_levelmod;
static Array<int16_t> a_matrix;
static Array<int16_t> a_matrix2;
static Array<struct st_misch> a_mischen;
static Array<int16_t> a_mit_was;
static Array<struct st_monsterstruct> a_monster;
static Array<std::string> a_nachricht_text;
static Array<struct st_inv> a_new_item;
static Array<struct st_mes> a_old_messages;
static Array<std::string> a_optionenliste;
static Array<struct st_pi> a_pilz;
static Array<int16_t> a_raeume;
static Array<int16_t> a_raumx;
static Array<int16_t> a_raumy;
static Array<int32_t> a_rsprites;
static Array<std::string> a_savedatum;
static Array<std::string> a_savenames;
static Array<std::string> a_schnellzauber;
static Array<std::string> a_schnellzauber2;
static Array<struct st_skill> a_skills;
static Array<int32_t> a_skilltyp_offset;
static Array<int32_t> a_skilltyp_range;
static Array<int16_t> a_sonderlevel;
static Array<struct st_character_data> a_spieler;
static Array<int16_t> a_spinnenkoenigin;
static Array<struct st_sprache> a_sprache;
static Array<int16_t> a_summoning;
static Array<struct st_lock> a_unmoeglich;
static Array<int16_t> a_untotenherr;
static Array<int16_t> a_visionen;
static Array<int32_t> a_xsprites;
static Array<int32_t> a_ysprites;
static Array<struct st_spell> a_zauber;
static Array<struct st_zl> a_zauberliste;
static Array<std::string> a_zwischen;


static int16_t g_abbrechen;
static int32_t g_adcount;
static int32_t g_admax;
static int16_t v_akt_level;
static int8_t g_akt_option;
static int8_t g_akt_spieler;
static int32_t g_akt_zauber;
static int32_t g_akt_zauber_offset;
static int32_t g_akt_zauber_offset2;
static int32_t g_aktion;
static int32_t g_aktive;
static int16_t g_aktuell;
static std::string g_altezeit;
static std::string g_anfangszeit;
static int16_t v_angreifen;
static int16_t g_anz_levels;
static int32_t g_anz_slraeume;
static int8_t g_anz_spieler;
static int16_t g_anz_zauber;
static int32_t g_anzz;
static int16_t g_autopickup;
static int16_t g_behinderung;
static int8_t g_benutzen;
static int16_t g_bewegen;
static int8_t g_bewegt;
static int16_t g_blocked;
static int32_t g_character_x;
static int32_t g_character_y;
static int8_t g_charsave_now;
static int16_t g_cinfo_menu;
static int32_t g_combi;
static int32_t g_currentstyp;
static int16_t g_do_it;
static int16_t g_do_it2;
static int16_t g_do_it3;
static int16_t g_do_it4;
static int32_t v_elapsedtime;
static int32_t v_elapsedtime2;
static std::string g_environment;
static int32_t v_eventid;
static int16_t g_feld;
static int16_t g_flaschen;
static int8_t g_frame;
static int8_t v_framestep;
static int16_t g_ganglaenge;
static int32_t g_gb_callfromtitlescreen;
static int32_t g_gegenstand;
static int16_t v_gesetzt;
static int32_t g_goblinkoenig;
static int32_t g_groesse;
static int32_t g_haendler_objekte;
static int32_t g_hscores;
static int32_t v_i;
static int32_t g_inhalt;
static int16_t g_inhalt_normal;
static int16_t g_itemmenue_aktiv;
static int32_t v_j;
static int16_t v_jax;
static int16_t v_jay;
static int32_t v_jb1;
static int16_t g_joystick_used;
static int32_t v_k;
static int32_t g_karten_typ;
static int32_t g_keydelay;
static int32_t g_keydelay2;
static int16_t g_klicking;
static int16_t g_knopf5;
static int32_t g_laby;
static int32_t g_labyrinth;
static int8_t g_letzter_eintrag;
static int32_t g_level;
static int32_t g_levelmod;
static int16_t g_maennchen_menu;
static int8_t g_mauszauber;
static int8_t g_mauszauber2;
static std::string v_messages;
static int16_t g_mit_was_normal;
static int16_t g_mmouse_links;
static int16_t g_mmouse_rechts;
static int16_t g_mmouse_x;
static int16_t g_mmouse_y;
static int32_t g_modules;
static int32_t g_monster;
static int16_t g_monsterauge;
static int32_t g_mouse_x_old;
static int32_t g_mouse_y_old;
static int16_t g_music;
static int32_t v_my_delay;
static int16_t g_mydelay;
static int16_t g_mydelay2;
static int16_t g_mydelay3;
static int16_t g_mydelay4;
static std::string g_myname;
static int8_t v_nach_kampf;
static int32_t g_nachricht_text;
static int16_t g_no_mouse;
static int32_t g_no_room_intro;
static int16_t g_nr;
static int16_t g_nr_of_saves;
static int32_t v_ok_button;
static int32_t v_okay;
static int32_t g_optionenliste;
static int16_t g_over_item;
static int32_t g_pilz;
static int8_t g_pos;
static int16_t g_punkte;
static int16_t g_released;
static int32_t v_result;
static int32_t v_room_cursprite_nr;
static std::string v_room_curtext;
static int32_t v_room_curtext_nr;
static int16_t g_roomtest;
static int32_t g_schnellzauber;
static int32_t g_schongemalt;
static int32_t g_schriftrolle;
static int16_t g_schutz_max;
static int16_t g_schutz_min;
static int32_t v_screenopen;
static int32_t g_selectdelay;
static int32_t g_silent;
static int32_t g_skillrow_offset;
static int32_t g_skills;
static int16_t g_skills_menu;
static int16_t g_sound;
static int32_t g_spalte;
static int16_t g_spell_x;
static int16_t g_spell_y;
static int32_t g_spieler;
static int32_t g_spielerwechsel;
static int32_t g_spinnenkoenigin;
static int8_t g_sprache;
static int16_t g_sprite_x;
static int16_t g_sprite_y;
static int32_t v_starttime;
static int32_t v_starttime2;
static int32_t g_stehlen;
static int8_t g_test;
static int16_t v_testfeld;
static int32_t g_untotenherr;
static int8_t g_von_ferne;
static int16_t g_warten;
static int32_t v_weitere;
static int16_t g_win_mode;
static int32_t g_windowsfenster;
static int16_t v_x_r;
static int8_t g_xmod;
static int16_t v_y_r;
static int8_t g_ymod;
static int32_t g_yplus;
static int32_t g_yplus2;
static int32_t g_zauber;
static int32_t g_zauberliste;
static int32_t g_zeile;
static std::string g_zeit;
static int8_t g_zw_bild;

static int32_t p_addelement(LinkedList *);
static void p_box(int32_t, int32_t, int32_t, int32_t, int32_t);
static int16_t p_catchsound(int16_t, int32_t);
static int16_t p_catchsprite(int16_t, int32_t);
static std::string p_chr(int8_t);
static void p_circle(int32_t, int32_t, int32_t, int32_t);
static void p_clearlist(LinkedList *);
static void p_clearscreen(int32_t);
static void p_clipsprite(int16_t, int32_t, int32_t, int32_t, int32_t);
static void p_closefile(int16_t);
static void p_closenetworkconnection(int32_t);
static void p_closescreen();
static float p_cos(float);
static int32_t p_countlist(LinkedList *);
static void p_createdirectory(std::string);
static int16_t p_createfile(int16_t, std::string);
static int32_t p_date();
static void p_delay(int32_t);
static void p_displaysprite(int16_t, int32_t, int32_t);
static void p_displaytransparentsprite(int16_t, int32_t, int32_t);
static void p_drawingmode(int32_t);
static int32_t p_drawtext(int32_t, int32_t, std::string, int32_t, int32_t);
static int32_t p_elapsedmilliseconds();
static int16_t p_eof(int32_t);
static void p_examinejoystick();
static void p_examinekeyboard();
static int32_t p_examinemouse();
static void p_flipbuffers(int32_t);
static std::string p_formatdate(std::string, int32_t);
static void p_frontcolor(int32_t);
static std::string p_getenvironmentvariable(std::string);
static int32_t p_initjoystick();
static int32_t p_initkeyboard();
static int32_t p_initmouse();
static int32_t p_initnetwork();
static int32_t p_initsound();
static int32_t p_initsprite();
static int32_t p_int(float);
static int32_t p_joystickaxisx();
static int32_t p_joystickaxisy();
static int32_t p_joystickbutton(int32_t);
static int32_t p_keyboardpushed(int32_t);
static int32_t p_keyboardreleased(int32_t);
static std::string p_lcase(std::string);
static int32_t p_len(std::string);
static void p_line(int32_t, int32_t, int32_t, int32_t, int32_t);
static void p_linexy(int32_t, int32_t, int32_t, int32_t);
static int16_t p_loadmodule(int16_t, std::string);
static std::string p_mid(std::string, int32_t, int32_t);
static int32_t p_mousebutton(int32_t);
static int32_t p_mousex();
static int32_t p_mousey();
static int32_t p_nextelement(LinkedList *);
static int32_t p_nextpackfile();
static int32_t p_opennetworkconnection(std::string, int16_t);
static int32_t p_openpack(std::string);
static int32_t p_openscreen(int32_t, int32_t, int32_t, std::string);
static int32_t p_openwindowedscreen(int32_t, int32_t, int32_t, int32_t, int32_t, int32_t, int32_t, int32_t);
static int32_t p_parsedate(std::string, std::string);
static uint8_t p_peekc(char *);
static void p_playmodule(int16_t);
static void p_playsound(int16_t);
static int32_t p_random(int32_t);
static int16_t p_readfile(int16_t, std::string);
static std::string p_readstring(int16_t);
static int16_t p_readword(int16_t);
static int32_t p_releasemouse(int32_t);
static std::string p_replacestring(std::string, std::string, std::string);
static int32_t p_rgb(int8_t, int8_t, int8_t);
static std::string p_right(std::string, int32_t);
static std::string p_rset(std::string, int32_t);
static int32_t p_screenoutput();
static void p_sdl_wm_setcaption_(std::string, std::string);
static void p_selectelement(LinkedList *, int32_t);
static void p_sendnetworkstring(int32_t, std::string);
static void p_setframerate(int32_t);
static float p_sin(float);
static void p_startdrawing(int32_t);
static void p_stopdrawing();
static void p_stopmodule(int16_t);
static std::string p_str(int32_t);
static int32_t p_textheight(std::string);
static int32_t p_textwidth(std::string);
static std::string p_ucase(std::string);
static int32_t p_usejpegimagedecoder();
static int32_t p_usepngimagedecoder();
static int32_t p_val(std::string);
static void p_writestringn(int16_t, std::string);
static void p_writeword(int16_t, int16_t);
static void insertonly(LinkedList *list, struct ListElement *elem) {
    elem->next = 0;
    elem->prev = 0;
    list->root = elem;
    list->last = elem;
    list->current = elem;
    list->length = 1;
    list->index = 0;
}
static void insertfirst(LinkedList *list, struct ListElement *elem) {
    elem->next = list->root;
    elem->prev = 0;
    list->root->prev = elem;
    list->root = elem;
    list->current = elem;
    list->length += 1;
    list->index = 0;
}
static void insertlast(LinkedList *list, struct ListElement *elem) {
    elem->next = 0;
    elem->prev = list->last;
    list->last->next = elem;
    list->last = elem;
    list->current = elem;
    list->length += 1;
    list->index = list->length - 1;
}
#include <SDL.h>
static SDL_Surface *screen;
#include <unistd.h>
static unsigned char *packfile;
static int32_t packfilesize;
static int packfd = -1;
static void closepack() {
    if (packfd >= 0) {
        close(packfd);
        packfd = -1;
        delete[] packfile;
        packfile = 0;
        packfilesize = 0;
    }
}
#include <SDL_mixer.h>
static Mix_Chunk *sounds[1024];
static int32_t unused_sound() {
    int i;
    for (i = 1; i < 1024; i++) {
      if (!sounds[i])
        return i;
    }
    return 0;
}
static SDL_Surface *sprites[1024];
static SDL_Rect spriteclips[1024];
static int32_t unused_sprite() {
    int i;
    for (i = 1; i < 1024; i++) {
      if (!sprites[i])
        return i;
    }
    return 0;
}
#include <SDL_image.h>
#include <SDL_gfxPrimitives.h>
static FILE *fh[1024];
static int32_t unused_fh() {
    /* Find a filehandle number to use for a new file.
     * It must not be handle 0, because 0 is returned as a failure code.
     */
    int i;
    for (i = 1; i < 1024; i++) {
      if (!fh[i])
        return i;
    }
    return 0;
}
#include <math.h>
#include <sys/stat.h>
#include <sys/types.h>
static int32_t fileopen(int32_t h, const char *fname, const char *mode) {
    int handle;
    if (h < 0) {
        handle = unused_fh();
        if (handle == 0)
          return 0;
    } else {
        handle = h;
    }
    if (fh[handle]) {
        fclose(fh[handle]);
        fh[handle] = 0;
    }
    fh[handle] = fopen(fname, mode);
    if (!fh[handle])
      return 0;
    return (h < 0) ? handle : 1;
}
/* Vera.ttf Release 1.10, included with permission:

Copyright (c) 2003 by Bitstream, Inc.
All Rights Reserved.
Bitstream Vera is a trademark of Bitstream, Inc.

Permission is hereby granted, free of charge, to any person obtaining
a copy of the fonts accompanying this license ("Fonts") and associated
documentation files (the "Font Software"), to reproduce and distribute
the Font Software, including without limitation the rights to use, copy,
merge, publish, distribute, and/or sell copies of the Font Software,
and to permit persons to whom the Font Software is furnished to do so,
subject to the following conditions:

The above copyright and trademark notices and this permission notice shall
be included in all copies of one or more of the Font Software typefaces.

The Font Software may be modified, altered, or added to, and in particular
the designs of glyphs or characters in the Fonts may be modified and
additional glyphs or characters may be added to the Fonts, only if the
fonts are renamed to names not containing either the words "Bitstream"
or the word "Vera".

This License becomes null and void to the extent applicable to Fonts
or Font Software that has been modified and is distributed under the
"Bitstream Vera" names.

The Font Software may be sold as part of a larger software package but no
copy of one or more of the Font Software typefaces may be sold by itself.

THE FONT SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
OF COPYRIGHT, PATENT, TRADEMARK, OR OTHER RIGHT. IN NO EVENT SHALL
BITSTREAM OR THE GNOME FOUNDATION BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, INCLUDING ANY GENERAL, SPECIAL, INDIRECT, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF THE USE OR INABILITY TO USE THE FONT
SOFTWARE OR FROM OTHER DEALINGS IN THE FONT SOFTWARE.

Except as contained in this notice, the names of Gnome, the Gnome
Foundation, and Bitstream Inc., shall not be used in advertising or
otherwise to promote the sale, use or other dealings in this Font
Software without prior written authorization from the Gnome Foundation
or Bitstream Inc., respectively. For further information, contact:
fonts at gnome dot org.http://www.bitstream.com

*/

static const char fontbits[] = {
0,1,0,0,0,17,1,0,0,4,0,16,79,83,47,50,
180,95,244,99,0,0,235,112,0,0,0,86,80,67,76,84,
209,138,94,151,0,0,235,200,0,0,0,54,99,109,97,112,
164,195,232,160,0,0,177,108,0,0,3,88,99,118,116,32,
255,211,29,57,0,0,30,252,0,0,1,252,102,112,103,109,
231,180,241,196,0,0,38,96,0,0,0,139,103,97,115,112,
0,7,0,7,0,1,1,72,0,0,0,12,103,108,121,102,
12,116,65,207,0,0,38,236,0,0,138,126,104,100,109,120,
52,240,33,14,0,0,236,0,0,0,21,72,104,101,97,100,
221,132,162,208,0,1,1,84,0,0,0,54,104,104,101,97,
16,69,8,111,0,0,235,76,0,0,0,36,104,109,116,120,
9,198,142,178,0,0,180,196,0,0,4,48,107,101,114,110,
220,82,213,153,0,0,189,160,0,0,45,138,108,111,99,97,
243,203,210,61,0,0,187,132,0,0,2,26,109,97,120,112,
5,71,6,58,0,0,235,44,0,0,0,32,110,97,109,101,
217,188,200,181,0,0,1,28,0,0,29,223,112,111,115,116,
180,90,47,187,0,0,184,244,0,0,2,142,112,114,101,112,
59,7,241,0,0,0,32,248,0,0,5,104,0,0,0,22,
1,14,0,1,0,0,0,0,0,0,0,58,0,0,0,1,
0,0,0,0,0,1,0,19,0,58,0,1,0,0,0,0,
0,2,0,5,0,95,0,1,0,0,0,0,0,3,0,19,
0,58,0,1,0,0,0,0,0,4,0,19,0,58,0,1,
0,0,0,0,0,5,0,12,0,100,0,1,0,0,0,0,
0,6,0,23,0,77,0,1,0,0,0,0,0,7,0,48,
0,173,0,1,0,0,0,0,0,8,0,14,8,108,0,1,
0,0,0,0,0,11,0,24,9,131,0,1,0,0,0,0,
0,13,9,19,0,112,0,3,0,1,4,9,0,0,0,116,
9,155,0,3,0,1,4,9,0,1,0,38,10,15,0,3,
0,1,4,9,0,2,0,10,10,89,0,3,0,1,4,9,
0,3,0,38,10,15,0,3,0,1,4,9,0,4,0,38,
10,15,0,3,0,1,4,9,0,5,0,24,10,99,0,3,
0,1,4,9,0,6,0,46,10,53,0,3,0,1,4,9,
0,7,0,96,10,245,0,3,0,1,4,9,0,8,0,28,
26,115,0,3,0,1,4,9,0,11,0,48,28,161,0,3,
0,1,4,9,0,13,18,38,10,123,67,111,112,121,114,105,
103,104,116,32,40,99,41,32,50,48,48,51,32,98,121,32,
66,105,116,115,116,114,101,97,109,44,32,73,110,99,46,32,
65,108,108,32,82,105,103,104,116,115,32,82,101,115,101,114,
118,101,100,46,66,105,116,115,116,114,101,97,109,32,86,101,
114,97,32,83,97,110,115,66,105,116,115,116,114,101,97,109,
86,101,114,97,83,97,110,115,45,82,111,109,97,110,82,101,
108,101,97,115,101,32,49,46,49,48,67,111,112,121,114,105,
103,104,116,32,40,99,41,32,50,48,48,51,32,98,121,32,
66,105,116,115,116,114,101,97,109,44,32,73,110,99,46,13,
10,65,108,108,32,82,105,103,104,116,115,32,82,101,115,101,
114,118,101,100,46,13,10,66,105,116,115,116,114,101,97,109,
32,86,101,114,97,32,105,115,32,97,32,116,114,97,100,101,
109,97,114,107,32,111,102,32,66,105,116,115,116,114,101,97,
109,44,32,73,110,99,46,13,10,13,10,80,101,114,109,105,
115,115,105,111,110,32,105,115,32,104,101,114,101,98,121,32,
103,114,97,110,116,101,100,44,32,102,114,101,101,32,111,102,
32,99,104,97,114,103,101,44,32,116,111,32,97,110,121,32,
112,101,114,115,111,110,32,111,98,116,97,105,110,105,110,103,
32,97,32,99,111,112,121,32,111,102,32,116,104,101,32,102,
111,110,116,115,32,97,99,99,111,109,112,97,110,121,105,110,
103,32,116,104,105,115,32,108,105,99,101,110,115,101,32,40,
34,70,111,110,116,115,34,41,32,97,110,100,32,97,115,115,
111,99,105,97,116,101,100,32,100,111,99,117,109,101,110,116,
97,116,105,111,110,32,102,105,108,101,115,32,40,116,104,101,
32,34,70,111,110,116,32,83,111,102,116,119,97,114,101,34,
41,44,32,116,111,32,114,101,112,114,111,100,117,99,101,32,
97,110,100,32,100,105,115,116,114,105,98,117,116,101,32,116,
104,101,32,70,111,110,116,32,83,111,102,116,119,97,114,101,
44,32,105,110,99,108,117,100,105,110,103,32,119,105,116,104,
111,117,116,32,108,105,109,105,116,97,116,105,111,110,32,116,
104,101,32,114,105,103,104,116,115,32,116,111,32,117,115,101,
44,32,99,111,112,121,44,32,109,101,114,103,101,44,32,112,
117,98,108,105,115,104,44,32,100,105,115,116,114,105,98,117,
116,101,44,32,97,110,100,47,111,114,32,115,101,108,108,32,
99,111,112,105,101,115,32,111,102,32,116,104,101,32,70,111,
110,116,32,83,111,102,116,119,97,114,101,44,32,97,110,100,
32,116,111,32,112,101,114,109,105,116,32,112,101,114,115,111,
110,115,32,116,111,32,119,104,111,109,32,116,104,101,32,70,
111,110,116,32,83,111,102,116,119,97,114,101,32,105,115,32,
102,117,114,110,105,115,104,101,100,32,116,111,32,100,111,32,
115,111,44,32,115,117,98,106,101,99,116,32,116,111,32,116,
104,101,32,102,111,108,108,111,119,105,110,103,32,99,111,110,
100,105,116,105,111,110,115,58,13,10,13,10,84,104,101,32,
97,98,111,118,101,32,99,111,112,121,114,105,103,104,116,32,
97,110,100,32,116,114,97,100,101,109,97,114,107,32,110,111,
116,105,99,101,115,32,97,110,100,32,116,104,105,115,32,112,
101,114,109,105,115,115,105,111,110,32,110,111,116,105,99,101,
32,115,104,97,108,108,32,98,101,32,105,110,99,108,117,100,
101,100,32,105,110,32,97,108,108,32,99,111,112,105,101,115,
32,111,102,32,111,110,101,32,111,114,32,109,111,114,101,32,
111,102,32,116,104,101,32,70,111,110,116,32,83,111,102,116,
119,97,114,101,32,116,121,112,101,102,97,99,101,115,46,13,
10,13,10,84,104,101,32,70,111,110,116,32,83,111,102,116,
119,97,114,101,32,109,97,121,32,98,101,32,109,111,100,105,
102,105,101,100,44,32,97,108,116,101,114,101,100,44,32,111,
114,32,97,100,100,101,100,32,116,111,44,32,97,110,100,32,
105,110,32,112,97,114,116,105,99,117,108,97,114,32,116,104,
101,32,100,101,115,105,103,110,115,32,111,102,32,103,108,121,
112,104,115,32,111,114,32,99,104,97,114,97,99,116,101,114,
115,32,105,110,32,116,104,101,32,70,111,110,116,115,32,109,
97,121,32,98,101,32,109,111,100,105,102,105,101,100,32,97,
110,100,32,97,100,100,105,116,105,111,110,97,108,32,103,108,
121,112,104,115,32,111,114,32,99,104,97,114,97,99,116,101,
114,115,32,109,97,121,32,98,101,32,97,100,100,101,100,32,
116,111,32,116,104,101,32,70,111,110,116,115,44,32,111,110,
108,121,32,105,102,32,116,104,101,32,102,111,110,116,115,32,
97,114,101,32,114,101,110,97,109,101,100,32,116,111,32,110,
97,109,101,115,32,110,111,116,32,99,111,110,116,97,105,110,
105,110,103,32,101,105,116,104,101,114,32,116,104,101,32,119,
111,114,100,115,32,34,66,105,116,115,116,114,101,97,109,34,
32,111,114,32,116,104,101,32,119,111,114,100,32,34,86,101,
114,97,34,46,13,10,13,10,84,104,105,115,32,76,105,99,
101,110,115,101,32,98,101,99,111,109,101,115,32,110,117,108,
108,32,97,110,100,32,118,111,105,100,32,116,111,32,116,104,
101,32,101,120,116,101,110,116,32,97,112,112,108,105,99,97,
98,108,101,32,116,111,32,70,111,110,116,115,32,111,114,32,
70,111,110,116,32,83,111,102,116,119,97,114,101,32,116,104,
97,116,32,104,97,115,32,98,101,101,110,32,109,111,100,105,
102,105,101,100,32,97,110,100,32,105,115,32,100,105,115,116,
114,105,98,117,116,101,100,32,117,110,100,101,114,32,116,104,
101,32,34,66,105,116,115,116,114,101,97,109,32,86,101,114,
97,34,32,110,97,109,101,115,46,13,10,13,10,84,104,101,
32,70,111,110,116,32,83,111,102,116,119,97,114,101,32,109,
97,121,32,98,101,32,115,111,108,100,32,97,115,32,112,97,
114,116,32,111,102,32,97,32,108,97,114,103,101,114,32,115,
111,102,116,119,97,114,101,32,112,97,99,107,97,103,101,32,
98,117,116,32,110,111,32,99,111,112,121,32,111,102,32,111,
110,101,32,111,114,32,109,111,114,101,32,111,102,32,116,104,
101,32,70,111,110,116,32,83,111,102,116,119,97,114,101,32,
116,121,112,101,102,97,99,101,115,32,109,97,121,32,98,101,
32,115,111,108,100,32,98,121,32,105,116,115,101,108,102,46,
13,10,13,10,84,72,69,32,70,79,78,84,32,83,79,70,
84,87,65,82,69,32,73,83,32,80,82,79,86,73,68,69,
68,32,34,65,83,32,73,83,34,44,32,87,73,84,72,79,
85,84,32,87,65,82,82,65,78,84,89,32,79,70,32,65,
78,89,32,75,73,78,68,44,32,69,88,80,82,69,83,83,
32,79,82,32,73,77,80,76,73,69,68,44,32,73,78,67,
76,85,68,73,78,71,32,66,85,84,32,78,79,84,32,76,
73,77,73,84,69,68,32,84,79,32,65,78,89,32,87,65,
82,82,65,78,84,73,69,83,32,79,70,32,77,69,82,67,
72,65,78,84,65,66,73,76,73,84,89,44,32,70,73,84,
78,69,83,83,32,70,79,82,32,65,32,80,65,82,84,73,
67,85,76,65,82,32,80,85,82,80,79,83,69,32,65,78,
68,32,78,79,78,73,78,70,82,73,78,71,69,77,69,78,
84,32,79,70,32,67,79,80,89,82,73,71,72,84,44,32,
80,65,84,69,78,84,44,32,84,82,65,68,69,77,65,82,
75,44,32,79,82,32,79,84,72,69,82,32,82,73,71,72,
84,46,32,73,78,32,78,79,32,69,86,69,78,84,32,83,
72,65,76,76,32,66,73,84,83,84,82,69,65,77,32,79,
82,32,84,72,69,32,71,78,79,77,69,32,70,79,85,78,
68,65,84,73,79,78,32,66,69,32,76,73,65,66,76,69,
32,70,79,82,32,65,78,89,32,67,76,65,73,77,44,32,
68,65,77,65,71,69,83,32,79,82,32,79,84,72,69,82,
32,76,73,65,66,73,76,73,84,89,44,32,73,78,67,76,
85,68,73,78,71,32,65,78,89,32,71,69,78,69,82,65,
76,44,32,83,80,69,67,73,65,76,44,32,73,78,68,73,
82,69,67,84,44,32,73,78,67,73,68,69,78,84,65,76,
44,32,79,82,32,67,79,78,83,69,81,85,69,78,84,73,
65,76,32,68,65,77,65,71,69,83,44,32,87,72,69,84,
72,69,82,32,73,78,32,65,78,32,65,67,84,73,79,78,
32,79,70,32,67,79,78,84,82,65,67,84,44,32,84,79,
82,84,32,79,82,32,79,84,72,69,82,87,73,83,69,44,
32,65,82,73,83,73,78,71,32,70,82,79,77,44,32,79,
85,84,32,79,70,32,84,72,69,32,85,83,69,32,79,82,
32,73,78,65,66,73,76,73,84,89,32,84,79,32,85,83,
69,32,84,72,69,32,70,79,78,84,32,83,79,70,84,87,
65,82,69,32,79,82,32,70,82,79,77,32,79,84,72,69,
82,32,68,69,65,76,73,78,71,83,32,73,78,32,84,72,
69,32,70,79,78,84,32,83,79,70,84,87,65,82,69,46,
13,10,13,10,69,120,99,101,112,116,32,97,115,32,99,111,
110,116,97,105,110,101,100,32,105,110,32,116,104,105,115,32,
110,111,116,105,99,101,44,32,116,104,101,32,110,97,109,101,
115,32,111,102,32,71,110,111,109,101,44,32,116,104,101,32,
71,110,111,109,101,32,70,111,117,110,100,97,116,105,111,110,
44,32,97,110,100,32,66,105,116,115,116,114,101,97,109,32,
73,110,99,46,44,32,115,104,97,108,108,32,110,111,116,32,
98,101,32,117,115,101,100,32,105,110,32,97,100,118,101,114,
116,105,115,105,110,103,32,111,114,32,111,116,104,101,114,119,
105,115,101,32,116,111,32,112,114,111,109,111,116,101,32,116,
104,101,32,115,97,108,101,44,32,117,115,101,32,111,114,32,
111,116,104,101,114,32,100,101,97,108,105,110,103,115,32,105,
110,32,116,104,105,115,32,70,111,110,116,32,83,111,102,116,
119,97,114,101,32,119,105,116,104,111,117,116,32,112,114,105,
111,114,32,119,114,105,116,116,101,110,32,97,117,116,104,111,
114,105,122,97,116,105,111,110,32,102,114,111,109,32,116,104,
101,32,71,110,111,109,101,32,70,111,117,110,100,97,116,105,
111,110,32,111,114,32,66,105,116,115,116,114,101,97,109,32,
73,110,99,46,44,32,114,101,115,112,101,99,116,105,118,101,
108,121,46,32,70,111,114,32,102,117,114,116,104,101,114,32,
105,110,102,111,114,109,97,116,105,111,110,44,32,99,111,110,
116,97,99,116,58,32,102,111,110,116,115,32,97,116,32,103,
110,111,109,101,32,100,111,116,32,111,114,103,46,104,116,116,
112,58,47,47,119,119,119,46,98,105,116,115,116,114,101,97,
109,46,99,111,109,0,67,0,111,0,112,0,121,0,114,0,
105,0,103,0,104,0,116,0,32,0,40,0,99,0,41,0,
32,0,50,0,48,0,48,0,51,0,32,0,98,0,121,0,
32,0,66,0,105,0,116,0,115,0,116,0,114,0,101,0,
97,0,109,0,44,0,32,0,73,0,110,0,99,0,46,0,
32,0,65,0,108,0,108,0,32,0,82,0,105,0,103,0,
104,0,116,0,115,0,32,0,82,0,101,0,115,0,101,0,
114,0,118,0,101,0,100,0,46,0,66,0,105,0,116,0,
115,0,116,0,114,0,101,0,97,0,109,0,32,0,86,0,
101,0,114,0,97,0,32,0,83,0,97,0,110,0,115,0,
66,0,105,0,116,0,115,0,116,0,114,0,101,0,97,0,
109,0,86,0,101,0,114,0,97,0,83,0,97,0,110,0,
115,0,45,0,82,0,111,0,109,0,97,0,110,0,82,0,
101,0,108,0,101,0,97,0,115,0,101,0,32,0,49,0,
46,0,49,0,48,0,67,0,111,0,112,0,121,0,114,0,
105,0,103,0,104,0,116,0,32,0,40,0,99,0,41,0,
32,0,50,0,48,0,48,0,51,0,32,0,98,0,121,0,
32,0,66,0,105,0,116,0,115,0,116,0,114,0,101,0,
97,0,109,0,44,0,32,0,73,0,110,0,99,0,46,0,
13,0,10,0,65,0,108,0,108,0,32,0,82,0,105,0,
103,0,104,0,116,0,115,0,32,0,82,0,101,0,115,0,
101,0,114,0,118,0,101,0,100,0,46,0,13,0,10,0,
66,0,105,0,116,0,115,0,116,0,114,0,101,0,97,0,
109,0,32,0,86,0,101,0,114,0,97,0,32,0,105,0,
115,0,32,0,97,0,32,0,116,0,114,0,97,0,100,0,
101,0,109,0,97,0,114,0,107,0,32,0,111,0,102,0,
32,0,66,0,105,0,116,0,115,0,116,0,114,0,101,0,
97,0,109,0,44,0,32,0,73,0,110,0,99,0,46,0,
13,0,10,0,13,0,10,0,80,0,101,0,114,0,109,0,
105,0,115,0,115,0,105,0,111,0,110,0,32,0,105,0,
115,0,32,0,104,0,101,0,114,0,101,0,98,0,121,0,
32,0,103,0,114,0,97,0,110,0,116,0,101,0,100,0,
44,0,32,0,102,0,114,0,101,0,101,0,32,0,111,0,
102,0,32,0,99,0,104,0,97,0,114,0,103,0,101,0,
44,0,32,0,116,0,111,0,32,0,97,0,110,0,121,0,
32,0,112,0,101,0,114,0,115,0,111,0,110,0,32,0,
111,0,98,0,116,0,97,0,105,0,110,0,105,0,110,0,
103,0,32,0,97,0,32,0,99,0,111,0,112,0,121,0,
32,0,111,0,102,0,32,0,116,0,104,0,101,0,32,0,
102,0,111,0,110,0,116,0,115,0,32,0,97,0,99,0,
99,0,111,0,109,0,112,0,97,0,110,0,121,0,105,0,
110,0,103,0,32,0,116,0,104,0,105,0,115,0,32,0,
108,0,105,0,99,0,101,0,110,0,115,0,101,0,32,0,
40,0,34,0,70,0,111,0,110,0,116,0,115,0,34,0,
41,0,32,0,97,0,110,0,100,0,32,0,97,0,115,0,
115,0,111,0,99,0,105,0,97,0,116,0,101,0,100,0,
32,0,100,0,111,0,99,0,117,0,109,0,101,0,110,0,
116,0,97,0,116,0,105,0,111,0,110,0,32,0,102,0,
105,0,108,0,101,0,115,0,32,0,40,0,116,0,104,0,
101,0,32,0,34,0,70,0,111,0,110,0,116,0,32,0,
83,0,111,0,102,0,116,0,119,0,97,0,114,0,101,0,
34,0,41,0,44,0,32,0,116,0,111,0,32,0,114,0,
101,0,112,0,114,0,111,0,100,0,117,0,99,0,101,0,
32,0,97,0,110,0,100,0,32,0,100,0,105,0,115,0,
116,0,114,0,105,0,98,0,117,0,116,0,101,0,32,0,
116,0,104,0,101,0,32,0,70,0,111,0,110,0,116,0,
32,0,83,0,111,0,102,0,116,0,119,0,97,0,114,0,
101,0,44,0,32,0,105,0,110,0,99,0,108,0,117,0,
100,0,105,0,110,0,103,0,32,0,119,0,105,0,116,0,
104,0,111,0,117,0,116,0,32,0,108,0,105,0,109,0,
105,0,116,0,97,0,116,0,105,0,111,0,110,0,32,0,
116,0,104,0,101,0,32,0,114,0,105,0,103,0,104,0,
116,0,115,0,32,0,116,0,111,0,32,0,117,0,115,0,
101,0,44,0,32,0,99,0,111,0,112,0,121,0,44,0,
32,0,109,0,101,0,114,0,103,0,101,0,44,0,32,0,
112,0,117,0,98,0,108,0,105,0,115,0,104,0,44,0,
32,0,100,0,105,0,115,0,116,0,114,0,105,0,98,0,
117,0,116,0,101,0,44,0,32,0,97,0,110,0,100,0,
47,0,111,0,114,0,32,0,115,0,101,0,108,0,108,0,
32,0,99,0,111,0,112,0,105,0,101,0,115,0,32,0,
111,0,102,0,32,0,116,0,104,0,101,0,32,0,70,0,
111,0,110,0,116,0,32,0,83,0,111,0,102,0,116,0,
119,0,97,0,114,0,101,0,44,0,32,0,97,0,110,0,
100,0,32,0,116,0,111,0,32,0,112,0,101,0,114,0,
109,0,105,0,116,0,32,0,112,0,101,0,114,0,115,0,
111,0,110,0,115,0,32,0,116,0,111,0,32,0,119,0,
104,0,111,0,109,0,32,0,116,0,104,0,101,0,32,0,
70,0,111,0,110,0,116,0,32,0,83,0,111,0,102,0,
116,0,119,0,97,0,114,0,101,0,32,0,105,0,115,0,
32,0,102,0,117,0,114,0,110,0,105,0,115,0,104,0,
101,0,100,0,32,0,116,0,111,0,32,0,100,0,111,0,
32,0,115,0,111,0,44,0,32,0,115,0,117,0,98,0,
106,0,101,0,99,0,116,0,32,0,116,0,111,0,32,0,
116,0,104,0,101,0,32,0,102,0,111,0,108,0,108,0,
111,0,119,0,105,0,110,0,103,0,32,0,99,0,111,0,
110,0,100,0,105,0,116,0,105,0,111,0,110,0,115,0,
58,0,13,0,10,0,13,0,10,0,84,0,104,0,101,0,
32,0,97,0,98,0,111,0,118,0,101,0,32,0,99,0,
111,0,112,0,121,0,114,0,105,0,103,0,104,0,116,0,
32,0,97,0,110,0,100,0,32,0,116,0,114,0,97,0,
100,0,101,0,109,0,97,0,114,0,107,0,32,0,110,0,
111,0,116,0,105,0,99,0,101,0,115,0,32,0,97,0,
110,0,100,0,32,0,116,0,104,0,105,0,115,0,32,0,
112,0,101,0,114,0,109,0,105,0,115,0,115,0,105,0,
111,0,110,0,32,0,110,0,111,0,116,0,105,0,99,0,
101,0,32,0,115,0,104,0,97,0,108,0,108,0,32,0,
98,0,101,0,32,0,105,0,110,0,99,0,108,0,117,0,
100,0,101,0,100,0,32,0,105,0,110,0,32,0,97,0,
108,0,108,0,32,0,99,0,111,0,112,0,105,0,101,0,
115,0,32,0,111,0,102,0,32,0,111,0,110,0,101,0,
32,0,111,0,114,0,32,0,109,0,111,0,114,0,101,0,
32,0,111,0,102,0,32,0,116,0,104,0,101,0,32,0,
70,0,111,0,110,0,116,0,32,0,83,0,111,0,102,0,
116,0,119,0,97,0,114,0,101,0,32,0,116,0,121,0,
112,0,101,0,102,0,97,0,99,0,101,0,115,0,46,0,
13,0,10,0,13,0,10,0,84,0,104,0,101,0,32,0,
70,0,111,0,110,0,116,0,32,0,83,0,111,0,102,0,
116,0,119,0,97,0,114,0,101,0,32,0,109,0,97,0,
121,0,32,0,98,0,101,0,32,0,109,0,111,0,100,0,
105,0,102,0,105,0,101,0,100,0,44,0,32,0,97,0,
108,0,116,0,101,0,114,0,101,0,100,0,44,0,32,0,
111,0,114,0,32,0,97,0,100,0,100,0,101,0,100,0,
32,0,116,0,111,0,44,0,32,0,97,0,110,0,100,0,
32,0,105,0,110,0,32,0,112,0,97,0,114,0,116,0,
105,0,99,0,117,0,108,0,97,0,114,0,32,0,116,0,
104,0,101,0,32,0,100,0,101,0,115,0,105,0,103,0,
110,0,115,0,32,0,111,0,102,0,32,0,103,0,108,0,
121,0,112,0,104,0,115,0,32,0,111,0,114,0,32,0,
99,0,104,0,97,0,114,0,97,0,99,0,116,0,101,0,
114,0,115,0,32,0,105,0,110,0,32,0,116,0,104,0,
101,0,32,0,70,0,111,0,110,0,116,0,115,0,32,0,
109,0,97,0,121,0,32,0,98,0,101,0,32,0,109,0,
111,0,100,0,105,0,102,0,105,0,101,0,100,0,32,0,
97,0,110,0,100,0,32,0,97,0,100,0,100,0,105,0,
116,0,105,0,111,0,110,0,97,0,108,0,32,0,103,0,
108,0,121,0,112,0,104,0,115,0,32,0,111,0,114,0,
32,0,99,0,104,0,97,0,114,0,97,0,99,0,116,0,
101,0,114,0,115,0,32,0,109,0,97,0,121,0,32,0,
98,0,101,0,32,0,97,0,100,0,100,0,101,0,100,0,
32,0,116,0,111,0,32,0,116,0,104,0,101,0,32,0,
70,0,111,0,110,0,116,0,115,0,44,0,32,0,111,0,
110,0,108,0,121,0,32,0,105,0,102,0,32,0,116,0,
104,0,101,0,32,0,102,0,111,0,110,0,116,0,115,0,
32,0,97,0,114,0,101,0,32,0,114,0,101,0,110,0,
97,0,109,0,101,0,100,0,32,0,116,0,111,0,32,0,
110,0,97,0,109,0,101,0,115,0,32,0,110,0,111,0,
116,0,32,0,99,0,111,0,110,0,116,0,97,0,105,0,
110,0,105,0,110,0,103,0,32,0,101,0,105,0,116,0,
104,0,101,0,114,0,32,0,116,0,104,0,101,0,32,0,
119,0,111,0,114,0,100,0,115,0,32,0,34,0,66,0,
105,0,116,0,115,0,116,0,114,0,101,0,97,0,109,0,
34,0,32,0,111,0,114,0,32,0,116,0,104,0,101,0,
32,0,119,0,111,0,114,0,100,0,32,0,34,0,86,0,
101,0,114,0,97,0,34,0,46,0,13,0,10,0,13,0,
10,0,84,0,104,0,105,0,115,0,32,0,76,0,105,0,
99,0,101,0,110,0,115,0,101,0,32,0,98,0,101,0,
99,0,111,0,109,0,101,0,115,0,32,0,110,0,117,0,
108,0,108,0,32,0,97,0,110,0,100,0,32,0,118,0,
111,0,105,0,100,0,32,0,116,0,111,0,32,0,116,0,
104,0,101,0,32,0,101,0,120,0,116,0,101,0,110,0,
116,0,32,0,97,0,112,0,112,0,108,0,105,0,99,0,
97,0,98,0,108,0,101,0,32,0,116,0,111,0,32,0,
70,0,111,0,110,0,116,0,115,0,32,0,111,0,114,0,
32,0,70,0,111,0,110,0,116,0,32,0,83,0,111,0,
102,0,116,0,119,0,97,0,114,0,101,0,32,0,116,0,
104,0,97,0,116,0,32,0,104,0,97,0,115,0,32,0,
98,0,101,0,101,0,110,0,32,0,109,0,111,0,100,0,
105,0,102,0,105,0,101,0,100,0,32,0,97,0,110,0,
100,0,32,0,105,0,115,0,32,0,100,0,105,0,115,0,
116,0,114,0,105,0,98,0,117,0,116,0,101,0,100,0,
32,0,117,0,110,0,100,0,101,0,114,0,32,0,116,0,
104,0,101,0,32,0,34,0,66,0,105,0,116,0,115,0,
116,0,114,0,101,0,97,0,109,0,32,0,86,0,101,0,
114,0,97,0,34,0,32,0,110,0,97,0,109,0,101,0,
115,0,46,0,13,0,10,0,13,0,10,0,84,0,104,0,
101,0,32,0,70,0,111,0,110,0,116,0,32,0,83,0,
111,0,102,0,116,0,119,0,97,0,114,0,101,0,32,0,
109,0,97,0,121,0,32,0,98,0,101,0,32,0,115,0,
111,0,108,0,100,0,32,0,97,0,115,0,32,0,112,0,
97,0,114,0,116,0,32,0,111,0,102,0,32,0,97,0,
32,0,108,0,97,0,114,0,103,0,101,0,114,0,32,0,
115,0,111,0,102,0,116,0,119,0,97,0,114,0,101,0,
32,0,112,0,97,0,99,0,107,0,97,0,103,0,101,0,
32,0,98,0,117,0,116,0,32,0,110,0,111,0,32,0,
99,0,111,0,112,0,121,0,32,0,111,0,102,0,32,0,
111,0,110,0,101,0,32,0,111,0,114,0,32,0,109,0,
111,0,114,0,101,0,32,0,111,0,102,0,32,0,116,0,
104,0,101,0,32,0,70,0,111,0,110,0,116,0,32,0,
83,0,111,0,102,0,116,0,119,0,97,0,114,0,101,0,
32,0,116,0,121,0,112,0,101,0,102,0,97,0,99,0,
101,0,115,0,32,0,109,0,97,0,121,0,32,0,98,0,
101,0,32,0,115,0,111,0,108,0,100,0,32,0,98,0,
121,0,32,0,105,0,116,0,115,0,101,0,108,0,102,0,
46,0,13,0,10,0,13,0,10,0,84,0,72,0,69,0,
32,0,70,0,79,0,78,0,84,0,32,0,83,0,79,0,
70,0,84,0,87,0,65,0,82,0,69,0,32,0,73,0,
83,0,32,0,80,0,82,0,79,0,86,0,73,0,68,0,
69,0,68,0,32,0,34,0,65,0,83,0,32,0,73,0,
83,0,34,0,44,0,32,0,87,0,73,0,84,0,72,0,
79,0,85,0,84,0,32,0,87,0,65,0,82,0,82,0,
65,0,78,0,84,0,89,0,32,0,79,0,70,0,32,0,
65,0,78,0,89,0,32,0,75,0,73,0,78,0,68,0,
44,0,32,0,69,0,88,0,80,0,82,0,69,0,83,0,
83,0,32,0,79,0,82,0,32,0,73,0,77,0,80,0,
76,0,73,0,69,0,68,0,44,0,32,0,73,0,78,0,
67,0,76,0,85,0,68,0,73,0,78,0,71,0,32,0,
66,0,85,0,84,0,32,0,78,0,79,0,84,0,32,0,
76,0,73,0,77,0,73,0,84,0,69,0,68,0,32,0,
84,0,79,0,32,0,65,0,78,0,89,0,32,0,87,0,
65,0,82,0,82,0,65,0,78,0,84,0,73,0,69,0,
83,0,32,0,79,0,70,0,32,0,77,0,69,0,82,0,
67,0,72,0,65,0,78,0,84,0,65,0,66,0,73,0,
76,0,73,0,84,0,89,0,44,0,32,0,70,0,73,0,
84,0,78,0,69,0,83,0,83,0,32,0,70,0,79,0,
82,0,32,0,65,0,32,0,80,0,65,0,82,0,84,0,
73,0,67,0,85,0,76,0,65,0,82,0,32,0,80,0,
85,0,82,0,80,0,79,0,83,0,69,0,32,0,65,0,
78,0,68,0,32,0,78,0,79,0,78,0,73,0,78,0,
70,0,82,0,73,0,78,0,71,0,69,0,77,0,69,0,
78,0,84,0,32,0,79,0,70,0,32,0,67,0,79,0,
80,0,89,0,82,0,73,0,71,0,72,0,84,0,44,0,
32,0,80,0,65,0,84,0,69,0,78,0,84,0,44,0,
32,0,84,0,82,0,65,0,68,0,69,0,77,0,65,0,
82,0,75,0,44,0,32,0,79,0,82,0,32,0,79,0,
84,0,72,0,69,0,82,0,32,0,82,0,73,0,71,0,
72,0,84,0,46,0,32,0,73,0,78,0,32,0,78,0,
79,0,32,0,69,0,86,0,69,0,78,0,84,0,32,0,
83,0,72,0,65,0,76,0,76,0,32,0,66,0,73,0,
84,0,83,0,84,0,82,0,69,0,65,0,77,0,32,0,
79,0,82,0,32,0,84,0,72,0,69,0,32,0,71,0,
78,0,79,0,77,0,69,0,32,0,70,0,79,0,85,0,
78,0,68,0,65,0,84,0,73,0,79,0,78,0,32,0,
66,0,69,0,32,0,76,0,73,0,65,0,66,0,76,0,
69,0,32,0,70,0,79,0,82,0,32,0,65,0,78,0,
89,0,32,0,67,0,76,0,65,0,73,0,77,0,44,0,
32,0,68,0,65,0,77,0,65,0,71,0,69,0,83,0,
32,0,79,0,82,0,32,0,79,0,84,0,72,0,69,0,
82,0,32,0,76,0,73,0,65,0,66,0,73,0,76,0,
73,0,84,0,89,0,44,0,32,0,73,0,78,0,67,0,
76,0,85,0,68,0,73,0,78,0,71,0,32,0,65,0,
78,0,89,0,32,0,71,0,69,0,78,0,69,0,82,0,
65,0,76,0,44,0,32,0,83,0,80,0,69,0,67,0,
73,0,65,0,76,0,44,0,32,0,73,0,78,0,68,0,
73,0,82,0,69,0,67,0,84,0,44,0,32,0,73,0,
78,0,67,0,73,0,68,0,69,0,78,0,84,0,65,0,
76,0,44,0,32,0,79,0,82,0,32,0,67,0,79,0,
78,0,83,0,69,0,81,0,85,0,69,0,78,0,84,0,
73,0,65,0,76,0,32,0,68,0,65,0,77,0,65,0,
71,0,69,0,83,0,44,0,32,0,87,0,72,0,69,0,
84,0,72,0,69,0,82,0,32,0,73,0,78,0,32,0,
65,0,78,0,32,0,65,0,67,0,84,0,73,0,79,0,
78,0,32,0,79,0,70,0,32,0,67,0,79,0,78,0,
84,0,82,0,65,0,67,0,84,0,44,0,32,0,84,0,
79,0,82,0,84,0,32,0,79,0,82,0,32,0,79,0,
84,0,72,0,69,0,82,0,87,0,73,0,83,0,69,0,
44,0,32,0,65,0,82,0,73,0,83,0,73,0,78,0,
71,0,32,0,70,0,82,0,79,0,77,0,44,0,32,0,
79,0,85,0,84,0,32,0,79,0,70,0,32,0,84,0,
72,0,69,0,32,0,85,0,83,0,69,0,32,0,79,0,
82,0,32,0,73,0,78,0,65,0,66,0,73,0,76,0,
73,0,84,0,89,0,32,0,84,0,79,0,32,0,85,0,
83,0,69,0,32,0,84,0,72,0,69,0,32,0,70,0,
79,0,78,0,84,0,32,0,83,0,79,0,70,0,84,0,
87,0,65,0,82,0,69,0,32,0,79,0,82,0,32,0,
70,0,82,0,79,0,77,0,32,0,79,0,84,0,72,0,
69,0,82,0,32,0,68,0,69,0,65,0,76,0,73,0,
78,0,71,0,83,0,32,0,73,0,78,0,32,0,84,0,
72,0,69,0,32,0,70,0,79,0,78,0,84,0,32,0,
83,0,79,0,70,0,84,0,87,0,65,0,82,0,69,0,
46,0,13,0,10,0,13,0,10,0,69,0,120,0,99,0,
101,0,112,0,116,0,32,0,97,0,115,0,32,0,99,0,
111,0,110,0,116,0,97,0,105,0,110,0,101,0,100,0,
32,0,105,0,110,0,32,0,116,0,104,0,105,0,115,0,
32,0,110,0,111,0,116,0,105,0,99,0,101,0,44,0,
32,0,116,0,104,0,101,0,32,0,110,0,97,0,109,0,
101,0,115,0,32,0,111,0,102,0,32,0,71,0,110,0,
111,0,109,0,101,0,44,0,32,0,116,0,104,0,101,0,
32,0,71,0,110,0,111,0,109,0,101,0,32,0,70,0,
111,0,117,0,110,0,100,0,97,0,116,0,105,0,111,0,
110,0,44,0,32,0,97,0,110,0,100,0,32,0,66,0,
105,0,116,0,115,0,116,0,114,0,101,0,97,0,109,0,
32,0,73,0,110,0,99,0,46,0,44,0,32,0,115,0,
104,0,97,0,108,0,108,0,32,0,110,0,111,0,116,0,
32,0,98,0,101,0,32,0,117,0,115,0,101,0,100,0,
32,0,105,0,110,0,32,0,97,0,100,0,118,0,101,0,
114,0,116,0,105,0,115,0,105,0,110,0,103,0,32,0,
111,0,114,0,32,0,111,0,116,0,104,0,101,0,114,0,
119,0,105,0,115,0,101,0,32,0,116,0,111,0,32,0,
112,0,114,0,111,0,109,0,111,0,116,0,101,0,32,0,
116,0,104,0,101,0,32,0,115,0,97,0,108,0,101,0,
44,0,32,0,117,0,115,0,101,0,32,0,111,0,114,0,
32,0,111,0,116,0,104,0,101,0,114,0,32,0,100,0,
101,0,97,0,108,0,105,0,110,0,103,0,115,0,32,0,
105,0,110,0,32,0,116,0,104,0,105,0,115,0,32,0,
70,0,111,0,110,0,116,0,32,0,83,0,111,0,102,0,
116,0,119,0,97,0,114,0,101,0,32,0,119,0,105,0,
116,0,104,0,111,0,117,0,116,0,32,0,112,0,114,0,
105,0,111,0,114,0,32,0,119,0,114,0,105,0,116,0,
116,0,101,0,110,0,32,0,97,0,117,0,116,0,104,0,
111,0,114,0,105,0,122,0,97,0,116,0,105,0,111,0,
110,0,32,0,102,0,114,0,111,0,109,0,32,0,116,0,
104,0,101,0,32,0,71,0,110,0,111,0,109,0,101,0,
32,0,70,0,111,0,117,0,110,0,100,0,97,0,116,0,
105,0,111,0,110,0,32,0,111,0,114,0,32,0,66,0,
105,0,116,0,115,0,116,0,114,0,101,0,97,0,109,0,
32,0,73,0,110,0,99,0,46,0,44,0,32,0,114,0,
101,0,115,0,112,0,101,0,99,0,116,0,105,0,118,0,
101,0,108,0,121,0,46,0,32,0,70,0,111,0,114,0,
32,0,102,0,117,0,114,0,116,0,104,0,101,0,114,0,
32,0,105,0,110,0,102,0,111,0,114,0,109,0,97,0,
116,0,105,0,111,0,110,0,44,0,32,0,99,0,111,0,
110,0,116,0,97,0,99,0,116,0,58,0,32,0,102,0,
111,0,110,0,116,0,115,0,32,0,97,0,116,0,32,0,
103,0,110,0,111,0,109,0,101,0,32,0,100,0,111,0,
116,0,32,0,111,0,114,0,103,0,46,0,104,0,116,0,
116,0,112,0,58,0,47,0,47,0,119,0,119,0,119,0,
46,0,98,0,105,0,116,0,115,0,116,0,114,0,101,0,
97,0,109,0,46,0,99,0,111,0,109,0,1,53,0,184,
0,203,0,203,0,193,0,170,0,156,1,166,0,184,0,102,
0,0,0,113,0,203,0,160,2,178,0,133,0,117,0,184,
0,195,1,203,1,137,2,45,0,203,0,166,0,240,0,211,
0,170,0,135,0,203,3,170,4,0,1,74,0,51,0,203,
0,0,0,217,5,2,0,244,1,84,0,180,0,156,1,57,
1,20,1,57,7,6,4,0,4,78,4,180,4,82,4,184,
4,231,4,205,0,55,4,115,4,205,4,96,4,115,1,51,
3,162,5,86,5,166,5,86,5,57,3,197,2,18,0,201,
0,31,0,184,1,223,0,115,0,186,3,233,3,51,3,188,
4,68,4,14,0,223,3,205,3,170,0,229,3,170,4,4,
0,0,0,203,0,143,0,164,0,123,0,184,0,20,1,111,
0,127,2,123,2,82,0,143,0,199,5,205,0,154,0,154,
0,111,0,203,0,205,1,158,1,211,0,240,0,186,1,131,
0,213,0,152,3,4,2,72,0,158,1,213,0,193,0,203,
0,246,0,131,3,84,2,127,0,0,3,51,2,102,0,211,
0,199,0,164,0,205,0,143,0,154,0,115,4,0,5,213,
1,10,0,254,2,43,0,164,0,180,0,156,0,0,0,98,
0,156,0,0,0,29,3,45,5,213,5,213,5,213,5,240,
0,127,0,123,0,84,0,164,6,184,6,20,7,35,1,211,
0,184,0,203,0,166,1,195,1,236,6,147,0,160,0,211,
3,92,3,113,3,219,1,133,4,35,4,168,4,72,0,143,
1,57,1,20,1,57,3,96,0,143,5,213,1,154,6,20,
7,35,6,102,1,121,4,96,4,96,4,96,4,123,0,156,
0,0,2,119,4,96,1,170,0,233,4,96,7,98,0,123,
0,197,0,127,2,123,0,0,0,180,2,82,5,205,0,102,
0,188,0,102,0,119,6,16,0,205,1,59,1,133,3,137,
0,143,0,123,0,0,0,29,0,205,7,74,4,47,0,156,
0,156,0,0,7,125,0,111,0,0,0,111,3,53,0,106,
0,111,0,123,0,174,0,178,0,45,3,150,0,143,2,123,
0,246,0,131,3,84,6,55,5,246,0,143,0,156,4,225,
2,102,0,143,1,141,2,246,0,205,3,68,0,41,0,102,
4,238,0,115,0,0,20,0,184,2,128,64,255,251,254,3,
250,20,3,249,37,3,248,50,3,247,150,3,246,14,3,245,
254,3,244,254,3,243,37,3,242,14,3,241,150,3,240,37,
3,239,138,65,5,239,254,3,238,150,3,237,150,3,236,250,
3,235,250,3,234,254,3,233,58,3,232,66,3,231,254,3,
230,50,3,229,228,83,5,229,150,3,228,138,65,5,228,83,
3,227,226,47,5,227,250,3,226,47,3,225,254,3,224,254,
3,223,50,3,222,20,3,221,150,3,220,254,3,219,18,3,
218,125,3,217,187,3,216,254,3,214,138,65,5,214,125,3,
213,212,71,5,213,125,3,212,71,3,211,210,27,5,211,254,
3,210,27,3,209,254,3,208,254,3,207,254,3,206,254,3,
205,150,3,204,203,30,5,204,254,3,203,30,3,202,50,3,
201,254,3,198,133,17,5,198,28,3,197,22,3,196,254,3,
195,254,3,194,254,3,193,254,3,192,254,3,191,254,3,190,
254,3,189,254,3,188,254,3,187,254,3,186,17,3,185,134,
37,5,185,254,3,184,183,187,5,184,254,3,183,182,93,5,
183,187,3,183,128,4,182,181,37,5,182,93,64,255,3,182,
64,4,181,37,3,180,254,3,179,150,3,178,254,3,177,254,
3,176,254,3,175,254,3,174,100,3,173,14,3,172,171,37,
5,172,100,3,171,170,18,5,171,37,3,170,18,3,169,138,
65,5,169,250,3,168,254,3,167,254,3,166,254,3,165,18,
3,164,254,3,163,162,14,5,163,50,3,162,14,3,161,100,
3,160,138,65,5,160,150,3,159,254,3,158,157,12,5,158,
254,3,157,12,3,156,155,25,5,156,100,3,155,154,16,5,
155,25,3,154,16,3,153,10,3,152,254,3,151,150,13,5,
151,254,3,150,13,3,149,138,65,5,149,150,3,148,147,14,
5,148,40,3,147,14,3,146,250,3,145,144,187,5,145,254,
3,144,143,93,5,144,187,3,144,128,4,143,142,37,5,143,
93,3,143,64,4,142,37,3,141,254,3,140,139,46,5,140,
254,3,139,46,3,138,134,37,5,138,65,3,137,136,11,5,
137,20,3,136,11,3,135,134,37,5,135,100,3,134,133,17,
5,134,37,3,133,17,3,132,254,3,131,130,17,5,131,254,
3,130,17,3,129,254,3,128,254,3,127,254,3,64,255,126,
125,125,5,126,254,3,125,125,3,124,100,3,123,84,21,5,
123,37,3,122,254,3,121,254,3,120,14,3,119,12,3,118,
10,3,117,254,3,116,250,3,115,250,3,114,250,3,113,250,
3,112,254,3,111,254,3,110,254,3,108,33,3,107,254,3,
106,17,66,5,106,83,3,105,254,3,104,125,3,103,17,66,
5,102,254,3,101,254,3,100,254,3,99,254,3,98,254,3,
97,58,3,96,250,3,94,12,3,93,254,3,91,254,3,90,
254,3,89,88,10,5,89,250,3,88,10,3,87,22,25,5,
87,50,3,86,254,3,85,84,21,5,85,66,3,84,21,3,
83,1,16,5,83,24,3,82,20,3,81,74,19,5,81,254,
3,80,11,3,79,254,3,78,77,16,5,78,254,3,77,16,
3,76,254,3,75,74,19,5,75,254,3,74,73,16,5,74,
19,3,73,29,13,5,73,16,3,72,13,3,71,254,3,70,
150,3,69,150,3,68,254,3,67,2,45,5,67,250,3,66,
187,3,65,75,3,64,254,3,63,254,3,62,61,18,5,62,
20,3,61,60,15,5,61,18,3,60,59,13,5,60,64,255,
15,3,59,13,3,58,254,3,57,254,3,56,55,20,5,56,
250,3,55,54,16,5,55,20,3,54,53,11,5,54,16,3,
53,11,3,52,30,3,51,13,3,50,49,11,5,50,254,3,
49,11,3,48,47,11,5,48,13,3,47,11,3,46,45,9,
5,46,16,3,45,9,3,44,50,3,43,42,37,5,43,100,
3,42,41,18,5,42,37,3,41,18,3,40,39,37,5,40,
65,3,39,37,3,38,37,11,5,38,15,3,37,11,3,36,
254,3,35,254,3,34,15,3,33,1,16,5,33,18,3,32,
100,3,31,250,3,30,29,13,5,30,100,3,29,13,3,28,
17,66,5,28,254,3,27,250,3,26,66,3,25,17,66,5,
25,254,3,24,100,3,23,22,25,5,23,254,3,22,1,16,
5,22,25,3,21,254,3,20,254,3,19,254,3,18,17,66,
5,18,254,3,17,2,45,5,17,66,3,16,125,3,15,100,
3,14,254,3,13,12,22,5,13,254,3,12,1,16,5,12,
22,3,11,254,3,10,16,3,9,254,3,8,2,45,5,8,
254,3,7,20,3,6,100,3,4,1,16,5,4,254,3,64,
21,3,2,45,5,3,254,3,2,1,16,5,2,45,3,1,
16,3,0,254,3,1,184,1,100,133,141,1,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,0,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,
43,43,43,43,43,43,43,43,43,43,43,43,43,43,43,29,
182,6,5,4,3,2,1,0,44,32,16,176,2,37,73,100,
176,64,81,88,32,200,89,33,45,44,176,2,37,73,100,176,
64,81,88,32,200,89,33,45,44,32,16,7,32,176,0,80,
176,13,121,32,184,255,255,80,88,4,27,5,89,176,5,28,
176,3,37,8,176,4,37,35,225,32,176,0,80,176,13,121,
32,184,255,255,80,88,4,27,5,89,176,5,28,176,3,37,
8,225,45,44,75,80,88,32,176,253,69,68,89,33,45,44,
176,2,37,69,96,68,45,44,75,83,88,176,2,37,176,2,
37,69,68,89,33,33,45,44,69,68,45,0,0,2,0,102,
254,150,4,102,5,164,0,3,0,7,0,26,64,12,4,251,
0,6,251,1,8,5,127,2,4,0,47,196,212,236,49,0,
16,212,236,212,236,48,19,17,33,17,37,33,17,33,102,4,
0,252,115,3,27,252,229,254,150,7,14,248,242,114,6,41,
0,2,1,53,0,0,2,0,5,213,0,3,0,9,0,64,
64,15,7,0,131,4,129,2,8,7,5,1,3,4,0,0,
10,16,252,60,236,50,57,57,49,0,47,228,252,204,48,1,
75,176,11,84,88,189,0,10,0,64,0,1,0,10,0,10,
255,192,56,17,55,56,89,182,0,11,32,11,80,11,3,93,
37,51,21,35,17,51,17,3,35,3,1,53,203,203,203,20,
162,21,254,254,5,213,253,113,254,155,1,101,0,2,0,197,
3,170,2,233,5,213,0,3,0,7,0,77,64,15,5,1,
132,4,0,129,8,4,5,6,0,5,2,4,8,16,252,252,
220,236,49,0,16,244,60,236,50,48,1,75,176,18,84,75,
176,19,84,91,88,189,0,8,0,64,0,1,0,8,0,8,
255,192,56,17,55,56,89,64,15,48,9,64,9,80,9,96,
9,112,9,160,9,191,9,7,93,1,17,35,17,33,17,35,
17,1,111,170,2,36,170,5,213,253,213,2,43,253,213,2,
43,0,0,2,0,158,0,0,6,23,5,190,0,3,0,31,
0,96,64,49,27,11,0,135,7,4,29,9,5,25,13,2,
135,23,19,15,21,17,31,30,28,27,26,23,22,21,20,19,
18,17,16,14,13,12,9,8,7,6,5,4,3,2,1,0,
26,10,24,6,32,16,252,204,23,57,49,0,47,60,212,60,
60,252,60,60,212,60,60,196,50,236,50,50,48,64,17,11,
1,11,2,11,12,11,13,20,4,26,17,26,18,20,31,8,
1,93,1,33,3,33,11,1,33,19,51,3,33,21,33,3,
33,21,33,3,35,19,33,3,35,19,33,53,33,19,33,53,
33,19,4,23,254,221,84,1,37,68,104,1,36,105,160,103,
1,56,254,161,82,1,62,254,155,104,160,103,254,219,103,161,
104,254,197,1,96,84,254,190,1,105,102,3,133,254,178,3,
135,254,97,1,159,254,97,154,254,178,153,254,98,1,158,254,
98,1,158,153,1,78,154,1,159,0,0,3,0,170,254,211,
4,109,6,20,0,33,0,40,0,47,0,213,64,85,34,2,
10,11,10,39,1,38,40,2,11,11,10,29,1,30,28,2,
47,41,47,27,2,41,41,47,66,19,17,16,34,10,27,41,
4,23,6,9,42,33,5,2,23,134,22,6,134,5,17,35,
26,138,22,137,16,0,42,138,5,137,2,45,8,22,10,30,
7,41,26,18,3,0,9,34,16,9,3,1,7,38,8,13,
5,6,48,16,252,60,236,244,23,60,252,23,60,244,228,236,
49,0,47,228,236,196,212,228,236,50,196,16,238,16,238,17,
18,57,17,57,17,18,23,57,17,18,57,48,75,83,88,7,
16,4,237,7,16,14,237,17,23,57,7,16,14,237,17,23,
57,7,16,4,237,89,34,1,75,176,9,84,88,189,0,48,
0,64,0,1,0,48,0,48,255,192,56,17,55,56,89,1,
75,176,12,84,75,176,16,84,91,75,176,15,84,91,88,189,
0,48,255,192,0,1,0,48,0,48,0,64,56,17,55,56,
89,1,35,3,46,1,39,53,30,1,23,17,46,1,53,52,
54,55,53,51,21,30,1,23,21,46,1,39,17,30,1,21,
20,6,7,3,17,14,1,21,20,22,23,17,62,1,53,52,
38,2,180,100,1,105,210,106,102,209,111,221,201,218,204,100,
93,174,83,83,175,92,227,214,227,214,100,116,122,113,225,127,
129,123,254,211,1,45,2,45,45,180,64,65,1,1,200,36,
172,150,163,188,14,235,232,4,31,27,175,42,46,4,254,85,
35,180,156,169,195,15,3,0,1,154,13,106,88,86,96,213,
254,79,17,110,90,88,104,0,0,5,0,113,255,227,7,41,
5,240,0,11,0,23,0,35,0,39,0,51,0,149,64,54,
36,15,37,38,37,38,15,39,36,39,66,0,146,12,30,146,
46,141,24,146,36,6,146,12,141,38,18,140,40,36,145,52,
39,33,27,37,9,3,13,21,14,9,13,15,33,13,43,14,
27,13,15,49,11,52,16,252,196,236,244,236,16,238,246,238,
17,57,17,18,57,49,0,16,228,50,244,60,228,236,16,238,
246,238,16,238,48,75,83,88,7,16,5,237,7,16,5,237,
89,34,1,75,176,9,84,75,176,11,84,91,75,176,12,84,
91,75,176,20,84,91,75,176,14,84,91,75,176,13,84,91,
88,189,0,52,0,64,0,1,0,52,0,52,255,192,56,17,
55,56,89,1,34,6,21,20,22,51,50,54,53,52,38,39,
50,22,21,20,6,35,34,38,53,52,54,1,34,6,21,20,
22,51,50,54,53,52,38,37,51,1,35,19,50,22,21,20,
6,35,34,38,53,52,54,5,209,87,99,99,87,85,99,99,
85,158,186,187,157,160,186,187,252,151,86,99,98,87,87,99,
100,3,49,160,252,90,160,31,158,188,187,159,159,185,186,2,
145,148,132,130,149,149,130,131,149,127,220,187,187,219,219,187,
188,219,2,97,149,130,132,148,148,132,129,150,127,249,243,6,
13,219,187,189,218,219,188,186,220,0,0,2,0,129,255,227,
5,254,5,240,0,9,0,48,1,205,64,150,13,1,14,12,
134,17,18,17,11,134,10,11,18,18,17,9,134,0,9,21,
22,21,7,1,6,8,134,22,22,21,2,1,3,1,134,29,
30,29,0,134,9,0,30,30,29,32,31,2,33,30,17,10,
19,10,23,22,21,3,24,20,17,19,10,7,8,2,6,9,
17,19,19,10,2,1,2,3,0,17,10,19,10,23,22,2,
24,21,17,19,10,20,17,19,19,10,66,18,11,9,3,6,
0,10,30,3,40,21,14,6,40,39,6,149,24,43,149,39,
148,36,145,24,140,14,19,10,46,11,14,9,0,46,18,21,
39,14,30,3,46,18,39,33,14,17,15,19,33,3,18,27,
16,49,16,252,236,196,212,212,236,16,198,238,17,57,17,18,
57,57,17,57,57,17,57,17,57,49,0,47,198,228,246,230,
238,16,238,16,198,17,18,57,17,23,57,17,23,57,48,75,
83,88,7,16,5,237,7,5,237,17,23,57,7,16,5,237,
17,23,57,7,16,5,237,17,23,57,7,5,237,17,23,57,
7,16,5,237,17,23,57,7,16,8,237,7,16,14,237,17,
23,57,7,16,14,237,17,23,57,7,16,8,237,7,16,8,
237,7,16,14,237,17,23,57,89,34,178,15,50,1,1,93,
64,178,7,11,5,34,9,41,28,0,28,1,31,2,23,11,
42,0,42,1,38,18,58,0,52,18,68,11,94,0,89,1,
90,10,85,18,90,26,90,31,89,48,103,30,123,0,155,0,
154,1,153,2,151,8,149,11,147,21,149,22,149,34,153,45,
31,9,11,9,12,8,17,12,39,12,40,24,2,27,9,25,
11,25,12,25,17,28,20,28,21,22,29,31,50,39,0,39,
1,41,9,35,18,42,19,42,20,40,21,47,50,59,9,52,
18,57,19,63,50,74,9,76,20,75,21,70,25,79,50,86,
1,90,9,89,12,85,18,89,19,92,31,95,50,106,12,105,
17,96,50,117,1,121,12,122,17,147,0,147,1,151,2,149,
5,156,7,156,8,159,8,154,9,155,11,154,12,144,50,160,
50,176,50,57,93,0,93,1,14,1,21,20,22,51,50,54,
55,9,1,62,1,55,51,6,2,7,1,35,39,14,1,35,
34,0,53,52,54,55,46,1,53,52,54,51,50,22,23,21,
46,1,35,34,6,21,20,22,1,242,91,85,212,160,95,166,
73,254,123,1,252,59,66,6,186,12,104,93,1,23,252,143,
104,228,131,241,254,206,134,134,48,50,222,184,83,165,85,87,
158,68,105,131,59,3,35,81,161,88,146,194,63,64,2,143,
253,248,89,203,114,132,254,254,126,254,227,147,89,87,1,19,
215,128,225,99,63,125,60,162,197,36,36,182,47,49,111,88,
51,103,0,1,0,197,3,170,1,111,5,213,0,3,0,66,
64,10,1,132,0,129,4,0,5,2,4,4,16,252,236,49,
0,16,244,236,48,1,75,176,18,84,75,176,19,84,91,88,
189,0,4,0,64,0,1,0,4,0,4,255,192,56,17,55,
56,89,64,13,64,5,80,5,96,5,112,5,144,5,160,5,
6,93,1,17,35,17,1,111,170,5,213,253,213,2,43,0,
0,1,0,176,254,242,2,123,6,18,0,13,0,79,64,15,
6,152,0,151,14,13,7,0,3,18,6,0,19,10,14,16,
220,228,50,236,17,57,57,49,0,16,252,236,48,1,75,176,
19,84,88,189,0,14,0,64,0,1,0,14,0,14,255,192,
56,17,55,56,89,1,75,176,15,84,88,189,0,14,255,192,
0,1,0,14,0,14,0,64,56,17,55,56,89,1,6,2,
21,20,18,23,35,38,2,53,52,18,55,2,123,134,130,131,
133,160,150,149,148,151,6,18,230,254,62,231,231,254,59,229,
235,1,198,224,223,1,196,236,0,1,0,164,254,242,2,111,
6,18,0,13,0,31,64,15,7,152,0,151,14,7,1,0,
11,18,4,19,8,0,14,16,220,60,244,236,17,57,57,49,
0,16,252,236,48,19,51,22,18,21,20,2,7,35,54,18,
53,52,2,164,160,150,149,149,150,160,133,131,131,6,18,236,
254,60,223,224,254,58,235,229,1,197,231,231,1,194,0,1,
0,61,2,74,3,195,5,240,0,17,0,78,64,44,16,13,
11,0,4,12,9,7,4,2,4,8,3,153,5,17,12,153,
10,1,14,145,18,8,12,10,3,9,6,17,3,1,3,2,
0,20,15,4,11,9,20,13,6,18,16,212,60,228,50,220,
60,228,50,23,57,17,18,23,57,49,0,16,244,212,60,236,
50,196,236,50,23,57,18,23,57,48,1,5,5,7,37,17,
35,17,5,39,37,37,55,5,17,51,17,37,3,195,254,153,
1,103,58,254,176,114,254,176,58,1,103,254,153,58,1,80,
114,1,80,4,223,194,195,98,203,254,135,1,121,203,98,195,
194,99,203,1,121,254,135,203,0,1,0,217,0,0,5,219,
5,4,0,11,0,35,64,17,0,9,1,156,7,3,5,2,
21,4,0,23,10,6,21,8,12,16,220,252,60,252,60,236,
49,0,47,212,60,252,60,196,48,1,17,33,21,33,17,35,
17,33,53,33,17,3,174,2,45,253,211,168,253,211,2,45,
5,4,253,211,170,253,211,2,45,170,2,45,0,1,0,158,
255,18,1,195,0,254,0,5,0,25,64,12,3,158,0,131,
6,3,4,1,25,0,24,6,16,252,236,212,204,49,0,16,
252,236,48,55,51,21,3,35,19,240,211,164,129,82,254,172,
254,192,1,64,0,1,0,100,1,223,2,127,2,131,0,3,
0,17,182,0,156,2,4,1,0,4,16,220,204,49,0,16,
212,236,48,19,33,21,33,100,2,27,253,229,2,131,164,0,
0,1,0,219,0,0,1,174,0,254,0,3,0,17,183,0,
131,2,1,25,0,24,4,16,252,236,49,0,47,236,48,55,
51,21,35,219,211,211,254,254,0,1,0,0,255,66,2,178,
5,213,0,3,0,45,64,20,0,26,1,2,1,2,26,3,
0,3,66,2,159,0,129,4,2,0,1,3,47,196,57,57,
49,0,16,244,236,48,75,83,88,7,16,5,237,7,16,5,
237,89,34,1,51,1,35,2,8,170,253,248,170,5,213,249,
109,0,0,2,0,135,255,227,4,143,5,240,0,11,0,23,
0,35,64,19,6,160,18,0,160,12,145,18,140,24,9,28,
15,30,3,28,21,27,24,16,252,236,244,236,49,0,16,228,
244,236,16,238,48,1,34,2,17,16,18,51,50,18,17,16,
2,39,50,0,17,16,0,35,34,0,17,16,0,2,139,156,
157,157,156,157,157,157,157,251,1,9,254,247,251,251,254,247,
1,9,5,80,254,205,254,204,254,205,254,205,1,51,1,51,
1,52,1,51,160,254,115,254,134,254,135,254,115,1,141,1,
121,1,122,1,141,0,0,1,0,225,0,0,4,90,5,213,
0,10,0,75,64,21,66,3,160,4,2,160,5,129,7,0,
160,9,8,31,6,28,3,0,31,1,11,16,212,236,196,252,
236,49,0,47,236,50,244,236,212,236,48,75,83,88,89,34,
1,75,176,15,84,88,189,0,11,255,192,0,1,0,11,0,
11,0,64,56,17,55,56,89,180,15,3,15,4,2,93,55,
33,17,5,53,37,51,17,33,21,33,254,1,74,254,153,1,
101,202,1,74,252,164,170,4,115,72,184,72,250,213,170,0,
0,1,0,150,0,0,4,74,5,240,0,28,0,165,64,39,
25,26,27,3,24,28,17,5,4,0,17,5,5,4,66,16,
161,17,148,13,160,20,145,4,0,160,2,0,16,10,2,1,
10,28,23,16,3,6,29,16,252,196,212,236,192,192,17,18,
57,49,0,47,236,50,244,236,244,236,48,75,83,88,7,16,
5,237,7,5,237,17,23,57,89,34,1,75,176,21,84,75,
176,22,84,91,75,176,20,84,91,88,189,0,29,0,64,0,
1,0,29,0,29,255,192,56,17,55,56,89,64,50,85,4,
86,5,86,7,122,4,122,5,118,27,135,25,7,4,0,4,
25,4,26,4,27,5,28,116,0,118,6,117,26,115,27,116,
28,130,0,134,25,130,26,130,27,130,28,168,0,168,27,17,
93,0,93,37,33,21,33,53,54,0,55,62,1,53,52,38,
35,34,6,7,53,62,1,51,50,4,21,20,6,7,6,0,
1,137,2,193,252,76,115,1,141,51,97,77,167,134,95,211,
120,122,212,88,232,1,20,69,91,25,254,244,170,170,170,119,
1,145,58,109,151,73,119,150,66,67,204,49,50,232,194,92,
165,112,29,254,235,0,0,1,0,156,255,227,4,115,5,240,
0,40,0,123,64,46,0,21,19,10,134,9,31,134,32,19,
160,21,13,160,9,147,6,28,160,32,147,35,145,6,140,21,
163,41,22,28,19,0,3,20,25,28,38,32,16,28,3,20,
31,9,6,41,16,252,196,196,212,236,244,236,17,23,57,57,
49,0,16,236,228,244,228,236,16,230,238,16,238,16,238,16,
238,17,18,57,48,1,75,176,22,84,75,176,20,84,91,88,
189,0,41,0,64,0,1,0,41,0,41,255,192,56,17,55,
56,89,64,9,100,30,97,31,97,32,100,33,4,0,93,1,
30,1,21,20,4,33,34,38,39,53,30,1,51,50,54,53,
52,38,43,1,53,51,50,54,53,52,38,35,34,6,7,53,
62,1,51,50,4,21,20,6,3,63,145,163,254,208,254,232,
94,199,106,84,200,109,190,199,185,165,174,182,149,158,163,152,
83,190,114,115,201,89,230,1,12,142,3,37,31,196,144,221,
242,37,37,195,49,50,150,143,132,149,166,119,112,115,123,36,
38,180,32,32,209,178,124,171,0,2,0,100,0,0,4,164,
5,213,0,2,0,13,0,140,64,29,1,13,3,13,0,3,
3,13,66,0,3,11,7,160,5,1,3,129,9,1,12,10,
0,28,6,8,4,12,14,16,220,212,60,196,236,50,17,57,
49,0,47,228,212,60,236,50,18,57,48,75,83,88,7,16,
4,201,7,16,5,201,89,34,1,75,176,11,84,75,176,13,
84,91,88,189,0,14,0,64,0,1,0,14,0,14,255,192,
56,17,55,56,89,64,42,11,0,42,0,72,0,89,0,105,
0,119,0,138,0,7,22,1,43,0,38,1,43,3,54,1,
78,1,79,12,79,13,86,1,102,1,117,1,122,3,133,1,
13,93,0,93,9,1,33,3,51,17,51,21,35,17,35,17,
33,53,3,6,254,2,1,254,53,254,213,213,201,253,94,5,
37,252,227,3,205,252,51,168,254,160,1,96,195,0,0,1,
0,158,255,227,4,100,5,213,0,29,0,117,64,35,4,26,
7,17,134,16,29,26,160,7,20,160,16,137,13,2,160,0,
129,13,140,7,164,30,23,28,1,10,3,28,0,10,16,6,
30,16,252,196,212,236,16,196,238,49,0,16,228,228,244,236,
16,230,238,16,254,196,16,238,17,18,57,48,1,75,176,22,
84,75,176,20,84,91,88,189,0,30,0,64,0,1,0,30,
0,30,255,192,56,17,55,56,89,1,75,176,15,84,88,189,
0,30,255,192,0,1,0,30,0,30,0,64,56,17,55,56,
89,19,33,21,33,17,62,1,51,50,0,21,20,0,33,34,
38,39,53,30,1,51,50,54,53,52,38,35,34,6,7,221,
3,25,253,160,44,88,44,250,1,36,254,212,254,239,94,195,
104,90,192,107,173,202,202,173,81,161,84,5,213,170,254,146,
15,15,254,238,234,241,254,245,32,32,203,49,48,182,156,156,
182,36,38,0,0,2,0,143,255,227,4,150,5,240,0,11,
0,36,0,88,64,36,19,6,0,13,134,12,0,160,22,6,
160,28,22,165,16,160,12,137,34,145,28,140,37,12,34,9,
28,25,30,19,28,3,33,31,27,37,16,252,236,236,244,236,
228,49,0,16,228,244,228,252,228,16,238,16,238,16,238,17,
18,57,48,64,20,203,0,203,1,205,2,205,3,205,4,203,
5,203,6,7,164,30,178,30,2,93,1,93,1,34,6,21,
20,22,51,50,54,53,52,38,1,21,46,1,35,34,2,3,
62,1,51,50,0,21,20,0,35,32,0,17,16,0,33,50,
22,2,164,136,159,159,136,136,159,159,1,9,76,155,76,200,
211,15,59,178,107,225,1,5,254,240,226,254,253,254,238,1,
80,1,27,76,155,3,59,186,162,161,187,187,161,162,186,2,
121,184,36,38,254,242,254,239,87,93,254,239,235,230,254,234,
1,141,1,121,1,98,1,165,30,0,0,1,0,168,0,0,
4,104,5,213,0,6,0,99,64,24,5,17,2,3,2,3,
17,4,5,4,66,5,160,0,129,3,5,3,1,4,1,0,
6,7,16,252,204,196,17,57,57,49,0,47,244,236,48,75,
83,88,7,16,5,237,7,16,5,237,89,34,1,75,176,22,
84,88,189,0,7,0,64,0,1,0,7,0,7,255,192,56,
17,55,56,89,64,18,88,2,1,6,3,26,5,57,5,72,
5,103,3,176,0,176,6,7,93,0,93,19,33,21,1,35,
1,33,168,3,192,253,226,211,1,254,253,51,5,213,86,250,
129,5,43,0,0,3,0,139,255,227,4,139,5,240,0,11,
0,35,0,47,0,67,64,37,24,12,0,160,39,6,160,30,
45,160,18,145,30,140,39,163,48,24,12,36,42,28,21,36,
28,15,9,28,21,27,30,3,28,15,33,27,48,16,252,196,
236,244,196,236,16,238,16,238,17,57,57,49,0,16,236,228,
244,236,16,238,16,238,57,57,48,1,34,6,21,20,22,51,
50,54,53,52,38,37,38,38,53,52,54,51,50,22,21,20,
6,7,22,22,21,20,4,35,34,36,53,52,54,19,20,22,
51,50,54,53,52,38,35,34,6,2,139,144,165,165,144,144,
166,165,254,165,130,145,255,222,223,254,145,129,146,163,254,247,
247,247,254,247,164,72,145,131,130,147,147,130,131,145,2,197,
154,135,135,154,155,134,135,154,86,32,178,128,179,208,208,179,
128,178,32,34,198,143,217,232,232,217,143,198,1,97,116,130,
130,116,116,130,130,0,0,2,0,129,255,227,4,135,5,240,
0,24,0,36,0,88,64,35,7,31,25,1,134,0,25,160,
10,165,4,160,0,137,22,31,160,16,145,22,140,37,7,28,
28,33,19,30,0,34,34,28,13,27,37,16,252,236,228,244,
236,236,49,0,16,228,244,236,16,230,254,245,238,16,238,17,
18,57,48,64,22,196,25,194,26,192,27,192,28,192,29,194,
30,196,31,7,170,18,188,18,233,18,3,93,1,93,55,53,
30,1,51,50,18,19,14,1,35,34,0,53,52,0,51,32,
0,17,16,0,33,34,38,1,50,54,53,52,38,35,34,6,
21,20,22,225,76,156,75,200,211,15,58,178,108,224,254,251,
1,16,226,1,3,1,17,254,177,254,229,76,156,1,62,136,
159,159,136,136,159,159,31,184,36,38,1,13,1,18,86,92,
1,15,235,230,1,22,254,115,254,134,254,159,254,91,30,2,
151,186,162,161,187,187,161,162,186,0,0,2,0,240,0,0,
1,195,4,35,0,3,0,7,0,28,64,14,6,131,4,166,
0,131,2,5,1,3,4,0,24,8,16,252,60,236,50,49,
0,47,236,244,236,48,55,51,21,35,17,51,21,35,240,211,
211,211,211,254,254,4,35,254,0,2,0,158,255,18,1,195,
4,35,0,3,0,9,0,37,64,19,2,131,0,7,158,4,
131,0,166,10,7,8,5,1,25,4,0,24,10,16,252,60,
236,50,212,204,49,0,16,228,252,236,16,238,48,19,51,21,
35,17,51,21,3,35,19,240,211,211,211,164,129,82,4,35,
254,253,217,172,254,192,1,64,0,1,0,217,0,94,5,219,
4,166,0,6,0,77,64,42,2,156,3,4,3,1,156,0,
1,4,4,3,1,156,2,1,5,6,5,0,156,6,5,66,
5,4,2,1,0,5,3,168,6,167,7,1,2,0,36,4,
35,7,16,252,236,50,57,49,0,16,244,236,23,57,48,75,
83,88,7,4,237,7,16,8,237,7,16,8,237,7,16,4,
237,89,34,9,2,21,1,53,1,5,219,251,248,4,8,250,
254,5,2,3,240,254,145,254,147,182,1,209,166,1,209,0,
0,2,0,217,1,96,5,219,3,162,0,3,0,7,0,28,
64,13,0,156,2,6,156,4,8,5,1,4,0,35,8,16,
252,60,196,50,49,0,16,212,236,212,236,48,19,33,21,33,
21,33,21,33,217,5,2,250,254,5,2,250,254,3,162,168,
240,170,0,1,0,217,0,94,5,219,4,166,0,6,0,79,
64,43,6,156,0,6,3,4,3,5,156,4,4,3,0,156,
1,2,1,6,156,5,6,2,2,1,66,6,5,3,2,0,
5,4,168,1,167,7,6,2,36,4,0,35,7,16,252,60,
236,57,49,0,16,244,236,23,57,48,75,83,88,7,16,8,
237,7,16,4,237,7,16,4,237,7,16,8,237,89,34,19,
53,1,21,1,53,1,217,5,2,250,254,4,6,3,240,182,
254,47,166,254,47,182,1,109,0,2,0,147,0,0,3,176,
5,240,0,3,0,36,0,112,64,43,36,30,9,6,4,10,
29,19,4,0,20,134,19,136,16,149,23,145,0,131,2,29,
26,13,9,5,4,10,30,1,13,28,26,4,28,5,1,3,
0,38,26,19,37,16,220,196,252,236,212,236,16,238,17,57,
57,17,18,57,17,18,57,49,0,47,238,246,254,244,238,16,
205,17,57,57,23,57,48,1,75,176,12,84,88,189,0,37,
0,64,0,1,0,37,0,37,255,192,56,17,55,56,89,182,
121,9,122,10,122,32,3,93,37,51,21,35,19,35,53,52,
54,63,1,62,1,53,52,38,35,34,6,7,53,62,1,51,
50,22,21,20,6,15,1,14,1,7,14,1,21,1,135,203,
203,197,191,56,90,90,57,51,131,108,79,179,97,94,193,103,
184,223,72,90,88,47,39,8,6,6,254,254,1,145,154,101,
130,86,89,53,94,49,89,110,70,67,188,57,56,194,159,76,
137,86,86,47,53,25,21,60,52,0,0,2,0,135,254,156,
7,113,5,162,0,11,0,76,0,149,64,50,24,12,3,9,
169,25,21,27,3,169,76,15,52,51,15,172,48,169,55,21,
172,36,169,55,67,77,51,52,30,26,0,40,18,6,24,12,
40,26,43,30,40,73,18,43,42,40,73,44,61,77,16,220,
236,252,236,16,254,253,254,60,198,16,238,17,18,57,57,49,
0,16,212,196,252,236,16,254,237,212,198,16,197,238,50,16,
196,238,17,57,57,48,0,75,176,9,84,75,176,12,84,91,
75,176,16,84,91,75,176,19,84,91,75,176,20,84,91,88,
189,0,77,255,192,0,1,0,77,0,77,0,64,56,17,55,
56,89,64,9,15,78,31,78,47,78,63,78,4,1,93,1,
20,22,51,50,54,53,52,38,35,34,6,1,14,1,35,34,
38,53,52,54,51,50,22,23,53,51,17,62,1,53,52,38,
39,38,36,35,34,6,7,6,2,21,20,18,23,22,4,51,
50,54,55,23,6,4,35,34,36,39,38,2,53,52,18,55,
54,36,51,50,4,23,30,1,21,16,0,5,2,250,142,124,
123,141,144,122,121,143,2,33,60,155,103,172,215,216,171,103,
156,59,143,146,165,63,64,104,254,213,176,123,226,96,157,177,
115,109,105,1,20,157,129,249,104,90,125,254,217,152,185,254,
184,128,128,134,136,126,129,1,82,189,212,1,107,123,75,79,
254,194,254,232,2,25,143,163,164,142,140,165,164,254,72,77,
73,249,200,200,250,75,76,131,253,32,22,223,177,107,188,80,
131,139,65,64,102,254,181,193,159,254,234,106,104,109,87,81,
111,97,103,131,125,125,1,73,189,182,1,74,125,127,135,174,
160,98,230,123,254,249,254,208,6,0,0,2,0,16,0,0,
5,104,5,213,0,2,0,10,0,186,64,65,0,17,1,0,
4,5,4,2,17,5,5,4,1,17,10,3,10,0,17,2,
0,3,3,10,7,17,5,4,6,17,5,5,4,9,17,3,
10,8,17,10,3,10,66,0,3,7,149,1,3,129,9,5,
9,8,7,6,4,3,2,1,0,9,5,10,11,16,212,196,
23,57,49,0,47,60,228,212,236,18,57,48,75,83,88,7,
16,5,237,7,5,237,7,16,5,237,7,5,237,7,16,8,
237,7,16,5,237,7,16,5,237,7,16,8,237,89,34,178,
32,12,1,1,93,64,58,15,0,88,0,118,0,112,0,140,
0,5,7,1,8,2,6,3,9,4,22,1,25,2,86,1,
88,2,80,12,103,1,104,2,120,1,118,2,124,3,114,4,
119,7,120,8,135,1,136,2,128,12,152,2,153,3,150,4,
23,93,0,93,9,1,33,1,51,1,35,3,33,3,35,2,
188,254,238,2,37,254,123,229,2,57,210,136,253,95,136,213,
5,14,253,25,3,174,250,43,1,127,254,129,0,3,0,201,
0,0,4,236,5,213,0,8,0,17,0,32,0,67,64,35,
25,0,149,10,9,149,18,129,1,149,10,173,31,17,11,8,
2,19,25,31,5,0,14,28,22,5,25,28,46,9,0,28,
18,4,33,16,252,236,50,252,236,212,236,17,23,57,57,57,
49,0,47,236,236,244,236,16,238,57,48,178,15,34,1,1,
93,1,17,33,50,54,53,52,38,35,1,17,33,50,54,53,
52,38,35,37,33,50,22,21,20,6,7,30,1,21,20,4,
35,33,1,147,1,68,163,157,157,163,254,188,1,43,148,145,
145,148,254,11,2,4,231,250,128,124,149,165,254,240,251,253,
232,2,201,253,221,135,139,140,133,2,102,254,62,111,114,113,
112,166,192,177,137,162,20,32,203,152,200,218,0,1,0,115,
255,227,5,39,5,240,0,25,0,54,64,26,13,161,14,174,
10,149,17,1,161,0,174,4,149,23,145,17,140,26,7,25,
13,0,48,20,16,26,16,252,236,50,236,49,0,16,228,244,
236,244,236,16,238,246,238,48,180,15,27,31,27,2,1,93,
1,21,46,1,35,32,0,17,16,0,33,50,54,55,21,14,
1,35,32,0,17,16,0,33,50,22,5,39,102,231,130,255,
0,254,240,1,16,1,0,130,231,102,106,237,132,254,173,254,
122,1,134,1,83,134,237,5,98,213,95,94,254,199,254,216,
254,217,254,199,94,95,211,72,72,1,159,1,103,1,104,1,
159,71,0,2,0,201,0,0,5,176,5,213,0,8,0,17,
0,46,64,21,0,149,9,129,1,149,16,8,2,16,10,0,
5,25,13,50,0,28,9,4,18,16,252,236,244,236,17,57,
57,57,57,49,0,47,236,244,236,48,178,96,19,1,1,93,
1,17,51,32,0,17,16,0,33,37,33,32,0,17,16,0,
41,1,1,147,244,1,53,1,31,254,225,254,203,254,66,1,
159,1,178,1,150,254,104,254,80,254,97,5,47,251,119,1,
24,1,46,1,44,1,23,166,254,151,254,128,254,126,254,150,
0,1,0,201,0,0,4,139,5,213,0,11,0,46,64,21,
6,149,4,2,149,0,129,8,149,4,173,10,5,1,9,7,
3,28,0,4,12,16,252,236,50,212,196,196,49,0,47,236,
236,244,236,16,238,48,178,31,13,1,1,93,19,33,21,33,
17,33,21,33,17,33,21,33,201,3,176,253,26,2,199,253,
57,2,248,252,62,5,213,170,254,70,170,253,227,170,0,1,
0,201,0,0,4,35,5,213,0,9,0,41,64,18,6,149,
4,2,149,0,129,4,173,8,5,1,7,3,28,0,4,10,
16,252,236,50,212,196,49,0,47,236,244,236,16,238,48,178,
15,11,1,1,93,19,33,21,33,17,33,21,33,17,35,201,
3,90,253,112,2,80,253,176,202,5,213,170,254,72,170,253,
55,0,0,1,0,115,255,227,5,139,5,240,0,29,0,57,
64,32,0,5,27,1,149,3,27,149,8,18,161,17,174,21,
149,14,145,8,140,30,2,0,28,17,52,4,51,24,25,11,
16,30,16,252,236,252,228,252,196,49,0,16,228,244,236,244,
236,16,254,212,238,17,57,57,48,37,17,33,53,33,17,6,
4,35,32,0,17,16,0,33,50,4,23,21,38,38,35,32,
0,17,16,0,33,50,54,4,195,254,182,2,18,117,254,230,
160,254,162,254,117,1,139,1,94,146,1,7,111,112,252,139,
254,238,254,237,1,19,1,18,107,168,213,1,145,166,253,127,
83,85,1,153,1,109,1,110,1,153,72,70,215,95,96,254,
206,254,209,254,210,254,206,37,0,1,0,201,0,0,5,59,
5,213,0,11,0,44,64,20,8,149,2,173,4,0,129,10,
6,7,3,28,5,56,9,1,28,0,4,12,16,252,236,50,
252,236,50,49,0,47,60,228,50,252,236,48,178,80,13,1,
1,93,19,51,17,33,17,51,17,35,17,33,17,35,201,202,
2,222,202,202,253,34,202,5,213,253,156,2,100,250,43,2,
199,253,57,0,0,1,0,201,0,0,1,147,5,213,0,3,
0,57,183,0,175,2,1,28,0,4,4,16,252,236,49,0,
47,236,48,1,75,176,16,84,88,189,0,4,255,192,0,1,
0,4,0,4,0,64,56,17,55,56,89,64,13,48,5,64,
5,80,5,96,5,143,5,159,5,6,93,19,51,17,35,201,
202,202,5,213,250,43,0,1,255,150,254,102,1,147,5,213,
0,11,0,77,64,19,11,2,0,7,149,5,176,0,129,12,
5,8,6,57,1,28,0,4,12,16,252,236,228,57,57,49,
0,16,228,252,236,17,57,57,48,1,75,176,16,84,88,189,
0,12,255,192,0,1,0,12,0,12,0,64,56,17,55,56,
89,64,13,48,13,64,13,80,13,96,13,143,13,159,13,6,
93,19,51,17,16,6,43,1,53,51,50,54,53,201,202,205,
227,77,63,134,110,5,213,250,147,254,242,244,170,150,194,0,
0,1,0,201,0,0,5,106,5,213,0,10,0,239,64,40,
8,17,5,6,5,7,17,6,6,5,3,17,4,5,4,2,
17,5,5,4,66,8,5,2,3,3,0,175,9,6,5,1,
4,6,8,1,28,0,4,11,16,252,236,50,212,196,17,57,
49,0,47,60,236,50,23,57,48,75,83,88,7,16,4,237,
7,16,5,237,7,16,5,237,7,16,4,237,89,34,178,8,
3,1,1,93,64,146,20,2,1,4,2,9,8,22,2,40,
5,40,8,55,2,54,5,52,8,71,2,70,5,67,8,85,
2,103,2,118,2,119,5,131,2,136,5,143,8,148,2,155,
8,231,2,21,6,3,9,5,9,6,27,3,25,7,5,10,
3,10,7,24,3,40,5,43,6,42,7,54,4,54,5,54,
6,53,7,48,12,65,3,64,4,69,5,64,6,64,7,64,
12,98,3,96,4,104,5,103,7,119,5,112,12,139,3,139,
5,142,6,143,7,143,12,154,3,157,6,157,7,182,3,181,
7,197,3,197,7,215,3,214,7,232,3,233,4,232,5,234,
6,247,3,248,5,249,6,44,93,113,0,93,113,19,51,17,
1,33,9,1,33,1,17,35,201,202,2,158,1,4,253,27,
3,26,254,246,253,51,202,5,213,253,137,2,119,253,72,252,
227,2,207,253,49,0,0,1,0,201,0,0,4,106,5,213,
0,5,0,37,64,12,2,149,0,129,4,1,28,3,58,0,
4,6,16,252,236,236,49,0,47,228,236,48,64,9,48,7,
80,7,128,3,128,4,4,1,93,19,51,17,33,21,33,201,
202,2,215,252,95,5,213,250,213,170,0,1,0,201,0,0,
6,31,5,213,0,12,0,191,64,52,3,17,7,8,7,2,
17,1,2,8,8,7,2,17,3,2,9,10,9,1,17,10,
10,9,66,10,7,2,3,8,3,0,175,8,11,5,9,8,
3,2,1,5,10,6,28,4,62,10,28,0,4,13,16,252,
236,252,236,17,23,57,49,0,47,60,196,236,50,17,23,57,
48,75,83,88,7,16,5,237,7,16,8,237,7,16,8,237,
7,16,5,237,89,34,178,112,14,1,1,93,64,86,3,7,
15,8,15,9,2,10,21,2,20,7,19,10,38,2,38,7,
32,7,38,10,32,10,52,7,53,10,105,2,124,2,123,7,
121,10,128,2,130,7,130,10,144,2,22,4,1,11,3,19,
1,27,3,35,1,44,3,39,8,40,9,52,1,60,3,86,
8,89,9,101,8,106,9,118,8,121,9,129,1,141,3,149,
1,155,3,20,93,0,93,19,33,9,1,33,17,35,17,1,
35,1,17,35,201,1,45,1,125,1,127,1,45,197,254,127,
203,254,127,196,5,213,252,8,3,248,250,43,5,31,252,0,
4,0,250,225,0,1,0,201,0,0,5,51,5,213,0,9,
0,121,64,30,7,17,1,2,1,2,17,6,7,6,66,7,
2,3,0,175,8,5,6,1,7,2,28,4,54,7,28,0,
4,10,16,252,236,252,236,17,57,57,49,0,47,60,236,50,
57,57,48,75,83,88,7,16,4,237,7,16,4,237,89,34,
178,31,11,1,1,93,64,48,54,2,56,7,72,2,71,7,
105,2,102,7,128,2,7,6,1,9,6,21,1,26,6,70,
1,73,6,87,1,88,6,101,1,105,6,121,6,133,1,138,
6,149,1,154,6,159,11,16,93,0,93,19,33,1,17,51,
17,33,1,17,35,201,1,16,2,150,196,254,240,253,106,196,
5,213,251,31,4,225,250,43,4,225,251,31,0,2,0,115,
255,227,5,217,5,240,0,11,0,23,0,35,64,19,6,149,
18,0,149,12,145,18,140,24,9,25,15,51,3,25,21,16,
24,16,252,236,252,236,49,0,16,228,244,236,16,238,48,1,
34,0,17,16,0,51,50,0,17,16,0,39,32,0,17,16,
0,33,32,0,17,16,0,3,39,220,254,253,1,3,220,220,
1,1,254,255,220,1,58,1,120,254,136,254,198,254,197,254,
135,1,121,5,76,254,184,254,229,254,230,254,184,1,72,1,
26,1,27,1,72,164,254,91,254,158,254,159,254,91,1,164,
1,98,1,98,1,165,0,2,0,201,0,0,4,141,5,213,
0,8,0,19,0,58,64,24,1,149,16,0,149,9,129,18,
16,10,8,2,4,0,5,25,13,63,17,0,28,9,4,20,
16,252,236,50,252,236,17,23,57,49,0,47,244,236,212,236,
48,64,11,15,21,31,21,63,21,95,21,175,21,5,1,93,
1,17,51,50,54,53,52,38,35,37,33,50,4,21,20,4,
43,1,17,35,1,147,254,141,154,154,141,254,56,1,200,251,
1,1,254,255,251,254,202,5,47,253,207,146,135,134,146,166,
227,219,221,226,253,168,0,2,0,115,254,248,5,217,5,240,
0,11,0,29,0,82,64,42,17,16,2,15,1,12,13,12,
14,1,13,13,12,66,15,30,12,6,149,18,0,149,24,145,
18,140,13,30,13,27,15,12,3,9,25,27,51,3,25,21,
16,30,16,252,236,252,236,17,57,57,17,57,49,0,16,196,
228,244,236,16,238,57,18,57,48,75,83,88,7,16,5,237,
7,16,5,237,23,57,89,34,1,34,0,17,16,0,51,50,
0,17,16,0,19,1,35,39,6,6,35,32,0,17,16,0,
33,32,0,17,16,2,3,39,220,254,253,1,3,220,220,1,
1,254,255,63,1,10,244,221,33,35,16,254,197,254,135,1,
121,1,59,1,58,1,120,209,5,76,254,184,254,229,254,230,
254,184,1,72,1,26,1,27,1,72,250,207,254,221,239,2,
2,1,165,1,97,1,98,1,165,254,91,254,158,254,252,254,
142,0,0,2,0,201,0,0,5,84,5,213,0,19,0,28,
0,177,64,53,9,8,7,3,10,6,17,3,4,3,5,17,
4,4,3,66,6,4,0,21,3,4,21,149,9,20,149,13,
129,11,4,5,6,3,17,9,0,28,22,14,5,10,25,25,
4,17,63,20,10,28,12,4,29,16,252,236,50,252,196,236,
17,23,57,17,57,57,57,49,0,47,60,244,236,212,236,18,
57,18,57,18,57,48,75,83,88,7,16,5,237,7,16,5,
237,17,23,57,89,34,178,64,30,1,1,93,64,66,122,19,
1,5,0,5,1,5,2,6,3,7,4,21,0,21,1,20,
2,22,3,23,4,37,0,37,1,37,2,38,3,39,6,38,
7,38,8,38,9,32,30,54,1,54,2,70,1,70,2,104,
5,117,4,117,5,119,19,136,6,136,7,152,6,152,7,31,
93,0,93,1,30,1,23,19,35,3,46,1,43,1,17,35,
17,33,32,22,21,20,6,1,17,51,50,54,53,52,38,35,
3,141,65,123,62,205,217,191,74,139,120,220,202,1,200,1,
0,252,131,253,137,254,146,149,149,146,2,188,22,144,126,254,
104,1,127,150,98,253,137,5,213,214,216,141,186,2,79,253,
238,135,131,131,133,0,0,1,0,135,255,227,4,162,5,240,
0,39,0,126,64,60,13,12,2,14,11,2,30,31,30,8,
9,2,7,10,2,31,31,30,66,10,11,30,31,4,21,1,
0,21,161,20,148,24,149,17,4,149,0,148,37,145,17,140,
40,30,10,11,31,27,7,0,34,27,25,14,45,7,25,20,
34,40,16,220,196,236,252,236,228,17,18,57,57,57,57,49,
0,16,228,244,228,236,16,238,246,238,16,198,17,23,57,48,
75,83,88,7,16,14,237,17,23,57,7,16,14,237,17,23,
57,89,34,178,15,41,1,1,93,182,31,41,47,41,79,41,
3,93,1,21,46,1,35,34,6,21,20,22,31,1,30,1,
21,20,4,33,34,38,39,53,30,1,51,50,54,53,52,38,
47,1,46,1,53,52,36,51,50,22,4,72,115,204,95,165,
179,119,166,122,226,215,254,221,254,231,106,239,128,123,236,114,
173,188,135,154,123,226,202,1,23,245,105,218,5,164,197,55,
54,128,118,99,101,31,25,43,217,182,217,224,48,47,208,69,
70,136,126,110,124,31,24,45,192,171,198,228,38,0,0,1,
255,250,0,0,4,233,5,213,0,7,0,74,64,14,6,2,
149,0,129,4,1,64,3,28,0,64,5,8,16,212,228,252,
228,49,0,47,244,236,50,48,1,75,176,10,84,88,189,0,
8,0,64,0,1,0,8,0,8,255,192,56,17,55,56,89,
64,19,0,9,31,0,16,1,16,2,31,7,16,9,64,9,
112,9,159,9,9,93,3,33,21,33,17,35,17,33,6,4,
239,253,238,203,253,238,5,213,170,250,213,5,43,0,0,1,
0,178,255,227,5,41,5,213,0,17,0,75,64,22,8,2,
17,11,0,5,149,14,140,9,0,129,18,8,28,10,56,1,
28,0,65,18,16,252,236,252,236,49,0,16,228,50,244,236,
17,57,57,57,57,48,1,75,176,16,84,88,189,0,18,0,
64,0,1,0,18,0,18,255,192,56,17,55,56,89,182,31,
19,143,19,159,19,3,93,19,51,17,20,22,51,50,54,53,
17,51,17,16,0,33,32,0,17,178,203,174,195,194,174,203,
254,223,254,230,254,229,254,223,5,213,252,117,240,211,211,240,
3,139,252,92,254,220,254,214,1,42,1,36,0,1,0,16,
0,0,5,104,5,213,0,6,0,183,64,39,4,17,5,6,
5,3,17,2,3,6,6,5,3,17,4,3,0,1,0,2,
17,1,1,0,66,3,4,1,175,0,6,4,3,2,0,5,
5,1,7,16,212,196,23,57,49,0,47,236,50,57,48,75,
83,88,7,16,5,237,7,16,8,237,7,16,8,237,7,16,
5,237,89,34,178,80,8,1,1,93,64,98,0,3,42,3,
71,4,71,5,90,3,125,3,131,3,7,6,0,7,2,8,
4,9,6,21,1,20,2,26,4,26,5,42,0,38,1,38,
2,41,4,41,5,37,6,32,8,56,0,51,1,51,2,60,
4,60,5,55,6,72,0,69,1,69,2,73,4,73,5,71,
6,89,0,86,6,102,2,105,4,105,5,122,0,118,1,118,
2,121,4,121,5,117,6,128,8,152,0,151,6,41,93,0,
93,33,1,51,9,1,51,1,2,74,253,198,211,1,217,1,
218,210,253,199,5,213,251,23,4,233,250,43,0,1,0,68,
0,0,7,166,5,213,0,12,1,123,64,73,5,26,6,5,
9,10,9,4,26,10,9,3,26,10,11,10,2,26,1,2,
11,11,10,6,17,7,8,7,5,17,4,5,8,8,7,2,
17,3,2,12,0,12,1,17,0,0,12,66,10,5,2,3,
6,3,0,175,11,8,12,11,10,9,8,6,5,4,3,2,
1,11,7,0,13,16,212,204,23,57,49,0,47,60,236,50,
50,23,57,48,75,83,88,7,16,5,237,7,16,8,237,7,
16,8,237,7,16,5,237,7,16,8,237,7,16,5,237,7,
5,237,7,16,8,237,89,34,178,0,14,1,1,93,64,242,
6,2,6,5,2,10,0,10,0,10,18,10,40,5,36,10,
32,10,62,2,62,5,52,10,48,10,76,2,77,5,66,10,
64,10,89,2,106,2,107,5,103,10,96,10,123,2,127,2,
124,5,127,5,128,10,150,2,149,5,29,7,0,9,2,8,
3,0,4,6,5,0,5,0,6,1,7,4,8,0,8,7,
9,0,9,4,10,10,12,0,14,26,3,21,4,21,8,25,
12,16,14,32,4,33,5,32,6,32,7,32,8,35,9,36,
10,37,11,32,14,32,14,60,2,58,3,53,4,51,5,48,
8,54,9,57,11,63,12,48,14,70,0,70,1,74,2,64,
4,69,5,64,5,66,6,66,7,66,8,64,8,64,9,68,
10,77,12,64,14,64,14,88,2,86,8,89,12,80,14,102,
2,103,3,97,4,98,5,96,6,96,7,96,8,100,9,100,
10,100,11,119,0,118,1,123,2,120,3,119,4,116,5,121,
6,121,7,119,8,112,8,120,12,127,12,127,14,134,2,135,
3,136,4,137,5,133,9,138,11,143,14,151,4,159,14,175,
14,91,93,0,93,19,51,9,1,51,9,1,51,1,35,9,
1,35,68,204,1,58,1,57,227,1,58,1,57,205,254,137,
254,254,197,254,194,254,5,213,251,18,4,238,251,18,4,238,
250,43,5,16,250,240,0,1,0,61,0,0,5,59,5,213,
0,11,1,93,64,70,9,17,10,11,10,8,17,7,8,11,
11,10,8,17,9,8,5,6,5,7,17,6,6,5,3,17,
4,5,4,2,17,1,2,5,5,4,2,17,3,2,11,0,
11,1,17,0,0,11,66,11,8,5,2,4,3,0,175,9,
6,11,8,5,2,4,0,4,6,0,10,12,16,212,196,220,
196,17,23,57,49,0,47,60,236,50,23,57,48,75,83,88,
7,16,5,237,7,16,8,237,7,16,8,237,7,16,5,237,
7,16,5,237,7,16,8,237,7,16,8,237,7,16,5,237,
89,34,1,75,176,12,84,75,176,13,84,91,75,176,14,84,
91,88,189,0,12,255,192,0,1,0,12,0,12,0,64,56,
17,55,56,89,64,184,7,2,8,8,22,2,25,8,23,11,
39,8,39,11,52,2,56,8,54,11,75,8,88,5,91,8,
102,2,107,8,119,2,119,11,134,2,128,2,135,5,139,8,
133,11,148,2,144,2,151,5,157,8,150,11,27,6,1,9,
3,8,7,7,9,22,1,25,3,25,7,23,9,16,13,38,
1,40,2,41,3,38,5,40,7,39,9,41,11,32,13,53,
0,52,1,60,3,59,4,58,6,59,7,52,9,52,10,56,
11,63,13,72,9,79,13,88,11,95,13,101,0,101,1,106,
3,106,4,104,5,105,6,105,7,108,9,108,10,120,3,121,
6,121,7,120,8,125,9,127,10,120,11,128,0,128,1,131,
2,136,3,133,5,132,8,131,11,143,13,144,0,144,1,148,
2,151,5,151,6,149,8,147,11,159,13,175,13,64,93,0,
93,19,51,9,1,51,9,1,35,9,1,35,1,129,217,1,
115,1,117,217,254,32,2,0,217,254,92,254,89,218,2,21,
5,213,253,213,2,43,253,51,252,248,2,123,253,133,3,29,
0,1,255,252,0,0,4,231,5,213,0,8,0,148,64,40,
3,17,4,5,4,2,17,1,2,5,5,4,2,17,3,2,
8,0,8,1,17,0,0,8,66,2,3,0,175,6,2,7,
4,64,5,28,0,64,7,9,16,212,228,252,228,18,57,49,
0,47,236,50,57,48,75,83,88,7,16,5,237,7,16,8,
237,7,16,8,237,7,16,5,237,89,34,178,0,10,1,1,
93,64,60,5,2,20,2,53,2,48,2,48,5,48,8,70,
2,64,2,64,5,64,8,81,2,81,5,81,8,101,2,132,
2,147,2,16,22,1,26,3,31,10,38,1,41,3,55,1,
56,3,64,10,103,1,104,3,120,3,112,10,159,10,13,93,
0,93,3,51,9,1,51,1,17,35,17,4,217,1,158,1,
155,217,253,240,203,5,213,253,154,2,102,252,242,253,57,2,
199,0,0,1,0,92,0,0,5,31,5,213,0,9,0,155,
64,27,3,17,7,8,7,8,17,2,3,2,66,8,149,0,
129,3,149,5,8,3,0,1,66,4,0,6,10,16,220,196,
212,228,17,57,57,49,0,47,236,244,236,48,75,83,88,7,
16,5,237,7,16,5,237,89,34,1,75,176,9,84,75,176,
10,84,91,88,189,0,10,0,64,0,1,0,10,0,10,255,
192,56,17,55,56,89,64,64,5,2,10,7,24,7,41,2,
38,7,56,7,72,2,71,7,72,8,9,5,3,11,8,0,
11,22,3,26,8,16,11,47,11,53,3,57,8,63,11,71,
3,74,8,79,11,85,3,89,8,102,3,105,8,111,11,119,
3,120,8,127,11,159,11,22,93,0,93,19,33,21,1,33,
21,33,53,1,33,115,4,149,252,80,3,199,251,61,3,176,
252,103,5,213,154,251,111,170,154,4,145,0,0,1,0,176,
254,242,2,88,6,20,0,7,0,83,64,15,4,169,6,178,
2,169,0,177,8,5,1,3,67,0,8,16,220,252,204,50,
49,0,16,252,236,244,236,48,1,75,176,12,84,88,189,0,
8,255,192,0,1,0,8,0,8,0,64,56,17,55,56,89,
1,75,176,18,84,75,176,19,84,91,88,189,0,8,0,64,
0,1,0,8,0,8,255,192,56,17,55,56,89,19,33,21,
35,17,51,21,33,176,1,168,240,240,254,88,6,20,143,249,
252,143,0,1,0,0,255,66,2,178,5,213,0,3,0,45,
64,20,2,26,1,1,0,0,26,3,3,2,66,1,159,0,
129,4,2,0,1,3,47,196,57,57,49,0,16,244,236,48,
75,83,88,7,16,5,237,7,16,5,237,89,34,19,1,35,
1,170,2,8,170,253,248,5,213,249,109,6,147,0,0,1,
0,199,254,242,2,111,6,20,0,7,0,60,64,16,3,169,
1,178,5,169,0,177,8,0,67,4,6,2,4,8,16,252,
60,220,236,49,0,16,252,236,244,236,48,1,75,176,15,84,
75,176,16,84,91,88,189,0,8,255,192,0,1,0,8,0,
8,0,64,56,17,55,56,89,1,17,33,53,51,17,35,53,
2,111,254,88,239,239,6,20,248,222,143,6,4,143,0,1,
0,217,3,168,5,219,5,213,0,6,0,24,64,10,3,4,
1,0,129,7,3,1,5,7,16,220,204,57,49,0,16,244,
204,50,57,48,1,1,35,1,1,35,1,3,188,2,31,201,
254,72,254,72,201,2,31,5,213,253,211,1,139,254,117,2,
45,0,0,1,255,236,254,29,4,20,254,172,0,3,0,15,
181,0,169,1,0,2,4,16,196,196,49,0,212,236,48,1,
21,33,53,4,20,251,216,254,172,143,143,0,0,1,0,170,
4,240,2,137,6,102,0,3,0,49,64,9,1,180,0,179,
4,3,68,1,4,16,220,236,49,0,16,244,236,48,0,75,
176,9,84,75,176,14,84,91,88,189,0,4,255,192,0,1,
0,4,0,4,0,64,56,17,55,56,89,9,1,35,1,1,
111,1,26,153,254,186,6,102,254,138,1,118,0,2,0,123,
255,227,4,45,4,123,0,10,0,37,0,188,64,39,25,31,
11,23,9,14,0,169,23,6,185,14,17,32,134,31,186,28,
185,35,184,17,140,23,12,0,23,3,24,13,9,8,11,31,
3,8,20,69,38,16,252,236,204,212,236,50,50,17,57,57,
49,0,47,196,228,244,252,244,236,16,198,238,16,238,17,57,
17,57,18,57,48,64,110,48,29,48,30,48,31,48,32,48,
33,48,34,63,39,64,29,64,30,64,31,64,32,64,33,64,
34,80,29,80,30,80,31,80,32,80,33,80,34,80,39,112,
39,133,29,135,30,135,31,135,32,135,33,133,34,144,39,160,
39,240,39,30,48,30,48,31,48,32,48,33,64,30,64,31,
64,32,64,33,80,30,80,31,80,32,80,33,96,30,96,31,
96,32,96,33,112,30,112,31,112,32,112,33,128,30,128,31,
128,32,128,33,24,93,1,93,1,34,6,21,20,22,51,50,
54,61,1,55,17,35,53,14,1,35,34,38,53,52,54,51,
33,53,52,38,35,34,6,7,53,62,1,51,50,22,2,190,
223,172,129,111,153,185,184,184,63,188,136,172,203,253,251,1,
2,167,151,96,182,84,101,190,90,243,240,2,51,102,123,98,
115,217,180,41,76,253,129,170,102,97,193,162,189,192,18,127,
139,46,46,170,39,39,252,0,0,2,0,186,255,227,4,164,
6,20,0,11,0,28,0,56,64,25,3,185,12,15,9,185,
24,21,140,15,184,27,151,25,0,18,18,71,24,12,6,8,
26,70,29,16,252,236,50,50,244,236,49,0,47,236,228,244,
196,236,16,198,238,48,182,96,30,128,30,160,30,3,1,93,
1,52,38,35,34,6,21,20,22,51,50,54,1,62,1,51,
50,18,17,16,2,35,34,38,39,21,35,17,51,3,229,167,
146,146,167,167,146,146,167,253,142,58,177,123,204,255,255,204,
123,177,58,185,185,2,47,203,231,231,203,203,231,231,2,82,
100,97,254,188,254,248,254,248,254,188,97,100,168,6,20,0,
0,1,0,113,255,227,3,231,4,123,0,25,0,63,64,27,
0,134,1,136,4,14,134,13,136,10,185,17,4,185,23,184,
17,140,26,7,18,13,0,72,20,69,26,16,252,228,50,236,
49,0,16,228,244,236,16,254,244,238,16,245,238,48,64,11,
15,27,16,27,128,27,144,27,160,27,5,1,93,1,21,46,
1,35,34,6,21,20,22,51,50,54,55,21,14,1,35,34,
0,17,16,0,33,50,22,3,231,78,157,80,179,198,198,179,
80,157,78,77,165,93,253,254,214,1,45,1,6,85,162,4,
53,172,43,43,227,205,205,227,43,43,170,36,36,1,62,1,
14,1,18,1,58,35,0,2,0,113,255,227,4,90,6,20,
0,16,0,28,0,56,64,25,26,185,0,14,20,185,5,8,
140,14,184,1,151,3,23,4,0,8,2,71,17,18,11,69,
29,16,252,236,244,236,50,50,49,0,47,236,228,244,196,236,
16,196,238,48,182,96,30,128,30,160,30,3,1,93,1,17,
51,17,35,53,14,1,35,34,2,17,16,18,51,50,22,1,
20,22,51,50,54,53,52,38,35,34,6,3,162,184,184,58,
177,124,203,255,255,203,124,177,253,199,167,146,146,168,168,146,
146,167,3,182,2,94,249,236,168,100,97,1,68,1,8,1,
8,1,68,97,254,21,203,231,231,203,203,231,231,0,0,2,
0,113,255,227,4,127,4,123,0,20,0,27,0,112,64,36,
0,21,1,9,134,8,136,5,21,169,1,5,185,12,1,187,
24,185,18,184,12,140,28,27,21,2,8,21,8,0,75,2,
18,15,69,28,16,252,236,244,236,196,17,18,57,49,0,16,
228,244,236,228,16,238,16,238,16,244,238,17,18,57,48,64,
41,63,29,112,29,160,29,208,29,240,29,5,63,0,63,1,
63,2,63,21,63,27,5,44,7,47,8,47,9,44,10,111,
0,111,1,111,2,111,21,111,27,9,93,113,1,93,1,21,
33,30,1,51,50,54,55,21,14,1,35,32,0,17,16,0,
51,50,0,7,46,1,35,34,6,7,4,127,252,178,12,205,
183,106,199,98,99,208,107,254,244,254,199,1,41,252,226,1,
7,184,2,165,136,154,185,14,2,94,90,190,199,52,52,174,
42,44,1,56,1,10,1,19,1,67,254,221,196,151,180,174,
158,0,0,1,0,47,0,0,2,248,6,20,0,19,0,112,
64,28,5,16,1,12,8,169,6,1,135,0,151,14,6,188,
10,2,19,7,0,7,9,5,8,13,15,11,76,20,16,252,
60,196,252,60,196,196,18,57,57,49,0,47,228,50,252,236,
16,238,50,18,57,57,48,1,75,176,10,84,88,189,0,20,
255,192,0,1,0,20,0,20,0,64,56,17,55,56,89,1,
75,176,14,84,88,189,0,20,0,64,0,1,0,20,0,20,
255,192,56,17,55,56,89,182,64,21,80,21,160,21,3,93,
1,21,35,34,6,29,1,33,21,33,17,35,17,35,53,51,
53,52,54,51,2,248,176,99,77,1,47,254,209,185,176,176,
174,189,6,20,153,80,104,99,143,252,47,3,209,143,78,187,
171,0,0,2,0,113,254,86,4,90,4,123,0,11,0,40,
0,74,64,35,25,12,29,9,18,134,19,22,185,15,3,185,
38,35,184,39,188,9,185,15,189,26,29,38,25,0,8,12,
71,6,18,18,32,69,41,16,252,196,236,244,236,50,50,49,
0,47,196,228,236,228,244,196,236,16,254,213,238,17,18,57,
57,48,182,96,42,128,42,160,42,3,1,93,1,52,38,35,
34,6,21,20,22,51,50,54,23,16,2,33,34,38,39,53,
30,1,51,50,54,61,1,14,1,35,34,2,17,16,18,51,
50,22,23,53,51,3,162,165,149,148,165,165,148,149,165,184,
254,254,250,97,172,81,81,158,82,181,180,57,178,124,206,252,
252,206,124,178,57,184,2,61,200,220,220,200,199,220,220,235,
254,226,254,233,29,30,179,44,42,189,191,91,99,98,1,58,
1,3,1,4,1,58,98,99,170,0,0,1,0,186,0,0,
4,100,6,20,0,19,0,52,64,25,3,9,0,3,14,1,
6,135,14,17,184,12,151,10,1,2,8,0,78,13,9,8,
11,70,20,16,252,236,50,244,236,49,0,47,60,236,244,196,
236,17,18,23,57,48,178,96,21,1,1,93,1,17,35,17,
52,38,35,34,6,21,17,35,17,51,17,62,1,51,50,22,
4,100,184,124,124,149,172,185,185,66,179,117,193,198,2,164,
253,92,2,158,159,158,190,164,253,135,6,20,253,158,101,100,
239,0,0,2,0,193,0,0,1,121,6,20,0,3,0,7,
0,43,64,14,6,190,4,177,0,188,2,5,1,8,4,0,
70,8,16,252,60,236,50,49,0,47,228,252,236,48,64,11,
16,9,64,9,80,9,96,9,112,9,5,1,93,19,51,17,
35,17,51,21,35,193,184,184,184,184,4,96,251,160,6,20,
233,0,0,2,255,219,254,86,1,121,6,20,0,11,0,15,
0,68,64,28,11,2,7,0,14,190,12,7,135,5,189,0,
188,12,177,16,8,16,5,6,79,13,1,8,12,0,70,16,
16,252,60,236,50,228,57,18,57,49,0,16,236,228,244,236,
16,238,17,18,57,57,48,64,11,16,17,64,17,80,17,96,
17,112,17,5,1,93,19,51,17,20,6,43,1,53,51,50,
54,53,17,51,21,35,193,184,163,181,70,49,105,76,184,184,
4,96,251,140,214,192,156,97,153,6,40,233,0,1,0,186,
0,0,4,156,6,20,0,10,0,188,64,41,8,17,5,6,
5,7,17,6,6,5,3,17,4,5,4,2,17,5,5,4,
66,8,5,2,3,3,188,0,151,9,6,5,1,4,6,8,
1,8,0,70,11,16,252,236,50,212,196,17,57,49,0,47,
60,236,228,23,57,48,75,83,88,7,16,4,237,7,16,5,
237,7,16,5,237,7,16,4,237,89,34,178,16,12,1,1,
93,64,95,4,2,10,8,22,2,39,2,41,5,43,8,86,
2,102,2,103,8,115,2,119,5,130,2,137,5,142,8,147,
2,150,5,151,8,163,2,18,9,5,9,6,2,11,3,10,
7,40,3,39,4,40,5,43,6,43,7,64,12,104,3,96,
12,137,3,133,4,137,5,141,6,143,7,154,3,151,7,170,
3,167,5,182,7,197,7,214,7,247,3,240,3,247,4,240,
4,26,93,113,0,93,19,51,17,1,51,9,1,35,1,17,
35,186,185,2,37,235,253,174,2,107,240,253,199,185,6,20,
252,105,1,227,253,244,253,172,2,35,253,221,0,1,0,193,
0,0,1,121,6,20,0,3,0,34,183,0,151,2,1,8,
0,70,4,16,252,236,49,0,47,236,48,64,13,16,5,64,
5,80,5,96,5,112,5,240,5,6,1,93,19,51,17,35,
193,184,184,6,20,249,236,0,0,1,0,186,0,0,7,29,
4,123,0,34,0,90,64,38,6,18,9,24,15,0,6,29,
7,21,12,135,29,32,3,184,27,188,25,16,7,0,17,15,
8,8,6,80,17,8,15,80,28,24,8,26,70,35,16,252,
236,50,252,252,252,236,17,18,57,49,0,47,60,60,228,244,
60,196,236,50,17,18,23,57,48,64,19,48,36,80,36,112,
36,144,36,160,36,160,36,191,36,223,36,255,36,9,1,93,
1,62,1,51,50,22,21,17,35,17,52,38,35,34,6,21,
17,35,17,52,38,35,34,6,21,17,35,17,51,21,62,1,
51,50,22,4,41,69,192,130,175,190,185,114,117,143,166,185,
114,119,141,166,185,185,63,176,121,122,171,3,137,124,118,245,
226,253,92,2,158,161,156,190,164,253,135,2,158,162,155,191,
163,253,135,4,96,174,103,98,124,0,0,1,0,186,0,0,
4,100,4,123,0,19,0,54,64,25,3,9,0,3,14,1,
6,135,14,17,184,12,188,10,1,2,8,0,78,13,9,8,
11,70,20,16,252,236,50,244,236,49,0,47,60,228,244,196,
236,17,18,23,57,48,180,96,21,207,21,2,1,93,1,17,
35,17,52,38,35,34,6,21,17,35,17,51,21,62,1,51,
50,22,4,100,184,124,124,149,172,185,185,66,179,117,193,198,
2,164,253,92,2,158,159,158,190,164,253,135,4,96,174,101,
100,239,0,2,0,113,255,227,4,117,4,123,0,11,0,23,
0,74,64,19,6,185,18,0,185,12,184,18,140,24,9,18,
15,81,3,18,21,69,24,16,252,236,244,236,49,0,16,228,
244,236,16,238,48,64,35,63,25,123,0,123,6,127,7,127,
8,127,9,127,10,127,11,123,12,127,13,127,14,127,15,127,
16,127,17,123,18,160,25,240,25,17,1,93,1,34,6,21,
20,22,51,50,54,53,52,38,39,50,0,17,16,0,35,34,
0,17,16,0,2,115,148,172,171,149,147,172,172,147,240,1,
18,254,238,240,241,254,239,1,17,3,223,231,201,201,231,232,
200,199,233,156,254,200,254,236,254,237,254,199,1,57,1,19,
1,20,1,56,0,2,0,186,254,86,4,164,4,123,0,16,
0,28,0,62,64,27,26,185,0,14,20,185,5,8,184,14,
140,1,189,3,188,29,17,18,11,71,23,4,0,8,2,70,
29,16,252,236,50,50,244,236,49,0,16,228,228,228,244,196,
236,16,196,238,48,64,9,96,30,128,30,160,30,224,30,4,
1,93,37,17,35,17,51,21,62,1,51,50,18,17,16,2,
35,34,38,1,52,38,35,34,6,21,20,22,51,50,54,1,
115,185,185,58,177,123,204,255,255,204,123,177,2,56,167,146,
146,167,167,146,146,167,168,253,174,6,10,170,100,97,254,188,
254,248,254,248,254,188,97,1,235,203,231,231,203,203,231,231,
0,2,0,113,254,86,4,90,4,123,0,11,0,28,0,62,
64,27,3,185,12,15,9,185,24,21,184,15,140,27,189,25,
188,29,24,12,6,8,26,71,0,18,18,69,29,16,252,236,
244,236,50,50,49,0,16,228,228,228,244,196,236,16,198,238,
48,64,9,96,30,128,30,160,30,224,30,4,1,93,1,20,
22,51,50,54,53,52,38,35,34,6,1,14,1,35,34,2,
17,16,18,51,50,22,23,53,51,17,35,1,47,167,146,146,
168,168,146,146,167,2,115,58,177,124,203,255,255,203,124,177,
58,184,184,2,47,203,231,231,203,203,231,231,253,174,100,97,
1,68,1,8,1,8,1,68,97,100,170,249,246,0,0,1,
0,186,0,0,3,74,4,123,0,17,0,48,64,20,6,11,
7,0,17,11,3,135,14,184,9,188,7,10,6,8,0,8,
70,18,16,252,196,236,50,49,0,47,228,244,236,196,212,204,
17,18,57,48,180,80,19,159,19,2,1,93,1,46,1,35,
34,6,21,17,35,17,51,21,62,1,51,50,22,23,3,74,
31,73,44,156,167,185,185,58,186,133,19,46,28,3,180,18,
17,203,190,253,178,4,96,174,102,99,5,5,0,1,0,111,
255,227,3,199,4,123,0,39,0,231,64,60,13,12,2,14,
11,83,31,30,8,9,2,7,10,83,30,31,30,66,10,11,
30,31,4,21,0,134,1,137,4,20,134,21,137,24,185,17,
4,185,37,184,17,140,40,30,10,11,31,27,7,0,82,27,
8,14,7,8,20,34,69,40,16,252,196,236,212,236,228,17,
18,57,57,57,57,49,0,16,228,244,236,16,254,245,238,16,
245,238,18,23,57,48,75,83,88,7,16,14,237,17,23,57,
7,14,237,17,23,57,89,34,178,0,39,1,1,93,64,109,
28,10,28,11,28,12,46,9,44,10,44,11,44,12,59,9,
59,10,59,11,59,12,11,32,0,32,1,36,2,40,10,40,
11,42,19,47,20,47,21,42,22,40,30,40,31,41,32,41,
33,36,39,134,10,134,11,134,12,134,13,18,0,0,0,1,
2,2,6,10,6,11,3,12,3,13,3,14,3,15,3,16,
3,25,3,26,3,27,3,28,4,29,9,39,47,41,63,41,
95,41,127,41,128,41,144,41,160,41,240,41,24,93,0,93,
113,1,21,46,1,35,34,6,21,20,22,31,1,30,1,21,
20,6,35,34,38,39,53,30,1,51,50,54,53,52,38,47,
1,46,1,53,52,54,51,50,22,3,139,78,168,90,137,137,
98,148,63,196,165,247,216,90,195,108,102,198,97,130,140,101,
171,64,171,152,224,206,102,180,4,63,174,40,40,84,84,64,
73,33,14,42,153,137,156,182,35,35,190,53,53,89,81,75,
80,37,15,36,149,130,158,172,30,0,0,1,0,55,0,0,
2,242,5,158,0,19,0,56,64,25,14,5,8,15,3,169,
0,17,1,188,8,135,10,11,8,9,2,4,0,8,16,18,
14,70,20,16,252,60,196,252,60,196,50,57,57,49,0,47,
236,244,60,196,236,50,17,57,57,48,178,175,21,1,1,93,
1,17,33,21,33,17,20,22,59,1,21,35,34,38,53,17,
35,53,51,17,1,119,1,123,254,133,75,115,189,189,213,162,
135,135,5,158,254,194,143,253,160,137,78,154,159,210,2,96,
143,1,62,0,0,1,0,174,255,227,4,88,4,96,0,19,
0,54,64,25,3,9,0,3,14,1,6,135,14,17,140,10,
1,188,12,13,9,8,11,78,2,8,0,70,20,16,252,236,
244,236,50,49,0,47,228,50,244,196,236,17,18,23,57,48,
180,96,21,207,21,2,1,93,19,17,51,17,20,22,51,50,
54,53,17,51,17,35,53,14,1,35,34,38,174,184,124,124,
149,173,184,184,67,177,117,193,200,1,186,2,166,253,97,159,
159,190,164,2,123,251,160,172,102,99,240,0,0,1,0,61,
0,0,4,127,4,96,0,6,1,18,64,39,3,17,4,5,
4,2,17,1,2,5,5,4,2,17,3,2,6,0,6,1,
17,0,0,6,66,2,3,0,191,5,6,5,3,2,1,5,
4,0,7,16,212,196,23,57,49,0,47,236,50,57,48,75,
83,88,7,16,5,237,7,16,8,237,7,16,8,237,7,16,
5,237,89,34,1,75,176,10,84,88,189,0,7,255,192,0,
1,0,7,0,7,0,64,56,17,55,56,89,1,75,176,20,
84,75,176,21,84,91,88,189,0,7,0,64,0,1,0,7,
0,7,255,192,56,17,55,56,89,64,142,72,2,106,2,123,
2,127,2,134,2,128,2,145,2,164,2,8,6,0,6,1,
9,3,9,4,21,0,21,1,26,3,26,4,38,0,38,1,
41,3,41,4,32,8,53,0,53,1,58,3,58,4,48,8,
70,0,70,1,73,3,73,4,70,5,72,6,64,8,86,0,
86,1,89,3,89,4,80,8,102,0,102,1,105,3,105,4,
103,5,104,6,96,8,117,0,116,1,123,3,123,4,117,5,
122,6,133,0,133,1,137,3,137,4,137,5,134,6,150,0,
150,1,151,2,154,3,152,4,152,5,151,6,168,5,167,6,
176,8,192,8,223,8,255,8,62,93,0,93,19,51,9,1,
51,1,35,61,195,1,94,1,94,195,254,92,250,4,96,252,
84,3,172,251,160,0,0,1,0,86,0,0,6,53,4,96,
0,12,2,1,64,73,5,85,6,5,9,10,9,4,85,10,
9,3,85,10,11,10,2,85,1,2,11,11,10,6,17,7,
8,7,5,17,4,5,8,8,7,2,17,3,2,12,0,12,
1,17,0,0,12,66,10,5,2,3,6,3,0,191,11,8,
12,11,10,9,8,6,5,4,3,2,1,11,7,0,13,16,
212,204,23,57,49,0,47,60,236,50,50,23,57,48,75,83,
88,7,16,5,237,7,16,8,237,7,16,8,237,7,16,5,
237,7,16,8,237,7,16,5,237,7,5,237,7,16,8,237,
89,34,1,75,176,10,84,75,176,17,84,91,75,176,18,84,
91,75,176,19,84,91,75,176,11,84,91,88,189,0,13,255,
192,0,1,0,13,0,13,0,64,56,17,55,56,89,1,75,
176,12,84,75,176,13,84,91,75,176,16,84,91,88,189,0,
13,0,64,0,1,0,13,0,13,255,192,56,17,55,56,89,
64,255,5,2,22,2,22,5,34,10,53,10,73,2,73,5,
70,10,64,10,91,2,91,5,85,10,80,10,110,2,110,5,
102,10,121,2,127,2,121,5,127,5,135,2,153,2,152,5,
148,10,188,2,188,5,206,2,199,3,207,5,29,5,2,9,
3,6,4,11,5,10,8,11,9,4,11,5,12,21,2,25,
3,22,4,26,5,27,8,27,9,20,11,21,12,37,0,37,
1,35,2,39,3,33,4,37,5,34,6,34,7,37,8,39,
9,36,10,33,11,35,12,57,3,54,4,54,8,57,12,48,
14,70,2,72,3,70,4,64,4,66,5,64,6,64,7,64,
8,68,9,68,10,68,11,64,14,64,14,86,0,86,1,86,
2,80,4,81,5,82,6,82,7,80,8,83,9,84,10,85,
11,99,0,100,1,101,2,106,3,101,4,106,5,106,6,106,
7,110,9,97,11,103,12,111,14,117,0,117,1,121,2,125,
3,120,4,125,5,122,6,127,6,122,7,127,7,120,8,121,
9,127,9,123,10,118,11,125,12,135,2,136,5,143,14,151,
0,151,1,148,2,147,3,156,4,155,5,152,6,152,7,153,
8,64,47,150,12,159,14,166,0,166,1,164,2,164,3,171,
4,171,5,169,6,169,7,171,8,164,12,175,14,181,2,177,
3,189,4,187,5,184,9,191,14,196,2,195,3,204,4,202,
5,121,93,0,93,19,51,27,1,51,27,1,51,1,35,11,
1,35,86,184,230,229,217,230,229,184,254,219,217,241,242,217,
4,96,252,150,3,106,252,150,3,106,251,160,3,150,252,106,
0,1,0,59,0,0,4,121,4,96,0,11,1,90,64,70,
5,17,6,7,6,4,17,3,4,7,7,6,4,17,5,4,
1,2,1,3,17,2,2,1,11,17,0,1,0,10,17,9,
10,1,1,0,10,17,11,10,7,8,7,9,17,8,8,7,
66,10,7,4,1,4,8,0,191,5,2,10,7,4,1,4,
8,0,2,8,6,12,16,212,196,212,196,17,23,57,49,0,
47,60,236,50,23,57,48,75,83,88,7,16,5,237,7,16,
8,237,7,16,8,237,7,16,5,237,7,16,5,237,7,16,
8,237,7,16,8,237,7,16,5,237,89,34,1,75,176,10,
84,75,176,15,84,91,75,176,16,84,91,75,176,17,84,91,
88,189,0,12,255,192,0,1,0,12,0,12,0,64,56,17,
55,56,89,1,75,176,20,84,88,189,0,12,0,64,0,1,
0,12,0,12,255,192,56,17,55,56,89,64,152,10,4,4,
10,26,4,21,10,38,10,61,4,49,10,85,4,87,7,88,
10,102,10,118,1,122,4,118,7,116,10,141,4,130,10,153,
4,159,4,151,7,146,10,144,10,166,1,169,4,175,4,165,
7,163,10,160,10,28,10,3,4,5,5,9,10,11,26,3,
21,5,21,9,26,11,41,3,38,5,37,9,42,11,32,13,
58,1,57,3,55,5,52,7,54,9,57,11,48,13,73,3,
70,5,69,9,74,11,64,13,89,0,86,1,89,2,89,3,
87,5,86,6,89,7,86,8,86,9,89,11,80,13,111,13,
120,1,127,13,155,1,148,7,171,1,164,7,176,13,207,13,
223,13,255,13,47,93,0,93,9,2,35,9,1,35,9,1,
51,9,1,4,100,254,107,1,170,217,254,186,254,186,217,1,
179,254,114,217,1,41,1,41,4,96,253,223,253,193,1,184,
254,72,2,74,2,22,254,113,1,143,0,1,0,61,254,86,
4,127,4,96,0,15,1,162,64,67,7,8,2,9,17,0,
15,10,17,11,10,0,0,15,14,17,15,0,15,13,17,12,
13,0,0,15,13,17,14,13,10,11,10,12,17,11,11,10,
66,13,11,9,16,0,11,5,135,3,189,14,11,188,16,14,
13,12,10,9,6,3,0,8,15,4,15,11,16,16,212,196,
196,17,23,57,49,0,16,228,50,244,236,17,57,17,57,18,
57,48,75,83,88,7,16,5,237,7,16,8,237,7,16,8,
237,7,16,5,237,7,16,8,237,7,5,237,23,50,89,34,
1,75,176,10,84,75,176,8,84,91,88,189,0,16,255,192,
0,1,0,16,0,16,0,64,56,17,55,56,89,1,75,176,
20,84,88,189,0,16,0,64,0,1,0,16,0,16,255,192,
56,17,55,56,89,64,240,6,0,5,8,6,9,3,13,22,
10,23,13,16,13,35,13,53,13,73,10,79,10,78,13,90,
9,90,10,106,10,135,13,128,13,147,13,18,10,0,10,9,
6,11,5,12,11,14,11,15,23,1,21,2,16,4,16,5,
23,10,20,11,20,12,26,14,26,15,39,0,36,1,36,2,
32,4,32,5,41,8,40,9,37,10,36,11,36,12,39,13,
42,14,42,15,32,17,55,0,53,1,53,2,48,4,48,5,
56,10,54,11,54,12,56,13,57,14,57,15,48,17,65,0,
64,1,64,2,64,3,64,4,64,5,64,6,64,7,64,8,
66,9,69,10,71,13,73,14,73,15,64,17,84,0,81,1,
81,2,85,3,80,4,80,5,86,6,85,7,86,8,87,9,
87,10,85,11,85,12,89,14,89,15,80,17,102,1,102,2,
104,10,105,14,105,15,96,17,123,8,120,14,120,15,137,0,
138,9,133,11,133,12,137,13,137,14,137,15,153,9,149,11,
149,12,154,14,154,15,164,11,164,12,171,14,171,15,176,17,
207,17,223,17,255,17,101,93,0,93,5,14,1,43,1,53,
51,50,54,63,1,1,51,9,1,51,2,147,78,148,124,147,
108,76,84,51,33,254,59,195,1,94,1,94,195,104,200,122,
154,72,134,84,4,78,252,148,3,108,0,1,0,88,0,0,
3,219,4,96,0,9,0,180,64,26,8,17,2,3,2,3,
17,7,8,7,66,8,169,0,188,3,169,5,8,3,1,0,
4,1,6,10,16,220,196,50,196,17,57,57,49,0,47,236,
244,236,48,75,83,88,7,16,5,237,7,16,5,237,89,34,
1,75,176,11,84,75,176,12,84,91,88,189,0,10,0,64,
0,1,0,10,0,10,255,192,56,17,55,56,89,1,75,176,
19,84,88,189,0,10,255,192,0,1,0,10,0,10,0,64,
56,17,55,56,89,64,66,5,2,22,2,38,2,71,2,73,
7,5,11,8,15,11,24,3,27,8,43,8,32,11,54,3,
57,8,48,11,64,1,64,2,69,3,64,4,64,5,67,8,
87,3,89,8,95,11,96,1,96,2,102,3,96,4,96,5,
98,8,127,11,128,11,175,11,27,93,0,93,19,33,21,1,
33,21,33,53,1,33,113,3,106,253,76,2,180,252,125,2,
180,253,101,4,96,168,252,219,147,168,3,37,0,1,1,0,
254,178,4,23,6,20,0,36,0,130,64,52,25,15,21,11,
6,37,9,26,16,21,29,11,5,32,33,3,0,11,169,9,
0,169,1,192,9,21,169,19,177,37,12,9,10,5,36,22,
25,0,29,10,5,19,2,20,0,32,25,67,10,15,5,37,
16,212,60,196,252,60,196,50,57,57,17,18,57,17,18,57,
57,17,18,57,57,49,0,16,252,236,196,244,236,16,238,18,
23,57,18,57,17,57,57,17,18,57,17,18,57,57,48,1,
75,176,12,84,88,189,0,37,255,192,0,1,0,37,0,37,
0,64,56,17,55,56,89,178,0,38,1,93,5,21,35,34,
38,61,1,52,38,43,1,53,51,50,54,61,1,52,54,59,
1,21,35,34,6,29,1,20,6,7,30,1,29,1,20,22,
51,4,23,62,249,169,108,142,61,61,143,107,169,249,62,68,
141,86,91,110,111,90,86,141,190,144,148,221,239,151,116,143,
115,149,240,221,147,143,88,141,248,157,142,25,27,142,156,248,
141,88,0,1,1,4,254,29,1,174,6,29,0,3,0,18,
183,1,0,177,4,0,5,2,4,16,212,236,49,0,16,252,
204,48,1,17,35,17,1,174,170,6,29,248,0,8,0,0,
0,1,1,0,254,178,4,23,6,20,0,36,0,158,64,54,
31,37,27,22,12,15,8,27,11,21,25,15,4,5,32,3,
0,25,169,27,0,169,35,192,27,15,169,17,177,37,28,25,
26,21,15,1,4,0,8,26,21,35,18,4,0,26,31,21,
67,16,0,11,4,37,16,212,60,196,50,252,60,196,17,18,
57,57,17,18,57,17,18,57,57,17,18,57,57,49,0,16,
252,236,196,244,236,16,238,18,23,57,17,18,57,57,17,57,
17,57,57,17,18,57,48,1,75,176,10,84,88,189,0,37,
0,64,0,1,0,37,0,37,255,192,56,17,55,56,89,1,
75,176,14,84,88,189,0,37,255,192,0,1,0,37,0,37,
0,64,56,17,55,56,89,178,0,38,1,93,5,51,50,54,
61,1,52,54,55,46,1,61,1,52,38,43,1,53,51,50,
22,29,1,20,22,59,1,21,35,34,6,29,1,20,6,43,
1,1,0,70,140,85,90,111,111,90,85,140,70,63,249,167,
108,142,62,62,142,108,167,249,63,190,86,143,248,156,142,27,
25,142,157,248,142,87,143,147,221,240,149,115,143,116,151,239,
221,148,0,1,0,217,1,211,5,219,3,49,0,29,0,35,
64,16,1,16,27,12,0,19,4,156,27,19,156,12,30,0,
15,30,16,212,196,49,0,16,212,252,212,236,16,192,17,18,
57,57,48,1,21,6,6,35,34,39,38,39,38,39,38,35,
34,6,7,53,54,54,51,50,23,22,23,22,23,22,51,50,
54,5,219,105,179,97,110,146,11,5,7,15,155,94,88,172,
98,105,179,97,110,147,10,5,8,14,155,94,86,169,3,49,
178,79,68,59,4,2,3,5,62,77,83,178,79,69,60,4,
2,3,5,62,76,0,255,255,0,16,0,0,5,104,7,78,
2,39,0,36,0,0,0,0,0,7,1,3,0,188,1,117,
0,3,0,16,0,0,5,104,7,109,0,11,0,14,0,33,
0,203,64,84,12,17,13,12,27,28,27,14,17,28,27,30,
17,28,27,29,17,28,28,27,13,17,33,15,33,12,17,14,
12,15,15,33,32,17,15,33,31,17,33,15,33,66,12,27,
15,13,9,3,193,21,9,30,149,13,9,142,32,28,30,29,
28,24,32,31,33,13,18,6,14,24,12,6,27,0,86,24,
28,15,6,86,18,28,33,34,16,212,196,212,236,50,16,212,
238,50,17,57,17,57,17,18,57,17,57,57,17,18,57,57,
49,0,47,60,230,214,238,16,212,238,17,18,57,57,57,48,
75,83,88,7,16,5,237,7,5,237,7,16,8,237,7,16,
5,237,7,16,5,237,7,5,237,7,5,237,7,16,8,237,
89,34,178,32,35,1,1,93,64,32,26,12,115,12,155,12,
3,7,15,8,27,80,35,102,13,105,14,117,13,123,14,121,
28,121,29,118,32,118,33,128,35,12,93,0,93,1,52,38,
35,34,6,21,20,22,51,50,54,3,1,33,1,46,1,53,
52,54,51,50,22,21,20,6,7,1,35,3,33,3,35,3,
84,89,63,64,87,88,63,63,89,152,254,240,2,33,254,88,
61,62,159,115,114,161,63,60,2,20,210,136,253,95,136,213,
6,90,63,89,87,65,63,88,88,254,243,253,25,3,78,41,
115,73,115,160,161,114,70,118,41,250,139,1,127,254,129,0,
255,255,0,115,254,117,5,39,5,240,2,39,0,38,0,0,
0,0,0,7,0,221,1,45,0,0,255,255,0,201,0,0,
4,139,7,107,2,39,0,40,0,0,0,0,0,7,1,4,
0,158,1,117,255,255,0,201,0,0,5,51,7,94,2,39,
0,49,0,0,0,0,0,7,1,5,0,254,1,117,255,255,
0,115,255,227,5,217,7,78,2,39,0,50,0,0,0,0,
0,7,1,3,1,39,1,117,255,255,0,178,255,227,5,41,
7,78,2,39,0,56,0,0,0,0,0,7,1,3,0,238,
1,117,255,255,0,123,255,227,4,45,6,102,2,39,0,68,
0,0,0,0,0,7,0,141,0,82,0,0,255,255,0,123,
255,227,4,45,6,102,2,39,0,68,0,0,0,0,0,7,
0,67,0,82,0,0,255,255,0,123,255,227,4,45,6,102,
2,39,0,68,0,0,0,0,0,7,0,215,0,82,0,0,
255,255,0,123,255,227,4,45,6,16,2,39,0,68,0,0,
0,0,0,7,0,142,0,82,0,0,255,255,0,123,255,227,
4,45,6,55,2,39,0,68,0,0,0,0,0,7,0,216,
0,82,0,0,255,255,0,123,255,227,4,45,7,6,2,39,
0,68,0,0,0,0,0,7,0,220,0,82,0,0,255,255,
0,113,254,117,3,231,4,123,2,39,0,70,0,0,0,0,
0,7,0,221,0,143,0,0,255,255,0,113,255,227,4,127,
6,102,2,39,0,72,0,0,0,0,0,7,0,141,0,139,
0,0,255,255,0,113,255,227,4,127,6,102,2,39,0,72,
0,0,0,0,0,7,0,67,0,139,0,0,255,255,0,113,
255,227,4,127,6,102,2,39,0,72,0,0,0,0,0,7,
0,215,0,139,0,0,255,255,0,113,255,227,4,127,6,16,
2,39,0,72,0,0,0,0,0,7,0,142,0,139,0,0,
255,255,0,144,0,0,2,111,6,102,2,39,0,214,0,0,
0,0,0,7,0,141,255,29,0,0,255,255,255,199,0,0,
1,166,6,102,2,39,0,214,0,0,0,0,0,7,0,67,
255,29,0,0,255,255,255,222,0,0,2,92,6,102,2,39,
0,214,0,0,0,0,0,7,0,215,255,29,0,0,255,255,
255,244,0,0,2,70,6,16,2,39,0,214,0,0,0,0,
0,7,0,142,255,29,0,0,255,255,0,186,0,0,4,100,
6,55,2,39,0,81,0,0,0,0,0,7,0,216,0,152,
0,0,255,255,0,113,255,227,4,117,6,102,2,39,0,82,
0,0,0,0,0,7,0,141,0,115,0,0,255,255,0,113,
255,227,4,117,6,102,2,39,0,82,0,0,0,0,0,7,
0,67,0,115,0,0,255,255,0,113,255,227,4,117,6,102,
2,39,0,82,0,0,0,0,0,7,0,215,0,115,0,0,
255,255,0,113,255,227,4,117,6,16,2,39,0,82,0,0,
0,0,0,7,0,142,0,115,0,0,255,255,0,113,255,227,
4,117,6,55,2,39,0,82,0,0,0,0,0,7,0,216,
0,115,0,0,255,255,0,174,255,227,4,88,6,102,2,39,
0,88,0,0,0,0,0,7,0,141,0,123,0,0,255,255,
0,174,255,227,4,88,6,102,2,39,0,88,0,0,0,0,
0,7,0,67,0,123,0,0,255,255,0,174,255,227,4,88,
6,102,2,39,0,88,0,0,0,0,0,7,0,215,0,123,
0,0,255,255,0,174,255,227,4,88,6,16,2,39,0,88,
0,0,0,0,0,7,0,142,0,123,0,0,0,1,0,57,
255,59,3,199,5,213,0,11,0,39,64,20,8,4,185,10,
2,0,129,6,194,12,3,89,5,1,87,9,89,7,0,12,
16,212,60,236,252,60,236,49,0,16,228,244,212,60,236,50,
48,1,51,17,33,21,33,17,35,17,33,53,33,1,168,176,
1,111,254,145,176,254,145,1,111,5,213,254,92,153,251,163,
4,93,153,0,0,2,0,195,3,117,3,61,5,240,0,11,
0,26,0,32,64,17,6,195,21,196,0,195,12,145,27,9,
90,18,91,3,90,24,27,16,220,236,252,236,49,0,16,244,
236,252,236,48,1,34,6,21,20,22,51,50,54,53,52,38,
39,50,22,23,22,22,21,20,6,35,34,38,53,52,54,2,
0,80,110,110,80,80,110,111,79,64,118,43,46,46,185,134,
135,180,184,5,111,111,80,79,109,109,79,79,112,129,49,46,
45,114,66,132,183,180,135,134,186,0,0,2,0,172,254,199,
4,35,5,152,0,6,0,33,0,81,64,43,19,22,20,0,
15,12,1,11,7,134,8,136,11,16,134,15,136,12,185,20,
22,11,185,29,31,28,184,22,140,34,28,21,0,9,30,19,
11,15,7,4,18,25,34,16,220,236,212,60,212,60,60,236,
50,50,49,0,16,228,244,60,196,236,16,196,254,244,238,16,
245,238,18,57,17,18,57,17,18,57,48,37,17,6,6,21,
20,22,1,21,38,38,39,3,54,54,55,21,6,6,7,17,
35,17,38,0,17,16,0,55,17,51,19,22,22,2,166,147,
164,164,2,16,74,136,68,1,70,137,72,65,137,77,102,241,
254,247,1,9,241,102,1,73,137,131,3,88,18,226,184,185,
226,3,161,172,41,42,3,252,160,5,42,39,170,30,35,7,
254,228,1,32,20,1,51,1,1,1,2,1,50,22,1,31,
254,225,4,33,0,1,0,129,0,0,4,98,5,240,0,27,
0,96,64,33,7,22,8,1,134,0,18,10,169,20,8,12,
4,160,0,148,25,145,16,12,160,14,0,13,9,11,7,28,
19,15,21,17,28,16,220,60,204,204,252,60,196,212,196,49,
0,47,236,50,244,228,236,16,212,60,238,50,16,238,17,57,
57,48,1,75,176,12,84,88,189,0,28,255,192,0,1,0,
28,0,28,0,64,56,17,55,56,89,180,54,1,54,2,2,
0,93,1,21,46,1,35,34,6,29,1,33,21,33,17,33,
21,33,53,51,17,35,53,51,53,16,54,51,50,22,4,78,
76,136,61,148,116,1,135,254,121,2,45,252,31,236,199,199,
214,232,61,151,5,180,182,41,41,155,212,215,143,254,47,170,
170,1,209,143,238,1,5,243,31,0,0,2,0,92,255,61,
3,162,5,240,0,11,0,62,0,145,64,60,47,48,42,6,
0,23,29,48,54,4,13,39,138,38,13,138,12,42,198,38,
197,35,16,198,12,197,60,145,35,63,47,6,0,23,48,4,
19,29,45,9,54,3,19,87,57,45,87,32,9,87,12,34,
26,57,38,34,3,87,51,63,16,220,236,228,196,212,228,236,
212,236,16,238,17,57,17,18,57,17,23,57,57,49,0,16,
196,244,228,236,16,230,238,16,238,16,238,17,23,57,57,57,
17,18,57,48,1,75,176,10,84,75,176,11,84,91,75,176,
12,84,91,75,176,14,84,91,88,189,0,63,0,64,0,1,
0,63,0,63,255,192,56,17,55,56,89,1,14,1,21,20,
22,23,62,1,53,52,38,19,21,46,1,35,34,6,21,20,
23,22,23,30,1,21,20,6,7,30,1,21,20,6,35,34,
38,39,53,30,1,51,50,54,53,52,47,1,46,1,53,52,
54,55,46,1,53,52,54,51,50,22,1,123,63,62,139,250,
63,62,143,204,83,143,56,97,108,206,26,14,211,131,92,93,
62,57,204,173,73,154,88,87,148,58,102,113,221,25,214,128,
93,91,59,59,200,166,73,153,3,168,46,90,46,76,133,135,
45,91,46,75,136,2,147,164,39,39,80,71,90,115,15,8,
119,154,101,90,140,53,52,109,64,142,168,29,29,164,39,39,
84,76,102,123,14,120,153,102,91,143,49,44,112,69,130,159,
29,0,0,1,1,51,1,209,3,133,4,33,0,11,0,18,
183,9,199,3,12,6,92,0,12,16,212,236,49,0,16,212,
236,48,1,52,54,51,50,22,21,20,6,35,34,38,1,51,
173,126,124,171,172,125,125,172,2,250,124,171,171,124,125,172,
172,0,0,1,0,158,255,59,4,57,5,213,0,13,0,37,
64,18,8,2,4,193,0,129,6,2,14,0,7,93,5,3,
93,1,11,14,16,212,212,252,220,236,57,49,0,16,196,50,
244,236,17,57,48,1,33,17,35,17,35,17,35,17,38,38,
53,52,36,2,121,1,192,141,190,142,215,235,1,4,5,213,
249,102,6,31,249,225,3,78,17,221,184,190,232,0,0,1,
0,186,255,227,4,172,6,20,0,47,0,154,64,48,45,39,
33,12,4,6,13,32,0,4,42,22,134,23,26,185,19,42,
185,3,151,19,140,46,12,9,13,29,32,33,39,9,8,36,
39,8,6,29,8,36,16,22,45,8,16,0,70,48,16,252,
196,252,204,16,198,238,212,238,16,238,17,57,57,18,57,18,
57,49,0,47,228,254,238,16,254,213,238,18,23,57,23,57,
48,64,64,15,5,15,6,15,7,15,39,15,40,138,12,138,
13,7,10,6,10,7,10,11,10,12,10,13,10,31,13,32,
10,33,12,34,4,38,25,13,25,31,25,32,58,32,58,33,
77,31,77,32,73,33,73,34,106,31,106,32,165,6,165,7,
166,32,24,93,1,93,19,52,54,51,50,22,23,14,1,21,
20,22,31,1,30,1,21,20,6,35,34,38,39,53,30,1,
51,50,54,53,52,38,47,1,46,1,53,52,54,55,46,1,
35,34,6,21,17,35,186,239,218,208,219,3,151,168,58,65,
57,166,96,225,211,64,136,73,80,140,65,116,120,59,101,92,
96,87,167,151,8,131,113,130,136,187,4,113,200,219,232,224,
8,115,96,47,81,42,37,106,142,100,172,183,25,24,164,30,
29,95,91,63,84,62,55,59,135,91,127,172,29,103,112,139,
131,251,147,0,0,4,1,27,0,0,6,229,5,205,0,23,
0,47,0,56,0,76,0,96,64,54,69,66,67,63,50,201,
72,48,201,57,74,67,202,12,57,202,0,201,24,200,12,201,
36,72,69,51,48,4,49,66,60,63,57,54,73,49,96,75,
54,96,67,60,94,18,9,30,75,94,6,9,30,95,42,77,
16,220,228,252,236,16,254,253,196,238,16,238,50,17,57,57,
18,57,18,23,57,49,0,47,238,246,254,237,16,237,50,16,
238,214,238,57,18,57,57,48,1,34,6,7,6,6,21,20,
22,23,22,22,51,50,54,55,54,54,53,52,38,39,38,38,
39,50,4,23,22,18,21,20,2,7,6,4,35,34,36,39,
38,2,53,52,18,55,54,36,19,35,17,51,50,54,53,52,
38,39,50,22,21,20,6,7,22,22,23,23,35,39,38,38,
35,35,17,35,17,4,0,131,226,94,94,96,96,94,94,226,
131,132,227,94,93,93,94,92,94,227,132,152,1,7,109,109,
108,108,109,109,254,249,152,152,254,249,109,109,108,108,109,109,
1,7,125,123,123,110,87,88,102,176,174,105,96,24,67,46,
137,172,129,59,73,54,66,155,5,102,94,94,94,229,130,129,
227,94,94,95,95,94,93,226,131,133,227,93,94,94,103,110,
109,109,254,250,154,152,254,251,109,109,110,110,109,109,1,5,
152,154,1,6,109,109,110,254,98,254,236,62,75,76,63,103,
119,121,86,112,17,8,77,73,223,209,96,51,254,156,3,68,
0,3,1,27,0,0,6,229,5,205,0,23,0,47,0,73,
0,67,64,38,61,203,62,58,204,65,202,36,49,203,48,52,
204,71,202,24,201,0,200,36,201,12,55,97,68,61,48,94,
42,9,6,68,94,30,9,6,18,74,16,220,204,252,236,16,
254,237,50,16,238,49,0,47,238,246,254,253,238,214,238,16,
253,238,214,238,48,1,50,4,23,22,18,21,20,2,7,6,
4,35,34,36,39,38,2,53,52,18,55,54,36,23,34,6,
7,6,6,21,20,22,23,22,22,51,50,54,55,54,54,53,
52,38,39,38,38,23,21,38,38,35,34,6,21,20,22,51,
50,54,55,21,6,6,35,34,38,53,52,54,51,50,22,4,
0,152,1,7,109,109,108,108,109,109,254,249,152,152,254,249,
109,109,108,108,109,109,1,7,152,131,226,94,94,96,96,94,
94,226,131,132,227,94,93,93,94,92,94,227,167,66,130,66,
149,167,171,155,64,122,66,67,137,70,216,251,251,216,73,136,
5,205,110,109,109,254,250,154,152,254,251,109,109,110,110,109,
109,1,5,152,154,1,6,109,109,110,103,94,94,94,229,130,
129,227,94,94,95,95,94,93,226,131,133,227,93,94,94,245,
129,33,32,175,157,159,174,31,34,127,29,28,244,208,209,242,
28,0,0,2,1,39,3,147,6,70,5,213,0,12,0,20,
0,62,64,33,1,6,7,16,10,4,18,14,9,3,6,201,
13,2,0,129,21,1,9,5,98,3,9,98,11,13,99,15,
98,19,99,17,21,16,212,228,252,228,212,236,212,236,17,57,
49,0,16,244,60,60,236,23,50,212,60,60,196,17,57,48,
1,19,19,51,17,35,17,3,35,3,17,35,17,35,21,35,
17,35,17,35,53,4,74,174,164,170,113,195,55,203,114,113,
203,114,201,5,213,255,0,1,0,253,190,1,228,254,209,1,
47,254,28,2,66,94,254,28,1,228,94,0,0,1,1,115,
4,238,3,82,6,102,0,3,0,49,64,9,2,180,0,179,
4,3,68,1,4,16,212,236,49,0,16,244,236,48,0,75,
176,9,84,75,176,14,84,91,88,189,0,4,255,192,0,1,
0,4,0,4,0,64,56,17,55,56,89,1,51,1,35,2,
139,199,254,186,153,6,102,254,136,0,0,2,0,215,5,70,
3,41,6,16,0,3,0,7,0,146,64,14,6,2,206,4,
0,205,8,1,100,0,5,100,4,8,16,220,252,212,236,49,
0,16,252,60,236,50,48,0,75,176,10,84,75,176,13,84,
91,88,189,0,8,0,64,0,1,0,8,0,8,255,192,56,
17,55,56,89,1,75,176,12,84,75,176,13,84,91,75,176,
14,84,91,75,176,23,84,91,88,189,0,8,255,192,0,1,
0,8,0,8,0,64,56,17,55,56,89,1,75,176,15,84,
75,176,25,84,91,88,189,0,8,0,64,0,1,0,8,0,
8,255,192,56,17,55,56,89,64,17,96,1,96,2,96,5,
96,6,112,1,112,2,112,5,112,6,8,93,1,51,21,35,
37,51,21,35,2,94,203,203,254,121,203,203,6,16,202,202,
202,0,0,1,0,217,0,39,5,219,4,221,0,19,0,62,
64,34,13,12,10,3,2,207,4,0,156,6,12,207,14,10,
156,18,6,16,8,20,18,14,13,12,8,4,3,2,8,9,
5,15,0,20,16,220,60,196,50,23,57,49,0,16,212,60,
204,50,252,60,236,16,254,60,236,57,17,18,57,48,19,33,
1,23,7,33,21,33,7,33,21,33,1,39,55,33,53,33,
55,33,217,3,4,1,0,125,174,1,47,254,72,195,2,123,
252,250,254,254,125,174,254,213,1,182,195,253,135,3,162,1,
59,102,213,168,240,170,254,199,102,211,170,240,0,2,0,8,
0,0,7,72,5,213,0,15,0,19,0,135,64,57,17,17,
14,15,14,16,17,15,15,14,13,17,15,14,12,17,14,15,
14,66,5,149,3,11,149,17,1,149,16,149,0,129,17,7,
149,3,173,13,9,17,16,15,13,12,5,14,10,0,4,8,
6,2,28,18,10,14,20,16,212,212,60,236,50,212,196,196,
17,18,23,57,49,0,47,60,236,236,196,244,236,236,16,238,
16,238,48,75,83,88,7,16,5,237,7,5,237,7,16,5,
237,7,16,5,237,89,34,178,128,21,1,1,93,64,19,103,
17,119,16,119,17,134,12,133,16,150,17,144,21,160,21,191,
21,9,93,1,21,33,17,33,21,33,17,33,21,33,17,33,
3,35,1,23,1,33,17,7,53,253,27,2,199,253,57,2,
248,252,61,253,240,160,205,2,113,139,254,182,1,203,5,213,
170,254,70,170,253,227,170,1,127,254,129,5,213,158,252,240,
3,16,0,3,0,102,255,186,5,229,6,23,0,9,0,19,
0,43,0,158,64,60,29,31,26,13,43,44,19,10,1,0,
4,13,41,38,32,20,13,4,42,38,30,26,4,149,38,13,
149,26,145,38,140,44,43,44,42,20,23,16,32,30,35,19,
10,1,0,4,29,41,16,7,31,7,25,35,51,16,25,23,
16,44,16,252,236,252,236,192,17,18,57,57,23,57,18,57,
57,17,18,57,57,17,57,49,0,16,228,244,236,16,238,16,
192,16,192,17,18,57,57,18,57,18,23,57,18,57,17,18,
57,57,48,64,42,87,0,90,21,87,25,85,33,106,21,101,
33,123,21,118,28,117,33,9,70,19,89,0,86,19,106,0,
100,19,100,28,106,40,124,0,115,19,118,28,122,40,11,93,
1,93,9,1,30,1,51,50,0,17,52,38,39,46,1,35,
34,0,17,20,22,23,7,38,2,53,16,0,33,50,22,23,
55,23,7,22,18,21,16,0,33,34,38,39,7,39,4,182,
253,51,62,161,95,220,1,1,39,121,61,161,95,220,254,253,
39,39,134,78,79,1,121,1,59,130,221,87,162,102,170,78,
80,254,136,254,198,128,221,91,162,103,4,88,252,178,64,67,
1,72,1,26,112,184,184,64,67,254,184,254,229,112,188,68,
158,102,1,8,160,1,98,1,165,77,75,191,89,198,103,254,
246,158,254,159,254,91,75,75,191,88,0,3,0,221,0,221,
5,207,3,238,0,11,0,23,0,47,0,255,64,29,45,27,
21,9,33,3,0,36,24,4,21,15,39,33,21,27,15,33,
48,12,0,36,24,18,6,42,18,30,48,16,212,196,212,196,
17,57,57,57,57,49,0,16,212,196,212,196,16,192,17,18,
23,57,18,57,17,18,57,48,64,190,5,2,5,3,5,4,
0,5,0,6,0,7,5,8,5,9,5,10,10,16,15,17,
15,18,15,19,10,20,21,2,21,3,21,4,16,5,16,6,
16,7,21,8,21,9,21,10,26,14,26,15,26,16,31,17,
31,18,31,19,26,20,26,21,26,22,36,2,36,3,36,4,
32,5,32,6,32,7,36,8,36,9,36,10,42,14,42,15,
42,16,47,17,47,18,47,19,42,20,42,21,42,22,53,2,
53,3,53,4,48,5,48,6,48,7,53,8,53,9,53,10,
58,14,58,15,58,16,63,17,63,18,63,19,58,20,58,21,
58,22,69,2,69,3,69,4,64,5,64,6,64,7,69,8,
69,9,69,10,74,14,74,15,74,16,79,17,79,18,79,19,
74,20,74,21,74,22,86,180,31,176,32,176,33,176,34,176,
38,176,39,176,40,180,41,8,93,1,93,1,30,1,51,50,
54,53,52,38,35,34,6,7,46,1,35,34,6,21,20,22,
51,50,54,23,14,1,35,34,38,53,52,54,51,50,22,23,
62,1,51,50,22,21,20,6,35,34,38,3,147,49,134,84,
101,128,118,89,82,133,196,49,133,85,102,127,118,89,82,134,
144,70,157,94,136,186,167,134,95,153,72,68,158,97,134,188,
167,134,94,149,2,47,88,90,135,105,101,134,135,55,88,88,
132,106,101,134,136,22,135,127,223,166,175,216,126,138,138,131,
225,167,175,214,119,0,0,2,0,217,0,0,5,219,5,4,
0,11,0,15,0,46,64,24,5,208,7,3,156,0,208,9,
1,12,156,14,13,2,21,4,0,23,12,8,21,10,6,16,
16,212,60,236,50,252,60,236,50,49,0,47,236,212,60,236,
252,60,236,48,1,17,33,21,33,17,35,17,33,53,33,17,
1,33,21,33,3,174,2,45,253,211,168,253,211,2,45,253,
211,5,2,250,254,5,4,254,125,170,254,125,1,131,170,1,
131,251,166,170,0,2,0,217,0,0,5,219,4,168,0,6,
0,10,0,84,64,46,2,156,3,4,3,1,156,0,1,4,
4,3,1,156,2,1,5,6,5,0,156,6,5,66,5,4,
2,1,0,5,3,209,6,167,7,156,9,1,8,2,0,36,
7,4,35,11,16,252,60,236,50,50,57,49,0,47,236,244,
236,23,57,48,75,83,88,7,4,237,7,16,8,237,7,16,
8,237,7,16,4,237,89,34,9,2,21,1,53,1,1,33,
21,33,5,219,252,64,3,192,250,254,5,2,250,254,5,2,
250,254,3,248,254,235,254,238,178,1,112,170,1,111,252,2,
170,0,0,2,0,217,0,0,5,219,4,168,0,6,0,10,
0,86,64,47,6,156,0,6,3,4,3,5,156,4,4,3,
0,156,1,2,1,6,156,5,6,2,2,1,66,6,5,3,
2,0,5,4,209,1,167,7,156,8,6,7,2,36,9,4,
0,35,11,16,252,60,60,236,50,57,49,0,47,236,244,236,
23,57,48,75,83,88,7,16,8,237,7,16,4,237,7,16,
4,237,7,16,8,237,89,34,19,53,1,21,1,53,1,1,
21,33,53,217,5,2,250,254,3,193,1,65,250,254,3,248,
176,254,145,170,254,144,178,1,18,253,199,170,170,0,0,1,
0,82,0,0,4,195,5,213,0,24,0,198,64,70,16,2,
17,22,17,15,2,14,15,22,22,17,15,2,16,15,8,13,
8,14,2,13,13,8,66,15,11,9,4,0,211,23,6,18,
11,211,20,9,16,13,129,2,12,9,14,3,5,22,15,3,
21,18,16,3,0,17,102,19,0,101,1,28,13,102,10,5,
101,7,3,25,16,212,60,236,50,236,252,236,50,236,18,23,
57,18,57,57,17,23,57,49,0,47,228,50,212,60,236,50,
212,60,236,50,17,18,57,48,75,83,88,7,16,5,237,7,
16,8,237,7,16,8,237,7,16,5,237,89,34,1,75,176,
12,84,88,189,0,25,255,192,0,1,0,25,0,25,0,64,
56,17,55,56,89,64,40,134,15,144,15,166,15,160,15,181,
15,5,39,12,39,13,39,14,41,16,40,17,40,18,55,14,
57,16,135,12,136,18,166,13,165,14,170,16,169,17,14,93,
0,93,1,33,17,35,17,33,53,33,53,39,33,53,33,1,
51,9,1,51,1,33,21,33,7,21,33,4,141,254,99,201,
254,96,1,160,84,254,180,1,8,254,195,190,1,123,1,121,
191,254,194,1,8,254,181,84,1,159,1,199,254,57,1,199,
123,51,155,123,2,74,253,68,2,188,253,182,123,155,51,0,
0,1,0,174,254,86,4,229,4,96,0,32,0,77,64,37,
19,25,31,3,22,6,3,9,12,3,1,18,15,6,135,28,
22,140,10,1,188,0,189,33,25,9,18,9,8,11,78,31,
2,8,0,70,33,16,252,236,50,244,236,196,18,57,49,0,
16,228,228,50,244,60,236,220,196,17,23,57,17,18,23,57,
48,182,31,34,96,34,207,34,3,1,93,19,17,51,17,20,
22,51,50,54,53,17,51,17,20,22,51,50,54,55,21,14,
1,35,34,38,39,14,1,35,34,38,39,17,174,184,138,135,
148,149,184,35,37,9,32,28,41,73,35,69,82,15,50,145,
98,102,143,42,254,86,6,10,253,72,145,148,168,168,2,141,
252,162,60,57,11,12,148,23,22,78,80,79,79,78,78,253,
215,0,0,2,0,104,255,231,3,193,5,45,0,29,0,41,
0,98,64,25,0,39,33,9,27,6,39,21,6,15,33,27,
15,21,213,42,12,36,3,0,30,18,36,24,42,16,212,204,
220,204,57,57,17,57,49,0,16,228,204,220,204,16,206,16,
206,17,18,57,17,18,57,48,1,75,176,12,84,75,176,11,
84,91,75,176,14,84,91,75,176,16,84,91,75,176,20,84,
91,88,189,0,42,0,64,0,1,0,42,0,42,255,192,56,
17,55,56,89,1,62,1,53,52,38,35,34,6,35,34,38,
53,52,54,51,50,18,17,16,0,35,34,38,53,52,18,51,
50,22,7,52,38,35,34,2,21,20,22,51,50,18,2,244,
15,15,73,72,55,144,36,36,48,144,101,180,214,254,223,213,
152,203,221,162,101,130,11,87,79,109,141,86,80,109,141,2,
109,87,163,75,129,131,116,44,31,62,98,254,202,254,249,254,
177,254,70,216,163,198,1,1,91,224,116,125,254,254,207,116,
123,1,4,0,0,1,0,25,254,119,5,59,5,193,0,11,
0,93,64,20,10,4,12,2,5,7,2,0,7,12,10,5,
4,3,1,0,6,6,8,12,16,212,196,23,57,49,0,16,
196,212,204,16,206,17,18,57,57,48,64,48,81,3,86,5,
80,5,90,10,115,3,112,3,118,4,117,5,112,5,122,10,
128,3,128,5,12,90,9,127,2,127,3,112,5,112,6,123,
9,116,11,143,2,143,3,128,5,128,6,11,93,1,93,19,
33,21,33,9,1,33,21,33,53,9,1,55,4,234,252,65,
2,160,253,74,3,239,250,222,2,213,253,73,5,193,193,253,
51,253,4,192,149,3,33,2,227,0,0,1,0,156,254,119,
5,113,5,193,0,7,0,30,64,15,6,2,215,4,214,0,
175,8,3,103,1,5,103,0,8,16,212,236,212,236,49,0,
16,252,236,236,50,48,19,33,17,35,17,33,17,35,156,4,
213,240,253,10,239,5,193,248,182,6,125,249,131,0,0,1,
255,225,255,240,4,170,4,47,0,35,0,203,64,49,11,2,
21,31,30,3,0,8,218,15,26,22,0,217,34,216,15,213,
24,12,30,27,26,25,24,23,6,36,18,1,0,11,2,4,
35,22,21,5,34,31,18,12,35,18,104,5,35,31,36,16,
212,212,212,236,18,57,17,18,57,18,57,57,17,23,57,17,
18,23,57,49,0,47,60,228,244,236,50,50,16,238,17,23,
57,57,57,48,1,75,176,10,84,88,189,0,36,255,192,0,
1,0,36,0,36,0,64,56,17,55,56,89,64,86,24,30,
24,31,2,9,0,9,1,13,2,13,3,15,4,15,5,15,
6,15,7,15,8,15,9,15,10,15,11,15,12,15,13,15,
14,15,15,15,16,15,17,15,18,15,19,14,20,13,21,9,
22,11,23,8,24,15,24,13,25,8,26,9,35,17,0,17,
1,22,2,22,3,23,20,22,21,17,22,23,23,28,24,28,
25,17,35,40,93,0,93,1,35,3,14,1,21,20,22,51,
50,54,55,7,14,1,35,34,38,53,52,54,55,19,33,3,
35,19,35,34,6,7,35,62,1,51,33,4,135,182,105,15,
15,47,55,17,46,37,30,30,55,26,118,121,21,34,80,254,
186,194,181,195,41,54,60,9,160,28,143,165,3,121,3,145,
254,25,74,92,22,58,49,5,5,141,8,8,102,100,46,144,
161,1,120,252,111,3,145,64,69,166,125,0,0,1,0,47,
254,141,3,250,6,14,0,37,0,38,64,20,32,219,0,26,
13,219,19,26,220,7,177,38,10,105,23,106,29,105,4,38,
16,220,236,252,236,49,0,16,252,236,220,228,16,222,228,48,
1,50,19,54,55,18,18,51,50,22,21,20,6,35,34,38,
39,38,38,35,34,3,6,7,2,2,35,34,38,53,52,54,
51,50,22,23,22,22,1,55,106,14,2,1,12,190,202,80,
100,64,55,42,56,12,6,9,16,107,14,4,4,17,189,196,
79,101,68,61,33,48,15,10,10,254,250,2,176,108,57,2,
3,1,188,84,65,54,63,38,35,15,72,253,149,193,110,254,
33,254,98,83,65,56,63,29,28,18,83,0,0,3,0,115,
1,213,3,59,5,240,0,3,0,30,0,41,0,95,64,51,
40,7,37,4,31,18,24,16,2,227,0,31,221,16,0,225,
37,221,5,10,25,223,24,222,21,221,10,224,28,145,42,0,
24,13,31,16,34,6,2,1,40,17,6,107,4,108,24,34,
107,13,42,16,220,236,204,252,236,50,50,192,192,17,18,57,
57,17,18,57,49,0,16,244,228,252,244,236,16,196,238,237,
214,238,16,238,17,18,57,18,57,17,57,57,48,19,33,21,
33,1,17,35,53,6,6,35,34,38,53,52,54,51,51,53,
52,38,35,34,6,7,53,54,54,51,50,22,5,34,6,21,
20,22,51,50,54,53,53,139,2,176,253,80,2,174,149,44,
144,93,128,152,191,188,182,117,117,62,136,68,73,145,69,183,
179,254,236,161,126,98,82,104,130,2,80,123,2,184,254,64,
112,63,68,135,113,135,138,4,91,91,34,34,127,28,28,176,
240,67,79,64,77,144,114,29,0,3,0,96,1,213,3,100,
5,240,0,3,0,15,0,27,0,46,64,25,2,227,0,225,
22,221,10,224,16,221,4,145,28,0,19,13,1,25,107,7,
108,19,107,13,28,16,220,236,252,236,57,17,18,57,49,0,
16,244,236,244,236,252,236,48,19,33,21,33,1,50,22,21,
20,6,35,34,38,53,52,54,23,34,6,21,20,22,51,50,
54,53,52,38,139,2,176,253,80,1,88,179,206,206,179,179,
208,208,179,105,126,127,104,105,125,124,2,80,123,4,27,221,
191,191,219,220,190,191,221,115,161,136,133,160,160,133,137,160,
0,1,0,78,0,0,5,207,5,231,0,31,0,64,64,34,
9,229,25,145,18,15,3,3,0,229,16,1,17,32,22,19,
15,12,31,6,2,1,0,2,109,6,28,28,15,109,12,28,
22,32,16,212,236,236,212,236,236,192,192,17,18,57,17,18,
57,17,18,57,49,0,47,60,236,23,50,244,236,48,37,21,
33,53,54,18,53,52,0,35,34,0,21,20,18,23,21,33,
53,33,38,2,53,16,0,33,32,0,17,20,2,7,5,207,
253,168,177,198,254,248,216,216,254,247,199,178,253,168,1,63,
158,145,1,127,1,49,1,47,1,129,142,161,178,178,178,97,
1,76,202,240,1,34,254,221,239,202,254,180,97,178,178,139,
1,42,184,1,62,1,138,254,119,254,203,194,254,216,141,0,
0,3,0,123,255,227,7,111,4,123,0,6,0,51,0,62,
1,3,64,67,39,45,37,61,14,13,0,52,169,37,22,134,
21,136,18,0,169,14,58,18,185,28,25,46,134,45,186,42,
3,185,14,187,7,49,10,184,31,25,140,37,63,52,55,38,
6,15,0,37,55,28,7,38,15,21,0,8,13,61,38,8,
15,45,55,8,34,69,63,16,252,236,204,212,252,60,212,236,
196,17,18,57,57,17,57,17,18,57,17,18,57,49,0,16,
196,228,50,244,60,196,228,252,60,244,236,16,196,238,50,16,
238,16,244,238,16,238,17,57,17,57,17,18,57,48,64,129,
48,43,48,44,48,45,48,46,48,47,48,48,64,43,64,44,
64,45,64,46,64,47,64,48,80,43,80,44,80,45,80,46,
80,47,80,48,133,43,133,48,128,64,144,64,160,64,176,64,
192,64,208,64,224,64,224,64,240,64,29,63,0,63,6,63,
13,63,14,63,15,5,48,44,48,45,48,46,48,47,64,44,
64,45,64,46,64,47,80,44,80,45,80,46,80,47,111,0,
111,6,111,13,111,14,111,15,96,44,96,45,96,46,96,47,
112,44,112,45,112,46,112,47,128,44,128,45,128,46,128,47,
29,93,113,1,93,1,46,1,35,34,6,7,3,62,1,51,
50,0,29,1,33,30,1,51,50,54,55,21,14,1,35,34,
38,39,14,1,35,34,38,53,52,54,51,33,53,52,38,35,
34,6,7,53,62,1,51,50,22,3,34,6,21,20,22,51,
50,54,61,1,6,182,1,165,137,153,185,14,68,74,212,132,
226,1,8,252,178,12,204,183,104,200,100,100,208,106,167,248,
77,73,216,143,189,210,253,251,1,2,167,151,96,182,84,101,
190,90,142,213,239,223,172,129,111,153,185,2,148,151,180,174,
158,1,48,90,94,254,221,250,90,191,200,53,53,174,42,44,
121,119,120,120,187,168,189,192,18,127,139,46,46,170,39,39,
96,254,24,102,123,98,115,217,180,41,0,3,0,72,255,162,
4,156,4,188,0,9,0,19,0,43,0,228,64,60,43,44,
38,31,29,26,19,10,1,0,4,13,41,38,32,20,13,4,
42,38,30,26,4,185,38,13,185,26,184,38,140,44,43,44,
42,20,23,16,32,30,35,19,10,1,0,4,16,7,31,29,
7,18,35,81,41,16,18,23,69,44,16,252,236,50,244,236,
50,192,17,18,23,57,18,57,57,17,18,57,57,17,57,49,
0,16,228,244,236,16,238,16,192,16,192,17,18,57,57,18,
57,18,23,57,17,57,57,17,18,57,48,64,112,40,1,63,
45,89,20,86,28,85,29,86,32,106,21,102,33,127,0,123,
4,127,5,127,6,127,7,127,8,127,9,127,10,127,11,127,
12,123,13,122,21,123,26,127,27,127,28,127,29,127,30,127,
31,127,32,123,33,127,34,127,35,127,36,127,37,123,38,155,
25,149,37,168,25,160,45,240,45,38,89,0,86,19,85,29,
90,40,105,0,102,19,101,28,106,40,122,0,116,19,118,28,
122,40,137,30,149,24,154,36,162,24,173,36,17,93,1,93,
9,1,30,1,51,50,54,53,52,38,39,46,1,35,34,6,
21,20,22,23,7,46,1,53,16,0,51,50,22,23,55,23,
7,30,1,21,16,0,35,34,38,39,7,39,3,137,254,25,
41,103,65,147,172,20,92,42,103,62,151,169,19,20,125,54,
54,1,17,241,93,159,67,139,95,146,53,54,254,238,240,96,
161,63,139,96,3,33,253,176,42,40,232,200,79,117,154,41,
41,235,211,72,110,46,151,77,197,119,1,20,1,56,51,52,
168,79,179,77,198,120,254,237,254,199,52,51,168,78,0,2,
0,143,255,227,3,172,5,213,0,32,0,36,0,134,64,47,
32,26,5,2,4,6,25,0,16,134,15,136,12,0,33,131,
35,12,149,19,140,35,129,37,6,34,25,22,9,5,1,0,
26,34,9,0,28,1,34,28,33,38,15,9,28,22,37,16,
220,236,212,252,236,212,236,17,18,57,17,18,57,17,18,57,
18,57,49,0,16,228,244,236,16,254,205,16,244,238,18,57,
57,23,57,48,1,75,176,16,84,75,176,18,84,91,75,176,
19,84,91,88,189,0,37,255,192,0,1,0,37,0,37,0,
64,56,17,55,56,89,64,11,116,4,116,5,116,6,116,7,
118,28,5,93,1,51,21,20,6,15,1,14,1,21,20,22,
51,50,54,55,21,14,1,35,34,38,53,52,54,63,1,62,
1,55,62,1,53,19,35,53,51,1,244,190,55,90,90,58,
51,131,109,78,180,96,94,192,103,184,224,73,89,88,48,38,
8,7,6,196,202,202,4,68,156,101,130,87,88,53,94,49,
89,110,70,67,188,57,56,194,159,76,137,86,86,47,53,25,
21,60,54,1,14,254,0,2,1,53,0,0,2,0,5,213,
0,3,0,9,0,98,64,15,7,0,131,2,129,4,8,7,
4,0,3,5,1,0,10,16,252,60,236,50,57,57,49,0,
47,244,252,204,48,1,75,176,11,84,88,189,0,10,0,64,
0,1,0,10,0,10,255,192,56,17,55,56,89,1,75,176,
15,84,75,176,16,84,91,75,176,19,84,91,88,189,0,10,
255,192,0,1,0,10,0,10,0,64,56,17,55,56,89,182,
0,11,32,11,80,11,3,93,1,35,53,51,17,35,17,19,
51,19,2,0,203,203,203,21,162,20,4,215,254,250,43,2,
143,1,101,254,155,0,0,1,0,217,1,31,5,219,3,94,
0,5,0,23,64,10,4,156,2,0,6,3,23,1,0,6,
16,220,212,236,49,0,16,212,196,236,48,19,33,17,35,17,
33,217,5,2,168,251,166,3,94,253,193,1,149,0,0,1,
0,61,255,215,5,25,6,125,0,10,0,42,64,24,10,9,
8,7,6,5,11,2,4,2,0,11,10,9,7,6,5,4,
3,0,8,1,8,11,16,212,204,23,57,49,0,16,212,204,
196,17,18,23,57,48,1,51,21,35,1,35,1,7,39,37,
1,4,92,189,115,253,174,66,254,193,125,25,1,27,1,0,
6,125,96,249,186,3,115,45,80,98,253,59,0,1,0,31,
254,86,5,2,6,20,0,35,0,138,64,64,14,13,2,15,
12,17,25,30,25,11,10,9,8,4,7,17,30,30,25,66,
25,12,19,10,7,30,1,26,10,169,8,19,138,18,230,22,
169,15,1,138,0,230,4,169,33,151,15,28,8,36,30,29,
27,26,25,12,11,9,8,7,10,0,18,36,16,212,204,23,
57,49,0,16,196,50,196,252,236,244,236,16,238,246,238,16,
238,50,18,57,57,17,18,57,57,48,75,83,88,7,16,5,
237,23,50,7,16,5,237,17,23,57,89,34,1,75,176,12,
84,88,189,0,36,255,192,0,1,0,36,0,36,0,64,56,
17,55,56,89,1,21,46,1,35,34,6,7,3,33,21,33,
3,2,6,35,34,38,39,53,30,1,51,50,54,55,19,35,
53,33,19,62,1,51,50,22,5,2,38,80,44,96,114,25,
60,1,31,254,195,127,58,188,186,58,100,47,52,97,47,97,
109,34,137,248,1,23,63,36,198,151,53,100,5,240,164,29,
28,122,132,254,201,143,253,133,254,227,211,21,22,166,33,33,
137,166,2,173,143,1,74,183,195,18,0,2,0,217,1,16,
5,219,3,244,0,29,0,59,0,63,64,31,46,31,57,42,
0,45,34,19,1,16,27,12,30,42,156,49,57,156,34,4,
156,27,12,156,19,60,30,0,45,15,60,16,212,60,196,50,
49,0,16,212,236,212,236,220,252,212,236,192,17,18,57,57,
17,18,57,57,17,18,57,57,48,1,21,6,6,35,34,39,
38,39,38,39,38,35,34,6,7,53,54,54,51,50,23,22,
23,22,23,22,51,50,54,19,21,6,6,35,34,39,38,39,
38,39,38,35,34,6,7,53,54,54,51,50,23,22,23,22,
23,22,51,50,54,5,219,105,179,97,110,146,10,7,6,15,
155,94,88,172,98,105,179,97,110,147,11,5,6,15,155,94,
86,169,103,105,179,97,110,146,10,7,6,15,155,94,88,172,
98,105,179,97,110,147,10,5,7,15,155,94,86,169,2,111,
179,78,69,59,4,3,2,6,61,76,84,179,78,69,59,5,
2,2,6,61,75,1,218,178,79,69,59,4,3,2,6,61,
76,83,178,78,69,59,4,2,3,6,61,75,0,2,255,250,
0,0,5,96,5,193,0,2,0,6,0,56,64,15,0,3,
1,3,5,4,3,2,1,0,5,7,5,6,7,16,212,204,
17,23,57,49,0,47,196,204,17,57,48,64,20,99,1,109,
2,112,1,120,2,127,2,121,5,118,6,7,110,0,127,0,
2,93,1,93,9,1,33,1,51,1,33,2,172,254,94,3,
68,253,239,224,2,67,250,154,4,238,251,196,5,15,250,63,
0,2,0,158,0,141,4,37,4,35,0,6,0,13,0,134,
64,73,3,232,4,5,4,2,232,1,2,5,5,4,2,232,
3,2,6,0,6,1,232,0,0,6,10,232,11,12,11,9,
232,8,9,12,12,11,9,232,10,9,13,7,13,8,232,7,
7,13,66,9,2,11,4,231,7,0,166,14,9,12,5,2,
7,3,0,111,5,10,7,111,12,110,14,16,252,252,60,212,
236,50,17,57,17,18,57,49,0,16,244,60,236,50,57,57,
48,75,83,88,7,16,4,237,7,16,8,237,7,16,8,237,
7,16,4,237,7,16,4,237,7,16,8,237,7,16,8,237,
7,16,4,237,89,34,1,21,1,1,21,1,53,19,21,1,
1,21,1,53,4,37,254,211,1,45,254,43,35,254,211,1,
45,254,43,4,35,191,254,244,254,244,191,1,162,82,1,162,
191,254,244,254,244,191,1,162,82,0,0,2,0,193,0,141,
4,72,4,35,0,6,0,13,0,134,64,73,12,232,13,12,
9,10,9,11,232,10,10,9,13,232,7,8,7,12,232,11,
12,8,8,7,5,232,6,5,2,3,2,4,232,3,3,2,
6,232,0,1,0,5,232,4,5,1,1,0,66,12,5,10,
3,231,7,0,166,14,12,8,1,5,0,8,111,10,7,1,
111,3,0,112,14,16,252,60,252,212,60,236,18,57,17,18,
57,49,0,16,244,60,236,50,57,57,48,75,83,88,7,16,
8,237,7,16,4,237,7,16,4,237,7,16,8,237,7,16,
8,237,7,16,4,237,7,16,4,237,7,16,8,237,89,34,
19,1,21,1,53,1,1,37,1,21,1,53,1,1,193,1,
213,254,43,1,45,254,211,1,178,1,213,254,43,1,45,254,
211,4,35,254,94,82,254,94,191,1,12,1,12,191,254,94,
82,254,94,191,1,12,1,12,0,3,0,236,0,0,7,20,
0,254,0,3,0,7,0,11,0,35,64,17,8,4,0,131,
10,6,2,4,25,5,0,25,1,9,25,8,12,16,212,252,
212,236,212,236,49,0,47,60,60,236,50,50,48,37,51,21,
35,37,51,21,35,37,51,21,35,3,150,212,212,2,169,213,
213,250,173,213,213,254,254,254,254,254,254,0,255,255,0,16,
0,0,5,104,7,107,2,39,0,36,0,0,0,0,0,7,
1,6,0,188,1,117,255,255,0,16,0,0,5,104,7,94,
2,39,0,36,0,0,0,0,0,7,1,5,0,188,1,117,
255,255,0,115,255,227,5,217,7,94,2,39,0,50,0,0,
0,0,0,7,1,5,1,39,1,117,0,2,0,115,0,0,
8,12,5,213,0,16,0,25,0,59,64,31,5,149,3,17,
1,149,0,129,24,7,149,3,173,9,24,18,16,10,21,6,
2,28,17,0,4,8,21,25,13,16,26,16,252,236,212,196,
196,212,236,50,18,57,57,57,57,49,0,47,236,236,50,244,
236,50,16,238,48,1,21,33,17,33,21,33,17,33,21,33,
32,0,17,16,0,33,23,35,32,0,17,16,0,33,51,7,
250,253,26,2,199,253,57,2,248,251,215,254,79,254,65,1,
191,1,177,103,129,254,191,254,192,1,64,1,65,129,5,213,
170,254,70,170,253,227,170,1,124,1,112,1,109,1,124,170,
254,225,254,224,254,223,254,223,0,3,0,113,255,227,7,195,
4,123,0,6,0,39,0,51,0,132,64,49,7,8,0,16,
134,15,136,12,0,169,8,46,12,185,22,19,40,3,185,8,
187,34,37,31,184,25,19,140,52,6,0,22,34,49,9,15,
0,8,7,75,49,18,9,81,43,18,28,69,52,16,252,236,
244,252,244,236,196,17,18,57,57,18,57,49,0,16,228,50,
244,60,196,228,236,50,16,196,238,50,16,238,16,244,238,17,
18,57,48,64,37,63,53,95,53,112,53,159,53,207,53,208,
53,240,53,7,63,0,63,6,63,7,63,8,63,9,5,111,
0,111,6,111,7,111,8,111,9,5,93,113,1,93,1,46,
1,35,34,6,7,5,21,33,30,1,51,50,54,55,21,14,
1,35,34,38,39,14,1,35,34,0,17,16,0,51,50,22,
23,62,1,51,50,0,37,34,6,21,20,22,51,50,54,53,
52,38,7,10,2,164,137,153,185,14,3,72,252,178,12,204,
183,106,200,98,100,208,106,160,242,81,71,209,140,241,254,239,
1,17,241,140,211,66,78,232,143,226,1,8,250,176,148,172,
171,149,147,172,172,2,148,152,179,174,158,53,90,190,199,52,
52,174,42,44,110,109,110,109,1,57,1,19,1,20,1,56,
111,108,107,112,254,221,135,231,201,201,231,232,200,199,233,0,
0,1,0,0,1,233,4,0,2,121,0,3,0,16,182,2,
169,0,233,4,1,0,47,198,49,0,16,252,236,48,17,33,
21,33,4,0,252,0,2,121,144,0,0,1,0,0,1,233,
8,0,2,121,0,3,0,15,181,2,169,0,4,1,0,47,
204,49,0,16,212,236,48,17,33,21,33,8,0,248,0,2,
121,144,0,2,0,174,3,233,3,109,5,213,0,5,0,11,
0,39,64,19,6,0,158,9,3,129,12,9,10,6,25,7,
3,4,7,0,25,1,12,16,220,252,204,212,204,16,254,212,
206,49,0,16,244,60,236,50,48,1,35,53,19,51,3,5,
35,53,19,51,3,1,129,211,164,129,82,1,154,211,164,129,
82,3,233,173,1,63,254,193,173,173,1,63,254,193,0,2,
0,174,3,233,3,109,5,213,0,5,0,11,0,39,64,19,
9,3,158,6,0,129,12,9,10,7,25,6,1,3,4,1,
25,0,12,16,220,236,212,204,16,220,238,212,206,49,0,16,
244,60,236,50,48,1,51,21,3,35,19,37,51,21,3,35,
19,1,0,211,164,129,82,1,154,211,164,129,82,5,213,172,
254,192,1,64,172,172,254,192,1,64,0,1,0,174,3,233,
1,211,5,213,0,5,0,24,64,11,0,158,3,129,6,3,
4,0,25,1,6,16,220,252,212,204,49,0,16,244,236,48,
1,35,53,19,51,3,1,129,211,164,129,82,3,233,173,1,
63,254,193,0,0,1,0,178,3,254,1,215,5,213,0,5,
0,24,64,11,3,158,0,129,6,3,4,1,113,0,6,16,
220,236,212,204,49,0,16,244,236,48,1,51,21,3,35,19,
1,4,211,164,129,82,5,213,152,254,193,1,63,0,0,3,
0,217,0,150,5,219,4,111,0,3,0,7,0,11,0,41,
64,20,0,234,2,6,234,4,2,8,156,4,10,12,9,5,
1,114,4,0,8,12,16,220,212,60,252,60,196,49,0,16,
212,196,252,196,16,238,16,238,48,1,51,21,35,17,51,21,
35,1,33,21,33,2,223,246,246,246,246,253,250,5,2,250,
254,4,111,246,254,18,245,2,65,170,0,2,0,6,254,35,
3,238,6,117,0,3,0,7,0,34,64,17,2,6,0,8,
4,6,8,6,4,3,2,1,0,6,5,7,8,16,212,204,
23,57,49,0,16,212,204,17,57,18,57,48,9,7,1,250,
254,127,1,129,1,129,254,127,1,244,254,12,254,12,5,129,
252,207,252,199,3,57,4,37,251,219,251,211,4,45,255,255,
0,61,254,86,4,127,6,16,2,39,0,92,0,0,0,0,
0,7,0,142,0,94,0,0,255,255,255,252,0,0,4,231,
7,78,2,39,0,60,0,0,0,0,0,7,1,3,0,115,
1,117,0,1,254,137,255,227,2,205,5,240,0,3,0,43,
64,19,0,15,1,2,1,2,15,3,0,3,66,2,140,0,
145,4,1,3,4,16,212,204,49,0,16,228,228,48,75,83,
88,7,16,5,237,7,16,5,237,89,34,1,51,1,35,2,
45,160,252,92,160,5,240,249,243,0,0,2,0,94,0,82,
4,188,4,178,0,35,0,47,0,131,64,73,3,9,27,21,
4,45,30,0,39,28,2,33,29,12,18,45,20,11,10,3,
19,15,1,29,45,185,19,235,15,236,39,185,29,235,33,48,
30,12,0,18,4,42,36,20,48,28,21,27,42,29,19,28,
24,9,3,36,11,10,1,3,2,36,40,2,115,6,116,42,
40,28,115,24,48,16,220,228,236,244,228,236,18,23,57,18,
57,57,17,18,57,57,18,57,57,17,18,57,17,18,23,57,
49,0,16,212,228,236,244,228,236,16,192,17,18,23,57,18,
57,57,17,18,57,57,17,57,57,18,23,57,48,1,55,23,
7,22,22,21,20,6,7,23,7,39,6,6,35,34,38,39,
7,39,55,38,38,53,52,54,55,39,55,23,54,54,51,50,
22,19,52,38,35,34,6,21,20,22,51,50,54,3,123,207,
114,206,37,36,38,40,209,114,207,59,116,61,58,120,61,207,
113,207,37,37,38,38,207,115,207,55,116,64,60,117,92,155,
114,112,158,157,113,113,156,3,225,209,115,206,59,119,62,63,
115,57,207,113,207,40,38,37,37,207,115,206,62,118,58,64,
116,56,206,115,207,39,37,36,254,124,112,154,154,112,114,156,
157,0,0,1,0,158,0,141,2,115,4,35,0,6,0,71,
64,37,3,232,4,5,4,2,232,1,2,5,5,4,2,232,
3,2,6,0,6,1,232,0,6,66,2,4,231,0,166,7,
2,3,0,111,5,110,7,16,252,236,50,57,49,0,16,244,
236,57,48,75,83,88,7,4,237,7,16,8,237,7,16,8,
237,7,16,4,237,89,34,1,21,1,1,21,1,53,2,115,
254,211,1,45,254,43,4,35,191,254,244,254,244,191,1,162,
82,0,0,1,0,193,0,141,2,150,4,35,0,6,0,73,
64,38,5,232,6,5,2,3,2,4,232,3,3,2,6,232,
0,1,0,5,232,4,5,1,1,0,66,5,3,231,0,166,
7,5,1,111,3,0,112,7,16,252,60,236,57,49,0,16,
244,236,57,48,75,83,88,7,16,8,237,7,16,4,237,7,
16,4,237,7,16,8,237,89,34,19,1,21,1,53,1,1,
193,1,213,254,43,1,45,254,211,4,35,254,94,82,254,94,
191,1,12,1,12,0,0,2,0,47,0,0,4,74,6,20,
0,21,0,25,0,155,64,40,11,20,24,7,3,169,0,16,
135,14,24,190,22,177,14,151,9,0,188,5,1,17,14,15,
4,22,2,8,0,15,20,4,8,8,23,0,10,6,76,26,
16,252,60,196,50,196,252,60,196,16,238,50,17,18,57,57,
49,0,47,60,230,50,238,254,238,16,238,16,238,50,18,57,
57,48,1,75,176,10,84,88,189,0,26,255,192,0,1,0,
26,0,26,0,64,56,17,55,56,89,1,75,176,14,84,88,
189,0,26,0,64,0,1,0,26,0,26,255,192,56,17,55,
56,89,64,26,16,22,16,23,16,24,16,25,4,48,27,80,
27,128,15,128,16,128,27,160,27,208,27,239,27,8,93,0,
93,1,17,35,17,33,17,35,17,35,53,51,53,52,54,59,
1,21,35,34,6,29,1,1,51,21,35,4,74,185,254,7,
185,176,176,173,179,185,176,99,77,1,249,185,185,4,96,251,
160,3,209,252,47,3,209,143,78,183,175,153,80,104,99,1,
178,233,0,1,0,47,0,0,4,74,6,20,0,21,0,132,
64,33,8,19,4,15,11,169,9,4,135,0,151,17,9,188,
13,2,5,0,10,8,3,8,1,10,12,8,8,16,1,18,
14,76,22,16,252,60,196,196,252,60,196,16,238,17,18,57,
57,49,0,47,60,230,50,254,238,16,238,50,18,57,57,48,
1,75,176,10,84,88,189,0,22,255,192,0,1,0,22,0,
22,0,64,56,17,55,56,89,1,75,176,14,84,88,189,0,
22,0,64,0,1,0,22,0,22,255,192,56,17,55,56,89,
64,17,48,23,80,23,128,10,128,11,128,23,160,23,208,23,
239,23,8,93,1,33,17,35,17,33,34,6,29,1,33,21,
33,17,35,17,35,53,51,53,52,54,2,74,2,0,185,254,
183,99,77,1,47,254,209,185,176,176,174,6,20,249,236,5,
123,80,104,99,143,252,47,3,209,143,78,187,171,0,0,1,
0,57,255,59,3,199,5,213,0,19,0,62,64,32,18,6,
185,0,16,8,185,10,4,0,2,14,10,12,129,2,194,20,
15,0,89,17,13,1,87,9,5,89,11,7,3,20,16,212,
60,60,236,50,252,60,60,236,50,49,0,16,228,244,196,50,
16,196,50,16,238,50,16,238,50,48,37,33,17,35,17,33,
53,33,17,33,53,33,17,51,17,33,21,33,17,33,3,199,
254,145,176,254,145,1,111,254,145,1,111,176,1,111,254,145,
1,111,223,254,92,1,164,154,2,31,153,1,164,254,92,153,
253,225,0,1,0,219,2,72,1,174,3,70,0,3,0,18,
183,2,131,0,4,1,25,0,4,16,212,236,49,0,16,212,
236,48,19,51,21,35,219,211,211,3,70,254,0,1,0,174,
255,18,1,211,0,254,0,5,0,24,64,11,3,158,0,131,
6,3,4,1,25,0,6,16,212,236,212,204,49,0,16,252,
236,48,37,51,21,3,35,19,1,0,211,164,129,82,254,172,
254,192,1,64,0,2,0,174,255,18,3,109,0,254,0,5,
0,11,0,39,64,19,9,3,158,6,0,131,12,3,4,1,
25,0,7,9,10,7,25,6,12,16,220,236,212,204,16,220,
238,212,206,49,0,16,252,60,236,50,48,37,51,21,3,35,
19,37,51,21,3,35,19,2,154,211,164,129,82,254,102,211,
164,129,82,254,172,254,192,1,64,172,172,254,192,1,64,0,
0,7,0,113,255,227,10,76,5,240,0,11,0,23,0,35,
0,39,0,51,0,63,0,75,0,174,64,68,36,15,37,38,
37,38,15,39,36,39,66,64,0,146,12,46,146,30,141,40,
146,24,70,6,146,52,12,141,58,38,18,140,36,24,145,76,
37,73,67,39,49,43,67,13,61,9,13,15,14,3,13,21,
49,13,27,61,14,73,13,21,55,43,13,27,14,33,11,76,
16,252,228,236,212,196,236,228,16,238,16,238,246,238,16,238,
17,18,57,17,18,57,49,0,16,228,50,244,60,60,228,50,
236,50,16,238,246,238,16,238,50,48,75,83,88,7,16,5,
237,7,16,5,237,89,34,1,75,176,20,84,75,176,9,84,
91,75,176,11,84,91,75,176,12,84,91,75,176,13,84,91,
75,176,14,84,91,88,189,0,76,0,64,0,1,0,76,0,
76,255,192,56,17,55,56,89,1,34,6,21,20,22,51,50,
54,53,52,38,39,50,22,21,20,6,35,34,38,53,52,54,
1,50,22,21,20,6,35,34,38,53,52,54,33,51,1,35,
19,34,6,21,20,22,51,50,54,53,52,38,1,50,22,21,
20,6,35,34,38,53,52,54,23,34,6,21,20,22,51,50,
54,53,52,38,8,244,87,100,100,87,85,99,99,85,158,186,
187,157,160,186,187,249,116,158,188,187,159,159,185,186,4,37,
160,252,90,160,31,86,99,98,87,87,99,100,3,178,158,186,
187,157,160,186,187,159,87,99,99,87,85,99,99,2,145,148,
132,130,149,149,130,131,149,127,220,187,187,219,219,187,188,219,
2,224,219,187,189,218,219,188,186,220,249,243,5,142,149,130,
132,148,148,132,129,150,253,159,220,187,187,219,219,187,188,219,
127,148,132,130,149,149,130,131,149,0,255,255,0,16,0,0,
5,104,7,109,2,39,0,36,0,0,0,0,0,7,1,7,
0,188,1,117,255,255,0,201,0,0,4,139,7,109,2,39,
0,40,0,0,0,0,0,7,1,7,0,158,1,117,255,255,
0,16,0,0,5,104,7,107,2,39,0,36,0,0,0,0,
0,7,1,4,0,188,1,117,255,255,0,201,0,0,4,139,
7,78,2,39,0,40,0,0,0,0,0,7,1,3,0,158,
1,117,255,255,0,201,0,0,4,139,7,107,2,39,0,40,
0,0,0,0,0,7,1,6,0,158,1,117,255,255,0,162,
0,0,2,31,7,107,2,39,0,44,0,0,0,0,0,7,
1,4,255,47,1,117,255,255,255,254,0,0,2,96,7,109,
2,39,0,44,0,0,0,0,0,7,1,7,255,47,1,117,
255,255,0,6,0,0,2,88,7,78,2,39,0,44,0,0,
0,0,0,7,1,3,255,47,1,117,255,255,0,59,0,0,
1,186,7,107,2,39,0,44,0,0,0,0,0,7,1,6,
255,47,1,117,255,255,0,115,255,227,5,217,7,107,2,39,
0,50,0,0,0,0,0,7,1,4,1,39,1,117,255,255,
0,115,255,227,5,217,7,109,2,39,0,50,0,0,0,0,
0,7,1,7,1,39,1,117,255,255,0,115,255,227,5,217,
7,107,2,39,0,50,0,0,0,0,0,7,1,6,1,39,
1,117,255,255,0,178,255,227,5,41,7,107,2,39,0,56,
0,0,0,0,0,7,1,4,0,238,1,117,255,255,0,178,
255,227,5,41,7,109,2,39,0,56,0,0,0,0,0,7,
1,7,0,238,1,117,255,255,0,178,255,227,5,41,7,107,
2,39,0,56,0,0,0,0,0,7,1,6,0,238,1,117,
0,1,0,193,0,0,1,121,4,96,0,3,0,32,183,0,
191,2,1,8,0,70,4,16,252,236,49,0,47,236,48,64,
11,16,5,64,5,80,5,96,5,112,5,5,1,93,19,51,
17,35,193,184,184,4,96,251,160,0,0,1,0,193,4,238,
3,63,6,102,0,6,0,55,64,12,4,5,2,180,0,179,
7,4,2,117,6,7,16,220,236,57,49,0,16,244,236,50,
57,48,0,75,176,9,84,75,176,14,84,91,88,189,0,7,
255,192,0,1,0,7,0,7,0,64,56,17,55,56,89,1,
51,19,35,39,7,35,1,182,148,245,139,180,180,139,6,102,
254,136,245,245,0,1,0,182,5,29,3,74,6,55,0,27,
0,99,64,36,0,18,7,14,11,4,1,18,7,15,11,4,
18,195,25,7,4,195,21,11,237,28,15,1,14,0,7,21,
86,22,119,7,86,8,118,28,16,244,236,252,236,17,57,57,
57,57,49,0,16,252,60,252,212,60,236,17,18,57,17,18,
57,17,18,57,17,18,57,48,0,75,176,9,84,75,176,12,
84,91,88,189,0,28,255,192,0,1,0,28,0,28,0,64,
56,17,55,56,89,1,39,46,1,35,34,6,7,35,62,1,
51,50,22,31,1,30,1,51,50,54,55,51,14,1,35,34,
38,1,252,57,22,33,13,38,36,2,125,2,102,91,38,64,
37,57,22,33,13,38,36,2,125,2,102,91,38,64,5,90,
55,20,19,73,82,135,147,28,33,55,20,19,73,82,135,147,
28,0,0,1,0,213,5,98,3,43,5,246,0,3,0,47,
183,2,239,0,238,4,1,0,4,16,212,204,49,0,16,252,
236,48,0,75,176,9,84,75,176,14,84,91,88,189,0,4,
255,192,0,1,0,4,0,4,0,64,56,17,55,56,89,19,
33,21,33,213,2,86,253,170,5,246,148,0,0,1,0,199,
5,41,3,57,6,72,0,13,0,87,64,14,11,240,4,7,
0,179,14,7,86,8,1,86,0,14,16,220,236,212,236,49,
0,16,244,60,212,236,48,0,75,176,9,84,88,189,0,14,
255,192,0,1,0,14,0,14,0,64,56,17,55,56,89,0,
75,176,15,84,75,176,16,84,91,75,176,17,84,91,88,189,
0,14,0,64,0,1,0,14,0,14,255,192,56,17,55,56,
89,19,51,30,1,51,50,54,55,51,14,1,35,34,38,199,
118,11,97,87,86,96,13,118,10,158,145,145,158,6,72,75,
75,74,76,143,144,144,0,1,1,154,5,68,2,102,6,16,
0,3,0,44,64,9,2,206,0,205,4,1,100,0,4,16,
212,236,49,0,16,252,236,48,0,75,176,9,84,88,189,0,
4,255,192,0,1,0,4,0,4,0,64,56,17,55,56,89,
1,51,21,35,1,154,204,204,6,16,204,0,0,2,0,238,
4,225,3,18,7,6,0,11,0,23,0,95,64,17,3,193,
21,242,9,193,15,241,24,0,86,12,120,6,86,18,24,16,
212,236,244,236,49,0,16,244,236,244,236,48,0,75,176,9,
84,75,176,12,84,91,88,189,0,24,255,192,0,1,0,24,
0,24,0,64,56,17,55,56,89,1,75,176,10,84,75,176,
11,84,91,75,176,12,84,91,88,189,0,24,255,192,0,1,
0,24,0,24,0,64,56,17,55,56,89,1,52,38,35,34,
6,21,20,22,51,50,54,55,20,6,35,34,38,53,52,54,
51,50,22,2,152,88,64,65,87,87,65,64,88,122,159,115,
115,159,159,115,115,159,5,244,63,88,87,64,65,87,88,64,
115,160,160,115,115,159,159,0,0,1,1,35,254,117,2,193,
0,0,0,19,0,31,64,14,9,6,10,13,243,6,0,19,
0,16,39,3,9,20,16,220,212,236,212,204,49,0,47,212,
252,196,18,57,48,33,22,22,21,20,6,35,34,38,39,53,
22,22,51,50,54,53,52,38,39,2,84,55,54,120,118,46,
87,43,34,74,47,59,60,43,45,62,105,48,89,91,12,12,
131,17,15,48,46,30,87,61,0,2,0,240,4,238,3,174,
6,102,0,3,0,7,0,66,64,17,6,2,180,4,0,179,
8,4,7,3,0,5,1,3,5,7,8,16,212,220,212,204,
17,57,17,18,57,49,0,16,244,60,236,50,48,0,75,176,
9,84,75,176,14,84,91,88,189,0,8,255,192,0,1,0,
8,0,8,0,64,56,17,55,56,89,1,51,3,35,3,51,
3,35,2,252,178,248,135,129,170,223,137,6,102,254,136,1,
120,254,136,0,0,1,1,76,254,117,2,193,0,0,0,19,
0,32,64,15,11,14,10,7,243,14,244,0,1,0,10,4,
39,17,20,16,212,236,196,212,204,49,0,47,252,252,196,18,
57,48,33,51,6,6,21,20,22,51,50,54,55,21,6,6,
35,34,38,53,52,54,1,184,119,45,43,55,54,32,62,31,
38,68,30,122,115,53,61,88,31,46,46,15,15,133,10,10,
87,93,48,105,0,1,0,193,4,238,3,63,6,102,0,6,
0,55,64,12,3,0,180,4,1,179,7,3,5,117,1,7,
16,220,236,57,49,0,16,244,60,236,57,48,0,75,176,9,
84,75,176,14,84,91,88,189,0,7,255,192,0,1,0,7,
0,7,0,64,56,17,55,56,89,1,3,51,23,55,51,3,
1,182,245,139,180,180,139,245,4,238,1,120,245,245,254,136,
0,1,255,242,0,0,4,117,5,213,0,13,0,63,64,30,
12,11,10,4,3,2,6,0,6,149,0,129,8,3,4,1,
11,14,0,4,5,1,28,12,7,58,9,0,121,14,16,244,
60,236,196,252,60,196,17,18,57,17,18,57,49,0,47,228,
236,17,23,57,48,180,48,15,80,15,2,1,93,19,51,17,
37,23,1,17,33,21,33,17,7,39,55,211,203,1,57,80,
254,119,2,215,252,94,148,77,225,5,213,253,152,219,111,254,
238,253,227,170,2,59,106,110,158,0,0,1,0,2,0,0,
2,72,6,20,0,11,0,94,64,26,10,9,8,4,3,2,
6,0,151,6,3,4,1,9,10,0,4,122,5,1,8,10,
122,7,0,12,16,212,60,228,252,60,228,17,18,57,17,18,
57,49,0,47,236,23,57,48,1,75,176,16,84,88,189,0,
12,0,64,0,1,0,12,0,12,255,192,56,17,55,56,89,
64,19,16,13,64,13,80,13,96,13,115,4,122,10,112,13,
224,13,240,13,9,93,19,51,17,55,23,7,17,35,17,7,
39,55,199,184,125,76,201,184,123,74,197,6,20,253,166,90,
106,141,252,227,2,154,88,106,141,0,255,255,0,135,255,227,
4,162,7,109,2,39,0,54,0,0,0,0,0,7,1,8,
0,139,1,117,255,255,0,111,255,227,3,199,6,102,2,39,
0,86,0,0,0,0,0,7,0,224,0,23,0,0,255,255,
0,92,0,0,5,31,7,109,2,39,0,61,0,0,0,0,
0,7,1,8,0,190,1,117,255,255,0,88,0,0,3,219,
6,102,2,39,0,93,0,0,0,0,0,7,0,224,0,27,
0,0,0,2,1,4,254,162,1,174,5,152,0,3,0,7,
0,28,64,13,1,245,0,4,245,5,8,4,0,5,6,2,
8,16,220,60,236,50,49,0,16,212,236,212,236,48,1,17,
35,17,19,17,35,17,1,174,170,170,170,1,152,253,10,2,
246,4,0,253,10,2,246,0,0,2,0,10,0,0,5,186,
5,213,0,12,0,25,0,103,64,32,16,9,169,11,13,149,
0,129,18,149,14,11,7,7,1,25,19,4,15,13,22,25,
4,50,10,17,13,28,8,0,121,26,16,244,60,236,50,196,
244,236,16,196,23,57,49,0,47,198,50,238,246,238,16,238,
50,48,64,40,32,27,127,27,176,27,3,159,9,159,10,159,
11,159,12,159,14,159,15,159,16,159,17,191,9,191,10,191,
11,191,12,191,14,191,15,191,16,191,17,16,93,1,93,19,
33,32,0,17,16,0,41,1,17,35,53,51,19,17,33,21,
33,17,51,32,0,17,16,0,33,211,1,160,1,177,1,150,
254,105,254,80,254,96,201,201,203,1,80,254,176,243,1,53,
1,31,254,225,254,203,5,213,254,151,254,128,254,126,254,150,
2,188,144,1,227,254,29,144,253,234,1,24,1,46,1,44,
1,23,0,2,0,113,255,227,4,117,6,20,0,14,0,40,
1,39,64,94,37,123,38,37,30,35,30,36,123,35,35,30,
15,123,35,30,40,123,39,40,30,35,30,38,39,40,39,37,
36,37,40,40,39,34,35,34,31,32,31,33,32,32,31,66,
40,39,38,37,34,33,32,31,8,35,30,3,15,35,3,185,
27,9,185,21,140,27,35,177,41,38,39,18,12,33,32,24,
40,37,35,34,31,5,30,15,6,12,18,18,81,6,18,24,
69,41,16,252,236,244,236,17,57,57,23,57,18,57,57,17,
18,57,57,49,0,16,236,196,244,236,16,238,18,57,18,57,
18,23,57,48,75,83,88,7,16,14,201,7,16,8,201,7,
16,8,201,7,16,14,201,7,16,8,237,7,14,237,7,16,
5,237,7,16,8,237,89,34,178,63,42,1,1,93,64,118,
22,37,43,31,40,34,47,35,47,36,41,37,45,38,45,39,
42,40,54,37,70,37,88,32,88,33,96,32,96,33,102,34,
117,32,117,33,117,34,19,37,35,37,36,38,38,38,39,39,
40,54,36,54,37,70,36,69,37,90,32,90,33,98,32,98,
33,127,0,127,1,127,2,122,3,123,9,127,10,127,11,127,
12,127,13,127,14,127,15,127,16,127,17,127,18,127,19,127,
20,123,21,122,27,122,28,127,29,127,30,118,32,118,33,120,
34,160,42,240,42,39,93,0,93,1,46,1,35,34,6,21,
20,22,51,50,54,53,52,38,19,22,18,21,20,0,35,34,
0,53,52,0,51,50,22,23,39,5,39,37,39,51,23,37,
23,5,3,70,50,88,41,167,185,174,146,145,174,54,9,126,
114,254,228,230,231,254,229,1,20,221,18,52,42,159,254,193,
33,1,25,181,228,127,1,77,33,254,217,3,147,17,16,216,
195,188,222,222,188,122,188,1,38,143,254,224,173,255,254,201,
1,55,255,250,1,55,5,5,180,107,99,92,204,145,111,97,
98,0,255,255,255,252,0,0,4,231,7,107,2,39,0,60,
0,0,0,0,0,7,1,4,0,115,1,117,255,255,0,61,
254,86,4,127,6,102,2,39,0,92,0,0,0,0,0,7,
0,141,0,94,0,0,0,2,0,201,0,0,4,141,5,213,
0,12,0,21,0,61,64,27,14,149,9,13,149,2,246,0,
129,11,21,15,9,3,4,1,18,25,6,63,13,10,1,28,
0,4,22,16,252,236,50,50,252,236,17,23,57,49,0,47,
244,252,236,212,236,48,64,9,15,23,31,23,63,23,95,23,
4,1,93,19,51,17,51,50,4,21,20,4,43,1,17,35,
19,17,51,50,54,53,52,38,35,201,202,254,251,1,1,254,
255,251,254,202,202,254,141,154,153,142,5,213,254,248,225,220,
220,226,254,174,4,39,253,209,146,134,134,145,0,2,0,186,
254,86,4,164,6,20,0,16,0,28,0,62,64,27,20,185,
5,8,26,185,0,14,140,8,184,1,189,3,151,29,17,18,
11,71,23,4,0,8,2,70,29,16,252,236,50,50,244,236,
49,0,16,236,228,228,244,196,236,16,198,238,48,64,9,96,
30,128,30,160,30,224,30,4,1,93,37,17,35,17,51,17,
62,1,51,50,18,17,16,2,35,34,38,1,52,38,35,34,
6,21,20,22,51,50,54,1,115,185,185,58,177,123,204,255,
255,204,123,177,2,56,167,146,146,167,167,146,146,167,168,253,
174,7,190,253,162,100,97,254,188,254,248,254,248,254,188,97,
1,235,203,231,231,203,203,231,231,0,0,1,0,217,2,45,
5,219,2,215,0,3,0,17,182,0,156,2,4,1,0,4,
16,212,196,49,0,16,212,236,48,19,33,21,33,217,5,2,
250,254,2,215,170,0,0,1,1,25,0,63,5,156,4,197,
0,11,0,133,64,77,10,156,11,10,7,8,7,9,156,8,
8,7,4,156,3,4,7,7,6,5,156,6,7,6,4,156,
5,4,1,2,1,3,156,2,2,1,11,156,0,1,0,10,
156,9,10,1,1,0,66,10,8,7,6,4,2,1,0,8,
5,3,11,9,12,11,10,9,7,5,4,3,1,8,2,0,
8,6,12,16,212,60,204,50,23,57,49,0,16,212,60,204,
50,23,57,48,75,83,88,7,16,8,237,7,16,5,237,7,
16,5,237,7,16,8,237,7,16,5,237,7,16,8,237,7,
16,5,237,7,16,8,237,89,34,9,2,7,1,1,39,1,
1,55,1,1,5,156,254,55,1,201,119,254,53,254,53,118,
1,200,254,56,118,1,203,1,203,4,76,254,53,254,55,121,
1,203,254,53,121,1,201,1,203,121,254,53,1,203,0,1,
0,137,2,156,2,197,5,223,0,10,0,44,64,24,7,0,
221,9,3,221,4,2,221,9,247,5,145,11,8,124,6,93,
3,124,1,124,0,11,16,220,244,228,252,228,49,0,16,244,
236,236,212,236,16,238,50,48,19,51,17,7,53,55,51,17,
51,21,33,156,204,223,230,137,205,253,215,3,10,2,99,41,
116,39,253,43,110,0,0,1,0,94,2,156,2,180,5,240,
0,24,0,74,64,36,0,125,6,4,0,23,125,6,6,4,
66,4,2,0,14,221,15,0,221,2,247,11,221,15,18,145,
25,0,14,8,126,1,21,14,3,25,16,220,196,212,196,236,
17,57,49,0,16,244,196,236,252,236,16,238,17,18,57,48,
75,83,88,7,16,5,237,23,50,7,5,237,89,34,1,33,
21,33,53,54,55,0,53,52,38,35,34,6,7,53,54,54,
51,50,22,21,20,1,6,1,12,1,168,253,170,34,63,1,
88,104,85,52,122,72,77,133,57,145,174,254,181,56,3,14,
114,110,31,56,1,49,94,66,81,35,35,123,28,28,132,108,
139,254,228,48,0,1,0,98,2,141,2,205,5,240,0,40,
0,72,64,39,0,21,19,10,221,9,31,221,32,19,221,21,
13,221,9,248,6,247,28,221,32,248,35,145,41,22,19,0,
20,25,126,38,16,126,3,20,31,9,41,16,220,196,196,212,
236,212,236,17,57,57,57,49,0,16,244,228,236,252,228,236,
212,236,16,238,16,238,17,18,57,48,1,22,22,21,20,6,
35,34,38,39,53,22,22,51,50,54,53,52,38,35,35,53,
51,50,54,53,52,38,35,34,6,7,53,54,54,51,50,22,
21,20,6,2,12,92,101,190,177,57,125,70,52,119,67,109,
120,111,108,86,94,94,97,100,95,40,102,81,73,128,55,144,
169,90,4,96,18,109,82,124,134,21,20,121,27,26,79,70,
74,76,108,63,60,58,61,18,23,115,17,18,118,99,69,96,
255,255,0,137,255,227,7,127,5,240,0,39,0,240,0,0,
0,0,0,39,0,188,3,53,0,0,0,7,1,9,4,139,
253,100,255,255,0,137,255,227,7,63,5,240,0,39,0,240,
0,0,0,0,0,39,0,188,3,53,0,0,0,7,0,241,
4,139,253,100,255,255,0,98,255,227,7,127,5,240,0,39,
0,242,0,0,0,0,0,39,0,188,3,53,0,0,0,7,
1,9,4,139,253,100,255,255,0,115,255,227,5,139,7,109,
2,39,0,42,0,0,0,0,0,7,1,10,1,27,1,117,
255,255,0,113,254,86,4,90,6,72,2,39,0,74,0,0,
0,0,0,7,0,218,0,139,0,0,255,255,0,201,0,0,
1,149,7,80,2,39,0,44,0,0,0,0,0,7,1,11,
255,47,1,117,255,255,0,135,254,117,4,162,5,240,2,39,
0,54,0,0,0,0,0,7,0,221,0,139,0,0,255,255,
0,111,254,117,3,199,4,123,2,39,0,86,0,0,0,0,
0,7,0,221,0,23,0,0,255,255,0,115,255,227,5,39,
7,107,2,39,0,38,0,0,0,0,0,7,1,4,1,45,
1,117,255,255,0,113,255,227,3,231,6,102,2,39,0,70,
0,0,0,0,0,7,0,141,0,137,0,0,255,255,0,115,
255,227,5,39,7,109,2,39,0,38,0,0,0,0,0,7,
1,8,1,45,1,117,255,255,0,113,255,227,3,231,6,102,
2,39,0,70,0,0,0,0,0,7,0,224,0,137,0,0,
0,2,0,113,255,227,4,244,6,20,0,24,0,36,0,74,
64,36,7,3,211,9,1,249,34,185,0,22,28,185,13,16,
140,22,184,5,151,11,2,31,12,4,3,0,8,8,10,6,
71,25,18,19,69,37,16,252,236,244,60,196,252,23,60,196,
49,0,47,236,228,244,196,236,16,196,238,253,60,238,50,48,
182,96,38,128,38,160,38,3,1,93,1,17,33,53,33,53,
51,21,51,21,35,17,35,53,14,1,35,34,2,17,16,18,
51,50,22,1,20,22,51,50,54,53,52,38,35,34,6,3,
162,254,186,1,70,184,154,154,184,58,177,124,203,255,255,203,
124,177,253,199,167,146,146,168,168,146,146,167,3,182,1,78,
125,147,147,125,250,252,168,100,97,1,68,1,8,1,8,1,
68,97,254,21,203,231,231,203,203,231,231,0,0,1,0,100,
1,223,2,127,2,131,0,3,0,17,182,0,156,2,4,1,
0,4,16,220,204,49,0,16,212,236,48,19,33,21,33,100,
2,27,253,229,2,131,164,0,0,1,0,219,2,72,1,174,
3,70,0,3,0,18,183,2,131,0,4,1,25,0,4,16,
212,236,49,0,16,212,236,48,19,51,21,35,219,211,211,3,
70,254,0,1,0,0,255,227,4,143,5,240,0,49,1,28,
64,58,32,18,211,34,16,43,7,211,9,25,161,26,174,22,
149,29,1,161,0,174,4,149,47,145,29,140,41,9,50,43,
34,33,41,35,38,18,16,10,3,13,9,17,8,44,32,38,
19,7,17,8,17,13,28,25,0,38,42,33,47,60,212,196,
50,252,196,196,18,57,57,18,57,57,17,18,57,17,23,57,
18,57,57,17,57,57,49,0,16,196,50,228,244,236,244,236,
16,238,246,238,16,238,50,221,60,238,50,48,1,75,176,9,
84,75,176,12,84,91,75,176,13,84,91,75,176,15,84,91,
75,176,23,84,91,75,176,24,84,91,88,189,0,50,255,192,
0,1,0,50,0,50,0,64,56,17,55,56,89,64,122,14,
0,14,1,11,2,11,49,84,20,105,12,108,14,110,15,111,
16,111,17,111,18,111,19,105,20,107,31,111,32,111,33,111,
34,111,35,110,36,108,37,105,39,105,45,159,7,159,8,159,
9,159,10,159,11,159,12,159,13,159,14,159,15,159,16,159,
17,159,18,159,19,150,31,159,32,159,33,159,34,159,35,159,
36,159,37,159,38,159,39,159,40,159,41,159,42,159,43,159,
44,157,45,50,0,8,0,9,16,8,16,9,32,8,32,9,
85,21,83,30,106,21,103,31,10,93,0,93,1,21,46,1,
35,34,6,7,33,7,33,14,1,21,20,22,23,33,7,33,
30,1,51,50,54,55,21,14,1,35,34,0,3,35,55,51,
52,38,53,52,54,53,35,55,51,18,0,51,50,22,4,143,
91,169,102,157,202,32,2,65,55,253,230,2,1,1,2,1,
190,56,254,138,32,202,157,102,169,91,89,185,96,237,254,203,
40,211,55,139,1,1,194,55,156,40,1,54,236,98,185,5,
98,213,105,90,200,187,123,24,46,35,32,46,24,123,187,202,
90,105,211,72,72,1,34,1,3,123,23,47,32,35,47,23,
123,1,1,1,34,71,0,2,0,215,5,14,3,41,5,217,
0,3,0,7,0,165,64,13,4,0,206,6,2,8,1,100,
0,5,100,4,8,16,212,252,220,236,49,0,16,212,60,236,
50,48,0,75,176,14,84,75,176,17,84,91,88,189,0,8,
0,64,0,1,0,8,0,8,255,192,56,17,55,56,89,1,
75,176,14,84,75,176,13,84,91,75,176,23,84,91,88,189,
0,8,255,192,0,1,0,8,0,8,0,64,56,17,55,56,
89,1,75,176,17,84,75,176,25,84,91,88,189,0,8,0,
64,0,1,0,8,0,8,255,192,56,17,55,56,89,0,75,
176,24,84,88,189,0,8,255,192,0,1,0,8,0,8,0,
64,56,17,55,56,89,64,17,96,1,96,2,96,5,96,6,
112,1,112,2,112,5,112,6,8,1,93,1,51,21,35,37,
51,21,35,2,94,203,203,254,121,203,203,5,217,203,203,203,
0,1,1,115,4,238,2,240,5,246,0,3,0,127,64,17,
2,3,0,3,1,0,0,3,66,0,2,250,4,1,3,3,
4,16,196,16,192,49,0,16,244,204,48,75,83,88,7,16,
5,201,7,16,5,201,89,34,0,75,176,12,84,88,189,0,
4,255,192,0,1,0,4,0,4,0,64,56,17,55,56,89,
0,75,176,14,84,88,189,0,4,0,64,0,1,0,4,0,
4,255,192,56,17,55,56,89,64,32,6,2,21,2,37,1,
37,2,54,2,70,2,86,2,106,1,103,2,9,15,0,15,
1,31,0,31,1,47,0,47,1,6,93,1,93,1,51,3,
35,2,55,185,228,153,5,246,254,248,0,1,0,182,5,14,
3,74,5,233,0,29,0,117,64,33,22,16,15,3,19,12,
7,1,0,3,8,23,12,195,4,19,195,27,8,250,30,16,
1,15,0,7,22,86,24,7,86,9,30,16,212,236,212,236,
17,57,57,57,57,49,0,16,244,60,236,212,236,50,18,23,
57,17,18,23,57,48,0,75,176,12,84,88,189,0,30,255,
192,0,1,0,30,0,30,0,64,56,17,55,56,89,0,75,
176,14,84,88,189,0,30,0,64,0,1,0,30,0,30,255,
192,56,17,55,56,89,180,16,11,31,26,2,93,1,39,46,
1,35,34,6,29,1,35,52,54,51,50,22,31,1,30,1,
51,50,54,61,1,51,14,1,35,34,38,1,252,57,25,31,
12,36,40,125,103,86,36,61,48,57,23,34,15,32,40,125,
2,103,84,34,59,5,57,33,14,11,50,45,6,101,118,16,
27,30,13,12,51,41,6,100,119,16,0,1,1,12,4,238,
2,139,5,246,0,3,0,137,64,17,1,2,3,2,0,3,
3,2,66,0,1,250,4,1,3,3,4,16,196,16,192,49,
0,16,244,204,48,75,83,88,7,16,5,201,7,16,5,201,
89,34,0,75,176,12,84,88,189,0,4,255,192,0,1,0,
4,0,4,0,64,56,17,55,56,89,0,75,176,14,84,88,
189,0,4,0,64,0,1,0,4,0,4,255,192,56,17,55,
56,89,64,42,6,0,6,1,22,0,18,1,36,0,36,1,
53,1,67,1,85,0,85,1,159,0,159,1,175,0,175,1,
14,15,0,15,3,31,0,31,3,47,0,47,3,6,93,1,
93,1,19,35,3,1,199,196,153,230,5,246,254,248,1,8,
0,1,0,207,4,238,3,49,5,248,0,6,0,119,64,10,
4,0,5,2,250,7,4,2,6,7,16,212,196,57,49,0,
16,244,60,196,57,48,0,75,176,12,84,88,189,0,7,255,
192,0,1,0,7,0,7,0,64,56,17,55,56,89,0,75,
176,14,84,88,189,0,7,0,64,0,1,0,7,0,7,255,
192,56,17,55,56,89,1,75,176,14,84,88,189,0,7,255,
192,0,1,0,7,0,7,0,64,56,17,55,56,89,64,19,
15,0,15,1,12,4,31,0,31,1,29,4,47,0,47,1,
45,4,9,0,93,1,51,19,35,39,7,35,1,162,188,211,
139,166,166,139,5,248,254,246,178,178,0,1,0,207,4,238,
3,49,5,248,0,6,0,134,64,10,3,4,1,0,250,7,
3,5,1,7,16,212,196,57,49,0,16,244,196,50,57,48,
0,75,176,12,84,75,176,9,84,91,75,176,10,84,91,75,
176,11,84,91,88,189,0,7,255,192,0,1,0,7,0,7,
0,64,56,17,55,56,89,0,75,176,14,84,88,189,0,7,
0,64,0,1,0,7,0,7,255,192,56,17,55,56,89,1,
75,176,14,84,88,189,0,7,255,192,0,1,0,7,0,7,
0,64,56,17,55,56,89,64,19,0,0,3,3,0,6,16,
0,18,3,16,6,32,0,34,3,32,6,9,0,93,1,3,
51,23,55,51,3,1,162,211,139,166,166,139,211,4,238,1,
10,178,178,254,246,0,0,2,0,63,2,156,2,244,5,223,
0,2,0,13,0,212,64,22,0,3,11,7,221,5,1,9,
247,3,145,14,1,12,10,0,93,6,8,4,12,14,16,220,
212,60,196,236,50,17,57,49,0,16,244,252,212,60,236,50,
18,57,48,1,75,176,14,84,75,176,15,84,91,75,176,16,
84,91,75,176,17,84,91,75,176,11,84,91,75,176,10,84,
91,88,189,0,14,0,64,0,1,0,14,0,14,255,192,56,
17,55,56,89,0,75,176,17,84,75,176,14,84,91,88,189,
0,14,255,192,0,1,0,14,0,14,0,64,56,17,55,56,
89,64,84,11,1,29,1,47,1,57,1,73,1,70,3,89,
3,105,3,139,3,171,3,187,3,11,1,0,15,1,15,2,
15,5,15,6,15,7,15,8,15,11,15,12,15,13,19,0,
31,1,31,2,31,5,31,6,31,7,31,8,31,11,31,12,
31,13,34,0,53,0,71,0,75,13,83,0,91,13,101,0,
132,0,165,0,181,0,30,93,1,93,9,1,33,3,51,17,
51,21,35,21,35,53,33,53,1,221,254,203,1,53,22,166,
135,135,144,254,98,5,102,254,93,2,28,253,228,109,186,186,
121,0,0,1,0,199,5,6,3,57,5,248,0,13,0,106,
64,14,7,0,4,195,11,250,14,7,86,8,1,86,0,14,
16,212,236,212,236,49,0,16,244,252,196,50,48,0,75,176,
12,84,88,189,0,14,255,192,0,1,0,14,0,14,0,64,
56,17,55,56,89,0,75,176,14,84,88,189,0,14,0,64,
0,1,0,14,0,14,255,192,56,17,55,56,89,1,75,176,
14,84,75,176,15,84,91,88,189,0,14,255,192,0,1,0,
14,0,14,0,64,56,17,55,56,89,19,51,30,1,51,50,
54,55,51,14,1,35,34,38,199,118,13,99,83,82,97,16,
118,10,160,143,144,159,5,248,54,57,55,56,119,123,122,0,
0,1,1,154,5,14,2,102,5,219,0,3,0,17,182,0,
2,250,4,1,0,4,16,212,204,49,0,16,244,204,48,1,
51,21,35,1,154,204,204,5,219,205,0,0,0,0,0,2,
0,1,0,0,0,0,0,20,0,3,0,1,0,0,1,26,
0,0,1,6,0,0,1,0,0,0,0,0,0,0,1,3,
0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,1,0,0,3,4,5,6,7,8,9,10,11,12,
13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,
29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,
45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,
61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,
77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,
93,94,95,96,97,0,98,99,100,101,102,103,104,105,106,107,
108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,
124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,
140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,
156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,
172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,
204,205,206,207,208,209,0,210,211,212,213,214,215,216,217,218,
219,220,221,222,223,224,0,4,2,62,0,0,0,58,0,32,
0,4,0,26,0,126,0,255,1,7,1,17,1,31,1,49,
1,66,1,83,1,97,1,120,1,126,1,146,2,199,2,221,
3,169,3,192,32,38,32,48,32,58,32,172,33,34,34,6,
34,30,34,43,34,72,34,101,37,202,251,2,255,255,0,0,
0,32,0,160,1,6,1,12,1,30,1,48,1,65,1,82,
1,94,1,120,1,125,1,146,2,198,2,216,3,169,3,192,
32,19,32,48,32,57,32,172,33,34,34,2,34,15,34,43,
34,72,34,96,37,202,251,1,255,255,255,227,0,0,255,245,
0,0,255,216,0,0,255,160,255,94,0,0,255,67,255,104,
255,20,0,0,0,0,252,246,252,219,0,0,224,150,224,133,
224,86,223,106,0,0,0,0,222,113,222,95,0,0,218,239,
5,191,0,1,0,0,0,56,0,0,0,244,0,0,0,252,
0,0,0,0,0,250,0,0,0,0,0,0,0,250,0,252,
0,0,0,0,1,2,0,0,0,0,0,0,0,0,1,32,
1,40,0,0,0,0,1,66,0,0,0,0,0,0,0,172,
0,163,0,132,0,133,0,189,0,150,0,231,0,134,0,142,
0,139,0,157,0,169,0,164,1,0,0,138,0,217,0,131,
0,147,0,241,0,242,0,141,0,151,0,136,0,195,0,221,
0,240,0,158,0,170,0,243,0,244,0,245,0,162,0,173,
0,201,0,199,0,174,0,98,0,99,0,144,0,100,0,203,
0,101,0,200,0,202,0,207,0,204,0,205,0,206,0,232,
0,102,0,210,0,208,0,209,0,175,0,103,0,239,0,145,
0,213,0,211,0,212,0,104,0,234,0,236,0,137,0,106,
0,105,0,107,0,109,0,108,0,110,0,160,0,111,0,113,
0,112,0,114,0,115,0,117,0,116,0,118,0,119,0,233,
0,120,0,122,0,121,0,123,0,125,0,124,0,184,0,161,
0,127,0,126,0,128,0,129,0,235,0,237,0,186,0,253,
0,254,0,0,0,0,0,0,0,255,0,248,0,214,0,249,
0,250,0,227,0,228,0,215,0,224,0,218,0,219,0,220,
0,223,0,216,0,222,0,178,0,179,0,0,0,0,0,0,
0,182,0,183,0,196,0,0,0,180,0,181,0,197,0,0,
0,130,0,194,0,135,0,0,0,0,0,0,0,171,0,152,
0,0,0,0,0,0,0,168,0,154,0,0,0,153,0,238,
0,0,0,0,0,188,0,0,0,0,0,0,1,1,0,165,
0,0,0,0,0,0,0,146,0,143,0,0,0,0,0,0,
0,148,0,149,4,205,0,102,0,0,0,0,2,139,0,0,
2,139,0,0,3,53,1,53,3,174,0,197,6,180,0,158,
5,23,0,170,7,154,0,113,6,61,0,129,2,51,0,197,
3,31,0,176,3,31,0,164,4,0,0,61,6,180,0,217,
2,139,0,158,2,227,0,100,2,139,0,219,2,178,0,0,
5,23,0,135,5,23,0,225,5,23,0,150,5,23,0,156,
5,23,0,100,5,23,0,158,5,23,0,143,5,23,0,168,
5,23,0,139,5,23,0,129,2,178,0,240,2,178,0,158,
6,180,0,217,6,180,0,217,6,180,0,217,4,63,0,147,
8,0,0,135,5,121,0,16,5,125,0,201,5,150,0,115,
6,41,0,201,5,14,0,201,4,154,0,201,6,51,0,115,
6,4,0,201,2,92,0,201,2,92,255,150,5,63,0,201,
4,117,0,201,6,231,0,201,5,252,0,201,6,76,0,115,
4,211,0,201,6,76,0,115,5,143,0,201,5,20,0,135,
4,227,255,250,5,219,0,178,5,121,0,16,7,233,0,68,
5,123,0,61,4,227,255,252,5,123,0,92,3,31,0,176,
2,178,0,0,3,31,0,199,6,180,0,217,4,0,255,236,
4,0,0,170,4,231,0,123,5,20,0,186,4,102,0,113,
5,20,0,113,4,236,0,113,2,209,0,47,5,20,0,113,
5,18,0,186,2,57,0,193,2,57,255,219,4,162,0,186,
2,57,0,193,7,203,0,186,5,18,0,186,4,229,0,113,
5,20,0,186,5,20,0,113,3,74,0,186,4,43,0,111,
3,35,0,55,5,18,0,174,4,188,0,61,6,139,0,86,
4,188,0,59,4,188,0,61,4,51,0,88,5,23,1,0,
2,178,1,4,5,23,1,0,6,180,0,217,5,121,0,16,
5,121,0,16,5,150,0,115,5,14,0,201,5,252,0,201,
6,76,0,115,5,219,0,178,4,231,0,123,4,231,0,123,
4,231,0,123,4,231,0,123,4,231,0,123,4,231,0,123,
4,102,0,113,4,236,0,113,4,236,0,113,4,236,0,113,
4,236,0,113,2,57,0,144,2,57,255,199,2,57,255,222,
2,57,255,244,5,18,0,186,4,229,0,113,4,229,0,113,
4,229,0,113,4,229,0,113,4,229,0,113,5,18,0,174,
5,18,0,174,5,18,0,174,5,18,0,174,4,0,0,57,
4,0,0,195,5,23,0,172,5,23,0,129,4,0,0,92,
4,184,1,51,5,23,0,158,5,10,0,186,8,0,1,27,
8,0,1,27,8,0,1,39,4,0,1,115,4,0,0,215,
6,180,0,217,7,203,0,8,6,76,0,102,6,170,0,221,
6,180,0,217,6,180,0,217,6,180,0,217,5,23,0,82,
5,23,0,174,4,35,0,104,5,100,0,25,6,14,0,156,
4,182,255,225,4,43,0,47,3,197,0,115,3,197,0,96,
6,29,0,78,7,219,0,123,4,229,0,72,4,63,0,143,
3,53,1,53,6,180,0,217,5,25,0,61,5,23,0,31,
6,180,0,217,5,90,255,250,4,229,0,158,4,229,0,193,
8,0,0,236,5,23,0,0,5,121,0,16,5,121,0,16,
6,76,0,115,8,143,0,115,8,47,0,113,4,0,0,0,
8,0,0,0,4,37,0,174,4,37,0,174,2,139,0,174,
2,139,0,178,6,180,0,217,3,244,0,6,4,188,0,61,
4,227,255,252,1,86,254,137,5,23,0,94,3,51,0,158,
3,51,0,193,5,10,0,47,5,10,0,47,4,0,0,57,
2,139,0,219,2,139,0,174,4,37,0,174,10,188,0,113,
5,121,0,16,5,14,0,201,5,121,0,16,5,14,0,201,
5,14,0,201,2,92,0,162,2,92,255,254,2,92,0,6,
2,92,0,59,6,76,0,115,6,76,0,115,6,76,0,115,
5,219,0,178,5,219,0,178,5,219,0,178,2,57,0,193,
4,0,0,193,4,0,0,182,4,0,0,213,4,0,0,199,
4,0,1,154,4,0,0,238,4,0,1,35,4,0,0,240,
4,0,1,76,4,0,0,193,4,127,255,242,2,70,0,2,
5,20,0,135,4,43,0,111,5,123,0,92,4,51,0,88,
2,178,1,4,6,51,0,10,4,229,0,113,4,227,255,252,
4,188,0,61,4,215,0,201,5,20,0,186,6,180,0,217,
6,180,1,25,3,53,0,137,3,53,0,94,3,53,0,98,
7,193,0,137,7,193,0,137,7,193,0,98,6,51,0,115,
5,20,0,113,2,92,0,201,5,20,0,135,4,43,0,111,
5,150,0,115,4,102,0,113,5,150,0,115,4,102,0,113,
5,20,0,113,2,227,0,100,2,139,0,219,5,23,0,0,
4,0,0,215,4,0,1,115,4,0,0,182,4,0,1,12,
4,0,0,207,4,0,0,207,3,53,0,63,4,0,0,199,
4,0,1,154,0,2,0,0,0,0,0,0,255,43,0,143,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,1,12,0,0,0,1,0,2,0,3,0,4,
0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,
0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,
0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,
0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,
0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,
0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,
0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,
0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,
0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,
0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,
0,85,0,86,0,87,0,88,0,89,0,90,0,91,0,92,
0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,
0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,
0,109,0,110,0,111,0,112,0,113,0,114,0,115,0,116,
0,117,0,118,0,119,0,120,0,121,0,122,0,123,0,124,
0,125,0,126,0,127,0,128,0,129,0,130,0,131,0,132,
0,133,0,134,0,135,0,136,0,137,0,138,0,139,0,140,
0,141,0,142,0,143,0,144,0,145,0,146,0,147,0,148,
0,149,0,150,0,151,0,152,0,153,0,154,0,155,0,156,
0,157,0,158,0,159,0,160,0,161,0,162,0,163,0,164,
0,165,0,166,0,167,0,168,0,169,0,170,0,171,0,172,
0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,
0,181,0,182,0,183,0,184,0,185,0,186,0,187,0,188,
0,189,0,190,0,191,0,192,0,193,0,194,0,195,0,196,
0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,
0,205,0,206,0,207,0,208,0,209,0,211,0,212,0,213,
0,214,0,215,0,216,0,217,0,218,0,219,0,220,0,221,
0,222,0,223,0,224,0,225,0,226,0,227,0,228,0,229,
0,230,0,231,0,232,0,233,0,234,0,235,0,236,0,237,
0,238,0,239,0,240,0,241,0,242,0,243,0,245,0,244,
0,246,0,248,0,249,0,250,0,251,0,252,0,253,0,254,
0,255,1,0,1,1,1,2,1,3,1,4,1,5,1,6,
1,7,1,8,1,9,1,10,1,11,1,12,1,13,9,115,
102,116,104,121,112,104,101,110,14,112,101,114,105,111,100,99,
101,110,116,101,114,101,100,4,69,117,114,111,5,99,54,52,
53,57,5,99,54,52,54,48,5,99,54,52,54,49,5,99,
54,52,54,50,5,99,54,52,54,51,5,99,54,52,54,54,
5,99,54,52,54,55,5,99,54,52,54,56,5,99,54,52,
54,57,0,0,0,0,0,34,0,34,0,34,0,34,0,88,
0,147,0,255,1,182,2,79,3,131,3,178,3,246,4,33,
4,110,4,152,4,180,4,202,4,222,5,3,5,69,5,130,
6,5,6,126,6,225,7,76,7,183,7,252,8,101,8,207,
8,238,9,22,9,82,9,115,9,174,10,31,10,223,11,88,
11,176,11,251,12,58,12,105,12,147,12,230,13,20,13,61,
13,122,14,13,14,47,14,172,15,0,15,69,15,133,15,235,
16,117,16,241,17,41,17,112,17,224,18,189,19,138,19,235,
20,80,20,139,20,177,20,225,21,3,21,24,21,64,21,214,
22,34,22,109,22,185,23,35,23,123,23,223,24,27,24,67,
24,128,24,248,25,22,25,119,25,179,26,4,26,82,26,161,
26,216,27,135,27,196,28,0,28,157,29,186,30,135,31,119,
31,232,32,91,32,114,32,243,33,53,33,66,33,226,33,239,
33,252,34,9,34,22,34,35,34,48,34,61,34,74,34,87,
34,100,34,113,34,126,34,139,34,152,34,165,34,178,34,191,
34,204,34,217,34,230,34,243,35,0,35,13,35,26,35,39,
35,52,35,65,35,78,35,91,35,104,35,148,35,207,36,52,
36,143,37,51,37,83,37,129,38,20,38,186,39,75,39,144,
39,183,40,19,40,88,40,195,41,95,42,37,42,92,42,163,
42,233,43,122,43,211,44,68,44,143,44,177,45,80,45,160,
46,14,46,82,46,170,47,135,48,65,48,189,49,5,49,33,
49,80,49,207,50,72,50,122,50,223,51,70,51,112,51,112,
51,125,51,138,51,151,51,230,52,122,52,143,52,163,52,209,
52,255,53,28,53,57,53,103,53,145,53,158,53,171,53,207,
54,91,54,147,54,205,55,67,55,169,55,235,56,0,56,28,
56,74,57,15,57,28,57,41,57,54,57,67,57,80,57,93,
57,106,57,119,57,132,57,145,57,158,57,171,57,184,57,197,
57,210,57,239,58,28,58,123,58,160,58,229,59,8,59,94,
59,142,59,196,59,244,60,34,60,95,60,167,60,180,60,193,
60,206,60,219,60,254,61,99,62,59,62,72,62,85,62,152,
62,231,62,253,63,97,63,141,63,220,64,58,64,75,64,92,
64,109,64,122,64,135,64,148,64,161,64,174,64,187,64,200,
64,213,64,226,65,64,65,86,65,107,66,69,66,170,66,247,
67,95,67,178,67,255,68,85,68,219,69,42,69,63,0,0,
0,0,0,1,0,0,45,134,0,1,7,148,24,0,0,10,
21,120,0,16,0,36,255,211,0,16,0,37,255,183,0,16,
0,38,0,0,0,16,0,39,0,0,0,16,0,41,0,0,
0,16,0,42,0,75,0,16,0,43,0,0,0,16,0,45,
0,114,0,16,0,46,0,0,0,16,0,47,0,0,0,16,
0,50,0,57,0,16,0,51,0,0,0,16,0,52,0,75,
0,16,0,53,0,0,0,16,0,55,255,68,0,16,0,57,
255,136,0,16,0,58,255,173,0,16,0,59,255,154,0,16,
0,60,255,13,0,16,0,61,0,0,0,16,0,73,0,0,
0,16,0,81,0,0,0,16,0,82,0,38,0,16,0,85,
0,0,0,16,0,89,255,201,0,16,0,90,0,0,0,16,
0,92,255,220,0,16,0,98,255,211,0,16,0,100,0,0,
0,16,0,103,0,57,0,16,0,120,0,0,0,16,0,121,
0,38,0,16,0,122,0,38,0,16,0,123,0,38,0,16,
0,124,0,38,0,16,0,125,0,38,0,16,0,137,0,0,
0,16,0,144,0,0,0,16,0,173,255,211,0,16,0,174,
255,211,0,16,0,175,0,57,0,16,0,186,255,220,0,16,
0,187,255,13,0,16,0,199,255,211,0,16,0,201,255,211,
0,16,0,208,0,57,0,16,0,209,0,57,0,16,0,210,
0,57,0,16,0,229,0,0,0,16,0,233,0,0,0,16,
0,234,255,13,0,16,0,235,255,220,0,16,0,236,0,0,
0,16,0,246,0,75,0,16,0,251,0,0,0,16,0,253,
0,0,0,36,0,16,255,211,0,36,0,17,255,220,0,36,
0,29,255,220,0,36,0,36,0,57,0,36,0,38,255,220,
0,36,0,42,255,220,0,36,0,50,255,220,0,36,0,52,
255,220,0,36,0,54,0,0,0,36,0,55,255,97,0,36,
0,56,0,0,0,36,0,57,255,125,0,36,0,58,255,144,
0,36,0,59,0,0,0,36,0,60,255,97,0,36,0,70,
255,220,0,36,0,71,255,220,0,36,0,72,255,220,0,36,
0,73,255,183,0,36,0,82,255,220,0,36,0,84,255,220,
0,36,0,87,255,220,0,36,0,88,0,0,0,36,0,89,
255,136,0,36,0,90,255,173,0,36,0,92,255,117,0,36,
0,98,0,57,0,36,0,100,255,220,0,36,0,103,255,220,
0,36,0,104,0,0,0,36,0,111,255,220,0,36,0,112,
255,220,0,36,0,113,255,220,0,36,0,114,255,220,0,36,
0,115,255,220,0,36,0,121,255,220,0,36,0,122,255,220,
0,36,0,123,255,220,0,36,0,124,255,220,0,36,0,125,
255,220,0,36,0,126,0,0,0,36,0,127,0,0,0,36,
0,128,0,0,0,36,0,129,0,0,0,36,0,169,255,183,
0,36,0,170,0,0,0,36,0,173,0,57,0,36,0,174,
0,57,0,36,0,175,255,220,0,36,0,180,254,248,0,36,
0,181,255,3,0,36,0,186,255,117,0,36,0,187,255,97,
0,36,0,197,0,47,0,36,0,199,0,57,0,36,0,201,
0,57,0,36,0,208,255,220,0,36,0,209,255,220,0,36,
0,210,255,220,0,36,0,211,0,0,0,36,0,212,0,0,
0,36,0,213,0,0,0,36,0,227,0,0,0,36,0,234,
255,97,0,36,0,235,255,117,0,36,0,246,255,220,0,36,
0,249,0,0,0,36,0,251,255,220,0,36,0,252,255,220,
0,36,0,253,255,220,0,36,0,254,255,220,0,37,0,16,
0,0,0,37,0,38,255,220,0,37,0,42,255,220,0,37,
0,50,255,220,0,37,0,54,255,220,0,37,0,57,255,193,
0,37,0,58,255,183,0,37,0,60,255,144,0,37,0,100,
255,220,0,37,0,103,255,220,0,37,0,169,255,193,0,37,
0,170,255,220,0,37,0,175,255,220,0,37,0,180,255,144,
0,37,0,181,255,144,0,37,0,187,255,144,0,37,0,197,
255,173,0,37,0,208,255,220,0,37,0,209,255,220,0,37,
0,210,255,220,0,37,0,227,255,220,0,37,0,234,255,144,
0,37,0,246,255,220,0,37,0,249,255,220,0,37,0,251,
255,220,0,37,0,253,255,220,0,38,0,16,0,0,0,38,
0,36,0,0,0,38,0,54,0,0,0,38,0,60,255,220,
0,38,0,98,0,0,0,38,0,169,255,220,0,38,0,170,
255,220,0,38,0,173,0,0,0,38,0,174,0,0,0,38,
0,180,0,0,0,38,0,181,0,38,0,38,0,187,255,220,
0,38,0,197,0,0,0,38,0,199,0,0,0,38,0,201,
0,0,0,38,0,227,0,0,0,38,0,234,255,220,0,38,
0,249,0,0,0,39,0,16,0,0,0,39,0,36,255,220,
0,39,0,57,255,220,0,39,0,58,0,0,0,39,0,60,
255,144,0,39,0,98,255,220,0,39,0,169,255,220,0,39,
0,170,255,220,0,39,0,173,255,220,0,39,0,174,255,220,
0,39,0,180,255,211,0,39,0,181,255,201,0,39,0,187,
255,144,0,39,0,197,255,68,0,39,0,199,255,220,0,39,
0,201,255,220,0,39,0,234,255,144,0,41,0,16,0,0,
0,41,0,17,254,183,0,41,0,29,255,97,0,41,0,36,
255,68,0,41,0,54,255,220,0,41,0,55,255,220,0,41,
0,68,255,68,0,41,0,72,255,144,0,41,0,76,255,107,
0,41,0,82,255,183,0,41,0,85,255,107,0,41,0,88,
255,144,0,41,0,92,255,68,0,41,0,98,255,68,0,41,
0,105,255,68,0,41,0,106,255,68,0,41,0,107,255,68,
0,41,0,108,255,68,0,41,0,109,255,68,0,41,0,110,
255,68,0,41,0,112,255,144,0,41,0,113,255,144,0,41,
0,114,255,144,0,41,0,115,255,144,0,41,0,121,255,183,
0,41,0,122,255,183,0,41,0,123,255,183,0,41,0,124,
255,183,0,41,0,125,255,183,0,41,0,126,255,144,0,41,
0,127,255,144,0,41,0,128,255,144,0,41,0,129,255,144,
0,41,0,169,0,0,0,41,0,170,0,0,0,41,0,173,
255,68,0,41,0,174,255,68,0,41,0,180,255,211,0,41,
0,181,0,0,0,41,0,186,255,68,0,41,0,197,254,136,
0,41,0,199,255,68,0,41,0,201,255,68,0,41,0,227,
255,220,0,41,0,235,255,68,0,41,0,249,255,220,0,42,
0,16,0,0,0,42,0,36,0,0,0,42,0,55,255,183,
0,42,0,58,0,0,0,42,0,60,255,154,0,42,0,98,
0,0,0,42,0,169,255,220,0,42,0,170,255,220,0,42,
0,173,0,0,0,42,0,174,0,0,0,42,0,180,255,211,
0,42,0,181,255,211,0,42,0,187,255,154,0,42,0,197,
255,201,0,42,0,199,0,0,0,42,0,201,0,0,0,42,
0,234,255,154,0,43,0,16,0,0,0,43,0,17,255,220,
0,43,0,29,0,0,0,43,0,169,0,0,0,43,0,170,
0,0,0,43,0,180,255,183,0,43,0,181,255,193,0,43,
0,197,255,183,0,45,0,16,255,183,0,45,0,36,255,220,
0,45,0,98,255,220,0,45,0,169,255,220,0,45,0,170,
255,220,0,45,0,173,255,220,0,45,0,174,255,220,0,45,
0,180,255,183,0,45,0,181,255,193,0,45,0,197,255,144,
0,45,0,199,255,220,0,45,0,201,255,220,0,46,0,16,
255,41,0,46,0,36,255,220,0,46,0,38,255,144,0,46,
0,50,255,144,0,46,0,55,255,97,0,46,0,56,255,201,
0,46,0,58,255,183,0,46,0,60,255,183,0,46,0,68,
255,220,0,46,0,72,255,154,0,46,0,82,255,154,0,46,
0,88,255,154,0,46,0,92,255,107,0,46,0,98,255,220,
0,46,0,100,255,144,0,46,0,103,255,144,0,46,0,104,
255,201,0,46,0,105,255,220,0,46,0,106,255,220,0,46,
0,107,255,220,0,46,0,108,255,220,0,46,0,109,255,220,
0,46,0,110,255,220,0,46,0,112,255,154,0,46,0,113,
255,154,0,46,0,114,255,154,0,46,0,115,255,154,0,46,
0,121,255,154,0,46,0,122,255,154,0,46,0,123,255,154,
0,46,0,124,255,154,0,46,0,125,255,154,0,46,0,126,
255,154,0,46,0,127,255,154,0,46,0,128,255,154,0,46,
0,129,255,154,0,46,0,169,255,125,0,46,0,170,0,0,
0,46,0,173,255,220,0,46,0,174,255,220,0,46,0,175,
255,144,0,46,0,180,255,193,0,46,0,181,255,193,0,46,
0,186,255,107,0,46,0,187,255,183,0,46,0,197,0,0,
0,46,0,199,255,220,0,46,0,201,255,220,0,46,0,208,
255,144,0,46,0,209,255,144,0,46,0,210,255,144,0,46,
0,211,255,201,0,46,0,212,255,201,0,46,0,213,255,201,
0,46,0,234,255,183,0,46,0,235,255,107,0,46,0,251,
255,144,0,46,0,253,255,144,0,47,0,16,255,220,0,47,
0,36,0,47,0,47,0,50,255,183,0,47,0,55,254,230,
0,47,0,56,255,154,0,47,0,57,255,31,0,47,0,58,
255,68,0,47,0,60,254,240,0,47,0,68,0,0,0,47,
0,72,255,220,0,47,0,82,255,220,0,47,0,88,255,220,
0,47,0,92,255,68,0,47,0,98,0,47,0,47,0,103,
255,183,0,47,0,104,255,154,0,47,0,105,0,0,0,47,
0,106,0,0,0,47,0,107,0,0,0,47,0,108,0,0,
0,47,0,109,0,0,0,47,0,110,0,0,0,47,0,112,
255,220,0,47,0,113,255,220,0,47,0,114,255,220,0,47,
0,115,255,220,0,47,0,121,255,220,0,47,0,122,255,220,
0,47,0,123,255,220,0,47,0,124,255,220,0,47,0,125,
255,220,0,47,0,126,255,220,0,47,0,127,255,220,0,47,
0,128,255,220,0,47,0,129,255,220,0,47,0,169,0,0,
0,47,0,170,0,0,0,47,0,173,0,47,0,47,0,174,
0,47,0,47,0,175,255,183,0,47,0,180,254,97,0,47,
0,181,253,230,0,47,0,186,255,68,0,47,0,187,254,240,
0,47,0,197,0,0,0,47,0,199,0,47,0,47,0,201,
0,47,0,47,0,208,255,183,0,47,0,209,255,183,0,47,
0,210,255,183,0,47,0,211,255,154,0,47,0,212,255,154,
0,47,0,213,255,154,0,47,0,234,254,240,0,47,0,235,
255,68,0,50,0,16,0,57,0,50,0,17,255,173,0,50,
0,29,255,220,0,50,0,36,255,220,0,50,0,57,255,220,
0,50,0,59,255,125,0,50,0,60,255,144,0,50,0,98,
255,220,0,50,0,169,255,220,0,50,0,170,0,0,0,50,
0,173,255,220,0,50,0,174,255,220,0,50,0,180,255,211,
0,50,0,181,255,220,0,50,0,187,255,144,0,50,0,197,
255,68,0,50,0,199,255,220,0,50,0,201,255,220,0,50,
0,234,255,144,0,51,0,16,255,211,0,51,0,17,254,193,
0,51,0,29,0,0,0,51,0,36,255,125,0,51,0,56,
0,0,0,51,0,58,0,0,0,51,0,60,255,211,0,51,
0,68,255,164,0,51,0,72,255,183,0,51,0,76,255,211,
0,51,0,81,255,220,0,51,0,82,255,183,0,51,0,85,
255,220,0,51,0,86,255,220,0,51,0,88,255,220,0,51,
0,92,0,0,0,51,0,98,255,125,0,51,0,104,0,0,
0,51,0,105,255,164,0,51,0,106,255,164,0,51,0,107,
255,164,0,51,0,108,255,164,0,51,0,109,255,164,0,51,
0,110,255,164,0,51,0,112,255,183,0,51,0,113,255,183,
0,51,0,114,255,183,0,51,0,115,255,183,0,51,0,120,
255,220,0,51,0,121,255,183,0,51,0,122,255,183,0,51,
0,123,255,183,0,51,0,124,255,183,0,51,0,125,255,183,
0,51,0,126,255,220,0,51,0,127,255,220,0,51,0,128,
255,220,0,51,0,129,255,220,0,51,0,169,255,220,0,51,
0,170,0,0,0,51,0,173,255,125,0,51,0,174,255,125,
0,51,0,180,0,38,0,51,0,181,0,38,0,51,0,186,
0,0,0,51,0,187,255,211,0,51,0,197,254,183,0,51,
0,199,255,125,0,51,0,201,255,125,0,51,0,211,0,0,
0,51,0,212,0,0,0,51,0,213,0,0,0,51,0,228,
255,220,0,51,0,234,255,211,0,51,0,235,0,0,0,51,
0,250,255,220,0,52,0,16,0,57,0,52,0,169,0,0,
0,52,0,170,0,0,0,52,0,180,255,211,0,52,0,181,
255,220,0,52,0,197,255,125,0,53,0,16,255,173,0,53,
0,17,255,183,0,53,0,29,255,193,0,53,0,36,255,173,
0,53,0,38,255,154,0,53,0,55,255,107,0,53,0,57,
255,144,0,53,0,58,255,173,0,53,0,60,255,125,0,53,
0,68,255,211,0,53,0,72,255,164,0,53,0,82,255,164,
0,53,0,88,255,164,0,53,0,92,255,144,0,53,0,98,
255,173,0,53,0,100,255,154,0,53,0,105,255,211,0,53,
0,106,255,211,0,53,0,107,255,211,0,53,0,108,255,211,
0,53,0,109,255,211,0,53,0,110,255,211,0,53,0,112,
255,164,0,53,0,113,255,164,0,53,0,114,255,164,0,53,
0,115,255,164,0,53,0,121,255,164,0,53,0,122,255,164,
0,53,0,123,255,164,0,53,0,124,255,164,0,53,0,125,
255,164,0,53,0,126,255,164,0,53,0,127,255,164,0,53,
0,128,255,164,0,53,0,129,255,164,0,53,0,169,255,144,
0,53,0,170,255,220,0,53,0,173,255,173,0,53,0,174,
255,173,0,53,0,180,255,107,0,53,0,181,255,125,0,53,
0,186,255,144,0,53,0,187,255,125,0,53,0,197,255,220,
0,53,0,199,255,173,0,53,0,201,255,173,0,53,0,234,
255,125,0,53,0,235,255,144,0,53,0,251,255,154,0,53,
0,253,255,154,0,54,0,36,0,38,0,54,0,38,0,0,
0,54,0,42,0,0,0,54,0,50,0,0,0,54,0,52,
0,0,0,54,0,54,0,0,0,54,0,98,0,38,0,54,
0,100,0,0,0,54,0,103,0,0,0,54,0,173,0,38,
0,54,0,174,0,38,0,54,0,175,0,0,0,54,0,199,
0,38,0,54,0,201,0,38,0,54,0,208,0,0,0,54,
0,209,0,0,0,54,0,210,0,0,0,54,0,227,0,0,
0,54,0,246,0,0,0,54,0,249,0,0,0,54,0,251,
0,0,0,54,0,253,0,0,0,55,0,16,255,68,0,55,
0,17,255,13,0,55,0,29,255,31,0,55,0,36,255,97,
0,55,0,38,255,136,0,55,0,55,255,220,0,55,0,68,
254,173,0,55,0,70,254,164,0,55,0,72,254,164,0,55,
0,76,255,193,0,55,0,82,254,164,0,55,0,85,254,211,
0,55,0,86,254,173,0,55,0,88,254,201,0,55,0,90,
254,173,0,55,0,92,254,193,0,55,0,98,255,97,0,55,
0,100,255,136,0,55,0,105,254,173,0,55,0,106,254,173,
0,55,0,107,254,173,0,55,0,108,254,173,0,55,0,109,
254,173,0,55,0,110,254,173,0,55,0,111,254,164,0,55,
0,112,254,164,0,55,0,113,254,164,0,55,0,114,254,164,
0,55,0,115,254,164,0,55,0,121,254,164,0,55,0,122,
254,164,0,55,0,123,254,164,0,55,0,124,254,164,0,55,
0,125,254,164,0,55,0,126,254,201,0,55,0,127,254,201,
0,55,0,128,254,201,0,55,0,129,254,201,0,55,0,169,
255,68,0,55,0,170,255,144,0,55,0,173,255,97,0,55,
0,174,255,97,0,55,0,180,0,0,0,55,0,181,255,211,
0,55,0,186,254,193,0,55,0,197,254,248,0,55,0,199,
255,97,0,55,0,201,255,97,0,55,0,228,254,173,0,55,
0,235,254,193,0,55,0,250,254,173,0,55,0,251,255,136,
0,55,0,252,254,164,0,55,0,253,255,136,0,55,0,254,
254,164,0,56,0,36,0,0,0,56,0,45,0,0,0,56,
0,61,255,220,0,56,0,98,0,0,0,56,0,173,0,0,
0,56,0,174,0,0,0,56,0,199,0,0,0,56,0,201,
0,0,0,56,0,229,255,220,0,57,0,16,255,136,0,57,
0,17,254,248,0,57,0,29,255,89,0,57,0,36,255,125,
0,57,0,50,255,220,0,57,0,68,255,97,0,57,0,72,
255,97,0,57,0,76,255,211,0,57,0,82,255,97,0,57,
0,88,255,117,0,57,0,92,255,201,0,57,0,98,255,125,
0,57,0,103,255,220,0,57,0,105,255,97,0,57,0,106,
255,97,0,57,0,107,255,97,0,57,0,108,255,97,0,57,
0,109,255,97,0,57,0,110,255,97,0,57,0,112,255,97,
0,57,0,113,255,97,0,57,0,114,255,97,0,57,0,115,
255,97,0,57,0,121,255,97,0,57,0,122,255,97,0,57,
0,123,255,97,0,57,0,124,255,97,0,57,0,125,255,97,
0,57,0,126,255,117,0,57,0,127,255,117,0,57,0,128,
255,117,0,57,0,129,255,117,0,57,0,169,255,78,0,57,
0,170,255,144,0,57,0,173,255,125,0,57,0,174,255,125,
0,57,0,175,255,220,0,57,0,180,0,0,0,57,0,181,
0,0,0,57,0,186,255,201,0,57,0,197,254,230,0,57,
0,199,255,125,0,57,0,201,255,125,0,57,0,208,255,220,
0,57,0,209,255,220,0,57,0,210,255,220,0,57,0,235,
255,201,0,58,0,16,255,173,0,58,0,17,255,21,0,58,
0,29,255,136,0,58,0,36,255,144,0,58,0,68,255,125,
0,58,0,72,255,136,0,58,0,76,255,211,0,58,0,82,
255,136,0,58,0,85,255,164,0,58,0,88,255,183,0,58,
0,92,255,220,0,58,0,98,255,144,0,58,0,105,255,125,
0,58,0,106,255,125,0,58,0,107,255,125,0,58,0,108,
255,125,0,58,0,109,255,125,0,58,0,110,255,125,0,58,
0,112,255,136,0,58,0,113,255,136,0,58,0,114,255,136,
0,58,0,115,255,136,0,58,0,121,255,136,0,58,0,122,
255,136,0,58,0,123,255,136,0,58,0,124,255,136,0,58,
0,125,255,136,0,58,0,126,255,183,0,58,0,127,255,183,
0,58,0,128,255,183,0,58,0,129,255,183,0,58,0,169,
255,144,0,58,0,170,255,220,0,58,0,173,255,144,0,58,
0,174,255,144,0,58,0,180,255,220,0,58,0,181,0,0,
0,58,0,186,255,220,0,58,0,197,254,248,0,58,0,199,
255,144,0,58,0,201,255,144,0,58,0,235,255,220,0,59,
0,16,255,154,0,59,0,36,0,0,0,59,0,38,255,107,
0,59,0,50,255,125,0,59,0,55,255,220,0,59,0,72,
255,164,0,59,0,98,0,0,0,59,0,100,255,107,0,59,
0,103,255,125,0,59,0,112,255,164,0,59,0,113,255,164,
0,59,0,114,255,164,0,59,0,115,255,164,0,59,0,169,
255,144,0,59,0,170,0,0,0,59,0,173,0,0,0,59,
0,174,0,0,0,59,0,175,255,125,0,59,0,180,255,97,
0,59,0,181,255,173,0,59,0,197,255,211,0,59,0,199,
0,0,0,59,0,201,0,0,0,59,0,208,255,125,0,59,
0,209,255,125,0,59,0,210,255,125,0,59,0,251,255,107,
0,59,0,253,255,107,0,60,0,16,255,13,0,60,0,17,
254,97,0,60,0,29,254,240,0,60,0,36,255,97,0,60,
0,38,255,144,0,60,0,50,255,144,0,60,0,68,254,230,
0,60,0,72,254,240,0,60,0,76,255,183,0,60,0,82,
254,240,0,60,0,88,255,21,0,60,0,98,255,97,0,60,
0,100,255,144,0,60,0,103,255,144,0,60,0,105,254,230,
0,60,0,106,254,230,0,60,0,107,254,230,0,60,0,108,
254,230,0,60,0,109,254,230,0,60,0,110,254,230,0,60,
0,112,254,240,0,60,0,113,254,240,0,60,0,114,254,240,
0,60,0,115,254,240,0,60,0,121,254,240,0,60,0,122,
254,240,0,60,0,123,254,240,0,60,0,124,254,240,0,60,
0,125,254,240,0,60,0,126,255,21,0,60,0,127,255,21,
0,60,0,128,255,21,0,60,0,129,255,21,0,60,0,169,
255,31,0,60,0,170,255,107,0,60,0,173,255,97,0,60,
0,174,255,97,0,60,0,175,255,144,0,60,0,180,255,144,
0,60,0,181,255,220,0,60,0,197,254,248,0,60,0,199,
255,97,0,60,0,201,255,97,0,60,0,208,255,144,0,60,
0,209,255,144,0,60,0,210,255,144,0,60,0,251,255,144,
0,60,0,253,255,144,0,61,0,16,255,220,0,61,0,169,
0,0,0,61,0,170,0,0,0,61,0,180,255,220,0,61,
0,181,255,220,0,61,0,197,255,220,0,72,0,91,255,220,
0,73,0,16,255,144,0,73,0,17,255,107,0,73,0,29,
255,183,0,73,0,87,255,220,0,73,0,90,255,220,0,73,
0,92,255,220,0,73,0,169,255,183,0,73,0,170,255,220,
0,73,0,180,0,65,0,73,0,181,0,0,0,73,0,186,
255,220,0,73,0,197,255,21,0,73,0,235,255,220,0,78,
0,68,255,220,0,78,0,72,255,183,0,78,0,82,255,183,
0,78,0,88,255,193,0,78,0,92,255,183,0,78,0,105,
255,220,0,78,0,106,255,220,0,78,0,107,255,220,0,78,
0,108,255,220,0,78,0,109,255,220,0,78,0,110,255,220,
0,78,0,112,255,183,0,78,0,113,255,183,0,78,0,114,
255,183,0,78,0,115,255,183,0,78,0,121,255,183,0,78,
0,122,255,183,0,78,0,123,255,183,0,78,0,124,255,183,
0,78,0,125,255,183,0,78,0,126,255,193,0,78,0,127,
255,193,0,78,0,128,255,193,0,78,0,129,255,193,0,78,
0,186,255,183,0,78,0,235,255,183,0,81,0,16,0,0,
0,81,0,17,0,0,0,81,0,29,0,0,0,81,0,169,
0,0,0,81,0,170,0,0,0,81,0,180,255,107,0,81,
0,181,255,144,0,81,0,197,255,164,0,82,0,16,0,38,
0,82,0,17,255,220,0,82,0,29,0,0,0,82,0,91,
255,193,0,82,0,169,0,0,0,82,0,170,0,0,0,82,
0,180,255,107,0,82,0,181,255,183,0,82,0,197,255,125,
0,85,0,16,255,125,0,85,0,17,255,68,0,85,0,29,
255,220,0,85,0,70,255,211,0,85,0,71,255,220,0,85,
0,72,255,211,0,85,0,73,0,0,0,85,0,74,255,220,
0,85,0,75,255,220,0,85,0,80,255,220,0,85,0,81,
255,220,0,85,0,82,255,211,0,85,0,84,255,220,0,85,
0,85,255,220,0,85,0,88,0,0,0,85,0,89,0,0,
0,85,0,90,0,0,0,85,0,91,255,201,0,85,0,92,
0,0,0,85,0,93,0,0,0,85,0,111,255,211,0,85,
0,112,255,211,0,85,0,113,255,211,0,85,0,114,255,211,
0,85,0,115,255,211,0,85,0,120,255,220,0,85,0,121,
255,211,0,85,0,122,255,211,0,85,0,123,255,211,0,85,
0,124,255,211,0,85,0,125,255,211,0,85,0,126,0,0,
0,85,0,127,0,0,0,85,0,128,0,0,0,85,0,129,
0,0,0,85,0,169,255,183,0,85,0,170,0,0,0,85,
0,180,0,0,0,85,0,181,0,86,0,85,0,186,0,0,
0,85,0,197,254,201,0,85,0,230,0,0,0,85,0,235,
0,0,0,85,0,247,255,220,0,85,0,252,255,211,0,85,
0,254,255,211,0,89,0,16,255,201,0,89,0,17,255,97,
0,89,0,29,255,144,0,89,0,169,255,220,0,89,0,170,
255,220,0,89,0,180,0,0,0,89,0,181,255,220,0,89,
0,197,254,240,0,90,0,16,0,0,0,90,0,17,255,68,
0,90,0,29,255,144,0,90,0,169,255,220,0,90,0,170,
255,220,0,90,0,180,0,0,0,90,0,181,0,0,0,90,
0,197,255,41,0,91,0,70,255,220,0,91,0,72,255,193,
0,91,0,82,255,193,0,91,0,111,255,220,0,91,0,112,
255,193,0,91,0,113,255,193,0,91,0,114,255,193,0,91,
0,115,255,193,0,91,0,121,255,193,0,91,0,122,255,193,
0,91,0,123,255,193,0,91,0,124,255,193,0,91,0,125,
255,193,0,91,0,252,255,220,0,91,0,254,255,220,0,92,
0,16,255,220,0,92,0,17,254,220,0,92,0,29,255,107,
0,92,0,169,255,220,0,92,0,170,255,220,0,92,0,180,
0,0,0,92,0,181,0,0,0,92,0,197,254,211,0,98,
0,16,255,211,0,98,0,17,255,220,0,98,0,29,255,220,
0,98,0,36,0,57,0,98,0,38,255,220,0,98,0,42,
255,220,0,98,0,50,255,220,0,98,0,52,255,220,0,98,
0,54,0,0,0,98,0,55,255,97,0,98,0,56,0,0,
0,98,0,57,255,125,0,98,0,58,255,144,0,98,0,59,
0,0,0,98,0,60,255,97,0,98,0,70,255,220,0,98,
0,71,255,220,0,98,0,72,255,220,0,98,0,73,255,183,
0,98,0,82,255,220,0,98,0,84,255,220,0,98,0,87,
255,220,0,98,0,88,0,0,0,98,0,89,255,136,0,98,
0,90,255,173,0,98,0,92,255,117,0,98,0,98,0,57,
0,98,0,100,255,220,0,98,0,103,255,220,0,98,0,104,
0,0,0,98,0,111,255,220,0,98,0,112,255,220,0,98,
0,113,255,220,0,98,0,114,255,220,0,98,0,115,255,220,
0,98,0,121,255,220,0,98,0,122,255,220,0,98,0,123,
255,220,0,98,0,124,255,220,0,98,0,125,255,220,0,98,
0,126,0,0,0,98,0,127,0,0,0,98,0,128,0,0,
0,98,0,129,0,0,0,98,0,169,255,183,0,98,0,170,
0,0,0,98,0,173,0,57,0,98,0,174,0,57,0,98,
0,175,255,220,0,98,0,180,254,248,0,98,0,181,255,3,
0,98,0,186,255,117,0,98,0,187,255,97,0,98,0,197,
0,47,0,98,0,199,0,57,0,98,0,201,0,57,0,98,
0,208,255,220,0,98,0,209,255,220,0,98,0,210,255,220,
0,98,0,211,0,0,0,98,0,212,0,0,0,98,0,213,
0,0,0,98,0,227,0,0,0,98,0,234,255,97,0,98,
0,235,255,117,0,98,0,246,255,220,0,98,0,249,0,0,
0,98,0,251,255,220,0,98,0,252,255,220,0,98,0,253,
255,220,0,98,0,254,255,220,0,100,0,16,0,0,0,100,
0,36,0,0,0,100,0,54,0,0,0,100,0,60,255,220,
0,100,0,98,0,0,0,100,0,169,255,220,0,100,0,170,
255,220,0,100,0,173,0,0,0,100,0,174,0,0,0,100,
0,180,0,0,0,100,0,181,0,38,0,100,0,187,255,220,
0,100,0,197,0,0,0,100,0,199,0,0,0,100,0,201,
0,0,0,100,0,227,0,0,0,100,0,234,255,220,0,100,
0,249,0,0,0,103,0,16,0,57,0,103,0,17,255,173,
0,103,0,29,255,220,0,103,0,36,255,220,0,103,0,57,
255,220,0,103,0,59,255,125,0,103,0,60,255,144,0,103,
0,98,255,220,0,103,0,169,255,220,0,103,0,170,0,0,
0,103,0,173,255,220,0,103,0,174,255,220,0,103,0,180,
255,211,0,103,0,181,255,220,0,103,0,187,255,144,0,103,
0,197,255,68,0,103,0,199,255,220,0,103,0,201,255,220,
0,103,0,234,255,144,0,104,0,36,0,0,0,104,0,45,
0,0,0,104,0,61,255,220,0,104,0,98,0,0,0,104,
0,173,0,0,0,104,0,174,0,0,0,104,0,199,0,0,
0,104,0,201,0,0,0,104,0,229,255,220,0,112,0,91,
255,220,0,113,0,91,255,220,0,114,0,91,255,220,0,115,
0,91,255,220,0,120,0,16,0,0,0,120,0,17,0,0,
0,120,0,29,0,0,0,120,0,169,0,0,0,120,0,170,
0,0,0,120,0,180,255,107,0,120,0,181,255,144,0,120,
0,197,255,164,0,121,0,16,0,38,0,121,0,17,255,220,
0,121,0,29,0,0,0,121,0,91,255,193,0,121,0,169,
0,0,0,121,0,170,0,0,0,121,0,180,255,107,0,121,
0,181,255,183,0,121,0,197,255,125,0,122,0,16,0,38,
0,122,0,17,255,220,0,122,0,29,0,0,0,122,0,91,
255,193,0,122,0,169,0,0,0,122,0,170,0,0,0,122,
0,180,255,107,0,122,0,181,255,183,0,122,0,197,255,125,
0,123,0,16,0,38,0,123,0,17,255,220,0,123,0,29,
0,0,0,123,0,91,255,193,0,123,0,169,0,0,0,123,
0,170,0,0,0,123,0,180,255,107,0,123,0,181,255,183,
0,123,0,197,255,125,0,124,0,16,0,38,0,124,0,17,
255,220,0,124,0,29,0,0,0,124,0,91,255,193,0,124,
0,169,0,0,0,124,0,170,0,0,0,124,0,180,255,107,
0,124,0,181,255,183,0,124,0,197,255,125,0,125,0,16,
0,38,0,125,0,17,255,220,0,125,0,29,0,0,0,125,
0,91,255,193,0,125,0,169,0,0,0,125,0,170,0,0,
0,125,0,180,255,107,0,125,0,181,255,183,0,125,0,197,
255,125,0,137,0,16,0,38,0,137,0,169,0,0,0,137,
0,170,0,0,0,137,0,180,255,144,0,137,0,181,255,144,
0,137,0,197,255,173,0,144,0,16,0,0,0,144,0,169,
0,0,0,144,0,170,0,0,0,144,0,180,255,173,0,144,
0,181,255,164,0,144,0,197,255,144,0,169,0,36,0,0,
0,169,0,37,255,220,0,169,0,38,255,220,0,169,0,39,
255,220,0,169,0,41,0,0,0,169,0,42,255,220,0,169,
0,43,0,0,0,169,0,45,255,220,0,169,0,46,0,0,
0,169,0,47,0,0,0,169,0,50,0,0,0,169,0,51,
0,0,0,169,0,52,0,0,0,169,0,53,0,0,0,169,
0,55,255,144,0,169,0,57,255,144,0,169,0,58,255,220,
0,169,0,59,0,0,0,169,0,60,255,107,0,169,0,61,
0,0,0,169,0,73,0,0,0,169,0,81,0,0,0,169,
0,82,0,0,0,169,0,85,0,0,0,169,0,89,255,220,
0,169,0,90,255,220,0,169,0,92,255,220,0,169,0,98,
0,0,0,169,0,100,255,220,0,169,0,103,0,0,0,169,
0,120,0,0,0,169,0,121,0,0,0,169,0,122,0,0,
0,169,0,123,0,0,0,169,0,124,0,0,0,169,0,125,
0,0,0,169,0,137,0,0,0,169,0,144,0,151,0,169,
0,173,0,0,0,169,0,174,0,0,0,169,0,175,0,0,
0,169,0,186,255,220,0,169,0,187,255,107,0,169,0,199,
0,0,0,169,0,201,0,0,0,169,0,208,0,0,0,169,
0,209,0,0,0,169,0,210,0,0,0,169,0,229,0,0,
0,169,0,233,0,0,0,169,0,234,255,107,0,169,0,235,
255,220,0,169,0,236,0,0,0,169,0,246,255,220,0,169,
0,251,255,220,0,169,0,253,255,220,0,170,0,36,255,183,
0,170,0,37,255,183,0,170,0,38,255,220,0,170,0,39,
255,220,0,170,0,41,0,0,0,170,0,42,0,0,0,170,
0,43,0,0,0,170,0,45,255,220,0,170,0,46,0,0,
0,170,0,47,0,0,0,170,0,50,255,220,0,170,0,51,
0,0,0,170,0,52,0,0,0,170,0,53,0,0,0,170,
0,55,255,68,0,170,0,57,255,78,0,170,0,58,255,144,
0,170,0,59,255,144,0,170,0,60,255,31,0,170,0,61,
0,0,0,170,0,73,0,0,0,170,0,81,0,0,0,170,
0,82,0,0,0,170,0,85,0,0,0,170,0,89,255,220,
0,170,0,90,255,220,0,170,0,92,255,220,0,170,0,98,
255,183,0,170,0,100,255,220,0,170,0,103,255,220,0,170,
0,120,0,0,0,170,0,121,0,0,0,170,0,122,0,0,
0,170,0,123,0,0,0,170,0,124,0,0,0,170,0,125,
0,0,0,170,0,137,0,0,0,170,0,144,0,0,0,170,
0,173,255,183,0,170,0,174,255,183,0,170,0,175,255,220,
0,170,0,186,255,220,0,170,0,187,255,31,0,170,0,199,
255,183,0,170,0,201,255,183,0,170,0,208,255,220,0,170,
0,209,255,220,0,170,0,210,255,220,0,170,0,229,0,0,
0,170,0,233,0,0,0,170,0,234,255,31,0,170,0,235,
255,220,0,170,0,236,0,0,0,170,0,246,0,0,0,170,
0,251,255,220,0,170,0,253,255,220,0,173,0,16,255,211,
0,173,0,17,255,220,0,173,0,29,255,220,0,173,0,36,
0,57,0,173,0,38,255,220,0,173,0,42,255,220,0,173,
0,50,255,220,0,173,0,52,255,220,0,173,0,54,0,0,
0,173,0,55,255,97,0,173,0,56,0,0,0,173,0,57,
255,125,0,173,0,58,255,144,0,173,0,59,0,0,0,173,
0,60,255,97,0,173,0,70,255,220,0,173,0,71,255,220,
0,173,0,72,255,220,0,173,0,73,255,183,0,173,0,82,
255,220,0,173,0,84,255,220,0,173,0,87,255,220,0,173,
0,88,0,0,0,173,0,89,255,136,0,173,0,90,255,173,
0,173,0,92,255,117,0,173,0,98,0,57,0,173,0,100,
255,220,0,173,0,103,255,220,0,173,0,104,0,0,0,173,
0,111,255,220,0,173,0,112,255,220,0,173,0,113,255,220,
0,173,0,114,255,220,0,173,0,115,255,220,0,173,0,121,
255,220,0,173,0,122,255,220,0,173,0,123,255,220,0,173,
0,124,255,220,0,173,0,125,255,220,0,173,0,126,0,0,
0,173,0,127,0,0,0,173,0,128,0,0,0,173,0,129,
0,0,0,173,0,169,255,183,0,173,0,170,0,0,0,173,
0,173,0,57,0,173,0,174,0,57,0,173,0,175,255,220,
0,173,0,180,254,248,0,173,0,181,255,3,0,173,0,186,
255,117,0,173,0,187,255,97,0,173,0,197,0,47,0,173,
0,199,0,57,0,173,0,201,0,57,0,173,0,208,255,220,
0,173,0,209,255,220,0,173,0,210,255,220,0,173,0,211,
0,0,0,173,0,212,0,0,0,173,0,213,0,0,0,173,
0,227,0,0,0,173,0,234,255,97,0,173,0,235,255,117,
0,173,0,246,255,220,0,173,0,249,0,0,0,173,0,251,
255,220,0,173,0,252,255,220,0,173,0,253,255,220,0,173,
0,254,255,220,0,174,0,16,255,211,0,174,0,17,255,220,
0,174,0,29,255,220,0,174,0,36,0,57,0,174,0,38,
255,220,0,174,0,42,255,220,0,174,0,50,255,220,0,174,
0,52,255,220,0,174,0,54,0,0,0,174,0,55,255,97,
0,174,0,56,0,0,0,174,0,57,255,125,0,174,0,58,
255,144,0,174,0,59,0,0,0,174,0,60,255,97,0,174,
0,70,255,220,0,174,0,71,255,220,0,174,0,72,255,220,
0,174,0,73,255,183,0,174,0,82,255,220,0,174,0,84,
255,220,0,174,0,87,255,220,0,174,0,88,0,0,0,174,
0,89,255,136,0,174,0,90,255,173,0,174,0,92,255,117,
0,174,0,98,0,57,0,174,0,100,255,220,0,174,0,103,
255,220,0,174,0,104,0,0,0,174,0,111,255,220,0,174,
0,112,255,220,0,174,0,113,255,220,0,174,0,114,255,220,
0,174,0,115,255,220,0,174,0,121,255,220,0,174,0,122,
255,220,0,174,0,123,255,220,0,174,0,124,255,220,0,174,
0,125,255,220,0,174,0,126,0,0,0,174,0,127,0,0,
0,174,0,128,0,0,0,174,0,129,0,0,0,174,0,169,
255,183,0,174,0,170,0,0,0,174,0,173,0,57,0,174,
0,174,0,57,0,174,0,175,255,220,0,174,0,180,254,248,
0,174,0,181,255,3,0,174,0,186,255,117,0,174,0,187,
255,97,0,174,0,197,0,47,0,174,0,199,0,57,0,174,
0,201,0,57,0,174,0,208,255,220,0,174,0,209,255,220,
0,174,0,210,255,220,0,174,0,211,0,0,0,174,0,212,
0,0,0,174,0,213,0,0,0,174,0,227,0,0,0,174,
0,234,255,97,0,174,0,235,255,117,0,174,0,246,255,220,
0,174,0,249,0,0,0,174,0,251,255,220,0,174,0,252,
255,220,0,174,0,253,255,220,0,174,0,254,255,220,0,175,
0,16,0,57,0,175,0,17,255,173,0,175,0,29,255,220,
0,175,0,36,255,220,0,175,0,57,255,220,0,175,0,59,
255,125,0,175,0,60,255,144,0,175,0,98,255,220,0,175,
0,169,255,220,0,175,0,170,0,0,0,175,0,173,255,220,
0,175,0,174,255,220,0,175,0,180,255,211,0,175,0,181,
255,220,0,175,0,187,255,144,0,175,0,197,255,68,0,175,
0,199,255,220,0,175,0,201,255,220,0,175,0,234,255,144,
0,180,0,36,254,248,0,180,0,37,255,193,0,180,0,38,
255,183,0,180,0,39,255,193,0,180,0,41,255,193,0,180,
0,42,255,183,0,180,0,43,255,193,0,180,0,45,255,193,
0,180,0,46,255,193,0,180,0,47,255,193,0,180,0,50,
255,183,0,180,0,51,255,193,0,180,0,52,255,183,0,180,
0,53,255,193,0,180,0,55,0,0,0,180,0,57,0,0,
0,180,0,58,0,0,0,180,0,59,255,136,0,180,0,60,
0,0,0,180,0,61,255,220,0,180,0,73,255,183,0,180,
0,81,255,144,0,180,0,82,255,107,0,180,0,85,255,144,
0,180,0,89,255,183,0,180,0,90,255,183,0,180,0,92,
255,183,0,180,0,98,254,248,0,180,0,100,255,183,0,180,
0,103,255,183,0,180,0,120,255,144,0,180,0,121,255,107,
0,180,0,122,255,107,0,180,0,123,255,107,0,180,0,124,
255,107,0,180,0,125,255,107,0,180,0,137,255,193,0,180,
0,144,254,125,0,180,0,173,254,248,0,180,0,174,254,248,
0,180,0,175,255,183,0,180,0,186,255,183,0,180,0,187,
0,0,0,180,0,199,254,248,0,180,0,201,254,248,0,180,
0,208,255,183,0,180,0,209,255,183,0,180,0,210,255,183,
0,180,0,229,255,220,0,180,0,233,255,183,0,180,0,234,
0,0,0,180,0,235,255,183,0,180,0,236,255,193,0,180,
0,246,255,183,0,180,0,251,255,183,0,180,0,253,255,183,
0,186,0,16,255,220,0,186,0,17,254,220,0,186,0,29,
255,107,0,186,0,169,255,220,0,186,0,170,255,220,0,186,
0,180,0,0,0,186,0,181,0,0,0,186,0,197,254,211,
0,187,0,16,255,13,0,187,0,17,254,97,0,187,0,29,
254,240,0,187,0,36,255,97,0,187,0,38,255,144,0,187,
0,50,255,144,0,187,0,68,254,230,0,187,0,72,254,240,
0,187,0,76,255,183,0,187,0,82,254,240,0,187,0,88,
255,21,0,187,0,98,255,97,0,187,0,100,255,144,0,187,
0,103,255,144,0,187,0,105,254,230,0,187,0,106,254,230,
0,187,0,107,254,230,0,187,0,108,254,230,0,187,0,109,
254,230,0,187,0,110,254,230,0,187,0,112,254,240,0,187,
0,113,254,240,0,187,0,114,254,240,0,187,0,115,254,240,
0,187,0,121,254,240,0,187,0,122,254,240,0,187,0,123,
254,240,0,187,0,124,254,240,0,187,0,125,254,240,0,187,
0,126,255,21,0,187,0,127,255,21,0,187,0,128,255,21,
0,187,0,129,255,21,0,187,0,169,255,31,0,187,0,170,
255,107,0,187,0,173,255,97,0,187,0,174,255,97,0,187,
0,175,255,144,0,187,0,180,255,144,0,187,0,181,255,220,
0,187,0,197,254,248,0,187,0,199,255,97,0,187,0,201,
255,97,0,187,0,208,255,144,0,187,0,209,255,144,0,187,
0,210,255,144,0,187,0,251,255,144,0,187,0,253,255,144,
0,197,0,36,0,38,0,197,0,37,255,183,0,197,0,38,
255,144,0,197,0,39,255,183,0,197,0,41,255,183,0,197,
0,42,255,183,0,197,0,43,255,183,0,197,0,45,0,47,
0,197,0,46,255,183,0,197,0,47,255,183,0,197,0,50,
255,144,0,197,0,51,255,183,0,197,0,52,255,144,0,197,
0,53,255,183,0,197,0,55,254,230,0,197,0,57,254,136,
0,197,0,58,255,3,0,197,0,59,255,183,0,197,0,60,
254,136,0,197,0,61,0,0,0,197,0,73,255,220,0,197,
0,81,255,183,0,197,0,82,255,183,0,197,0,85,255,183,
0,197,0,89,255,21,0,197,0,90,255,60,0,197,0,92,
255,144,0,197,0,98,0,38,0,197,0,100,255,144,0,197,
0,103,255,144,0,197,0,120,255,183,0,197,0,121,255,183,
0,197,0,122,255,183,0,197,0,123,255,183,0,197,0,124,
255,183,0,197,0,125,255,183,0,197,0,137,255,183,0,197,
0,144,0,38,0,197,0,173,0,38,0,197,0,174,0,38,
0,197,0,175,255,144,0,197,0,186,255,144,0,197,0,187,
254,136,0,197,0,199,0,38,0,197,0,201,0,38,0,197,
0,208,255,144,0,197,0,209,255,144,0,197,0,210,255,144,
0,197,0,229,0,0,0,197,0,233,255,183,0,197,0,234,
254,136,0,197,0,235,255,144,0,197,0,236,255,183,0,197,
0,246,255,183,0,197,0,251,255,144,0,197,0,253,255,144,
0,199,0,16,255,211,0,199,0,17,255,220,0,199,0,29,
255,220,0,199,0,36,0,57,0,199,0,38,255,220,0,199,
0,42,255,220,0,199,0,50,255,220,0,199,0,52,255,220,
0,199,0,54,0,0,0,199,0,55,255,97,0,199,0,56,
0,0,0,199,0,57,255,125,0,199,0,58,255,144,0,199,
0,59,0,0,0,199,0,60,255,97,0,199,0,70,255,220,
0,199,0,71,255,220,0,199,0,72,255,220,0,199,0,73,
255,183,0,199,0,82,255,220,0,199,0,84,255,220,0,199,
0,87,255,220,0,199,0,88,0,0,0,199,0,89,255,136,
0,199,0,90,255,173,0,199,0,92,255,117,0,199,0,98,
0,57,0,199,0,100,255,220,0,199,0,103,255,220,0,199,
0,104,0,0,0,199,0,111,255,220,0,199,0,112,255,220,
0,199,0,113,255,220,0,199,0,114,255,220,0,199,0,115,
255,220,0,199,0,121,255,220,0,199,0,122,255,220,0,199,
0,123,255,220,0,199,0,124,255,220,0,199,0,125,255,220,
0,199,0,126,0,0,0,199,0,127,0,0,0,199,0,128,
0,0,0,199,0,129,0,0,0,199,0,169,255,183,0,199,
0,170,0,0,0,199,0,173,0,57,0,199,0,174,0,57,
0,199,0,175,255,220,0,199,0,180,254,248,0,199,0,181,
255,3,0,199,0,186,255,117,0,199,0,187,255,97,0,199,
0,197,0,47,0,199,0,199,0,57,0,199,0,201,0,57,
0,199,0,208,255,220,0,199,0,209,255,220,0,199,0,210,
255,220,0,199,0,211,0,0,0,199,0,212,0,0,0,199,
0,213,0,0,0,199,0,227,0,0,0,199,0,234,255,97,
0,199,0,235,255,117,0,199,0,246,255,220,0,199,0,249,
0,0,0,199,0,251,255,220,0,199,0,252,255,220,0,199,
0,253,255,220,0,199,0,254,255,220,0,201,0,16,255,211,
0,201,0,17,255,220,0,201,0,29,255,220,0,201,0,36,
0,57,0,201,0,38,255,220,0,201,0,42,255,220,0,201,
0,50,255,220,0,201,0,52,255,220,0,201,0,54,0,0,
0,201,0,55,255,97,0,201,0,56,0,0,0,201,0,57,
255,125,0,201,0,58,255,144,0,201,0,59,0,0,0,201,
0,60,255,97,0,201,0,70,255,220,0,201,0,71,255,220,
0,201,0,72,255,220,0,201,0,73,255,183,0,201,0,82,
255,220,0,201,0,84,255,220,0,201,0,87,255,220,0,201,
0,88,0,0,0,201,0,89,255,136,0,201,0,90,255,173,
0,201,0,92,255,117,0,201,0,98,0,57,0,201,0,100,
255,220,0,201,0,103,255,220,0,201,0,104,0,0,0,201,
0,111,255,220,0,201,0,112,255,220,0,201,0,113,255,220,
0,201,0,114,255,220,0,201,0,115,255,220,0,201,0,121,
255,220,0,201,0,122,255,220,0,201,0,123,255,220,0,201,
0,124,255,220,0,201,0,125,255,220,0,201,0,126,0,0,
0,201,0,127,0,0,0,201,0,128,0,0,0,201,0,129,
0,0,0,201,0,169,255,183,0,201,0,170,0,0,0,201,
0,173,0,57,0,201,0,174,0,57,0,201,0,175,255,220,
0,201,0,180,254,248,0,201,0,181,255,3,0,201,0,186,
255,117,0,201,0,187,255,97,0,201,0,197,0,47,0,201,
0,199,0,57,0,201,0,201,0,57,0,201,0,208,255,220,
0,201,0,209,255,220,0,201,0,210,255,220,0,201,0,211,
0,0,0,201,0,212,0,0,0,201,0,213,0,0,0,201,
0,227,0,0,0,201,0,234,255,97,0,201,0,235,255,117,
0,201,0,246,255,220,0,201,0,249,0,0,0,201,0,251,
255,220,0,201,0,252,255,220,0,201,0,253,255,220,0,201,
0,254,255,220,0,208,0,16,0,57,0,208,0,17,255,173,
0,208,0,29,255,220,0,208,0,36,255,220,0,208,0,57,
255,220,0,208,0,59,255,125,0,208,0,60,255,144,0,208,
0,98,255,220,0,208,0,169,255,220,0,208,0,170,0,0,
0,208,0,173,255,220,0,208,0,174,255,220,0,208,0,180,
255,211,0,208,0,181,255,220,0,208,0,187,255,144,0,208,
0,197,255,68,0,208,0,199,255,220,0,208,0,201,255,220,
0,208,0,234,255,144,0,209,0,16,0,57,0,209,0,17,
255,173,0,209,0,29,255,220,0,209,0,36,255,220,0,209,
0,57,255,220,0,209,0,59,255,125,0,209,0,60,255,144,
0,209,0,98,255,220,0,209,0,169,255,220,0,209,0,170,
0,0,0,209,0,173,255,220,0,209,0,174,255,220,0,209,
0,180,255,211,0,209,0,181,255,220,0,209,0,187,255,144,
0,209,0,197,255,68,0,209,0,199,255,220,0,209,0,201,
255,220,0,209,0,234,255,144,0,210,0,16,0,57,0,210,
0,17,255,173,0,210,0,29,255,220,0,210,0,36,255,220,
0,210,0,57,255,220,0,210,0,59,255,125,0,210,0,60,
255,144,0,210,0,98,255,220,0,210,0,169,255,220,0,210,
0,170,0,0,0,210,0,173,255,220,0,210,0,174,255,220,
0,210,0,180,255,211,0,210,0,181,255,220,0,210,0,187,
255,144,0,210,0,197,255,68,0,210,0,199,255,220,0,210,
0,201,255,220,0,210,0,234,255,144,0,211,0,36,0,0,
0,211,0,45,0,0,0,211,0,61,255,220,0,211,0,98,
0,0,0,211,0,173,0,0,0,211,0,174,0,0,0,211,
0,199,0,0,0,211,0,201,0,0,0,211,0,229,255,220,
0,212,0,36,0,0,0,212,0,45,0,0,0,212,0,61,
255,220,0,212,0,98,0,0,0,212,0,173,0,0,0,212,
0,174,0,0,0,212,0,199,0,0,0,212,0,201,0,0,
0,212,0,229,255,220,0,213,0,36,0,0,0,213,0,45,
0,0,0,213,0,61,255,220,0,213,0,98,0,0,0,213,
0,173,0,0,0,213,0,174,0,0,0,213,0,199,0,0,
0,213,0,201,0,0,0,213,0,229,255,220,0,227,0,36,
0,38,0,227,0,38,0,0,0,227,0,42,0,0,0,227,
0,50,0,0,0,227,0,52,0,0,0,227,0,54,0,0,
0,227,0,98,0,38,0,227,0,100,0,0,0,227,0,103,
0,0,0,227,0,173,0,38,0,227,0,174,0,38,0,227,
0,175,0,0,0,227,0,199,0,38,0,227,0,201,0,38,
0,227,0,208,0,0,0,227,0,209,0,0,0,227,0,210,
0,0,0,227,0,227,0,0,0,227,0,246,0,0,0,227,
0,249,0,0,0,227,0,251,0,0,0,227,0,253,0,0,
0,229,0,16,255,220,0,229,0,169,0,0,0,229,0,170,
0,0,0,229,0,180,255,220,0,229,0,181,255,220,0,229,
0,197,255,220,0,233,0,16,0,0,0,233,0,169,0,0,
0,233,0,170,0,0,0,233,0,180,255,164,0,233,0,181,
255,144,0,233,0,197,255,183,0,234,0,16,255,13,0,234,
0,17,254,97,0,234,0,29,254,240,0,234,0,36,255,97,
0,234,0,38,255,144,0,234,0,50,255,144,0,234,0,68,
254,230,0,234,0,72,254,240,0,234,0,76,255,183,0,234,
0,82,254,240,0,234,0,88,255,21,0,234,0,98,255,97,
0,234,0,100,255,144,0,234,0,103,255,144,0,234,0,105,
254,230,0,234,0,106,254,230,0,234,0,107,254,230,0,234,
0,108,254,230,0,234,0,109,254,230,0,234,0,110,254,230,
0,234,0,112,254,240,0,234,0,113,254,240,0,234,0,114,
254,240,0,234,0,115,254,240,0,234,0,121,254,240,0,234,
0,122,254,240,0,234,0,123,254,240,0,234,0,124,254,240,
0,234,0,125,254,240,0,234,0,126,255,21,0,234,0,127,
255,21,0,234,0,128,255,21,0,234,0,129,255,21,0,234,
0,169,255,31,0,234,0,170,255,107,0,234,0,173,255,97,
0,234,0,174,255,97,0,234,0,175,255,144,0,234,0,180,
255,144,0,234,0,181,255,220,0,234,0,197,254,248,0,234,
0,199,255,97,0,234,0,201,255,97,0,234,0,208,255,144,
0,234,0,209,255,144,0,234,0,210,255,144,0,234,0,251,
255,144,0,234,0,253,255,144,0,235,0,16,255,220,0,235,
0,17,254,220,0,235,0,29,255,107,0,235,0,169,255,220,
0,235,0,170,255,220,0,235,0,180,0,0,0,235,0,181,
0,0,0,235,0,197,254,211,0,236,0,16,0,0,0,236,
0,17,255,107,0,236,0,29,255,183,0,236,0,169,0,0,
0,236,0,170,0,0,0,236,0,180,255,220,0,236,0,181,
0,0,0,236,0,197,255,68,0,246,0,16,0,0,0,246,
0,36,0,0,0,246,0,55,255,183,0,246,0,58,0,0,
0,246,0,60,255,154,0,246,0,98,0,0,0,246,0,169,
255,220,0,246,0,170,255,220,0,246,0,173,0,0,0,246,
0,174,0,0,0,246,0,180,255,211,0,246,0,181,255,211,
0,246,0,187,255,154,0,246,0,197,255,201,0,246,0,199,
0,0,0,246,0,201,0,0,0,246,0,234,255,154,0,249,
0,36,0,38,0,249,0,38,0,0,0,249,0,42,0,0,
0,249,0,50,0,0,0,249,0,52,0,0,0,249,0,54,
0,0,0,249,0,98,0,38,0,249,0,100,0,0,0,249,
0,103,0,0,0,249,0,173,0,38,0,249,0,174,0,38,
0,249,0,175,0,0,0,249,0,199,0,38,0,249,0,201,
0,38,0,249,0,208,0,0,0,249,0,209,0,0,0,249,
0,210,0,0,0,249,0,227,0,0,0,249,0,246,0,0,
0,249,0,249,0,0,0,249,0,251,0,0,0,249,0,253,
0,0,0,251,0,16,0,0,0,251,0,36,0,0,0,251,
0,54,0,0,0,251,0,60,255,220,0,251,0,98,0,0,
0,251,0,169,255,220,0,251,0,170,255,220,0,251,0,173,
0,0,0,251,0,174,0,0,0,251,0,180,0,0,0,251,
0,181,0,38,0,251,0,187,255,220,0,251,0,197,0,0,
0,251,0,199,0,0,0,251,0,201,0,0,0,251,0,227,
0,0,0,251,0,234,255,220,0,251,0,249,0,0,0,253,
0,16,0,0,0,253,0,36,0,0,0,253,0,54,0,0,
0,253,0,60,255,220,0,253,0,98,0,0,0,253,0,169,
255,220,0,253,0,170,255,220,0,253,0,173,0,0,0,253,
0,174,0,0,0,253,0,180,0,0,0,253,0,181,0,38,
0,253,0,187,255,220,0,253,0,197,0,0,0,253,0,199,
0,0,0,253,0,201,0,0,0,253,0,227,0,0,0,253,
0,234,255,220,0,253,0,249,0,0,0,0,0,1,0,0,
1,12,0,77,0,7,0,66,0,4,0,2,0,16,0,64,
0,7,0,0,4,21,5,104,0,3,0,1,0,1,0,0,
7,109,254,29,0,0,10,188,254,137,254,137,10,76,0,1,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,12,
0,1,4,14,1,144,0,5,0,4,5,71,4,204,0,0,
254,66,5,71,4,204,0,0,2,83,0,143,2,102,8,2,
2,11,6,3,3,8,4,2,2,4,128,0,0,175,16,0,
32,74,0,0,0,0,0,0,0,0,66,105,116,115,0,64,
0,32,251,2,6,20,254,20,1,154,7,109,1,227,0,0,
0,1,0,0,0,0,0,0,0,1,0,0,66,0,29,177,
2,139,4,96,0,0,35,99,5,213,0,0,86,101,114,97,
83,97,110,115,0,0,0,0,0,0,0,0,255,255,255,255,
54,255,255,254,54,50,56,82,48,48,0,0,64,0,0,0,
0,0,0,20,0,0,1,16,9,12,5,0,3,3,3,4,
8,6,9,8,2,4,4,5,8,3,3,3,3,6,6,6,
6,6,6,6,6,6,6,3,3,8,8,8,5,10,6,7,
7,7,6,6,7,7,3,3,6,5,8,7,7,6,7,6,
7,5,7,6,7,6,5,5,4,3,4,8,5,5,6,6,
6,6,6,3,6,6,3,3,5,3,9,6,6,6,6,4,
5,4,6,5,7,5,5,6,5,3,5,8,6,6,7,6,
7,7,7,6,6,6,6,6,6,6,6,6,6,6,3,3,
3,3,6,6,6,6,6,6,6,6,6,6,5,5,6,6,
5,5,6,6,9,9,9,5,5,8,9,7,8,8,8,8,
6,6,5,6,7,5,5,4,4,7,9,6,5,3,8,6,
6,8,6,6,6,9,6,6,6,7,10,9,5,9,5,5,
3,3,8,4,5,5,2,6,4,4,6,6,5,3,3,5,
12,6,6,6,6,6,3,3,3,3,7,7,7,7,7,7,
3,5,5,5,5,5,5,5,5,5,5,5,3,7,5,5,
6,3,7,6,5,5,6,6,8,8,4,4,4,9,9,9,
7,6,3,7,5,7,6,7,6,6,3,3,6,5,5,5,
5,5,5,4,5,5,0,0,10,13,6,0,3,3,4,5,
8,6,10,9,3,4,4,5,8,3,4,3,3,6,6,6,
6,6,6,6,6,6,6,3,3,8,8,8,5,11,7,7,
8,8,7,6,8,8,3,3,7,6,9,8,8,7,8,7,
7,5,8,7,9,6,7,6,4,3,4,8,5,5,6,6,
5,6,6,4,6,6,2,2,5,2,10,6,6,6,6,4,
5,4,6,6,8,6,6,5,6,3,6,8,7,7,8,7,
8,8,8,6,6,6,6,6,6,5,6,6,6,6,2,2,
2,2,6,6,6,6,6,6,6,6,6,6,5,5,6,6,
5,6,6,6,10,10,10,5,5,8,10,8,8,8,8,8,
6,7,5,7,8,6,5,5,5,8,10,6,5,4,8,6,
6,8,7,6,6,10,6,7,7,8,11,10,5,10,5,5,
3,3,8,5,6,7,2,6,4,4,6,6,5,3,3,5,
13,7,7,7,7,7,3,3,3,3,8,8,8,8,8,8,
2,5,5,5,5,5,5,5,5,5,5,6,2,7,5,6,
5,3,8,6,7,6,7,6,8,8,4,4,4,10,10,10,
8,6,3,7,5,8,5,8,5,6,4,3,6,5,5,5,
5,5,5,4,5,5,0,0,11,15,7,0,3,3,3,5,
9,7,10,10,3,4,4,6,9,4,4,4,4,7,7,7,
7,7,7,7,7,7,7,4,4,9,9,9,6,12,7,8,
8,8,7,6,9,8,3,3,7,6,9,8,9,7,9,7,
8,7,8,7,9,7,7,9,4,4,4,9,6,6,7,7,
6,7,7,4,7,7,3,3,6,3,11,7,7,7,7,5,
7,4,7,6,9,6,6,5,7,4,7,9,7,7,8,7,
8,9,8,7,7,7,7,7,7,6,7,7,7,7,3,3,
3,3,7,7,7,7,7,7,7,7,7,7,6,6,7,7,
6,6,7,7,11,11,11,6,6,9,11,9,9,9,9,9,
7,7,6,7,8,6,6,5,5,8,11,7,6,3,9,7,
7,9,7,7,7,11,7,7,7,9,12,11,6,11,6,6,
4,4,9,5,6,7,2,7,4,4,7,7,6,4,4,6,
15,7,7,7,7,7,3,3,3,3,9,9,9,8,8,8,
3,6,6,6,6,6,6,6,6,6,6,6,3,8,7,9,
5,4,8,7,7,6,7,7,9,9,4,4,4,11,11,11,
9,7,3,8,7,8,6,8,6,7,4,4,7,6,6,6,
6,6,6,4,6,6,0,0,12,16,7,0,4,4,5,5,
10,8,11,10,3,5,5,6,10,4,4,4,4,8,8,8,
8,8,8,8,8,8,8,4,4,10,10,10,6,13,8,8,
8,9,8,7,9,9,3,3,7,6,10,9,9,8,9,8,
8,7,9,8,11,9,7,9,5,4,5,10,6,6,8,8,
7,8,8,4,8,8,3,3,7,3,11,8,8,8,8,5,
7,5,8,6,9,6,6,5,8,4,8,10,8,8,8,8,
9,9,9,8,8,8,8,8,8,7,8,8,8,8,3,3,
3,3,8,8,8,8,8,8,8,8,8,8,6,6,8,8,
6,7,8,8,12,12,12,6,6,10,12,9,10,10,10,10,
8,8,6,8,9,7,6,6,6,9,12,8,6,5,10,8,
8,10,8,7,7,12,8,8,8,9,13,13,6,12,6,6,
4,4,10,6,6,7,2,8,5,5,7,7,6,4,4,6,
16,8,8,8,8,8,3,3,3,3,9,9,9,9,9,9,
3,6,6,6,6,6,6,6,6,6,6,6,3,8,7,9,
5,4,9,8,7,6,8,8,10,10,5,5,5,12,12,12,
9,8,3,8,7,8,7,8,7,8,4,4,8,6,6,6,
6,6,6,5,6,6,0,0,13,17,8,0,4,4,5,5,
11,8,12,11,3,5,5,7,11,4,5,4,4,8,8,8,
8,8,8,8,8,8,8,4,4,11,11,11,7,13,9,9,
9,10,8,7,10,10,3,3,8,7,11,10,10,8,10,8,
9,7,10,9,11,10,7,10,5,4,5,11,7,7,8,8,
7,8,8,4,8,8,3,3,7,3,13,8,8,8,8,5,
7,5,8,7,9,7,7,7,8,4,8,11,9,9,9,8,
10,10,10,8,8,8,8,8,8,7,8,8,8,8,3,3,
3,3,8,8,8,8,8,8,8,8,8,8,7,7,8,8,
7,8,8,8,13,13,13,7,7,11,13,10,11,11,11,11,
8,8,7,9,10,8,7,6,6,10,13,8,7,5,11,8,
8,11,9,8,8,13,8,9,9,10,14,13,7,13,7,7,
4,4,11,6,7,7,2,8,5,5,8,8,7,4,4,7,
17,9,8,9,8,8,3,3,3,3,10,10,10,10,10,10,
3,7,7,7,7,7,7,7,7,7,7,7,3,9,7,10,
7,4,10,8,7,7,8,8,11,11,5,5,5,13,13,13,
10,8,3,9,7,9,7,9,7,8,5,4,8,7,7,7,
7,7,7,5,7,7,0,0,14,19,8,0,4,4,5,5,
12,9,13,12,3,5,5,7,12,4,5,4,5,9,9,9,
9,9,9,9,9,9,9,5,5,12,12,12,7,14,9,10,
10,11,9,8,11,10,3,3,9,7,12,10,11,9,11,10,
9,9,10,9,13,11,9,10,5,5,5,12,7,7,8,9,
8,9,9,4,9,9,3,3,8,3,13,9,9,9,9,5,
8,5,9,7,11,7,7,8,9,5,9,12,9,9,10,9,
10,11,10,8,8,8,8,8,8,8,9,9,9,9,3,3,
3,3,9,9,9,9,9,9,9,9,9,9,7,7,9,9,
7,8,9,9,14,14,14,7,7,12,14,11,12,12,12,12,
9,9,7,9,11,8,7,7,7,11,14,9,7,5,12,9,
9,12,9,9,9,14,9,9,9,11,15,15,7,14,7,7,
4,4,12,7,7,9,2,9,6,6,8,8,7,4,4,7,
19,9,9,9,9,9,3,3,3,3,11,11,11,10,10,10,
3,7,7,7,7,7,7,7,7,7,7,7,3,9,8,10,
8,5,11,9,9,7,9,9,12,12,6,6,6,14,14,14,
11,9,3,9,8,10,8,10,8,9,5,4,9,7,7,7,
7,7,7,6,7,7,0,0,15,20,9,0,5,5,6,6,
13,10,14,11,3,6,6,8,13,5,5,5,5,10,10,10,
10,10,10,10,10,10,10,5,5,13,13,13,8,15,10,10,
10,11,9,9,12,11,3,3,10,8,13,11,12,9,12,10,
10,9,11,10,15,10,9,11,6,5,6,13,8,8,9,9,
8,9,9,5,9,9,3,3,8,3,15,9,9,9,9,6,
8,6,9,8,13,10,8,8,10,5,10,13,10,10,10,9,
11,12,11,9,9,9,9,9,9,8,9,9,9,9,3,3,
3,3,9,9,9,9,9,9,9,9,9,9,8,8,10,10,
8,9,10,9,15,15,15,8,8,13,15,12,13,13,13,13,
10,9,8,10,11,9,8,7,7,11,15,9,8,6,13,10,
10,13,10,9,9,15,10,10,10,12,16,15,8,15,8,8,
5,5,13,7,8,9,3,10,6,6,9,9,8,5,5,8,
20,10,9,10,9,9,3,3,3,3,12,12,12,11,11,11,
3,8,8,8,8,8,8,8,8,8,8,8,3,10,8,11,
8,5,12,9,9,8,9,9,13,13,6,6,6,15,15,15,
12,9,3,10,8,10,8,10,8,9,5,5,10,8,8,8,
8,8,8,6,8,8,0,0,16,21,10,0,5,5,6,6,
13,10,15,12,3,6,6,8,13,5,6,5,5,10,10,10,
10,10,10,10,10,10,10,5,5,13,13,13,9,16,11,11,
11,12,10,9,12,12,5,5,10,9,13,12,13,10,13,11,
10,9,12,11,17,11,9,12,6,5,6,13,8,8,9,10,
9,10,9,6,10,10,3,3,9,3,15,10,10,10,10,7,
9,6,10,9,13,10,9,9,10,5,10,13,11,11,11,10,
12,13,12,9,9,9,9,9,9,9,9,9,9,9,3,3,
3,3,10,10,10,10,10,10,10,10,10,10,8,8,10,10,
8,9,10,10,16,16,16,8,8,13,16,13,13,13,13,13,
10,10,8,11,12,9,8,8,8,12,16,10,9,6,13,10,
10,13,11,10,10,16,10,11,11,13,17,15,8,16,8,8,
5,5,13,8,9,9,3,10,6,6,10,10,8,5,5,8,
21,11,10,11,10,10,5,5,5,5,13,13,13,12,12,12,
3,8,8,8,8,8,8,8,8,8,8,9,4,10,9,12,
9,5,13,10,9,9,10,10,13,13,6,6,6,16,16,16,
12,10,5,10,9,11,9,11,9,10,6,5,10,8,8,8,
8,8,8,6,8,8,0,0,17,23,10,0,5,5,7,8,
14,11,16,13,5,7,7,9,14,5,6,5,6,11,11,11,
11,11,11,11,11,11,11,6,6,14,14,14,9,17,11,12,
12,13,11,10,13,13,6,6,12,9,15,13,13,10,13,12,
11,10,13,11,18,13,10,12,7,6,7,14,9,9,10,10,
8,10,10,6,10,11,5,5,10,5,17,11,10,10,10,7,
8,7,11,10,15,10,10,8,11,6,11,14,11,11,12,11,
13,13,13,10,10,10,10,10,10,8,10,10,10,10,5,5,
5,5,11,10,10,10,10,10,11,11,11,11,9,9,11,11,
9,10,11,11,17,17,17,9,9,14,16,13,14,14,14,14,
11,11,9,11,13,10,9,8,8,13,16,10,9,7,14,11,
11,14,11,10,10,17,11,11,11,13,18,17,9,17,9,9,
5,5,14,8,10,10,3,11,7,7,10,10,9,5,5,9,
23,11,11,11,11,11,6,6,6,6,13,13,13,13,13,13,
5,9,9,9,9,9,9,9,9,9,9,10,5,11,8,12,
8,6,13,10,10,10,10,10,14,14,7,7,7,16,16,16,
13,10,6,11,8,12,8,12,8,10,6,5,11,9,9,9,
9,9,9,7,9,9,0,0,18,24,11,0,6,6,7,8,
15,11,17,13,4,7,7,9,15,6,7,6,6,11,11,11,
11,11,11,11,11,11,11,6,6,15,15,15,10,18,12,12,
13,14,11,10,14,14,6,6,12,10,16,14,14,11,14,13,
11,12,14,12,19,13,12,13,7,6,7,15,9,9,10,11,
9,11,11,6,11,11,5,5,10,5,17,11,11,11,11,8,
8,7,11,11,16,11,11,9,11,6,11,15,12,12,13,11,
14,14,14,10,10,10,10,10,10,9,11,11,11,11,5,5,
5,5,11,11,11,11,11,11,11,11,11,11,9,9,11,11,
9,11,11,11,18,18,18,9,9,15,17,14,15,15,15,15,
11,11,9,12,14,11,9,8,8,14,17,11,10,7,15,11,
11,15,12,11,11,18,11,12,12,14,19,19,9,18,9,9,
6,6,15,9,11,12,3,11,7,7,11,11,9,6,6,9,
24,12,11,12,11,11,6,6,6,6,14,14,14,14,14,14,
5,9,9,9,9,9,9,9,9,9,9,10,5,11,8,13,
9,6,14,11,12,11,11,11,15,15,7,7,7,17,17,17,
14,11,6,11,8,13,9,13,9,11,7,6,11,9,9,9,
9,9,9,7,9,9,0,0,19,26,11,0,6,6,8,8,
16,12,18,14,4,7,7,10,16,6,7,6,6,12,12,12,
12,12,12,12,12,12,12,6,6,16,16,16,10,19,13,13,
13,15,12,11,15,14,6,6,12,11,16,14,15,12,15,13,
12,12,14,13,20,14,12,13,7,6,7,16,10,10,11,11,
9,11,11,6,11,12,5,5,11,5,17,12,11,11,11,8,
9,8,12,11,17,11,11,11,12,6,12,16,13,13,13,12,
14,15,14,11,11,11,11,11,11,9,11,11,11,11,5,5,
5,5,12,11,11,11,11,11,12,12,12,12,10,10,12,12,
10,11,12,12,19,19,19,10,10,16,18,15,16,16,16,16,
12,12,10,13,14,11,10,9,9,15,18,11,10,8,16,12,
12,16,13,12,12,19,12,13,13,15,20,19,10,19,10,10,
6,6,16,9,11,12,3,12,8,8,11,11,10,6,6,10,
26,13,12,13,12,12,6,6,6,6,15,15,15,14,14,14,
5,10,10,10,10,10,10,10,10,10,10,11,5,12,9,13,
11,6,15,11,12,11,12,11,16,16,8,8,8,18,18,18,
15,11,6,12,9,13,9,13,9,11,7,6,12,10,10,10,
10,10,10,8,10,10,0,0,20,27,12,0,6,6,8,10,
17,13,19,15,6,8,8,10,17,6,7,6,7,13,13,13,
13,13,13,13,13,13,13,7,7,17,17,17,11,20,14,14,
14,15,13,12,16,15,6,6,13,11,17,15,16,12,16,14,
13,12,15,14,20,14,12,14,8,7,8,17,10,10,12,13,
11,13,12,7,13,13,6,6,12,6,20,13,12,13,13,8,
10,8,13,11,17,11,11,11,13,7,13,17,14,14,14,13,
15,16,15,12,12,12,12,12,12,11,12,12,12,12,6,6,
6,6,13,12,12,12,12,12,13,13,13,13,10,10,13,13,
10,12,13,13,20,20,20,10,10,17,20,16,17,17,17,17,
13,13,10,13,15,12,10,9,9,15,19,12,11,8,17,13,
13,17,13,12,12,20,13,14,14,16,21,20,10,20,10,10,
6,6,17,10,11,12,3,13,8,8,13,13,10,6,6,10,
27,14,13,14,13,13,6,6,6,6,16,16,16,15,15,15,
6,10,10,10,10,10,10,10,10,10,10,11,6,13,10,14,
11,7,15,12,12,11,12,13,17,17,8,8,8,19,19,19,
16,13,6,13,10,14,11,14,11,13,7,6,13,10,10,10,
10,10,10,8,10,10,0,0,21,28,13,0,7,7,8,10,
18,13,20,16,6,8,8,11,18,7,8,7,7,13,13,13,
13,13,13,13,13,13,13,7,7,18,18,18,11,21,14,14,
15,16,13,12,16,16,6,6,14,12,18,16,17,13,17,15,
13,13,15,14,21,14,13,14,8,7,8,18,11,11,13,13,
12,13,13,7,13,13,6,6,12,6,20,14,13,13,13,9,
11,8,14,11,17,13,13,11,13,7,13,18,14,14,15,13,
16,17,15,13,13,13,13,13,13,12,13,13,13,13,6,6,
6,6,14,13,13,13,13,13,14,14,14,14,11,11,13,13,
11,12,13,13,21,21,21,11,11,18,20,17,18,18,18,18,
13,14,11,14,16,12,11,10,10,16,20,13,11,8,18,13,
13,18,14,13,13,21,13,14,14,17,22,22,11,21,11,11,
7,7,18,10,13,13,4,13,8,8,13,13,11,7,7,11,
28,14,13,14,13,13,6,6,6,6,17,17,17,15,15,15,
6,11,11,11,11,11,11,11,11,11,11,12,6,13,11,14,
11,7,16,13,13,13,13,13,18,18,8,8,8,20,20,20,
16,13,6,13,11,15,12,15,12,13,8,7,13,11,11,11,
11,11,11,8,11,11,0,0,22,30,13,0,7,7,9,10,
18,14,21,17,6,9,9,11,18,7,8,7,7,14,14,14,
14,14,14,14,14,14,14,7,7,18,18,18,12,22,15,15,
15,17,14,13,17,17,6,6,14,12,19,16,17,13,17,15,
14,13,16,15,22,15,13,15,9,7,9,18,11,11,13,14,
12,14,13,8,14,14,6,6,13,6,22,14,13,14,14,9,
11,9,14,14,18,14,14,12,14,7,14,18,15,15,15,14,
16,17,16,13,13,13,13,13,13,12,13,13,13,13,6,6,
6,6,14,13,13,13,13,13,14,14,14,14,11,11,14,14,
11,13,14,14,22,22,22,11,11,18,21,17,18,18,18,18,
14,14,11,15,17,13,11,10,10,17,21,13,12,9,18,14,
14,18,15,13,13,22,14,15,15,17,24,22,11,22,11,11,
7,7,18,11,14,13,4,14,9,9,13,13,11,7,7,11,
30,15,14,15,14,14,6,6,6,6,17,17,17,16,16,16,
6,11,11,11,11,11,11,11,11,11,11,12,6,14,11,15,
12,7,17,13,13,14,13,14,18,18,9,9,9,21,21,21,
17,14,6,14,11,15,12,15,12,14,8,7,14,11,11,11,
11,11,11,9,11,11,0,0,23,31,14,0,7,7,9,11,
19,15,22,18,6,9,9,12,19,7,8,7,8,15,15,15,
15,15,15,15,15,15,15,8,8,19,19,19,12,23,16,16,
16,18,15,13,18,17,7,7,15,13,20,17,18,14,18,16,
15,14,17,16,23,16,14,16,9,8,9,19,12,12,14,15,
13,15,14,8,15,15,6,6,13,6,22,15,14,14,14,9,
12,9,15,14,19,14,14,12,15,8,15,19,16,16,16,15,
17,18,17,14,14,14,14,14,14,13,14,14,14,14,6,6,
6,6,15,14,14,14,14,14,15,15,15,15,12,12,15,15,
12,14,15,14,23,23,23,12,12,19,22,18,19,19,19,19,
15,15,12,16,17,14,12,11,11,18,21,14,12,9,19,15,
15,19,15,14,14,23,15,16,16,18,25,24,12,23,12,12,
7,7,19,11,14,14,4,15,9,9,15,15,12,7,7,12,
31,16,15,16,15,15,7,7,7,7,18,18,18,17,17,17,
6,12,12,12,12,12,12,12,12,12,12,13,6,15,12,16,
12,8,18,14,14,14,14,14,19,19,9,9,9,22,22,22,
18,15,7,15,12,16,13,16,13,15,8,7,15,12,12,12,
12,12,12,9,12,12,0,0,24,32,14,0,8,8,10,11,
20,15,23,19,7,9,9,12,20,8,9,8,8,15,15,15,
15,15,15,15,15,15,15,8,8,20,20,20,13,24,16,16,
17,18,15,14,19,18,7,7,16,13,21,18,19,14,19,17,
15,15,18,16,24,16,15,16,9,8,9,20,12,12,14,15,
13,15,14,8,15,15,7,7,14,6,24,15,14,15,15,10,
12,9,15,15,20,15,15,13,15,8,15,20,16,16,17,15,
18,19,18,14,14,14,14,14,14,13,14,14,14,14,7,7,
7,7,15,14,14,14,14,14,15,15,15,15,12,12,15,15,
12,14,15,15,24,24,24,12,12,20,23,19,20,20,20,20,
15,15,12,16,18,14,13,11,11,18,23,14,13,10,20,15,
15,20,16,15,15,24,15,16,16,19,26,24,12,24,12,12,
8,8,20,12,15,15,4,15,10,10,15,15,12,8,8,12,
32,16,15,16,15,15,7,7,7,7,19,19,19,18,18,18,
7,12,12,12,12,12,12,12,12,12,12,13,6,15,12,16,
13,8,19,14,15,15,15,15,20,20,10,10,10,23,23,23,
19,15,7,15,12,17,13,17,13,15,9,8,15,12,12,12,
12,12,12,10,12,12,0,0,25,34,15,0,8,8,10,12,
21,16,24,20,7,10,10,13,21,8,9,8,8,16,16,16,
16,16,16,16,16,16,16,8,8,21,21,21,13,25,17,17,
17,19,16,14,19,19,7,7,16,14,22,19,20,15,20,17,
16,15,18,17,25,17,15,17,10,8,10,21,13,13,15,16,
14,16,15,9,16,16,7,7,14,7,24,16,15,16,16,10,
13,10,16,15,20,15,15,13,16,8,16,21,17,17,17,16,
19,20,18,15,15,15,15,15,15,14,15,15,15,15,7,7,
7,7,16,15,15,15,15,15,16,16,16,16,13,13,16,16,
13,15,16,16,25,25,25,13,13,21,24,20,21,21,21,21,
16,16,13,17,19,15,13,12,12,19,25,15,13,10,21,16,
16,21,17,15,15,25,16,17,17,20,27,26,13,25,13,13,
8,8,21,12,15,15,4,16,10,10,16,16,13,8,8,13,
34,17,16,17,16,16,7,7,7,7,20,20,20,18,18,18,
7,13,13,13,13,13,13,13,13,13,13,14,7,16,13,17,
13,8,19,15,15,15,15,16,21,21,10,10,10,24,24,24,
19,16,7,16,13,17,14,17,14,16,9,8,16,13,13,13,
13,13,13,10,13,13,0,0,26,35,16,0,8,8,10,12,
22,17,25,20,7,10,10,13,22,8,9,8,9,17,17,17,
17,17,17,17,17,17,17,9,9,22,22,22,14,26,18,18,
18,20,16,15,20,20,8,8,17,14,22,19,20,16,20,18,
17,16,19,18,26,18,16,18,10,9,10,22,13,13,16,17,
14,17,16,9,17,16,7,7,15,7,25,16,16,17,17,11,
14,10,16,15,21,15,15,14,17,9,17,22,18,18,18,16,
19,20,19,16,16,16,16,16,16,14,16,16,16,16,7,7,
7,7,16,16,16,16,16,16,16,16,16,16,13,13,17,17,
13,15,17,16,26,26,26,13,13,22,25,20,22,22,22,22,
17,17,13,18,20,15,14,12,12,20,26,16,14,10,22,17,
17,22,17,16,16,26,17,18,18,20,28,27,13,26,13,13,
8,8,22,13,15,16,4,17,10,10,16,16,13,8,8,13,
35,18,16,18,16,16,8,8,8,8,20,20,20,19,19,19,
7,13,13,13,13,13,13,13,13,13,13,15,7,17,14,18,
14,9,20,16,16,15,16,17,22,22,10,10,10,25,25,25,
20,17,8,17,14,18,14,18,14,17,9,8,17,13,13,13,
13,13,13,10,13,13,0,0,27,36,16,0,9,9,11,12,
23,17,26,21,7,11,11,14,23,9,10,9,9,17,17,17,
17,17,17,17,17,17,17,9,9,23,23,23,14,27,18,19,
19,21,17,16,21,20,8,8,18,15,23,20,21,16,21,19,
17,17,20,18,27,19,17,19,11,9,11,23,14,14,17,17,
15,17,17,10,17,17,8,8,16,8,26,17,17,17,17,11,
14,11,17,16,22,16,16,14,17,9,17,23,18,18,19,17,
20,21,20,17,17,17,17,17,17,15,17,17,17,17,8,8,
8,8,17,17,17,17,17,17,17,17,17,17,14,14,17,17,
14,16,17,17,27,27,27,14,14,23,26,21,22,23,23,23,
17,17,14,18,20,16,14,13,13,21,27,17,14,11,23,17,
17,23,18,17,17,27,17,18,18,21,29,28,14,27,14,14,
9,9,23,13,16,17,5,17,11,11,17,17,14,9,9,14,
36,18,17,18,17,17,8,8,8,8,21,21,21,20,20,20,
8,14,14,14,14,14,14,14,14,14,14,15,8,17,14,19,
14,9,21,17,17,16,16,17,23,23,11,11,11,26,26,26,
21,17,8,17,14,19,15,19,15,17,10,9,17,14,14,14,
14,14,14,11,14,14,0,0,28,38,17,0,9,9,11,13,
23,18,27,22,8,11,11,14,23,9,10,9,9,18,18,18,
18,18,18,18,18,18,18,9,9,23,23,23,15,28,19,19,
20,22,18,16,22,21,8,8,18,16,24,21,22,17,22,19,
18,17,21,19,28,19,17,19,11,9,11,23,14,14,17,18,
15,18,17,10,18,18,8,8,16,8,27,18,17,18,18,12,
15,11,18,17,23,17,17,15,18,9,18,23,19,19,20,18,
21,22,21,17,17,17,17,17,17,15,17,17,17,17,8,8,
8,8,18,17,17,17,17,17,18,18,18,18,14,14,18,18,
14,17,18,18,28,28,28,14,14,23,27,22,23,23,23,23,
18,18,14,19,21,16,15,13,13,21,28,17,15,11,23,18,
18,23,19,17,17,28,18,19,19,22,30,29,14,28,15,15,
9,9,23,14,17,17,5,18,11,11,18,18,14,9,9,15,
38,19,18,19,18,18,8,8,8,8,22,22,22,21,21,21,
8,14,14,14,14,14,14,14,14,14,14,16,8,18,15,19,
15,9,22,17,17,17,17,18,23,23,11,11,11,27,27,27,
22,18,8,18,15,20,15,20,15,18,10,9,18,14,14,14,
14,14,14,11,14,14,0,0,0,0,0,2,0,8,0,2,
255,255,0,3,0,1,0,0,0,2,0,0,12,80,10,236,
95,15,60,245,0,31,8,0,0,0,0,0,186,185,240,184,
0,0,0,0,186,194,103,145,254,137,254,29,10,76,7,109,
0,0,0,8,0,1,0,0,0,0,0,0
};
#include <SDL_ttf.h>
static TTF_Font *font;
static void init_text() {
    SDL_RWops *fontrw = SDL_RWFromMem((void *)fontbits, sizeof(fontbits));
    if (!TTF_WasInit()) {
        TTF_Init();
        font = TTF_OpenFontRW(fontrw, 0, 12);
    }
}
#include <sys/time.h>
#include <time.h>
static Uint8 *keystate;  /* for KeyboardPushed */
static int numkeys;
static Uint8 keyrel[SDLK_LAST];  /* for KeyboardReleased */
static Uint8 mousebuttons;
static int mousex;
static int mousey;
static int framerate = 60;
static SDL_Color frontcolor;
static SDL_Joystick *joystick;
#include <cctype>
static void putpixel(SDL_Surface *surface, int x, int y, uint32_t color) {
	if (x < 0 || y < 0 || x > surface->w || y > surface->h)
		return;

	switch (surface->format->BytesPerPixel) {
	case 1:
		((uint8_t *)surface->pixels)[x + y * surface->pitch] = color;
		break;
	case 2:
		((uint16_t *)surface->pixels)[x + y * surface->pitch/2] = color;
		break;
	case 4:
		((uint32_t *)surface->pixels)[x + y * surface->pitch/4] = color;
		break;
	}
}

static void linedraw(int x, int y, int dx, int dy, Uint32 color) {
	int i, j;

	SDL_LockSurface(screen);

	if (abs(dx) > abs(dy)) {
		/* Normalize dx positive */
		if (dx < 0) {
			x += dx;
			y += dy;
			dx = -dx;
			dy = -dy;
		}
		j = 0;
		for (i = 0; i < dx; i++) {
			putpixel(screen, x + i, y, color);
			j += dy;
			if (j >= dx) {
				j -= dx;
				y += dy > 0 ? 1 : -1;
			}
		}
	} else {
		/* Normalize dy positive */
		if (dy < 0) {
			x += dx;
			y += dy;
			dx = -dx;
			dy = -dy;
		}
		j = 0;
		for (i = 0; i < dy; i++) {
			putpixel(screen, x, y + i, color);
			j += dx;
			if (j >= dy) {
				j -= dy;
				x += dx > 0 ? 1 : -1;
			}
		}
	}

	SDL_UnlockSurface(screen);
}
static Mix_Music *mods[1024];
static int32_t unused_mod() {
    int i;
    for (i = 1; i < 1024; i++) {
        if (!mods[i])
            return i;
    }
    return 0;
}
#include <errno.h>
static uint32_t word(unsigned char *w) {
	return w[0] | (w[1]<<8) | (w[2]<<16) | (w[3]<<24);
}

static ssize_t fullread(int fd, unsigned char *buf, size_t count) {
	size_t n = 0;
	ssize_t r = 0;
	while (n < count) {
		r = read(fd, buf + n, count - n);
		if (r < 0 && errno == EINTR)
			continue;
		if (r < 0)
			return r;
		if (r == 0)
			return n;
		n += r;
	}
	return n;
}

static unsigned char *packed;
static int packedsize;

static unsigned char *packp;
static uint64_t curword;
static int bitsleft;

static uint32_t getbits(int bits) {
	if (bits > bitsleft) {
		curword <<= 32;
		curword |= word(packp);
		packp += 4;
		bitsleft += 32;
	}
	bitsleft -= bits;
	return (curword >> bitsleft) & ((1 << bits) - 1);
}

static uint32_t decodegamma() {
	uint32_t w = 1;
	do {
		w = (w << 1) | getbits(1);
	} while (getbits(1));
	return w;
}

static int decode() {
	int indexbase = 8;
	int lastindex = 1;
	int minimumliteral = 0;
	int literalbits = 8;
	unsigned char *dest = packfile;

	bitsleft = 0;
	curword = 0;

	for (;;) {
		if (packp - packed > packedsize + 4)
			return 0;
		if (dest - packfile > packfilesize)
			return 0;
		if (getbits(1)) {
			/* 1 Literal */
			*dest++ = getbits(literalbits) + minimumliteral;
		} else if (getbits(1)) {
			/* 01 Normal phrase */
			int l;
			int g = decodegamma();
			if (g == 2) {
				/* 0100 repeated normal phrase */
				l = decodegamma();
			} else {
				lastindex = getbits(indexbase) | ((g-3) << indexbase);
				l = decodegamma();
				if (lastindex >= 0x10000)
					l += 3;
				else if (lastindex >= 0x37ff)
					l += 2;
				else if (lastindex >= 0x27f)
					l += 1;
				else if (lastindex <= 0x7f)
					l += 4;
			}
			if (dest - packfile < lastindex)
				return 0;
			if (dest - packfile + l > packfilesize)
				return 0;
			/* Unfortunately can't use memmove or memcpy here,
                         * because l > lastindex is allowed, and the
                         * overlapping copy should be handled in this
                         * specific way. */
			while (l--) {
				*dest = *(dest - lastindex);
				dest++;
			}
		} else if (getbits(1)) {
			int x = getbits(4);
			if (!x) {
				if (getbits(1)) {
					/* 00100001 Block sequence */
					do {
						int n;
						if (dest - packfile + 256 > packfilesize)
							return 0;
						for (n = 0; n < 256; n++) {
							*dest++ = getbits(8);
						}
					} while (getbits(1));
				} else if (getbits(1)) {
					/* 001000001 */
					literalbits = 8;
					minimumliteral = 0;
				} else {
					/* 001000000xxxxxxxx */
					literalbits = 7;
					minimumliteral = getbits(8);
				}
			} else if (x == 1) {
				/* 0010001 literal byte 00 */
				*dest++ = 0;
			} else {
				/* 001xxxx single byte match */
				if (dest - packfile < x-1)
					return 0;
				*dest = *(dest-(x-1));
				dest++;
			}
		} else {
			int x = getbits(7);
			int y = getbits(2);
			if (!x && !y) {
				/* 000000000000 done */
				return dest - packfile; /* decoded size */
			}
			if (x) {
				if (dest - packfile < x)
					return 0;
				if (dest - packfile + y+2 > packfilesize)
					return 0;
				/* 000xxxxxxxyy Short match */
				lastindex = x;
				y += 2;
				/* can't memmove, same reason as above */
			        while (y--) {
					*dest = *(dest - lastindex);
					dest++;
				}
			} else {
				/* 0000000000yybbbb New index base */
				indexbase = getbits(y+3);
			}
		}
	}
}

static int nextpack() {
	unsigned char sizes[8];
	if (packfd < 0)
		return 0;
	if (fullread(packfd, sizes, 8) < 8) {
		closepack();
		return 0;
	}
	packfilesize = word(sizes);
	packedsize = word(sizes + 4);
	if (packedsize > packfilesize) {
		closepack();
		return 0;
	}
	packfile = new unsigned char [packfilesize];
	if (packedsize == packfilesize) {  /* not compressed */
		if (fullread(packfd, packfile, packfilesize) < packfilesize) {
			closepack();
			return 0;
		}
		return 1;
	}
	packed = new unsigned char [packedsize];
	packp = packed + 10;
	if (packedsize < 14 ||
	    fullread(packfd, packed, packedsize) < packedsize ||
	    word(packed + 2) != packfilesize ||
	    packed[0] != 'J' || packed[1] != 'C' ||
	    decode() != packfilesize) {
		delete[] packed;
		closepack();
		return 0;
	}
	return 1;
}
#include <netdb.h>
#include <sys/socket.h>
#include <fcntl.h>
static void init_random() {
    struct timeval tv;
    unsigned int seed;

    gettimeofday(&tv, 0);
    seed = tv.tv_usec ^ tv.tv_sec ^ getpid();
    srandom(seed);
}
#include <string.h>

static int32_t p_addelement(LinkedList * p1) {
struct ListElement *newelem = p1->alloc_elem();
if (!newelem)
    return 0;
if (p1->length == 0) {
    insertonly(p1, newelem);
} else if (!p1->current) {
    insertfirst(p1, newelem);
} else if (p1->current == p1->last) {
    insertlast(p1, newelem);
} else {
    newelem->next = p1->current->next;
    newelem->prev = p1->current;
    newelem->next->prev = newelem;
    newelem->prev->next = newelem;
    p1->current = newelem;
    p1->length += 1;
    p1->index += 1;
}
return 1;

}

static void p_box(int32_t p1, int32_t p2, int32_t p3, int32_t p4, int32_t p5) {
SDL_Rect dstrect;
Uint32 color;
dstrect.x = p1;
dstrect.y = p2;
dstrect.w = p3;
dstrect.h = p4;
if (p5 < 0) {
  color = SDL_MapRGB(screen->format, frontcolor.r, frontcolor.g, frontcolor.b);
} else {
  color = SDL_MapRGB(screen->format, (p5 >> 16) && 0xff, (p5 >> 8) && 0xff, p5 && 0xff);
}
SDL_FillRect(screen, &dstrect, color);

}

static int16_t p_catchsound(int16_t p1, int32_t p2) {
int handle;
SDL_RWops *rw;
if (p1 < 0) {
    handle = unused_sound();
    if (handle == 0)
        return 0;
} else {
   handle = p1;
}
if (sounds[handle]) {
    Mix_FreeChunk(sounds[handle]);
    sounds[handle] = 0;
}
rw = SDL_RWFromMem(packfile, packfilesize);
if (!rw)
    return 0;
sounds[handle] = Mix_LoadWAV_RW(rw, 0);
SDL_RWclose(rw);
if (!sounds[handle])
    return 0;
delete[] packfile;
packfile = 0;
packfilesize = 0;
return (p1 < 0) ? handle : 1;

}

static int16_t p_catchsprite(int16_t p1, int32_t p2) {
int handle;
SDL_RWops *rw;
if (p1 < 0) {
    handle = unused_sprite();
    if (handle == 0)
      return 0;
} else {
    handle = p1;
}
if (sprites[handle]) {
    SDL_FreeSurface(sprites[handle]);
    sprites[handle] = 0;
}
/* Cheat: ignore p2, assume that the source is the current packfile */
if (!packfile)
    return 0;
rw = SDL_RWFromMem(packfile, packfilesize);
if (!rw)
    return 0;
sprites[handle] = IMG_Load_RW(rw, 0);
if (!sprites[handle])
    return 0;
delete[] packfile;
packfile = 0;
packfilesize = 0;
return (p2 < 0) ? handle : 1;

}

static std::string p_chr(int8_t p1) {
char *s = new char [2];
s[0] = p1;
s[1] = 0;
return s;

}

static void p_circle(int32_t p1, int32_t p2, int32_t p3, int32_t p4) {
Uint32 color;
if (p4 < 0) {
  color = SDL_MapRGB(screen->format, frontcolor.r, frontcolor.g, frontcolor.b);
} else {
  color = SDL_MapRGB(screen->format, (p4 >> 16) && 0xff, (p4 >> 8) && 0xff, p4 && 0xff);
}
filledCircleColor(screen, p1, p2, p3, color);

}

static void p_clearlist(LinkedList * p1) {
struct ListElement *p = p1->root;
struct ListElement *n;
while (p) {
    n = p->next;
    p1->del_elem(p);
    p = n;
}
p1->root = 0;
p1->current = 0;
p1->last = 0;
p1->length = 0;
p1->index = -1;

}

static void p_clearscreen(int32_t p1) {
int r, g, b;
uint32_t color;
if (!screen)
    return;
r = (p1 >> 16) & 0xff;
g = (p1 >> 8) & 0xff;
b = p1 & 0xff;
color = SDL_MapRGB(screen->format, r, g, b);
SDL_FillRect(screen, 0, color);

}

static void p_clipsprite(int16_t p1, int32_t p2, int32_t p3, int32_t p4, int32_t p5) {
if (p1 >= 1024 || !sprites[p1])
    return;
spriteclips[p1].x = p2;
spriteclips[p1].y = p3;
spriteclips[p1].w = p4;
spriteclips[p1].h = p5;

}

static void p_closefile(int16_t p1) {
if (fh[p1]) {
  fclose(fh[p1]);
  fh[p1] = 0;
}

}

static void p_closenetworkconnection(int32_t p1) {
close(p1 - 1);

}

static void p_closescreen() {
SDL_QuitSubSystem(SDL_INIT_VIDEO);
screen = 0;

}

static float p_cos(float p1) {
return cos(p1);

}

static int32_t p_countlist(LinkedList * p1) {
return p1->length;

}

static void p_createdirectory(std::string p1) {
mkdir(p1.c_str(), 0777);

}

static int16_t p_createfile(int16_t p1, std::string p2) {
return fileopen(p1, p2.c_str(), "w");

}

static int32_t p_date() {
return time(0);

}

static void p_delay(int32_t p1) {
usleep(p1*1000);

}

static void p_displaysprite(int16_t p1, int32_t p2, int32_t p3) {
SDL_Rect dstrect = { p2, p3, 0, 0 };
if (p1 >= 1024 || !sprites[p1])
    return;
SDL_SetColorKey(sprites[p1], 0, 0);
SDL_SetAlpha(sprites[p1], 0, 0);
SDL_BlitSurface(sprites[p1], &spriteclips[p1], screen, &dstrect);

}

static void p_displaytransparentsprite(int16_t p1, int32_t p2, int32_t p3) {
SDL_Rect dstrect = { p2, p3, 0, 0 };
uint32_t color;
if (p1 >= 1024 || !sprites[p1])
    return;
color = SDL_MapRGB(sprites[p1]->format, 0, 0, 0);
SDL_SetColorKey(sprites[p1], SDL_SRCCOLORKEY, color);
SDL_SetAlpha(sprites[p1], 0, 0);
SDL_BlitSurface(sprites[p1], &spriteclips[p1], screen, &dstrect);

}

static void p_drawingmode(int32_t p1) {
;  /* cheat -- always draw in mode 1 */

}

static int32_t p_drawtext(int32_t p1, int32_t p2, std::string p3, int32_t p4, int32_t p5) {
SDL_Rect textpos;
SDL_Surface *textsurf;
int w;
textpos.x = p1;
textpos.y = p2;
if (!screen)
    return textpos.x;
/* background color is in p5, but it's not actually supported yet. */
if (p4 < 0) {
    textsurf = TTF_RenderText_Blended(font, p3.c_str(), frontcolor);
} else {
    SDL_Color color;
    color.r = (p4 >> 16) & 0xff;
    color.g = (p4 >> 8) & 0xff;
    color.b = p4 & 0xff;
    textsurf = TTF_RenderText_Blended(font, p3.c_str(), color);
}
if (!textsurf)
    return textpos.x;
SDL_BlitSurface(textsurf, NULL, screen, &textpos);
w = textsurf->w;
SDL_FreeSurface(textsurf);  /* cache this? */
return textpos.x + w;

}

static int32_t p_elapsedmilliseconds() {
/* Instead of going out and parsing /proc/uptime or something,
 * just fake it. Pretend that the system was up for one hour,
 * at the first call to ElapsedMilliseconds. Callers are going
 * to be interested in time differences, not absolute time. */
static struct timeval elapsedbasis;
struct timeval tv;
gettimeofday(&tv, 0);
if (elapsedbasis.tv_sec == 0) {
    elapsedbasis = tv;
    elapsedbasis.tv_sec -= 3600;
}
return (tv.tv_sec - elapsedbasis.tv_sec) * 1000 +
       (tv.tv_usec - elapsedbasis.tv_usec) / 1000;

}

static int16_t p_eof(int32_t p1) {
/* Can't use feof() here. Eof() should return true when the file
 * pointer is actually at the end of the file, while feof only
 * returns true when a previous read has failed. */
int c;
if (!fh[p1])
  return 0;
c = getc(fh[p1]);
if (c == EOF)
  return 1;
ungetc(c, fh[p1]);
return 0;

}

static void p_examinejoystick() {
SDL_JoystickUpdate();

}

static void p_examinekeyboard() {
SDL_Event event;

/* KeyboardReleased needs to report whether a key has actually gone
 * from pressed to released since the last poll. Unlike KeyboardPushed,
 * this cannot be done via the implicitly updated keystate array. */
memset(keyrel, 0, SDLK_LAST);
while (SDL_PollEvent(&event)) {
    if (event.type == SDL_KEYUP) {
        SDLKey sym = event.key.keysym.sym;
        if (sym >= 0 && sym < SDLK_LAST) {
            keyrel[sym] = 1;
        }
        break;
    }
}

}

static int32_t p_examinemouse() {
SDL_PumpEvents();
mousebuttons = SDL_GetMouseState(&mousex, &mousey);
return 1;

}

static void p_flipbuffers(int32_t p1) {
static struct timeval lastflip;
struct timeval now;
long elapsed;
if (!screen)
    return;
gettimeofday(&now, 0);
elapsed = now.tv_usec - lastflip.tv_usec
        + (now.tv_sec - lastflip.tv_sec) * 1000000;
if (elapsed < 1000000 / framerate)
    usleep(1000000 / framerate - elapsed);
SDL_Flip(screen);
gettimeofday(&lastflip, 0);

}

static std::string p_formatdate(std::string p1, int32_t p2) {
char c;
/* Allocating s at same length as p1 is safe as long as all formatting
 * codes are at least as long as the string they represent.
 * That's going to be true until the year 100000. Remember to fix
 * this before then. */
char *s = new char [p1.length() + 1];
const char *q = p1.c_str();
char *r = s;
time_t t = p2;
struct tm *tm = localtime(&t);
while (c = *q++) {
    if (c == '%') {
        if (q[0] == 'y' && q[1] == 'y' && q[2] == 'y' && q[3] == 'y') {
            sprintf(s, "%04d", tm->tm_year + 1900);
            s += strlen(s);
            q += 4;
        } else if (q[0] == 'y' && q[1] == 'y') {
            sprintf(s, "%02d", tm->tm_year % 100);
            s += 2;
            q += 2;
        } else if (q[0] == 'm' && q[1] == 'm') {
            sprintf(s, "%02d", tm->tm_mon + 1);
            s += 2;
            q += 2;
        } else if (q[0] == 'd' && q[1] == 'd') {
            sprintf(s, "%02d", tm->tm_mday);
            s += 2;
            q += 2;
        } else if (q[0] == 'h' && q[1] == 'h') {
            sprintf(s, "%02d", tm->tm_hour);
            s += 2;
            q += 2;
        } else if (q[0] == 'i' && q[1] == 'i') {
            sprintf(s, "%02d", tm->tm_min);
            s += 2;
            q += 2;
        } else if (q[0] == 's' && q[1] == 's') {
            sprintf(s, "%02d", tm->tm_sec);
            s += 2;
            q += 2;
        } else {
            *s++ = c;
        }
    } else {
        *s++ = c;
    }
}
*s++ = 0;
std::string rs = r;
delete[] r;
return rs;

}

static void p_frontcolor(int32_t p1) {
frontcolor.r = (p1 >> 16) & 0xff;
frontcolor.g = (p1 >> 8) & 0xff;;
frontcolor.b = p1 & 0xff;

}

static std::string p_getenvironmentvariable(std::string p1) {
char *s = getenv(p1.c_str());
return s ? s : "";

}

static int32_t p_initjoystick() {
if (SDL_InitSubSystem(SDL_INIT_JOYSTICK) != 0)
    return 0;
if (SDL_NumJoysticks() == 0)
    return 0;
joystick = SDL_JoystickOpen(0);
if (!joystick)
    return 0;
return 1;

}

static int32_t p_initkeyboard() {
keystate = SDL_GetKeyState(&numkeys);
return 1;

}

static int32_t p_initmouse() {
return 1;

}

static int32_t p_initnetwork() {
return 1;

}

static int32_t p_initsound() {
SDL_InitSubSystem(SDL_INIT_AUDIO);
Mix_OpenAudio(44100, AUDIO_S16SYS, 2, 4096);

}

static int32_t p_initsprite() {
return SDL_Init(SDL_INIT_VIDEO) == 0;

}

static int32_t p_int(float p1) {
return p1;

}

static int32_t p_joystickaxisx() {
int x = SDL_JoystickGetAxis(joystick, 0);
if (x < -100) return -1;
if (x > 100) return 1;
return 0;

}

static int32_t p_joystickaxisy() {
int y = SDL_JoystickGetAxis(joystick, 1);
if (y < -100) return -1;
if (y > 100) return 1;
return 0;

}

static int32_t p_joystickbutton(int32_t p1) {
return SDL_JoystickGetButton(joystick, p1-1);

}

static int32_t p_keyboardpushed(int32_t p1) {
if (p1 >= numkeys)
  return 0;
if (p1 < 0)
  return 0;
return keystate[p1] != 0;

}

static int32_t p_keyboardreleased(int32_t p1) {
if (p1 >= numkeys)
  return 0;
if (p1 < 0)
  return 0;
return keyrel[p1] != 0;

}

static std::string p_lcase(std::string p1) {
std::string::iterator it;
for (it = p1.begin(); it < p1.end(); it++) {
  *it = tolower(*it);
}
return p1;

}

static int32_t p_len(std::string p1) {
return p1.length();

}

static void p_line(int32_t p1, int32_t p2, int32_t p3, int32_t p4, int32_t p5) {
Uint32 color;
if (p5 < 0) {
  color = SDL_MapRGB(screen->format, frontcolor.r, frontcolor.g, frontcolor.b);
} else {
  color = SDL_MapRGB(screen->format, (p5 >> 16) && 0xff, (p5 >> 8) && 0xff, p5 && 0xff);
}
linedraw(p1, p2, p3, p4, color);

}

static void p_linexy(int32_t p1, int32_t p2, int32_t p3, int32_t p4) {
linedraw(p1, p2, p3 - p1, p4 - p2, -1);

}

static int16_t p_loadmodule(int16_t p1, std::string p2) {
int handle;
if (p1 < 0) {
    handle = unused_mod();
    if (handle == 0)
        return 0;
} else {
    handle = p1;
}
if (mods[handle]) {
    Mix_FreeMusic(mods[handle]);
    mods[handle] = 0;
}
mods[handle] = Mix_LoadMUS(p2.c_str());
if (!mods[handle])
    return 0;
return (p1 < 0) ? handle : 1;

}

static std::string p_mid(std::string p1, int32_t p2, int32_t p3) {
if (p2 > p1.length())
  return "";
if (p2 <= 0)
  p2 = 1;
if (p3 < 0)
  p3 = 0;
return p1.substr(p2 - 1, p3);

}

static int32_t p_mousebutton(int32_t p1) {
if (p1 == 1)
    return (mousebuttons & SDL_BUTTON(SDL_BUTTON_LEFT)) != 0;
if (p1 == 2)
    return (mousebuttons & SDL_BUTTON(SDL_BUTTON_RIGHT)) != 0;

}

static int32_t p_mousex() {
return mousex;

}

static int32_t p_mousey() {
return mousey;

}

static int32_t p_nextelement(LinkedList * p1) {
if (!p1->current)
  p1->current = p1->root;
else
  p1->current = p1->current->next;
p1->index += 1;
return p1->current != 0;

}

static int32_t p_nextpackfile() {
return nextpack();

}

static int32_t p_opennetworkconnection(std::string p1, int16_t p2) {
struct hostent *h;
int sockfd;
h = gethostbyname(p1.c_str());
if (!h)
    return 0;
sockfd = socket(h->h_addrtype, SOCK_STREAM, 0);
if (sockfd < 0)
    return 0;
if (connect(sockfd, (struct sockaddr *) h->h_addr_list[0], h->h_length) < 0) {
    close(sockfd);
    return 0;
}
return sockfd + 1;  /* offset by one because sockfd might be 0 */

}

static int32_t p_openpack(std::string p1) {
closepack();
packfd = open(p1.c_str(), O_RDONLY);
return packfd >= 0;

}

static int32_t p_openscreen(int32_t p1, int32_t p2, int32_t p3, std::string p4) {
uint32_t flags = SDL_HWSURFACE | SDL_DOUBLEBUF | SDL_FULLSCREEN;
if (!SDL_WasInit(SDL_INIT_VIDEO)) {
    SDL_InitSubSystem(SDL_INIT_VIDEO);
}
screen = SDL_SetVideoMode(p1, p2, p3, flags);
if (!screen)
    return 0;
SDL_WM_SetCaption(p4.c_str(), "");
SDL_ShowCursor(SDL_DISABLE);
return 1;

}

static int32_t p_openwindowedscreen(int32_t p1, int32_t p2, int32_t p3, int32_t p4, int32_t p5, int32_t p6, int32_t p7, int32_t p8) {
uint32_t flags = SDL_HWSURFACE | SDL_DOUBLEBUF;
if (p6) {
    flags |= SDL_RESIZABLE;
}
if (!SDL_WasInit(SDL_INIT_VIDEO)) {
    SDL_InitSubSystem(SDL_INIT_VIDEO);
}
screen = SDL_SetVideoMode(p4, p5, 0, flags);
if (!screen)
    return 0;
SDL_ShowCursor(SDL_DISABLE);
/* SDL_WM_GrabInput(SDL_GRAB_ON);    too annoying while debugging */
return 1;

}

static int32_t p_parsedate(std::string p1, std::string p2) {
char c;
int n;
int v;
struct tm tm = { 0, 0, 0, 1, 0, 0, 0, 0, 0 };
const char *q = p1.c_str();
const char *r = p2.c_str();
while (c = *q++) {
    if (c == '%') {
        if (q[0] == 'y' && q[1] == 'y' && q[2] == 'y' && q[3] == 'y') {
            n = sscanf(r, "%4d", &v);
            tm.tm_year = v - 1900;
        } else if (q[0] == 'y' && q[1] == 'y') {
            n = sscanf(r, "%2d", &v);
            tm.tm_year = v + 100;
        } else if (q[0] == 'm' && q[1] == 'm') {
            n = sscanf(r, "%2d", &v);
            tm.tm_mon = v - 1;
        } else if (q[0] == 'd' && q[1] == 'd') {
            n = sscanf(r, "%2d", &v);
            tm.tm_mday = v;
        } else if (q[0] == 'h' && q[1] == 'h') {
            n = sscanf(r, "%2d", &v);
            tm.tm_hour = v;
        } else if (q[0] == 'i' && q[1] == 'i') {
            n = sscanf(r, "%2d", &v);
            tm.tm_min = v;
        } else if (q[0] == 's' && q[1] == 's') {
            n = sscanf(r, "%2d", &v);
            tm.tm_sec = v;
        } else {
            n = 1;
        }
        if (n == EOF)
            return -1;
        r += n;
    } else {
        r++;
    }
}
return mktime(&tm);

}

static uint8_t p_peekc(char * p1) {
return * (uint8_t *) p1;

}

static void p_playmodule(int16_t p1) {
if (p1 > 1024 || p1 < 0 || !mods[p1])
    return;
Mix_PlayMusic(mods[p1], -1);

}

static void p_playsound(int16_t p1) {
if (p1 > 1024 || p1 < 0 || !sounds[p1])
    return;
Mix_PlayChannel(-1, sounds[p1], 0);

}

static int32_t p_random(int32_t p1) {
/* Generate a random integer from 0..p1 inclusive */
/* Strategy: Use libc random(), which returns 0..RAND_MAX inclusive,
 * and take the result modulo (p1+1). Avoid bias if p1+1 does not
 * divide evenly into RAND_MAX+1. Be very careful about overflow. */
long v, limit, top;
if (p1 <= 0)
  return 0;
if (p1 == 0x7FFFFFFF)  /* avoid overflow in p1+1 */
  return random() & 0x7FFFFFFF;
limit = p1 + 1;
if (RAND_MAX % limit == p1)  /* divides evenly? */
  return random() % limit;
/* RAND_MAX + 1 would overflow, so move the +1 out of the modulo */
/* This is safe because of the "divides evenly" check above. */
top = RAND_MAX - ((RAND_MAX % limit) + 1);
do { v = random(); } while (v > top);
return v % limit;

}

static int16_t p_readfile(int16_t p1, std::string p2) {
return fileopen(p1, p2.c_str(), "r");

}

static std::string p_readstring(int16_t p1) {
size_t bufsz = 1024;
size_t n = 0;
char *buffer = 0;
if (!fh[p1])
    return 0;
for (;;) {
    buffer = (char *) realloc(buffer, bufsz);
    if (fgets(buffer + n, bufsz - n, fh[p1])) {
        n += strlen(buffer + n);
        if (buffer[n - 1] == '\n') {
            buffer[--n] = 0;
            break;
        }
    } else {
        break;
    }
    bufsz = bufsz * 2;
}
if (n > 1 && buffer[n - 1] == '\r')
  buffer[--n] = 0;
std::string r (buffer, n);
free(buffer);
return r;

}

static int16_t p_readword(int16_t p1) {
int b1, b2;
if (!fh[p1])
    return 0;
b1 = fgetc(fh[p1]);
if (b1 == EOF)
  b1 = 0;
b2 = fgetc(fh[p1]);
if (b2 == EOF)
  b2 = 0;
return b1 + b2 * 256;

}

static int32_t p_releasemouse(int32_t p1) {
SDL_WM_GrabInput(p1 ? SDL_GRAB_OFF : SDL_GRAB_ON);

}

static std::string p_replacestring(std::string p1, std::string p2, std::string p3) {
size_t pos;
if (p2.empty()) /* avoid infinite loop */
    return p1;
pos = p1.find(p2);
while (pos != std::string::npos) {
    p1.replace(pos, p2.length(), p3);
    pos = p1.find(p2, pos + p3.length());
}
return p1;

}

static int32_t p_rgb(int8_t p1, int8_t p2, int8_t p3) {
return ((uint8_t) p1 << 16) | ((uint8_t) p2 << 8) | (uint8_t) p3;

}

static std::string p_right(std::string p1, int32_t p2) {
if (p2 >= p1.length())
  return p1;
return p1.substr(p1.length() - p2);

}

static std::string p_rset(std::string p1, int32_t p2) {
int spaces;
spaces = p2 - p1.length();
if (spaces < 0)
  spaces = 0;
return std::string(spaces, ' ') + p1.substr(0, p2);

}

static int32_t p_screenoutput() {
return 1;  /* cheat -- all output to main screen */

}

static void p_sdl_wm_setcaption_(std::string p1, std::string p2) {
SDL_WM_SetCaption(p1.c_str(), p2.c_str());

}

static void p_selectelement(LinkedList * p1, int32_t p2) {
int i;
struct ListElement *p = p1->root;
for (i = 0; p && i < p2; i++) {
    p = p->next;
}
if (p) {
    p1->current = p;
    p1->index = i;
}

}

static void p_sendnetworkstring(int32_t p1, std::string p2) {
size_t count = p2.length();
ssize_t r = 0;
size_t n = 0;
while (n < count) {
    r = write(p1 - 1, p2.data() + n, count - n);
    if (r < 0 && errno == EINTR)
        continue;
    if (r < 0)
        return;
    /* What should happen if write() returns 0 all the time?
     * I assume it can sometimes return 0 legitimately,
     * if it failed to write anything this time. */
    n += r;
 }

}

static void p_setframerate(int32_t p1) {
framerate = p1;

}

static float p_sin(float p1) {
return sin(p1);

}

static void p_startdrawing(int32_t p1) {
;  /* cheat -- all output to main screen */

}

static void p_stopdrawing() {
;  /* cheat -- all output to main screen */

}

static void p_stopmodule(int16_t p1) {
Mix_HaltMusic();

}

static std::string p_str(int32_t p1) {
char s[256];
sprintf(s, "%ld", (long) p1);
return s;

}

static int32_t p_textheight(std::string p1) {
int h = 0;
TTF_SizeText(font, p1.c_str(), 0, &h);
return h;

}

static int32_t p_textwidth(std::string p1) {
int w = 0;
TTF_SizeText(font, p1.c_str(), &w, 0);
return w;

}

static std::string p_ucase(std::string p1) {
std::string::iterator it;
for (it = p1.begin(); it < p1.end(); it++) {
  *it = toupper(*it);
}
return p1;

}

static int32_t p_usejpegimagedecoder() {
return 1;

}

static int32_t p_usepngimagedecoder() {
return 1;

}

static int32_t p_val(std::string p1) {
return strtol(p1.c_str(), 0, 10);

}

static void p_writestringn(int16_t p1, std::string p2) {
if (!fh[p1])
    return;
fputs(p2.c_str(), fh[p1]);
fputc('\n', fh[p1]);

}

static void p_writeword(int16_t p1, int16_t p2) {
if (!fh[p1])
    return;
fputc(p2, fh[p1]);
fputc((p2 >> 8), fh[p1]);

}

static int32_t p_ablegen();
static int32_t p_advancements();
static int32_t p_alchemie(int16_t);
static int32_t p_altar();
static int32_t p_angriff();
static int32_t p_attack_spell(int16_t);
static int32_t p_aufstehen(int16_t);
static int32_t p_aufstehen2(int16_t);
static int32_t p_aufstehen3(int16_t);
static int32_t p_aufsteigen(int8_t);
static int32_t p_aufsteigen2();
static int32_t p_aus_schule(int16_t);
static int32_t p_ausweichen();
static int32_t p_autodelay(int32_t, int8_t, int32_t);
static int32_t p_autopickup();
static int32_t p_belastung();
static int32_t p_beschreiben(int16_t, int16_t, int16_t);
static int32_t p_blockiert(int16_t, int16_t, int16_t);
static int32_t p_blockiert2(int16_t, int16_t, int16_t);
static int32_t p_bogen();
static int32_t p_bogenangriff(int16_t, int16_t, int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_bogenschuetze();
static int32_t p_bubblesort();
static int32_t p_cast_it();
static int32_t p_cast_it2();
static int32_t p_character_info();
static int32_t p_creature_attacke();
static int32_t p_creature_bewegen();
static int32_t p_creature_lebenspunkte();
static int32_t p_creature_schaden(int16_t);
static int32_t p_creature_speed();
static int32_t p_credit(int32_t, std::string, int32_t);
static int32_t p_details(int16_t);
static int32_t p_diagonal(int16_t);
static int32_t p_dieb();
static int32_t p_dispelled();
static int32_t p_display(std::string);
static int32_t p_doubleclick(int8_t);
static int32_t p_draw_advancements();
static int32_t p_draw_character(int8_t, int8_t, int16_t);
static int32_t p_draw_creature(int8_t, int16_t);
static int32_t p_draw_item(int16_t, int16_t, int16_t, int8_t, int8_t);
static int32_t p_draw_monster(int16_t, int16_t, int16_t, int16_t, int8_t, int8_t);
static int32_t p_draw_monster2(int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_draw_screen(int8_t, int8_t);
static int32_t p_draw_screen2(int8_t, int8_t);
static int32_t p_draw_screen3(int8_t, int8_t);
static int32_t p_draw_screen4(int8_t, int8_t);
static int32_t p_draw_screen5(int8_t, int8_t);
static int32_t p_draw_screen6(int8_t, int8_t);
static int32_t p_draw_screen7(int8_t, int8_t);
static int32_t p_draw_screen8(int8_t, int8_t);
static int32_t p_draw_screen_total();
static int32_t p_draw_skills(int32_t, int32_t, int32_t, int32_t, int32_t);
static int32_t p_draw_small_monster(int16_t, int16_t, int16_t, int8_t, int8_t);
static int32_t p_draw_small_tile(int16_t, int16_t, int16_t, int8_t, int8_t);
static int32_t p_draw_tile(int16_t, int16_t, int16_t, int8_t, int8_t);
static int32_t p_drawbitmapfont(int32_t, int32_t, int32_t, int32_t, int32_t, std::string);
static int32_t p_drawbuttonnotpressed(int32_t, int32_t, int32_t, int32_t, int32_t, std::string);
static int32_t p_drawbuttonpressed(int32_t, int32_t, int32_t, int32_t, int32_t, std::string);
static int32_t p_drawcentered(int32_t, int32_t, int32_t, std::string, int32_t);
static int32_t p_drawtooltip(int32_t, int32_t, int32_t, int32_t, int32_t, std::string);
static int32_t p_duplizieren();
static int32_t p_eintragen(int16_t, int16_t, int16_t, int16_t);
static int32_t p_eisschaden(int16_t);
static int32_t p_ende();
static int32_t p_entdecken();
static int32_t p_erfolgreich(int16_t);
static int32_t p_erstelle_liste();
static int32_t p_erstelle_matrix(int16_t);
static int32_t p_explain(int16_t, int16_t);
static int32_t p_explodiert();
static int32_t p_faechergrafik();
static int32_t p_falle();
static int32_t p_feld_waehlen();
static int32_t p_fenster(int32_t);
static int32_t p_fernangriff_monster(int16_t);
static int32_t p_fernattack(int16_t, int16_t, int16_t);
static int32_t p_fernkampf();
static int32_t p_feuerschaden(int16_t);
static int32_t p_finden1();
static int32_t p_finden2();
static int32_t p_freie_magie();
static int32_t p_ftasten();
static int32_t p_fullscreen();
static int32_t p_gamespeed();
static int32_t p_gang_graben(int16_t, int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_gefaehrte(int32_t);
static int32_t p_gen_laby(int16_t);
static int32_t p_get_creature(int16_t);
static int32_t p_gewicht();
static int32_t p_gold(int16_t, int16_t);
static int32_t p_gold_anzahl();
static int32_t p_gold_finden(int16_t);
static int32_t p_gold_finden2(int16_t);
static int32_t p_gold_verlieren(int16_t);
static int32_t p_gott_check();
static int32_t p_habich(int16_t);
static int32_t p_haendler();
static int32_t p_haendler_init1(int16_t);
static int32_t p_haendler_init2(int16_t);
static int32_t p_haendler_init3(int16_t);
static int32_t p_haendler_init4(int16_t);
static int32_t p_haendler_init5(int16_t);
static int32_t p_hat_eigenschaft(int16_t, int16_t, int16_t);
static int32_t p_hat_eigenschaft2(int16_t, int16_t);
static int32_t p_hat_fernkampf(int16_t, int16_t);
static int32_t p_hater(int16_t, int32_t);
static int32_t p_helpful_wizard();
static int32_t p_highscore_upload();
static int32_t p_hilfe();
static int32_t p_hinterhalt(int16_t);
static int32_t p_hinterlassen(int16_t, int16_t);
static int32_t p_horizontal(int16_t);
static int32_t p_hydra_zauber(int16_t);
static int32_t p_ich_trage(int16_t);
static int32_t p_ich_trage2(int16_t);
static int32_t p_ich_trage3(int16_t);
static int32_t p_ich_trage4();
static int32_t p_immune(int16_t);
static int32_t p_in_rucksack(int16_t, int16_t);
static int32_t p_init_creatures();
static int32_t p_init_highscores();
static int32_t p_init_pilze();
static int32_t p_init_skills();
static int32_t p_init_spells();
static int32_t p_init_traenke();
static int32_t p_inv();
static int32_t p_isthydra(int16_t, int16_t);
static int32_t p_istmonster(int16_t, int16_t);
static int32_t p_itemmenue(std::string, std::string, std::string, std::string);
static int32_t p_itemtest();
static int32_t p_kaempfer();
static int32_t p_kampf();
static int32_t p_karte(int8_t, int8_t);
static std::string p_keyboard_string(std::string, int8_t);
static int32_t p_kleinhaendler_init(int16_t);
static int32_t p_kopiere_matrix();
static int32_t p_kopiere_matrix2();
static int32_t p_laby_rahmen();
static int32_t p_laby_screen();
static int32_t p_laby_screen2();
static int32_t p_laby_screen3();
static int32_t p_laby_screen4();
static int32_t p_leeren(int32_t);
static int32_t p_lehrer(int32_t);
static int32_t p_lernen(int16_t, int16_t);
static int32_t p_levelmodtext(int16_t);
static int32_t p_liste_leeren();
static int32_t p_load(std::string);
static int32_t p_load_graphics();
static int32_t p_load_settings();
static int32_t p_load_sounds();
static int32_t p_loading_screen();
static int32_t p_locken(int16_t);
static int32_t p_los();
static int32_t p_luck();
static int32_t p_maennchen_auswaehlen();
static int32_t p_mana_verlieren(int16_t);
static int32_t p_max(int16_t, int16_t);
static int32_t p_maxlife();
static int32_t p_maxmana();
static int32_t p_maxspeed();
static int32_t p_min(int16_t, int16_t);
static int32_t p_mischung(int16_t);
static int32_t p_misslungen();
static int32_t p_monster_angriff(int16_t, int16_t);
static int32_t p_monster_angriff2(int16_t, int16_t);
static int32_t p_monster_random(int16_t, int16_t);
static int32_t p_monster_setzen(int32_t, int32_t);
static int32_t p_monsterkunde();
static int32_t p_monsterschaden(int16_t);
static int32_t p_mystisch();
static int32_t p_nach_zug();
static int32_t p_nachricht(int16_t, int16_t);
static int32_t p_nachricht2(int16_t, int16_t);
static int32_t p_nachricht3(int16_t, int16_t, int16_t);
static std::string p_nachricht4(int16_t);
static std::string p_nachricht5(int16_t, int16_t);
static std::string p_nachricht6(int16_t, std::string);
static int32_t p_nachricht7(std::string, int16_t);
static int32_t p_naechster();
static int32_t p_namenlos();
static int32_t p_nekro();
static int32_t p_neuer_level();
static int32_t p_new_highscore();
static int32_t p_objekt(int16_t, int16_t);
static int32_t p_okaybox(int32_t);
static int32_t p_old_message(std::string, int16_t);
static int32_t p_opfern();
static int32_t p_opfern2();
static int32_t p_opfern3();
static int32_t p_optionen();
static int32_t p_optionen2();
static int32_t p_optionen_rahmen();
static int32_t p_ork();
static int32_t p_pilz_essen(std::string);
static int32_t p_power(int16_t);
static int32_t p_punkte();
static int32_t p_radius();
static int32_t p_radius2();
static int32_t p_raum();
static int32_t p_read_highscores();
static int32_t p_reflexe();
static int32_t p_reparieren(int16_t);
static int32_t p_restaurieren();
static int32_t p_restaurieren2();
static int32_t p_save(std::string);
static int32_t p_save_settings();
static int32_t p_saving_screen();
static int32_t p_schaden_critical();
static int32_t p_schaden_max();
static int32_t p_schaden_min();
static int32_t p_schleichen();
static int32_t p_schnelltasten();
static int32_t p_schulenicons();
static int32_t p_schutz();
static int32_t p_schutz_behinderung(int32_t);
static int32_t p_schutz_max(int32_t);
static int32_t p_schutz_min(int32_t);
static int32_t p_screen1(int16_t);
static int32_t p_screen2();
static int32_t p_select_inventory(int16_t);
static int32_t p_select_skills();
static int32_t p_select_spieler();
static int32_t p_setitem(int16_t, int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_setlaby(int16_t, int16_t, int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_setmonster(int16_t, int16_t, int16_t, int16_t, int16_t, int16_t, int16_t, int16_t);
static int32_t p_setzen(int16_t, int16_t, int16_t);
static int32_t p_show_automap();
static int32_t p_show_buttons();
static int32_t p_show_buttons2();
static int32_t p_show_credits();
static int32_t p_show_detail(int32_t);
static int32_t p_show_highscore();
static int32_t p_show_logo();
static int32_t p_show_old_messages();
static int32_t p_show_schnellinventory();
static int32_t p_show_sight();
static int32_t p_show_sight2();
static int32_t p_show_varys();
static int32_t p_show_varys2();
static int32_t p_sog();
static int32_t p_sonderfeld();
static int32_t p_sonderlevel_text(int16_t);
static int32_t p_sound(int16_t);
static int32_t p_special_success(int16_t);
static int32_t p_spellweaving();
static int32_t p_spieler_angriffswert();
static int32_t p_spielerschaden(int16_t, int16_t, int16_t);
static int32_t p_spraygrafik(int32_t, int32_t);
static int32_t p_staerke();
static int32_t p_stehlen();
static int32_t p_sternchen(int16_t, int16_t, int16_t);
static int32_t p_sternchen2(int16_t, int16_t, int16_t);
static int32_t p_teacher(int16_t);
static int32_t p_templates(int32_t, int32_t);
static int32_t p_terminate(int16_t, int16_t);
static int32_t p_title();
static int32_t p_todesblick();
static int32_t p_tot();
static int32_t p_trinken(std::string);
static int32_t p_truhe(int16_t, int16_t);
static int32_t p_umwandeln(int16_t);
static int32_t p_unlocken(int16_t);
static int32_t p_update_automap();
static int32_t p_update_automap2();
static int32_t p_upload_box();
static int32_t p_vergiften();
static int32_t p_vergolden();
static int32_t p_versteinern();
static int32_t p_vertikal(int16_t);
static int32_t p_vor_bewegung();
static int32_t p_vorheriger_level();
static int32_t p_waehlen(int16_t);
static int32_t p_waffe_attack();
static int32_t p_wahrnehmung();
static int32_t p_wassermonster_setzen(int32_t, int32_t);
static int32_t p_weiss();
static int32_t p_werfen();
static int32_t p_wounded_hero();
static int32_t p_wr_txt(int32_t, int32_t, int32_t, int32_t, int32_t);
static int32_t p_zauber_nehmen(int16_t);
static int32_t p_zauber_rahmen();
static int32_t p_zauberchance(int16_t);
static int32_t p_zauberkosten(int16_t);
static int32_t p_zaubern();
static int32_t p_zeige_unsichtbare(int16_t, int16_t);
static int32_t p_zerstoeren(int32_t);
static int32_t p_zerstoert(int16_t, int16_t);
static int32_t p_zug_verlieren();
static int32_t p_zwischenbild();

static int32_t p_ablegen() {
	int16_t v_ablegen = 0;
	if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
		if ((((((((((a_inventory(g_feld, g_akt_spieler).f_name != 163) && (a_inventory(g_feld, g_akt_spieler).f_name != 156)) && (a_inventory(g_feld, g_akt_spieler).f_name != 254)) && (a_inventory(g_feld, g_akt_spieler).f_name != 240)) && (a_inventory(g_feld, g_akt_spieler).f_name != 169)) && (a_inventory(g_feld, g_akt_spieler).f_name != 248)) && (a_inventory(g_feld, g_akt_spieler).f_name != 186)) && (a_inventory(g_feld, g_akt_spieler).f_name != 242)) && (a_inventory(g_feld, g_akt_spieler).f_name != 157))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				if ((a_laby_item((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level] == 0)) {
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 150)) {
						v_ablegen = (a_inventory(g_feld, g_akt_spieler).f_attri1 / 4);
						p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 150, v_ablegen, 0);
						a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - v_ablegen);
					} else {
						p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
						p_leeren(g_feld);
					}
					p_laby_screen();
					p_delay(g_mydelay);
					g_aktion = 1;
				}
			} else {
				p_nachricht(233, 3);
			}
		} else {
			p_nachricht(281, 3);
		}
	}
}

static int32_t p_advancements() {
	int32_t v_akt_pilz = 0;
	int16_t v_gift = 0;
	int16_t v_heiltrank = 0;
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_nach = 0;
	int16_t v_obj = 0;
	int16_t v_pos = 0;
	int32_t v_welcher = 0;
	int32_t v_willi = 0;
	if ((a_skills(122, g_akt_spieler).f_gewaehlt == 0)) {
		p_in_rucksack(46, 1);
		p_in_rucksack(44, 1);
		p_in_rucksack(193, 1);
		p_in_rucksack(1, 1);
		v_heiltrank = 0;
		for (v_j = 0; v_j <= 37; v_j += 1) {
			if ((a_gegenstand((75 + v_j)).f_name[2] == "Starker Heiltrank")) {
				v_heiltrank = (75 + v_j);
			}
		}
		v_pos = p_in_rucksack(v_heiltrank, 1);
		a_inventory(v_pos, g_akt_spieler).f_status = 1;
		if ((g_test == 1)) {
			p_in_rucksack(229, 1);
			p_in_rucksack(230, 1);
			p_in_rucksack(257, 1);
			p_in_rucksack(193, 1);
			p_in_rucksack(383, 1);
			p_in_rucksack(170, 1);
			p_in_rucksack(401, 1);
			p_in_rucksack(219, 1);
			p_in_rucksack(142, 1);
			p_in_rucksack(140, 1);
			p_in_rucksack(289, 1);
			p_in_rucksack(233, 1);
			p_in_rucksack(234, 1);
			p_in_rucksack(235, 1);
			p_in_rucksack(238, 1);
			p_in_rucksack(236, 1);
			p_in_rucksack(49, 1);
		}
	}
	if ((a_skills(1, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_attack = 4;
	}
	if ((a_skills(2, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_lifepoints = 15;
		a_spieler(g_akt_spieler).f_maxlifepoints = 15;
		a_spieler(g_akt_spieler).f_lifegain = 4;
	}
	if ((a_skills(3, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_strength = 4;
	}
	if ((a_skills(5, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_dexterity = 4;
	}
	if ((a_skills(9, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(24, 1);
		p_in_rucksack(32, 1);
		p_in_rucksack(30, 1);
		p_in_rucksack(3, 1);
		p_in_rucksack(28, 1);
		p_in_rucksack(26, 1);
	}
	if ((a_skills(32, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(170, 1);
		p_in_rucksack(171, 1);
		p_in_rucksack(190, 1);
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(270, 2);
		p_in_rucksack(219, 1);
		p_in_rucksack(4, 1);
	}
	if ((a_skills(116, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_giftlehre = (a_spieler(g_akt_spieler).f_giftlehre + 2);
		v_nach = (75 + p_random(37));
		v_gift = 0;
		for (v_j = 0; v_j <= 37; v_j += 1) {
			if ((a_gegenstand((75 + v_j)).f_name[2] == "Starkes Gift")) {
				v_gift = (75 + v_j);
			}
		}
		p_in_rucksack(v_gift, 5);
	}
	if ((a_skills(30, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(21, 1);
		p_in_rucksack(20, 1);
	}
	if ((a_skills(37, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_circle = 3;
		if ((g_test == 1)) {
			a_spieler(g_akt_spieler).f_circle = 15;
		}
		if ((a_skills(65, g_akt_spieler).f_gewaehlt == 1)) {
			for (v_i = 1; v_i <= 3; v_i += 1) {
				p_freie_magie();
			}
		}
	}
	if ((a_skills(118, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_circle = 1;
		if ((a_skills(65, g_akt_spieler).f_gewaehlt == 1)) {
			p_freie_magie();
		}
	}
	if ((a_skills(38, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_power_score = 4;
	}
	if ((a_skills(42, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_magieresistenz = 70;
	}
	if ((a_skills(39, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_mana = 12;
		a_spieler(g_akt_spieler).f_maxmana = 12;
		a_spieler(g_akt_spieler).f_managain = 4;
		if ((g_test == 1)) {
			a_spieler(g_akt_spieler).f_mana = 120;
			a_spieler(g_akt_spieler).f_maxmana = 120;
			a_spieler(g_akt_spieler).f_managain = 40;
		}
	}
	if ((a_skills(43, g_akt_spieler).f_gewaehlt == 1)) {
		for (v_hugo = 1; v_hugo <= 5; v_hugo += 1) {
			v_akt_pilz = (p_random(9) + 65);
			p_in_rucksack(v_akt_pilz, 1);
		}
	}
	if ((a_skills(44, g_akt_spieler).f_gewaehlt == 1)) {
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!(a_inventory(v_i, g_akt_spieler).f_name == 0));
		for (v_hugo = 1; v_hugo <= 5; v_hugo += 1) {
			v_welcher = (p_random(28) + 1);
			v_obj = 0;
			switch (v_welcher) {
			case 1:
				v_obj = 197;
				break;
			case 2:
				v_obj = 198;
				break;
			case 3:
				v_obj = 199;
				break;
			case 4:
				v_obj = 209;
				break;
			case 5:
				v_obj = 210;
				break;
			case 6:
				v_obj = 152;
				break;
			case 7:
				v_obj = 295;
				break;
			case 8:
				v_obj = 296;
				break;
			case 9:
				v_obj = 297;
				break;
			case 10:
				v_obj = 298;
				break;
			case 11:
				v_obj = 299;
				break;
			case 12:
				v_obj = 300;
				break;
			case 13:
				v_obj = 301;
				break;
			case 14:
				v_obj = 211;
				break;
			case 15:
				v_obj = 213;
				break;
			case 16:
				v_obj = 214;
				break;
			case 17:
				v_obj = 215;
				break;
			case 18:
				v_obj = 216;
				break;
			case 19:
				v_obj = 217;
				break;
			case 20:
				v_obj = 218;
				break;
			case 21:
				v_obj = 387;
				break;
			case 22:
				v_obj = 388;
				break;
			case 23:
				v_obj = 389;
				break;
			case 24:
				v_obj = 390;
				break;
			case 25:
				v_obj = 391;
				break;
			case 26:
				v_obj = 392;
				break;
			case 27:
				v_obj = 393;
				break;
			case 28:
				v_obj = 394;
				break;
			case 29:
				v_obj = 395;
				break;
			}
			if ((v_welcher > 5)) {
				a_inventory(v_i, g_akt_spieler).f_name = v_obj;
				a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_obj).f_art;
				a_inventory(v_i, g_akt_spieler).f_status = p_random(2);
				a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(v_obj).f_attri1;
				a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_obj).f_attri2;
				a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_obj).f_attri3;
				a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_obj).f_attri4;
			} else {
				a_inventory(v_i, g_akt_spieler).f_name = v_obj;
				a_inventory(v_i, g_akt_spieler).f_art = 16;
			}
			a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
			v_i = (v_i + 1);
		}
	}
	if ((a_skills(47, g_akt_spieler).f_gewaehlt == 1)) {
		for (v_hugo = 1; v_hugo <= 5; v_hugo += 1) {
			p_in_rucksack(38, 1);
		}
		p_in_rucksack(186, 1);
	}
	if ((a_skills(70, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_perception = 4;
	}
	if ((a_skills(72, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_speed = 11;
		a_spieler(g_akt_spieler).f_maxspeed = 11;
	}
	if ((a_skills(83, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_luck_score = 4;
	}
	if ((a_skills(86, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(169, 1);
	}
	if ((a_skills(87, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(39, 1);
		p_in_rucksack(134, 2);
		p_in_rucksack(232, 1);
		p_in_rucksack(269, 1);
		p_in_rucksack(270, 1);
	}
	if ((a_skills(88, g_akt_spieler).f_gewaehlt == 1)) {
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
		a_inventory(v_i, g_akt_spieler).f_name = 150;
		a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(150).f_art;
		a_inventory(v_i, g_akt_spieler).f_attri1 = 1000;
		a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(150).f_attri2;
		a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(150).f_attri3;
		a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(150).f_attri4;
		if ((g_test == 1)) {
			a_inventory(v_i, g_akt_spieler).f_attri1 = 10000;
		}
	}
	if ((a_skills(113, g_akt_spieler).f_gewaehlt == 1)) {
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
		for (v_hugo = 1; v_hugo <= 5; v_hugo += 1) {
			v_akt_pilz = (p_random(9) + 65);
			p_in_rucksack(v_akt_pilz, 1);
		}
		p_in_rucksack(353, 5);
	}
	if ((a_skills(89, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(240, 1);
	}
	if ((a_skills(21, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(3, 1);
	}
	if ((a_skills(22, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(14, 1);
	}
	if ((a_skills(23, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(9, 1);
	}
	if ((a_skills(24, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(18, 1);
	}
	if ((a_skills(110, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(1, 5);
	}
	if ((a_skills(93, g_akt_spieler).f_gewaehlt == 1)) {
		p_in_rucksack(43, 1);
		p_in_rucksack(353, 5);
		p_in_rucksack(355, 1);
		p_in_rucksack(289, 1);
	}
	if ((a_skills(91, g_akt_spieler).f_gewaehlt == 1)) {
		v_willi = (p_random(11) + 1);
		switch (v_willi) {
		case 1:
			v_hugo = 220;
			break;
		case 2:
			v_hugo = 255;
			break;
		case 3:
			v_hugo = 256;
			break;
		case 4:
			v_hugo = 257;
			break;
		case 5:
			v_hugo = 149;
			break;
		case 6:
			v_hugo = 253;
			break;
		case 7:
			v_hugo = 302;
			break;
		case 8:
			v_hugo = 303;
			break;
		case 9:
			v_hugo = 304;
			break;
		case 10:
			v_hugo = 305;
			break;
		case 11:
			v_hugo = 306;
			break;
		case 12:
			v_hugo = 307;
			break;
		}
		p_in_rucksack(v_hugo, 1);
	}
	if ((a_skills(97, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_attack = (a_spieler(g_akt_spieler).f_attack + 1);
		a_spieler(g_akt_spieler).f_strength = (a_spieler(g_akt_spieler).f_strength + 1);
		a_spieler(g_akt_spieler).f_dexterity = (a_spieler(g_akt_spieler).f_dexterity + 1);
		a_spieler(g_akt_spieler).f_perception = (a_spieler(g_akt_spieler).f_perception + 1);
		a_spieler(g_akt_spieler).f_luck_score = (a_spieler(g_akt_spieler).f_luck_score + 1);
		a_spieler(g_akt_spieler).f_power_score = (a_spieler(g_akt_spieler).f_power_score + 1);
	}
	if ((a_skills(121, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_lifepoints = 10;
		a_spieler(g_akt_spieler).f_maxlifepoints = 10;
		a_spieler(g_akt_spieler).f_lifegain = 2;
	}
	if ((a_skills(41, g_akt_spieler).f_gewaehlt == 1)) {
		for (v_i = 1; v_i <= 177; v_i += 1) {
			if ((a_zauber(v_i, g_akt_spieler).f_kosten > 1)) {
				a_zauber(v_i, g_akt_spieler).f_kosten = (a_zauber(v_i, g_akt_spieler).f_kosten - 1);
			}
		}
	}
	if ((a_skills(124, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_mana = 1;
		a_spieler(g_akt_spieler).f_maxmana = 1;
		a_spieler(g_akt_spieler).f_managain = 2;
	}
	if ((a_skills(130, g_akt_spieler).f_gewaehlt == 1)) {
		a_spieler(g_akt_spieler).f_dumm = 3;
	}
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if ((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_qualitaet > 0)) {
			a_inventory(v_i, g_akt_spieler).f_status = (p_random(2) + 1);
		}
	}
}

static int32_t p_alchemie(int16_t v_feld) {
	int16_t v_mag_geg = 0;
	int32_t v_obje = 0;
	if ((a_skills(43, g_akt_spieler).f_gewaehlt == 1)) {
		do {
			v_obje = (p_random(37) + 75);
		} while (!(a_gegenstand(v_obje).f_name[2] != "Trank der G\357\277\275tter"));
		v_mag_geg = 0;
		p_in_rucksack(v_obje, 1);
		p_leeren(v_feld);
	}
}

static int32_t p_altar() {
	int16_t v_verkauf = 0;
	v_verkauf = p_select_inventory(523);
	if ((v_verkauf != 0)) {
		p_sound(11);
		if ((a_gegenstand(a_inventory(v_verkauf, g_akt_spieler).f_name).f_einkauf > 40)) {
			p_leeren(v_verkauf);
			p_nachricht(12, 5);
			p_aufsteigen(2);
		} else {
			p_nachricht(13, 5);
		}
	}
}

static int32_t p_angriff() {
	int16_t v_akt_angriff = 0;
	int16_t v_anfuehrer = 0;
	int32_t v_i = 0;
	int16_t v_zw = 0;
	v_akt_angriff = a_spieler(g_akt_spieler).f_attack;
	v_akt_angriff = (v_akt_angriff + a_spieler(g_akt_spieler).f_attackgegenstand);
	v_akt_angriff = (v_akt_angriff + p_habich(176));
	v_anfuehrer = 0;
	for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
		if ((a_skills(26, v_i).f_gewaehlt == 1)) {
			v_anfuehrer = 2;
		}
	}
	if ((a_skills(10, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_angriff = (v_akt_angriff + (p_reflexe() / 2));
	}
	if ((a_skills(11, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_angriff = (v_akt_angriff + (p_staerke() / 2));
	}
	v_akt_angriff = (v_akt_angriff + v_anfuehrer);
	v_akt_angriff = (v_akt_angriff - a_spieler(g_akt_spieler).f_krankheit);
	if ((a_spieler(g_akt_spieler).f_style == 1)) {
		v_akt_angriff = (v_akt_angriff + 2);
	}
	if (((((a_spieler(g_akt_spieler).f_style == 2) || (a_spieler(g_akt_spieler).f_style == 4)) || (a_spieler(g_akt_spieler).f_style == 7)) || (a_spieler(g_akt_spieler).f_style == 9))) {
		v_akt_angriff = (v_akt_angriff - 2);
	}
	if ((a_spieler(g_akt_spieler).f_style == 3)) {
		v_akt_angriff = (v_akt_angriff / 2);
	}
	if ((a_spieler(g_akt_spieler).f_style == 5)) {
		v_zw = ((90 - v_akt_angriff) / 2);
		v_akt_angriff = (v_akt_angriff + v_zw);
	}
	if ((v_akt_angriff < 1)) {
		v_akt_angriff = 1;
	}
	return v_akt_angriff;
}

static int32_t p_attack_spell(int16_t v_aussehen) {
	int16_t v_akt_frame = 0;
	int32_t v_i = 0;
	int32_t v_zielx = 0;
	int32_t v_ziely = 0;
	int16_t v_zw_frame = 0;
	v_akt_frame = 1;
	v_zw_frame = 1;
	if ((g_spell_x > 0)) {
		v_zielx = (32 * g_spell_x);
	}
	if ((g_spell_x < 0)) {
		v_zielx = (-32 * g_spell_x);
	}
	if ((g_spell_y > 0)) {
		v_ziely = (32 * g_spell_y);
	}
	if ((g_spell_y < 0)) {
		v_ziely = (-32 * g_spell_y);
	}
	if ((g_spell_x > 0)) {
		v_i = 1;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 96, 128, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 96, 192, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 5)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 96, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 96, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 6)) {
				p_clipsprite(8, 480, 384, 32, 32);
				p_displaytransparentsprite(8, (160 + v_i), 160);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 0, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 8)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 9)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 10)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
			}
			if ((v_aussehen == 11)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, (160 + v_i), 160);
			}
			v_i = (v_i + g_mydelay4);
			p_flipbuffers(1);
			v_i = (v_i + 2);
		} while (!(v_i >= v_zielx));
	}
	if ((g_spell_x < 0)) {
		v_i = 1;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 96, 128, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 96, 192, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 5)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 96, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 96, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 6)) {
				p_clipsprite(8, 480, 384, 32, 32);
				p_displaytransparentsprite(8, (160 - v_i), 160);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 0, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 8)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 9)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 10)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
			}
			if ((v_aussehen == 11)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, (160 - v_i), 160);
			}
			v_i = (v_i + g_mydelay4);
			p_flipbuffers(1);
			v_i = (v_i + 2);
		} while (!(v_i >= v_zielx));
	}
	if ((g_spell_y > 0)) {
		v_i = 1;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 96, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 96, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 5)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 96, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 96, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 6)) {
				p_clipsprite(8, 480, 384, 32, 32);
				p_displaytransparentsprite(8, 160, (160 + v_i));
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 0, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 8)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 + v_i));
			}
			if ((v_aussehen == 9)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 10)) {
				p_clipsprite(8, 64, 128, 32, 32);
				p_displaytransparentsprite(8, 160, (160 + v_i));
			}
			if ((v_aussehen == 11)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, 160, (160 + v_i));
			}
			v_i = (v_i + g_mydelay4);
			p_flipbuffers(1);
			v_i = (v_i + 2);
		} while (!(v_i >= v_ziely));
	}
	if ((g_spell_y < 0)) {
		v_i = 1;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 96, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 96, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 5)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 96, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 96, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 96, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 6)) {
				p_clipsprite(8, 480, 384, 32, 32);
				p_displaytransparentsprite(8, 160, (160 - v_i));
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 0, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 8)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 9)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
			}
			if ((v_aussehen == 10)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
			}
			if ((v_aussehen == 11)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, 160, (160 - v_i));
			}
			v_i = (v_i + g_mydelay4);
			p_flipbuffers(1);
			v_i = (v_i + 2);
		} while (!(v_i >= v_ziely));
	}
}

static int32_t p_aufstehen(int16_t v_nr) {
	int32_t v_a = 0;
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	v_inhalt_x = v_nr;
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	for (v_i = 1; v_i <= 32; v_i += 1) {
		p_laby_screen2();
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), (5 + g_ymod), 0, 0);
		p_clipsprite(9, ((v_inhalt_x * 32) - 32), (v_inhalt_y * 32), 32, 32);
		p_displaytransparentsprite(9, (160 + (g_xmod * 32)), ((160 + (g_ymod * 32)) + (32 - v_i)));
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		if (p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1))) {
			p_draw_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_graphic[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_character_x, ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + v_a)).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_tile(a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		if (p_istmonster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y)) {
			p_draw_monster(a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_graphic[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
		p_restaurieren();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(30);
	}
}

static int32_t p_aufstehen2(int16_t v_nr) {
	int32_t v_i = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	v_sprite_x = v_nr;
	v_sprite_y = 0;
	if ((v_sprite_x > 10)) {
		do {
			v_sprite_y = (v_sprite_y + 1);
			v_sprite_x = (v_sprite_x - 10);
		} while (!(v_sprite_x < 11));
	}
	for (v_i = 1; v_i <= 32; v_i += 1) {
		p_laby_screen2();
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), (5 + g_ymod), 0, 0);
		p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(9, (160 + (g_xmod * 32)), ((160 + (g_ymod * 32)) + (32 - v_i)));
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		if (p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1))) {
			p_draw_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_graphic[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_character_x, ((a_spieler(g_akt_spieler).f_character_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_tile(a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		if (p_istmonster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y)) {
			p_draw_monster(a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_graphic[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
		p_restaurieren();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(30);
	}
}

static int32_t p_aufstehen3(int16_t v_nr) {
	int32_t v_i = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	v_sprite_x = v_nr;
	v_sprite_y = 0;
	if ((v_sprite_x > 10)) {
		do {
			v_sprite_y = (v_sprite_y + 1);
			v_sprite_x = (v_sprite_x - 10);
		} while (!(v_sprite_x < 11));
	}
	for (v_i = 1; v_i <= 32; v_i += 1) {
		p_laby_screen4();
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), (5 + g_ymod), 0, 0);
		p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(9, (160 + (g_xmod * 32)), ((160 + (g_ymod * 32)) + (32 - v_i)));
		p_draw_tile(a_labyrinth((a_spieler(g_akt_spieler).f_creature_x + g_xmod), ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1)).f_feld[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		if (p_istmonster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1))) {
			p_draw_monster(a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1)).f_graphic[a_spieler(g_akt_spieler).f_level], (5 + g_xmod), ((5 + g_ymod) + 1), 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_creature_x, ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_creature_x, ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) + 1)).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_tile(a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		if (p_istmonster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y)) {
			p_draw_monster(a_laby_monster(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_character_y).f_graphic[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		if ((a_laby_item(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
			p_draw_item(a_laby_item(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_name[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
		}
		p_draw_creature(g_frame, 0);
		p_restaurieren2();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(30);
	}
}

static int32_t p_aufsteigen(int8_t v_neuer) {
	int32_t v_i = 0;
	int16_t v_udj_pos = 0;
	int8_t v_udjat = 0;
	if ((v_neuer == 1)) {
		if ((a_spieler(g_akt_spieler).f_status == 1)) {
			a_spieler(g_akt_spieler).f_speed = 0;
L_und_nochmal: ;
			p_aufsteigen2();
			v_udjat = 0;
			v_udj_pos = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 240)) {
					v_udjat = 1;
					v_udj_pos = v_i;
				}
			}
			if ((v_udjat == 1)) {
				if ((a_spieler(g_akt_spieler).f_udjat_ben == 1)) {
					a_spieler(g_akt_spieler).f_udjat_ben = 0;
					if ((a_inventory(v_udj_pos, g_akt_spieler).f_attri1 > 0)) {
						a_inventory(v_udj_pos, g_akt_spieler).f_attri1 = (a_inventory(v_udj_pos, g_akt_spieler).f_attri1 - 1);
						p_nachricht(62, 1);
						p_nachricht(63, 1);
						p_nachricht(64, 1);
						goto L_und_nochmal;
					}
				}
			}
			if ((a_skills(90, g_akt_spieler).f_gewaehlt == 1)) {
				a_spieler(g_akt_spieler).f_weisheit = (a_spieler(g_akt_spieler).f_weisheit + 1);
				if ((a_spieler(g_akt_spieler).f_weisheit > 3)) {
					a_spieler(g_akt_spieler).f_weisheit = 0;
					p_nachricht(65, 1);
					p_nachricht(63, 1);
					p_nachricht(64, 1);
					goto L_und_nochmal;
				}
			}
		}
	}
	if ((v_neuer == 2)) {
		p_aufsteigen2();
	}
	p_delay(g_mydelay);
}

static int32_t p_aufsteigen2() {
	int32_t v_actual = 0;
	int16_t v_freie = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_jb2 = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int16_t v_pos = 0;
	int32_t v_result = 0;
	int16_t v_wait = 0;
	int32_t v_wohin = 0;
	if (((a_spieler(g_akt_spieler).f_fluch != 1) && (a_spieler(g_akt_spieler).f_dumm < 1))) {
		v_pos = 1;
		v_wait = 0;
		v_freie = 0;
		do {
			p_fenster(0);
			v_actual = 0;
			v_jay = 0;
			v_jb1 = 0;
			if ((g_joystick_used == 1)) {
				p_examinejoystick();
				v_jay = p_joystickaxisy();
				v_jb2 = p_joystickbutton(2);
			}
			p_examinekeyboard();
			a_addelaymax(1) = g_selectdelay;
			if ((p_keyboardpushed(274) || (v_jay == 1))) {
				if (p_autodelay(1, 1, -2)) {
					p_autodelay(1, 2, -2);
					if (((v_pos < 10) && (v_actual == 0))) {
						v_pos = (v_pos + 1);
						v_actual = 1;
						v_wait = 50;
					}
				}
			} else {
				if ((p_keyboardpushed(273) || (v_jay == -1))) {
					if (p_autodelay(1, 1, -2)) {
						p_autodelay(1, 2, -2);
						if (((v_pos > 1) && (v_actual == 0))) {
							v_pos = (v_pos - 1);
							v_actual = 1;
							v_wait = 50;
						}
					}
				} else {
					p_autodelay(1, 3, -2);
				}
			}
			p_laby_screen2();
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(0, 0, 0));
			p_box(74, 93, 220, 190, -1);
			p_stopdrawing();
			p_clipsprite(15, 1, 1, 335, 335);
			p_displaytransparentsprite(15, 16, 16);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(89, ((129 + g_yplus2) + ((v_pos * g_yplus) - g_yplus)), 189, g_yplus, -1);
			p_stopdrawing();
			p_draw_advancements();
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mouse_links = p_mousebutton(1);
			v_mouse_rechts = p_mousebutton(2);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
			p_flipbuffers(1);
			p_delay(40);
			v_wait = (v_wait - 1);
			if ((v_wait == 0)) {
				v_actual = 0;
			}
		} while (!(((((v_mouse_rechts == 1) || p_keyboardpushed(13)) || p_keyboardpushed(32)) || (v_jb2 == 1)) || (g_mauszauber2 > 0)));
		p_autodelay(1, 5, -2);
		if ((g_mauszauber2 > 0)) {
			v_pos = g_mauszauber2;
		}
		switch (v_pos) {
		case 1:
			a_spieler(g_akt_spieler).f_attack = (a_spieler(g_akt_spieler).f_attack + 1);
			break;
		case 2:
			a_spieler(g_akt_spieler).f_dexterity = (a_spieler(g_akt_spieler).f_dexterity + 1);
			break;
		case 3:
			a_spieler(g_akt_spieler).f_strength = (a_spieler(g_akt_spieler).f_strength + 1);
			break;
		case 4:
			a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + a_spieler(g_akt_spieler).f_lifegain);
			a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + a_spieler(g_akt_spieler).f_lifegain);
			break;
		case 5:
			a_spieler(g_akt_spieler).f_maxspeed = (a_spieler(g_akt_spieler).f_maxspeed + 1);
			break;
		case 6:
			a_spieler(g_akt_spieler).f_perception = (a_spieler(g_akt_spieler).f_perception + 1);
			break;
		case 7:
			a_spieler(g_akt_spieler).f_luck_score = (a_spieler(g_akt_spieler).f_luck_score + 1);
			break;
		case 8:
			a_spieler(g_akt_spieler).f_maxmana = (a_spieler(g_akt_spieler).f_maxmana + a_spieler(g_akt_spieler).f_managain);
			a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + a_spieler(g_akt_spieler).f_managain);
			break;
		case 9:
			a_spieler(g_akt_spieler).f_power_score = (a_spieler(g_akt_spieler).f_power_score + 1);
			break;
		case 10:
			a_spieler(g_akt_spieler).f_circle = (a_spieler(g_akt_spieler).f_circle + 1);
			p_delay(g_mydelay);
			if ((a_skills(65, g_akt_spieler).f_gewaehlt == 1)) {
				p_freie_magie();
				v_freie = 1;
			}
			break;
		default:
			a_spieler(g_akt_spieler).f_attack = (a_spieler(g_akt_spieler).f_attack + 1);

			break;
		}
		if ((v_freie == 0)) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(0, 0, 0));
			p_box(88, 102, 191, 155, -1);
			p_stopdrawing();
			p_draw_advancements();
			p_flipbuffers(1);
			p_delay((g_mydelay * 2));
		}
	} else {
		if ((a_spieler(g_akt_spieler).f_fluch == 1)) {
			p_namenlos();
		}
		if ((a_spieler(g_akt_spieler).f_dumm > 0)) {
			a_spieler(g_akt_spieler).f_dumm = (a_spieler(g_akt_spieler).f_dumm - 1);
			p_sonderlevel_text(27);
		}
	}
}

static int32_t p_aus_schule(int16_t v_spell) {
	int16_t v_schule = 0;
	v_schule = 0;
	if ((a_zauber(v_spell, g_akt_spieler).f_art == "basis")) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "sterne") && (a_skills(48, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "illusion") && (a_skills(49, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "weiss") && (a_skills(51, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "schwarz") && (a_skills(52, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "feuer") && (a_skills(53, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "wasser") && (a_skills(54, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "erde") && (a_skills(55, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "luft") && (a_skills(56, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "druide") && (a_skills(57, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "hexerei") && (a_skills(58, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "hohe") && (a_skills(59, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if (((a_zauber(v_spell, g_akt_spieler).f_art == "barde") && (a_skills(60, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	if ((((((a_zauber(v_spell, g_akt_spieler).f_art == "erde") || (a_zauber(v_spell, g_akt_spieler).f_art == "feuer")) || (a_zauber(v_spell, g_akt_spieler).f_art == "luft")) || (a_zauber(v_spell, g_akt_spieler).f_art == "wasser")) && (a_skills(62, g_akt_spieler).f_gewaehlt == 1))) {
		v_schule = 1;
	}
	return v_schule;
}

static int32_t p_ausweichen() {
	int16_t v_akt_ausweichen = 0;
	v_akt_ausweichen = (p_reflexe() * 10);
	v_akt_ausweichen = (v_akt_ausweichen + (a_spieler(g_akt_spieler).f_fallenlehre * 2));
	return v_akt_ausweichen;
}

static int32_t p_autodelay(int32_t v_adinput, int8_t v_adwhat, int32_t v_addelaymaxinput) {
	int32_t v_delaynull = 0;
	int32_t v_iii = 0;
	static int32_t v_timeold;
	v_delaynull = 0;
	if ((v_addelaymaxinput != -2)) {
		if ((v_adwhat == -1)) {
			if ((a_addelaymax(v_adinput) == 0)) {
				a_addelaymax(v_adinput) = v_addelaymaxinput;
			}
		} else {
			a_addelaymax(v_adinput) = v_addelaymaxinput;
		}
	}
	if ((v_adwhat == 1)) {
		if ((v_timeold == 0)) {
			v_timeold = p_elapsedmilliseconds();
		}
		if ((a_addelay(v_adinput) > 0)) {
			a_addelay(v_adinput) -= (p_elapsedmilliseconds() - v_timeold);
			v_timeold = p_elapsedmilliseconds();
			if ((a_addelay(v_adinput) < 0)) {
				a_addelay(v_adinput) = 0;
			}
		}
	}
	if ((v_adwhat == 2)) {
		a_addelay(v_adinput) = a_addelaymax(v_adinput);
		v_timeold = 0;
	}
	if ((v_adwhat == 3)) {
		a_addelay(v_adinput) = 0;
	}
	if ((v_adwhat == 5)) {
		for (v_iii = 1; v_iii <= 10; v_iii += 1) {
			a_addelaymax(v_iii) = 0;
			a_addelay(v_iii) = 0;
		}
	}
	if (((a_addelay(v_adinput) <= 0) && (a_addelay(v_adinput) != -999))) {
		v_delaynull = 1;
	} else {
		v_delaynull = 0;
	}
	return v_delaynull;
}

static int32_t p_autopickup() {
	int16_t v_ausg_x = 0;
	int16_t v_ausg_y = 0;
	int32_t v_feld = 0;
	int32_t v_gef_apfel = 0;
	int32_t v_grafik = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_nach_kampf = 0;
	int32_t v_result = 0;
	int16_t v_testfeld = 0;
	v_testfeld = a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
	g_over_item = 0;
	if (((v_testfeld >= 58) && (v_testfeld <= 61))) {
		if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] != 1)) {
			a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 1;
			if (((p_luck() * 10) < p_random(100))) {
				p_sound(9);
				v_i = 0;
				do {
					v_i = (v_i + 1);
				} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
				if ((v_i <= 50)) {
					v_gef_apfel = (v_gef_apfel + 1);
					a_inventory(v_i, g_akt_spieler).f_name = 56;
					a_inventory(v_i, g_akt_spieler).f_art = 3;
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					a_inventory(v_i, g_akt_spieler).f_attri1 = 30;
				}
				p_nachricht(311, 5);
			}
			g_aktion = 1;
		}
	}
	if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
		p_objekt(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
	}
	if ((v_testfeld == 6)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 192)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 68)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 194)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 63)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		g_aktion = 1;
	}
	if ((v_testfeld == 161)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 162)) {
		p_truhe(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 9)) {
		p_gold(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 118)) {
		a_spieler(g_akt_spieler).f_stabteile = (a_spieler(g_akt_spieler).f_stabteile + 1);
		p_sound(9);
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_laby_screen();
		p_nachricht(238, 5);
		if ((a_spieler(g_akt_spieler).f_stabteile > 8)) {
			p_ende();
		}
		if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 7)) {
		if (((((a_spieler(g_akt_spieler).f_lifepoints < p_maxlife()) || (a_skills(102, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(106, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(105, g_akt_spieler).f_gewaehlt == 1))) {
			v_grafik = 0;
			if (((a_skills(128, g_akt_spieler).f_gewaehlt == 0) && (a_spieler(g_akt_spieler).f_fluch != 15))) {
				if ((((a_spieler(g_akt_spieler).f_lifepoints < p_maxlife()) || (a_skills(106, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(105, g_akt_spieler).f_gewaehlt == 1))) {
					v_nach_kampf = 1;
					v_grafik = 1;
					a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
				}
				if ((a_skills(102, g_akt_spieler).f_gewaehlt == 1)) {
					v_grafik = 1;
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if (((a_aktive(v_i, g_akt_spieler).f_dauer > 0) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							a_aktive(v_i, g_akt_spieler).f_dauer = 0;
						}
					}
					a_spieler(g_akt_spieler).f_gift = 0;
					a_spieler(g_akt_spieler).f_giftdauer = 0;
					a_spieler(g_akt_spieler).f_fluch = 0;
					a_spieler(g_akt_spieler).f_fluchdauer = 0;
					a_spieler(g_akt_spieler).f_krankheit = 0;
					a_spieler(g_akt_spieler).f_krankheitdauer = 0;
					a_spieler(g_akt_spieler).f_mana = p_maxmana();
				}
			}
			if ((v_grafik == 1)) {
				g_aktion = 1;
				p_sound(11);
				for (v_j = 1; v_j <= 5; v_j += 1) {
					for (v_i = 1; v_i <= 4; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
						p_displaytransparentsprite(17, 156, 156);
						v_result = p_examinemouse();
						v_mmouse_x = p_mousex();
						v_mmouse_y = p_mousey();
						p_clipsprite(8, 192, 288, 32, 32);
						p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
						p_flipbuffers(1);
						p_delay(70);
					}
				}
				if ((a_skills(106, g_akt_spieler).f_gewaehlt == 1)) {
					if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_objekt[a_spieler(g_akt_spieler).f_level] == 1)) {
						a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_objekt[a_spieler(g_akt_spieler).f_level] = 0;
						a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
						p_nachricht(323, 5);
					}
				}
				if ((a_skills(105, g_akt_spieler).f_gewaehlt == 1)) {
					if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_objekt[a_spieler(g_akt_spieler).f_level] == 1)) {
						a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_objekt[a_spieler(g_akt_spieler).f_level] = 0;
						a_spieler(g_akt_spieler).f_maxmana = (a_spieler(g_akt_spieler).f_maxmana + 1);
						p_nachricht(324, 5);
					}
				}
				a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
					p_sound(15);
					p_nachricht(259, 2);
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				}
			}
			p_laby_screen();
		}
	}
	if (((((((v_testfeld == 64) || (v_testfeld == 82)) || (v_testfeld == 84)) || (v_testfeld == 87)) || (v_testfeld == 120)) || (v_testfeld == 121))) {
		if (((a_skills(131, g_akt_spieler).f_gewaehlt == 1) || (a_spieler(g_akt_spieler).f_fluch == 26))) {
			p_nachricht(327, 6);
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		} else {
			g_warten = 0;
			p_haendler();
		}
		p_laby_screen();
		g_aktion = 1;
	}
	if ((v_testfeld == 122)) {
		p_teacher(1);
	}
	if ((v_testfeld == 123)) {
		p_teacher(2);
	}
	if ((v_testfeld == 124)) {
		p_teacher(3);
	}
	if ((v_testfeld == 125)) {
		p_teacher(4);
	}
	if ((v_testfeld == 126)) {
		p_teacher(5);
	}
	if ((v_testfeld == 127)) {
		p_teacher(6);
	}
	if ((v_testfeld == 128)) {
		p_teacher(7);
	}
	if ((v_testfeld == 129)) {
		p_teacher(8);
	}
	if ((v_testfeld == 130)) {
		p_teacher(9);
	}
	if ((v_testfeld == 131)) {
		p_teacher(10);
	}
	if ((v_testfeld == 202)) {
		p_wounded_hero();
		p_laby_screen();
		g_aktion = 1;
	}
	if ((v_testfeld == 203)) {
		p_nachricht(513, 5);
	}
	if ((v_testfeld == 8)) {
		if (((a_spieler(g_akt_spieler).f_mana < p_maxmana()) && (a_skills(132, g_akt_spieler).f_gewaehlt == 0))) {
			if ((a_spieler(g_akt_spieler).f_fluch != 11)) {
				a_spieler(g_akt_spieler).f_mana = p_maxmana();
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if (((a_aktive(v_i, g_akt_spieler).f_dauer > 0) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_sound(12);
				p_sternchen(160, 160, 3);
				p_laby_screen();
				a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
					p_sound(15);
					p_nachricht(258, 2);
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					p_laby_screen();
				}
			} else {
				p_nachricht(9, 6);
			}
			g_aktion = 1;
		}
	}
	if ((v_testfeld == 54)) {
		p_sound(27);
		p_nachricht(11, 2);
		a_spieler(g_akt_spieler).f_durst = 0;
		a_spieler(g_akt_spieler).f_verdursten = 0;
		g_aktion = 1;
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
				a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
			}
		}
	}
	if ((v_testfeld == 119)) {
		p_sound(38);
		p_nachricht(412, 6);
		for (v_feld = 1; v_feld <= 50; v_feld += 1) {
			if ((((a_inventory(v_feld, g_akt_spieler).f_status == 1) || (a_inventory(v_feld, g_akt_spieler).f_status == 2)) && ((((((a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 1) || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 6)) || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 7)) || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 8)) || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 9)) || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art == 11)))) {
				a_inventory(v_feld, g_akt_spieler).f_status = 0;
			}
		}
		if ((p_random(100) > 80)) {
			p_sound(31);
			p_nachricht(413, 6);
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		g_aktion = 1;
	}
	if ((v_testfeld == 19)) {
		p_sound(31);
		p_nachricht(389, 1);
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 48, 0, 0, 0);
		for (v_i = 1; v_i <= a_groesse(a_spieler(g_akt_spieler).f_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(a_spieler(g_akt_spieler).f_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 2)) {
					v_ausg_x = v_i;
					v_ausg_y = v_j;
				}
			}
		}
		if ((a_labyrinth((v_ausg_x - 1), v_ausg_y).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
			p_setlaby((v_ausg_x - 1), v_ausg_y, a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
		}
		if ((a_labyrinth((v_ausg_x + 1), v_ausg_y).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
			p_setlaby((v_ausg_x + 1), v_ausg_y, a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
		}
		if ((a_labyrinth(v_ausg_x, (v_ausg_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
			p_setlaby(v_ausg_x, (v_ausg_y - 1), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
		}
		if ((a_labyrinth(v_ausg_x, (v_ausg_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
			p_setlaby(v_ausg_x, (v_ausg_y + 1), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
		}
	}
	if ((v_testfeld == 3)) {
		if ((a_spieler(g_akt_spieler).f_level > 1)) {
			p_nachricht(439, 1);
			p_vorheriger_level();
			g_aktion = 1;
		} else {
			p_nachricht(440, 1);
		}
	}
	if ((v_testfeld == 2)) {
		p_nachricht(193, 1);
		if (((a_spieler(g_akt_spieler).f_level + 1) > a_spieler(g_akt_spieler).f_maxlevel)) {
			p_aufsteigen(1);
		}
		p_neuer_level();
		g_aktion = 1;
	}
	if ((v_testfeld == 206)) {
		p_sound(14);
		p_nachricht(700, 5);
		a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - 10);
		if ((a_spieler(g_akt_spieler).f_durst < 1)) {
			a_spieler(g_akt_spieler).f_durst = 0;
		}
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		g_aktion = 1;
	}
}

static int32_t p_belastung() {
	int16_t v_belastung = 0;
	int16_t v_gewicht = 0;
	int32_t v_i = 0;
	v_belastung = 0;
	if ((a_skills(117, g_akt_spieler).f_gewaehlt == 0)) {
		v_gewicht = (p_gewicht() / 10);
		if ((a_spieler(g_akt_spieler).f_fluch == 24)) {
			v_gewicht = (v_gewicht * 2);
		}
		for (v_i = 2; v_i <= 9; v_i += 1) {
			if ((v_gewicht > (v_i * 10))) {
				v_belastung = (v_belastung + 1);
			}
		}
		if ((v_belastung > 0)) {
			v_belastung = (v_belastung - (p_staerke() / 2));
			if ((v_belastung < 0)) {
				v_belastung = 0;
			}
		}
	}
	return v_belastung;
}

static int32_t p_beschreiben(int16_t v_feld, int16_t v_x, int16_t v_y) {
	int32_t v_anzeigen = 0;
	int32_t v_wohin = 0;
	v_anzeigen = 1;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 1));
	if (((a_inventory(v_feld, g_akt_spieler).f_name >= 75) && (a_inventory(v_feld, g_akt_spieler).f_name <= 112))) {
		if (((((a_skills(43, g_akt_spieler).f_gewaehlt == 1) || (a_skills(113, g_akt_spieler).f_gewaehlt == 1)) || ((a_skills(116, g_akt_spieler).f_gewaehlt == 1) && ((a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[2] == "Starkes Gift") || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[2] == "Schwaches Gift")))) || (a_inventory(v_feld, g_akt_spieler).f_status == 1))) {
			a_inventory(v_feld, g_akt_spieler).f_status = 1;
		} else {
			v_anzeigen = 0;
			p_drawtext((v_x - 20), v_y, a_nachricht_text(586, (1 + g_sprache)), -1, 0);
		}
	}
	if (((a_inventory(v_feld, g_akt_spieler).f_name >= 65) && (a_inventory(v_feld, g_akt_spieler).f_name <= 74))) {
		if ((((a_skills(113, g_akt_spieler).f_gewaehlt == 1) || ((a_skills(116, g_akt_spieler).f_gewaehlt == 1) && ((a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[2] == "Schwach Giftig") || (a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[2] == "Stark Giftig")))) || (a_inventory(v_feld, g_akt_spieler).f_status == 1))) {
			a_inventory(v_feld, g_akt_spieler).f_status = 1;
		} else {
			v_anzeigen = 0;
			p_drawtext((v_x - 20), v_y, a_nachricht_text(585, (1 + g_sprache)), -1, 0);
		}
	}
	if ((a_inventory(v_feld, g_akt_spieler).f_name == 38)) {
		if ((((a_skills(47, g_akt_spieler).f_gewaehlt == 1) || (a_skills(64, g_akt_spieler).f_gewaehlt == 1)) || (a_inventory(v_feld, g_akt_spieler).f_status == 1))) {
			a_inventory(v_feld, g_akt_spieler).f_status = 1;
			p_drawtext((v_x - 20), v_y, a_zauber(a_inventory(v_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
		} else {
			p_drawtext((v_x - 20), v_y, a_nachricht_text(584, (1 + g_sprache)), -1, 0);
		}
	}
	if ((v_anzeigen == 1)) {
		p_drawtext((v_x - 20), v_y, a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[(1 + g_sprache)], -1, 0);
	}
	p_stopdrawing();
}

static int32_t p_blockiert(int16_t v_x, int16_t v_y, int16_t v_level) {
	int16_t v_blocked = 0;
	int16_t v_testfeld = 0;
	v_blocked = 0;
	v_testfeld = a_labyrinth(v_x, v_y).f_feld[v_level];
	if (((((((((((((((((((v_testfeld == 1) || (v_testfeld == 101)) || (v_testfeld == 102)) || (v_testfeld == 103)) || (v_testfeld == 104)) || (v_testfeld == 20)) || (v_testfeld == 70)) || (v_testfeld == 80)) || (v_testfeld == 199)) || (v_testfeld == 55)) || (v_testfeld == 136)) || (v_testfeld == 112)) || (v_testfeld == 45)) || (v_testfeld == 88)) || (v_testfeld == 164)) || (v_testfeld == 165)) || (v_testfeld == 41)) || (v_testfeld == 207))) {
		v_blocked = 1;
	}
	return v_blocked;
}

static int32_t p_blockiert2(int16_t v_x, int16_t v_y, int16_t v_level) {
	int16_t v_blocked = 0;
	int16_t v_testfeld = 0;
	v_blocked = 0;
	v_testfeld = a_labyrinth(v_x, v_y).f_feld[v_level];
	if ((((((((((((((((((((((v_testfeld == 1) || (v_testfeld == 101)) || (v_testfeld == 102)) || (v_testfeld == 103)) || (v_testfeld == 104)) || (v_testfeld == 20)) || (v_testfeld == 70)) || (v_testfeld == 80)) || (v_testfeld == 199)) || (v_testfeld == 55)) || (v_testfeld == 136)) || (v_testfeld == 112)) || (v_testfeld == 45)) || (v_testfeld == 88)) || (v_testfeld == 164)) || (v_testfeld == 165)) || (v_testfeld == 41)) || (v_testfeld == 207)) || (v_testfeld == 47)) || (v_testfeld == 53)) || (v_testfeld == 72))) {
		v_blocked = 1;
	}
	return v_blocked;
}

static int32_t p_bogen() {
	int16_t v_akt_munition = 0;
	int16_t v_angriff = 0;
	int16_t v_art = 0;
	int8_t v_bogen = 0;
	int32_t v_i = 0;
	int16_t v_kritisch = 0;
	int16_t v_magisch = 0;
	int8_t v_pfeile = 0;
	int16_t v_schaden = 0;
	int8_t v_schleuder = 0;
	int8_t v_steine = 0;
	v_akt_munition = 0;
	v_bogen = 0;
	v_schleuder = 0;
	v_pfeile = 0;
	v_steine = 0;
	v_angriff = 0;
	v_schaden = 0;
	v_kritisch = 0;
	g_spell_x = 0;
	g_spell_y = 0;
	p_feld_waehlen();
	g_blocked = 0;
	p_los();
	if ((g_blocked == 0)) {
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 10) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 19)) {
					v_schleuder = 1;
				} else {
					v_bogen = 1;
				}
				v_angriff = a_inventory(v_i, g_akt_spieler).f_attri2;
				v_angriff = (v_angriff + a_spieler(g_akt_spieler).f_bogentreffergegenstand);
				v_schaden = a_inventory(v_i, g_akt_spieler).f_attri3;
				v_schaden = (v_schaden + a_spieler(g_akt_spieler).f_bogenschadengegenstand);
				v_kritisch = a_inventory(v_i, g_akt_spieler).f_attri4;
			}
		}
		v_art = 0;
		v_magisch = 0;
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 13) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				if (((a_inventory(v_i, g_akt_spieler).f_name == 291) || (a_inventory(v_i, g_akt_spieler).f_name == 292))) {
					v_steine = 1;
				} else {
					if ((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_magisch == 1)) {
						v_magisch = 1;
					}
					v_pfeile = 1;
					if ((a_inventory(v_i, g_akt_spieler).f_name == 170)) {
						v_art = 1;
					}
					if ((a_inventory(v_i, g_akt_spieler).f_name == 173)) {
						v_art = 2;
					}
					if ((a_inventory(v_i, g_akt_spieler).f_name == 172)) {
						v_art = 3;
					}
				}
				v_akt_munition = v_i;
				a_inventory(v_akt_munition, g_akt_spieler).f_attri1 = (a_inventory(v_akt_munition, g_akt_spieler).f_attri1 - 1);
				if ((a_inventory(v_akt_munition, g_akt_spieler).f_attri1 < 1)) {
					p_leeren(v_akt_munition);
					if ((a_inventory(v_akt_munition, g_akt_spieler).f_attri1 < 1)) {
						p_nachricht(263, 1);
					}
				}
				v_angriff = (v_angriff + a_inventory(v_i, g_akt_spieler).f_attri2);
				v_schaden = (v_schaden + a_inventory(v_i, g_akt_spieler).f_attri3);
				v_kritisch = (v_kritisch + a_inventory(v_i, g_akt_spieler).f_attri4);
			}
		}
		if ((((v_bogen == 1) && (v_pfeile == 1)) || ((v_schleuder == 1) && (v_steine == 1)))) {
			if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 17) > 0) && ((v_magisch == 0) || (a_skills(16, g_akt_spieler).f_gewaehlt == 1)))) {
				g_aktion = 1;
				p_attack_spell(5);
				p_nachricht(736, 3);
			} else {
				g_aktion = 1;
				p_bogenangriff(v_bogen, v_schleuder, v_angriff, v_schaden, v_kritisch, v_art, v_akt_munition);
				if (((((v_bogen == 1) && (a_skills(31, g_akt_spieler).f_gewaehlt == 1)) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] > 0)) && (p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1))) {
					p_bogenangriff(v_bogen, v_schleuder, v_angriff, v_schaden, v_kritisch, v_art, v_akt_munition);
				}
			}
		} else {
			p_nachricht(14, 3);
		}
	}
}

static int32_t p_bogenangriff(int16_t v_bogen, int16_t v_schleuder, int16_t v_angriff, int16_t v_schaden, int16_t v_kritisch, int16_t v_art, int16_t v_akt_munition) {
	int16_t v_okay = 0;
	int16_t v_save_akt_spieler = 0;
	int16_t v_save_spell_x = 0;
	int16_t v_save_spell_y = 0;
	int16_t v_save_x = 0;
	int16_t v_save_y = 0;
	int16_t v_treffer = 0;
	int32_t v_unsichtbar = 0;
	int16_t v_vergl_x = 0;
	int16_t v_vergl_y = 0;
	int16_t v_weg = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_zaehl = 0;
	p_sound(26);
	if ((v_bogen == 1)) {
		v_schaden = (p_random(v_schaden) + 4);
		p_attack_spell(5);
		v_okay = 0;
		if ((v_art == 1)) {
			v_okay = 1;
			p_sound(34);
			for (v_y = ((g_spell_y - 1) + 5); v_y <= ((g_spell_y + 1) + 5); v_y += 1) {
				for (v_x = ((g_spell_x - 1) + 5); v_x <= ((g_spell_x + 1) + 5); v_x += 1) {
					p_draw_tile(42, v_x, v_y, 1, 1);
				}
			}
			p_flipbuffers(1);
			p_delay(g_mydelay);
		}
		if ((v_art == 3)) {
			v_okay = 1;
			p_sound(15);
			if ((g_spell_x < 0)) {
				v_y = 5;
				for (v_x = (g_spell_x + 5); v_x <= 4; v_x += 1) {
					p_draw_tile(204, v_x, v_y, 1, 1);
				}
			}
			if ((g_spell_x > 0)) {
				v_y = 5;
				for (v_x = 6; v_x <= (g_spell_x + 5); v_x += 1) {
					p_draw_tile(204, v_x, v_y, 1, 1);
				}
			}
			if ((g_spell_y < 0)) {
				v_x = 5;
				for (v_y = (g_spell_y + 5); v_y <= 4; v_y += 1) {
					p_draw_tile(204, v_x, v_y, 1, 1);
				}
			}
			if ((g_spell_y > 0)) {
				v_x = 5;
				for (v_y = 6; v_y <= (g_spell_y + 5); v_y += 1) {
					p_draw_tile(204, v_x, v_y, 1, 1);
				}
			}
			p_flipbuffers(1);
			p_delay(g_mydelay);
		}
	}
	if ((v_schleuder == 1)) {
		v_schaden = (p_random(v_schaden) + 1);
		p_attack_spell(11);
	}
	v_okay = 0;
	if ((v_art == 1)) {
		v_okay = 1;
		p_hydra_zauber(v_schaden);
		v_save_akt_spieler = g_akt_spieler;
		v_vergl_x = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
		v_vergl_y = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
		for (g_akt_spieler = 1; g_akt_spieler <= g_anz_spieler; g_akt_spieler += 1) {
			if (((((a_spieler(g_akt_spieler).f_character_x >= (v_vergl_x - 1)) && (a_spieler(g_akt_spieler).f_character_x <= (v_vergl_x + 1))) && (a_spieler(g_akt_spieler).f_character_y >= (v_vergl_y - 1))) && (a_spieler(g_akt_spieler).f_character_y <= (v_vergl_y + 1)))) {
				p_spielerschaden(2, 1, 14);
			}
		}
		g_akt_spieler = v_save_akt_spieler;
		v_save_spell_x = g_spell_x;
		v_save_spell_y = g_spell_y;
		for (v_zaehl = 1; v_zaehl <= 9; v_zaehl += 1) {
			v_schaden = (p_random(v_schaden) + 4);
			switch (v_zaehl) {
			case 1:
				g_spell_x = (g_spell_x - 1);
				g_spell_y = (g_spell_y - 1);
				break;
			case 2:
				g_spell_x = (g_spell_x + 1);
				break;
			case 3:
				g_spell_x = (g_spell_x + 1);
				break;
			case 4:
				g_spell_y = (g_spell_y + 1);
				g_spell_x = (g_spell_x - 2);
				break;
			case 5:
				g_spell_x = (g_spell_x + 1);
				break;
			case 6:
				g_spell_x = (g_spell_x + 1);
				break;
			case 7:
				g_spell_y = (g_spell_y + 1);
				g_spell_x = (g_spell_x - 2);
				break;
			case 8:
				g_spell_x = (g_spell_x + 1);
				break;
			case 9:
				g_spell_x = (g_spell_x + 1);
				break;
			}
			p_feuerschaden(v_schaden);
		}
		g_spell_x = v_save_spell_x;
		g_spell_y = v_save_spell_y;
	}
	if ((v_art == 3)) {
		v_okay = 1;
		v_weg = 0;
		v_save_x = g_spell_x;
		v_save_y = g_spell_y;
		if (((g_spell_x < 0) && (v_weg == 0))) {
			v_weg = 1;
			for (g_spell_x = -1; g_spell_x >= v_save_x; g_spell_x -= 1) {
				v_schaden = (p_random(v_schaden) + 4);
				p_eisschaden(v_schaden);
			}
		}
		if (((g_spell_x > 0) && (v_weg == 0))) {
			v_weg = 1;
			for (g_spell_x = 1; g_spell_x <= v_save_x; g_spell_x += 1) {
				v_schaden = (p_random(v_schaden) + 4);
				p_eisschaden(v_schaden);
			}
		}
		if (((g_spell_y < 0) && (v_weg == 0))) {
			v_weg = 1;
			for (g_spell_y = -1; g_spell_y >= v_save_y; g_spell_y -= 1) {
				v_schaden = (p_random(v_schaden) + 4);
				p_eisschaden(v_schaden);
			}
		}
		if (((g_spell_y > 0) && (v_weg == 0))) {
			v_weg = 1;
			for (g_spell_y = 1; g_spell_y <= v_save_y; g_spell_y += 1) {
				v_schaden = (p_random(v_schaden) + 4);
				p_eisschaden(v_schaden);
			}
		}
	}
	if ((v_okay == 0)) {
		if (((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1) || (p_isthydra((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1))) {
			v_unsichtbar = 0;
			if ((p_hat_eigenschaft2(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level], 19) == 1)) {
				v_unsichtbar = 1;
			}
			if ((((((v_unsichtbar == 1) && (p_random(100) > 80)) || (v_unsichtbar == 0)) || (p_habich(109) > 0)) || (v_art == 2))) {
				v_angriff = (v_angriff + p_angriff());
				v_angriff = (v_angriff * 10);
				if ((v_bogen == 1)) {
					v_angriff = (v_angriff + a_spieler(g_akt_spieler).f_bogentreffergegenstand);
					if ((a_skills(30, g_akt_spieler).f_gewaehlt == 1)) {
						v_angriff = (v_angriff + 50);
					}
				}
				if ((v_angriff > 90)) {
					v_angriff = 90;
				}
				if ((v_angriff < 10)) {
					v_angriff = 10;
				}
				if ((v_art == 2)) {
					v_angriff = 100;
				}
				v_treffer = p_random(100);
				if ((v_treffer < v_angriff)) {
					v_kritisch = ((v_kritisch + p_luck()) + p_reflexe());
					if ((a_skills(33, g_akt_spieler).f_gewaehlt == 1)) {
						v_kritisch = (v_kritisch * 2);
						if ((v_kritisch > 45)) {
							v_kritisch = 45;
						}
					} else {
						if ((v_kritisch > 35)) {
							v_kritisch = 35;
						}
					}
					if ((v_treffer < v_kritisch)) {
						p_hydra_zauber(v_schaden);
						p_clipsprite(38, 96, 224, 32, 32);
						p_displaytransparentsprite(38, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
						p_flipbuffers(1);
						p_delay(g_mydelay);
						p_zerstoert(g_spell_x, g_spell_y);
					} else {
						p_hydra_zauber(v_schaden);
						p_monsterschaden(v_schaden);
						if (((a_inventory(v_akt_munition, g_akt_spieler).f_status == 4) || (a_inventory(v_akt_munition, g_akt_spieler).f_name == 171))) {
							v_art = a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art;
							if (((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 3) == 0) && (v_art != 3)) && (v_art != 9)) && (v_art != 10))) {
								a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 4;
								a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_duration[a_spieler(g_akt_spieler).f_level] = (p_random(20) + 5);
							} else {
								p_nachricht(456, 4);
							}
						}
					}
				} else {
					p_nachricht(16, 3);
				}
			} else {
				p_nachricht(441, 3);
				a_spieler(g_akt_spieler).f_speed = 0;
				g_aktion = 1;
			}
		}
	}
}

static int32_t p_bogenschuetze() {
	p_waehlen(1);
	p_waehlen(2);
	p_waehlen(6);
	p_waehlen(30);
	p_waehlen(31);
	p_waehlen(32);
	p_waehlen(43);
	p_waehlen(69);
	p_waehlen(70);
	p_waehlen(85);
	p_waehlen(134);
	p_waehlen(124);
	p_waehlen(132);
}

static int32_t p_bubblesort() {
	int16_t v_i = 0;
	int16_t v_j = 0;
	int32_t v_k = 0;
	a_zwischen.dim(4);
	for (v_i = 1; v_i <= (g_anz_zauber - 2); v_i += 1) {
		for (v_j = 1; v_j <= (g_anz_zauber - 2); v_j += 1) {
			if ((a_zauberliste((v_j + g_akt_zauber_offset2)).f_name[(1 + g_sprache)] > a_zauberliste(((v_j + g_akt_zauber_offset2) + 1)).f_name[(1 + g_sprache)])) {
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_zwischen(v_k) = a_zauberliste((v_j + g_akt_zauber_offset2)).f_name[v_k];
					a_zauberliste((v_j + g_akt_zauber_offset2)).f_name[v_k] = a_zauberliste(((v_j + g_akt_zauber_offset2) + 1)).f_name[v_k];
					a_zauberliste(((v_j + g_akt_zauber_offset2) + 1)).f_name[v_k] = a_zwischen(v_k);
				}
			}
		}
	}
}

static int32_t p_cast_it() {
	p_cast_it2();
	if (((p_habich(161) > 0) && (a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] != "Verdoppeln"))) {
		p_cast_it2();
	}
}

static int32_t p_cast_it2() {
	int16_t v_akt_power = 0;
	int16_t v_art = 0;
	int16_t v_dauer = 0;
	int16_t v_gain = 0;
	int16_t v_gesetzt = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int8_t v_jemand = 0;
	int32_t v_jhemand = 0;
	int16_t v_monsterart = 0;
	int32_t v_neux = 0;
	int32_t v_neuy = 0;
	int32_t v_offset_x = 0;
	int32_t v_offset_y = 0;
	int32_t v_okay = 0;
	int16_t v_save1 = 0;
	int16_t v_save2 = 0;
	int16_t v_save3 = 0;
	int32_t v_save_player = 0;
	int16_t v_savex = 0;
	int16_t v_savey = 0;
	int16_t v_schaden = 0;
	int16_t v_spell = 0;
	int16_t v_testfeld = 0;
	int16_t v_testwert = 0;
	int16_t v_typtest = 0;
	int16_t v_welcher = 0;
	std::string v_willi;
	int16_t v_x = 0;
	int16_t v_x1 = 0;
	int16_t v_x2 = 0;
	int32_t v_x_offset = 0;
	int16_t v_xsave = 0;
	int16_t v_y = 0;
	int16_t v_y1 = 0;
	int16_t v_y2 = 0;
	int32_t v_y_offset = 0;
	int16_t v_ysave = 0;
	int32_t v_zaehl = 0;
	int16_t v_zaehler = 0;
	int32_t v_zittern = 0;
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Heilung")) {
		v_spell = 3;
		if ((a_spieler(g_akt_spieler).f_heal > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_heal = (a_spieler(g_akt_spieler).f_heal - 1);
					p_sound(11);
					v_gain = (p_random(3) + ((p_special_success(v_spell) * 2) * a_spieler(g_akt_spieler).f_spellweaving));
					a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + v_gain);
					if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
						a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
					}
					for (v_j = 1; v_j <= 5; v_j += 1) {
						for (v_i = 1; v_i <= 4; v_i += 1) {
							p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
							p_displaytransparentsprite(17, 156, 156);
							p_flipbuffers(1);
							p_delay(70);
						}
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(694, 2);
			p_zug_verlieren();
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Andere Heilen")) {
		v_spell = 100;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(11);
					v_jemand = 0;
					for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) == a_spieler(v_i).f_character_x) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) == a_spieler(v_i).f_character_y))) {
							v_jemand = v_i;
						}
					}
					if ((v_jemand > 0)) {
						v_gain = (p_random(3) + ((p_special_success(v_spell) * 2) * a_spieler(g_akt_spieler).f_spellweaving));
						a_spieler(v_jemand).f_lifepoints = (a_spieler(v_jemand).f_lifepoints + v_gain);
						v_save_player = g_akt_spieler;
						g_akt_spieler = v_jemand;
						if ((a_spieler(v_jemand).f_lifepoints > p_maxlife())) {
							a_spieler(v_jhemand).f_lifepoints = p_maxlife();
						}
						g_akt_spieler = v_save_player;
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 4; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(70);
							}
						}
					} else {
						p_nachricht(246, 2);
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Heile Kreatur")) {
		v_spell = 167;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(11);
					v_jemand = 0;
					for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
						if ((((a_spieler(g_akt_spieler).f_creature_typ > 0) && ((a_spieler(g_akt_spieler).f_character_x + g_spell_x) == a_spieler(v_i).f_creature_x)) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) == a_spieler(v_i).f_creature_y))) {
							v_jemand = v_i;
						}
					}
					if ((v_jemand > 0)) {
						v_gain = (p_random(3) + ((p_special_success(v_spell) * 2) * a_spieler(g_akt_spieler).f_spellweaving));
						a_spieler(v_jemand).f_creature_lifepoints = (a_spieler(v_jemand).f_creature_lifepoints + v_gain);
						if ((a_spieler(v_jemand).f_creature_lifepoints > p_creature_lebenspunkte())) {
							a_spieler(v_jemand).f_creature_lifepoints = p_creature_lebenspunkte();
						}
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 4; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(70);
							}
						}
					} else {
						p_nachricht(246, 2);
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Andere Entgiften")) {
		v_spell = 101;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(11);
					v_jemand = 0;
					for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) == a_spieler(v_i).f_character_x) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) == a_spieler(v_i).f_character_y))) {
							v_jemand = v_i;
						}
					}
					if ((v_jemand > 0)) {
						a_spieler(v_jemand).f_gift = 0;
						a_spieler(v_jemand).f_giftdauer = 0;
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 4; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(70);
							}
						}
					} else {
						p_nachricht(246, 2);
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Andere entfluchen")) {
		v_spell = 107;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(11);
					v_jemand = 0;
					for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) == a_spieler(v_i).f_character_x) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) == a_spieler(v_i).f_character_y))) {
							v_jemand = v_i;
						}
					}
					if ((v_jemand > 0)) {
						a_spieler(v_jemand).f_fluch = 0;
						a_spieler(v_jemand).f_fluchdauer = 0;
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 4; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(70);
							}
						}
					} else {
						p_nachricht(246, 2);
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Allheilung")) {
		v_spell = 78;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
				for (v_j = 1; v_j <= 5; v_j += 1) {
					for (v_i = 1; v_i <= 4; v_i += 1) {
						p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
						p_displaytransparentsprite(17, 156, 156);
						p_flipbuffers(1);
						p_delay(70);
					}
				}
				p_laby_screen();
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schmerzen lindern")) {
		v_spell = 13;
		if ((a_spieler(g_akt_spieler).f_heal > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_heal = (a_spieler(g_akt_spieler).f_heal - 1);
					p_sound(11);
					v_gain = (p_random(3) + ((p_special_success(v_spell) * 3) * a_spieler(g_akt_spieler).f_spellweaving));
					a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + v_gain);
					if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
						a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
					}
					for (v_j = 1; v_j <= 5; v_j += 1) {
						for (v_i = 1; v_i <= 4; v_i += 1) {
							p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
							p_displaytransparentsprite(17, 156, 156);
							p_flipbuffers(1);
							p_delay(70);
						}
					}
					p_laby_screen();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(694, 2);
			p_zug_verlieren();
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Chaos")) {
		v_spell = 173;
		if ((a_spieler(g_akt_spieler).f_heal > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sternchen(160, 160, 6);
					do {
						v_welcher = (p_random(176) + 1);
						a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(v_welcher, g_akt_spieler).f_name[2];
					} while (!((a_zauber(v_welcher, g_akt_spieler).f_level == 1) && (v_welcher != 173)));
					p_nachricht7(a_zauber(v_welcher, g_akt_spieler).f_name[(1 + g_sprache)], 2);
					p_cast_it();
					p_laby_screen();
					throw Lv_nach_zauber;
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(694, 2);
			p_zug_verlieren();
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Transmigration")) {
		v_spell = 174;
		if ((a_spieler(g_akt_spieler).f_heal > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > p_zauberkosten(v_spell)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sternchen(160, 160, 6);
					v_save1 = a_spieler(g_akt_spieler).f_lifepoints;
					v_save2 = a_spieler(g_akt_spieler).f_maxlifepoints;
					v_save3 = a_spieler(g_akt_spieler).f_lifegain;
					a_spieler(g_akt_spieler).f_lifepoints = a_spieler(g_akt_spieler).f_mana;
					a_spieler(g_akt_spieler).f_maxlifepoints = a_spieler(g_akt_spieler).f_maxmana;
					a_spieler(g_akt_spieler).f_lifegain = a_spieler(g_akt_spieler).f_managain;
					a_spieler(g_akt_spieler).f_mana = v_save1;
					a_spieler(g_akt_spieler).f_maxmana = v_save2;
					a_spieler(g_akt_spieler).f_managain = v_save3;
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(694, 2);
			p_zug_verlieren();
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wiederbelebung")) {
		v_spell = 126;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				for (v_j = 1; v_j <= 5; v_j += 1) {
					for (v_i = 1; v_i <= 4; v_i += 1) {
						p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
						p_displaytransparentsprite(17, 156, 156);
						p_flipbuffers(1);
						p_delay(70);
					}
				}
				for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
					if ((a_spieler(v_i).f_status == 3)) {
						a_spieler(v_i).f_status = 1;
						a_spieler(v_i).f_maxlifepoints = (a_spieler(v_i).f_maxlifepoints / 2);
						a_spieler(v_i).f_lifepoints = p_maxlife();
					}
				}
				p_laby_screen();
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Mondlicht")) {
		v_spell = 1;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(156, 156, 5);
				p_eintragen(200, 3, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Konzentration")) {
		v_spell = 175;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(156, 156, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(175, v_akt_power, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Pr\344zision")) {
		v_spell = 176;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(156, 156, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(176, v_akt_power, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Tunnel")) {
		v_spell = 156;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verl\344ngern2")) {
		v_spell = 157;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schnellzauber")) {
		v_spell = 158;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Penetration")) {
		v_spell = 160;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verdoppeln")) {
		v_spell = 161;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Brecher")) {
		v_spell = 159;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, 9998, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Regeneration")) {
		v_spell = 151;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				p_sternchen(156, 156, 3);
				p_eintragen(v_spell, 1, (a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Windmeister")) {
		v_spell = 141;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(156, 156, 4);
				p_eintragen(v_spell, 2, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Selbsthypnose")) {
		v_spell = 142;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(14);
				p_sternchen(156, 156, 3);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lebensbund")) {
		v_spell = 154;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(40);
				p_sternchen(156, 156, 3);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schock")) {
		v_spell = 145;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(46);
				p_sternchen(156, 156, 6);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Schutzes")) {
		v_spell = 143;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(156, 156, 5);
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Schlafes")) {
		v_spell = 165;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(156, 156, 5);
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Selbstmords")) {
		v_spell = 166;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(156, 156, 5);
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fledermausgestalt")) {
		v_spell = 86;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(86, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wolfsgestalt")) {
		v_spell = 87;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(87, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vogelgestalt")) {
		v_spell = 88;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(88, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Katzengestalt")) {
		v_spell = 89;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(89, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Drachengestalt")) {
		v_spell = 90;
		if ((a_spieler(g_akt_spieler).f_drachenform == 1)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_drachenform = 0;
					p_sound(21);
					p_sternchen(160, 160, 5);
					p_eintragen(90, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(35, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Syphon")) {
		v_spell = 82;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(25);
				p_sternchen(160, 160, 4);
				p_eintragen(82, 3, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fl\374che brechen")) {
		v_spell = 77;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				p_sternchen(160, 160, 5);
				a_spieler(g_akt_spieler).f_fluch = 0;
				a_spieler(g_akt_spieler).f_fluchdauer = 0;
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Winteratem")) {
		v_spell = 70;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(70, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Flammenaura")) {
		v_spell = 71;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 6);
				p_eintragen(71, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fallensinn")) {
		v_spell = 61;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(61, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuerschild")) {
		v_spell = 7;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Eisschild")) {
		v_spell = 68;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Unverwundbarkeit")) {
		v_spell = 124;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 5);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "T\344uschung")) {
		v_spell = 102;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 5);
				p_eintragen(v_spell, 1, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Macht")) {
		v_spell = 59;
		if ((a_spieler(g_akt_spieler).f_macht == 1)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_macht = 0;
					p_sound(13);
					p_sternchen(160, 160, 5);
					p_eintragen(v_spell, 0, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(35, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Gl\374ckszauber")) {
		v_spell = 75;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, v_akt_power, ((a_zauber(v_spell, g_akt_spieler).f_dauer * v_akt_power) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "St\344rkezauber")) {
		v_spell = 85;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, v_akt_power, ((a_zauber(v_spell, g_akt_spieler).f_dauer * v_akt_power) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Unsichtbares sehen")) {
		v_spell = 109;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Unsichtbarkeit")) {
		v_spell = 110;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verzaubere Kreatur 1")) {
		v_spell = 168;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verzaubere Kreatur 2")) {
		v_spell = 169;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verzaubere Kreatur 3")) {
		v_spell = 170;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verzaubere Kreatur 4")) {
		v_spell = 171;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Nordlicht")) {
		v_spell = 30;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 5, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sonnenlicht")) {
		v_spell = 31;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 6, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wahrlicht")) {
		v_spell = 74;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 9999, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Irrlicht")) {
		v_spell = 41;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 4, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vergolden")) {
		v_spell = 42;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_vergolden();
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fallen zeigen")) {
		v_spell = 20;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_faechergrafik();
				v_akt_power = p_special_success(v_spell);
				v_x1 = (a_spieler(g_akt_spieler).f_character_x - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y1 = (a_spieler(g_akt_spieler).f_character_y - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_x2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				if ((v_x1 < 1)) {
					v_x1 = 1;
				}
				if ((v_y1 < 1)) {
					v_y1 = 1;
				}
				if ((v_x2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_x2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				if ((v_y2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_y2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				for (v_i = v_x1; v_i <= v_x2; v_i += 1) {
					for (v_j = v_y1; v_j <= v_y2; v_j += 1) {
						if (((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] >= 22) && (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] <= 30))) {
							if ((p_random(100) > 80)) {
								p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] + 9), 0, 0, 0);
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Exorzismus")) {
		v_spell = 32;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_faechergrafik();
				v_akt_power = p_special_success(v_spell);
				v_x1 = (a_spieler(g_akt_spieler).f_character_x - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y1 = (a_spieler(g_akt_spieler).f_character_y - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_x2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y2 = (a_spieler(g_akt_spieler).f_character_y + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				if ((v_x1 < 1)) {
					v_x1 = 1;
				}
				if ((v_y1 < 1)) {
					v_y1 = 1;
				}
				if ((v_x2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_x2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				if ((v_y2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_y2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				for (v_i = v_x1; v_i <= v_x2; v_i += 1) {
					for (v_j = v_y1; v_j <= v_y2; v_j += 1) {
						if ((p_istmonster(v_i, v_j) == 1)) {
							if ((a_monster(a_laby_monster(v_i, v_j).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 3)) {
								p_setmonster(v_i, v_j, a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuer bannen")) {
		v_spell = 60;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_faechergrafik();
				v_akt_power = p_special_success(v_spell);
				v_x1 = (a_spieler(g_akt_spieler).f_character_x - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y1 = (a_spieler(g_akt_spieler).f_character_y - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_x2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				if ((v_x1 < 1)) {
					v_x1 = 1;
				}
				if ((v_y1 < 1)) {
					v_y1 = 1;
				}
				if ((v_x2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_x2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				if ((v_y2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_y2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				for (v_i = v_x1; v_i <= v_x2; v_i += 1) {
					for (v_j = v_y1; v_j <= v_y2; v_j += 1) {
						if (((((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 40) || (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 41)) || (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 42)) || (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 65))) {
							p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fallen entfernen")) {
		v_spell = 64;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(22);
				p_faechergrafik();
				v_akt_power = p_special_success(v_spell);
				v_x1 = (a_spieler(g_akt_spieler).f_character_x - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y1 = (a_spieler(g_akt_spieler).f_character_y - ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_x2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				v_y2 = (a_spieler(g_akt_spieler).f_character_x + ((v_akt_power * 2) * a_spieler(g_akt_spieler).f_spellweaving));
				if ((v_x1 < 1)) {
					v_x1 = 1;
				}
				if ((v_y1 < 1)) {
					v_y1 = 1;
				}
				if ((v_x2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_x2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				if ((v_y2 > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_y2 = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
				for (v_i = v_x1; v_i <= v_x2; v_i += 1) {
					for (v_j = v_y1; v_j <= v_y2; v_j += 1) {
						if (((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] >= 22) && (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] <= 39))) {
							p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						}
						if ((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 208)) {
							p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schutzschild")) {
		v_spell = 18;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Weisser Schutz")) {
		v_spell = 33;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schutz gegen Blitze")) {
		v_spell = 118;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schutz gegen Versteinern")) {
		v_spell = 119;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Giftschutz")) {
		v_spell = 130;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 7);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vergiftung heilen")) {
		v_spell = 34;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				for (v_j = 1; v_j <= 5; v_j += 1) {
					for (v_i = 1; v_i <= 4; v_i += 1) {
						p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
						p_displaytransparentsprite(17, 156, 156);
						p_flipbuffers(1);
						p_delay(70);
					}
				}
				a_spieler(g_akt_spieler).f_gift = 0;
				a_spieler(g_akt_spieler).f_giftdauer = 0;
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Heile Krankheit")) {
		v_spell = 172;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(11);
				for (v_j = 1; v_j <= 5; v_j += 1) {
					for (v_i = 1; v_i <= 4; v_i += 1) {
						p_clipsprite(17, ((v_i * 40) - 40), 1, 39, 39);
						p_displaytransparentsprite(17, 156, 156);
						p_flipbuffers(1);
						p_delay(70);
					}
				}
				a_spieler(g_akt_spieler).f_krankheit = 0;
				a_spieler(g_akt_spieler).f_krankheitdauer = 0;
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Erdst\344rke")) {
		v_spell = 6;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Terminus")) {
		v_spell = 44;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(21);
				p_sternchen(160, 160, 2);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if (((a_aktive(v_i, g_akt_spieler).f_dauer > 0) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
						a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + 1);
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
					a_spieler(g_akt_spieler).f_mana = p_maxmana();
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Magische Flamme")) {
		v_spell = 9;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 4, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sternenlicht")) {
		v_spell = 12;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_sternchen(160, 160, 5);
				p_eintragen(200, 4, ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Magieschutz")) {
		v_spell = 45;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 6);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schutz vor Geschossen")) {
		v_spell = 46;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 6);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Hexensicht")) {
		v_spell = 52;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 6);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verl\344ngern")) {
		v_spell = 47;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(9);
				p_sternchen(160, 160, 6);
				v_akt_power = p_special_success(v_spell);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if (((a_aktive(v_i, g_akt_spieler).f_dauer > 0) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
						a_aktive(v_i, g_akt_spieler).f_dauer = (a_aktive(v_i, g_akt_spieler).f_dauer + (v_akt_power * a_spieler(g_akt_spieler).f_spellweaving));
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verschwinden")) {
		v_spell = 43;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(160, 160, 4);
				do {
					v_neux = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
					v_neuy = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
				} while (!(a_labyrinth(v_neux, v_neuy).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level)));
				a_spieler(g_akt_spieler).f_character_x = v_neux;
				a_spieler(g_akt_spieler).f_character_y = v_neuy;
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fallen sp\374hren")) {
		v_spell = 26;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Erde sp\374hren")) {
		v_spell = 4;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				g_karten_typ = 1;
				p_karte(15, 15);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sternensicht")) {
		v_spell = 105;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				g_karten_typ = 2;
				p_karte(15, 15);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Nexus finden")) {
		v_spell = 122;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				g_karten_typ = 3;
				p_karte(15, 15);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sanktum finden")) {
		v_spell = 123;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				g_karten_typ = 4;
				p_karte(15, 15);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Magischer Apfel")) {
		v_spell = 10;
		if ((a_spieler(g_akt_spieler).f_magic_apple > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_magic_apple = (a_spieler(g_akt_spieler).f_magic_apple - 1);
					p_sound(20);
					p_sternchen(160, 160, 6);
					p_in_rucksack(242, 1);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(45, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Zauberschwert")) {
		v_spell = 53;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 6);
				p_in_rucksack(163, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Zauberschild")) {
		v_spell = 84;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				for (v_i = 1; v_i <= 8; v_i += 1) {
					p_clipsprite(37, ((v_i * 31) - 31), 62, 31, 31);
					p_displaytransparentsprite(37, 160, 160);
					p_flipbuffers(1);
					p_delay(90);
				}
				for (v_i = 1; v_i <= 8; v_i += 1) {
					p_clipsprite(37, ((v_i * 31) - 31), 93, 31, 31);
					p_displaytransparentsprite(37, 160, 160);
					p_flipbuffers(1);
					p_delay(90);
				}
				p_in_rucksack(254, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Zauberpfeile")) {
		v_spell = 54;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 6);
				p_in_rucksack(147, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Zauberr\374stung")) {
		v_spell = 104;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 6);
				p_in_rucksack(156, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Magischer Bogen")) {
		v_spell = 135;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 6);
				p_in_rucksack(157, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Erschaffe Besen")) {
		v_spell = 177;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(20);
				p_sternchen(160, 160, 6);
				p_in_rucksack(400, 1);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Erfrischung")) {
		v_spell = 11;
		if ((a_spieler(g_akt_spieler).f_refresh > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					a_spieler(g_akt_spieler).f_refresh = (a_spieler(g_akt_spieler).f_refresh - 1);
					p_sound(14);
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_clipsprite(37, ((v_i * 31) - 31), 319, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_clipsprite(37, ((v_i * 31) - 31), 350, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - 60);
					if ((a_spieler(g_akt_spieler).f_durst < 1)) {
						a_spieler(g_akt_spieler).f_durst = 0;
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(45, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied der Reise")) {
		v_spell = 14;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(160, 160, 5);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(40, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Kampfes")) {
		v_spell = 35;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied der Hoffnung")) {
		v_spell = 36;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied der Einsamkeit")) {
		v_spell = 37;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Todes")) {
		v_spell = 38;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied der Magie")) {
		v_spell = 79;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Lied des Lebens")) {
		v_spell = 80;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Geistertanz")) {
		v_spell = 121;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(12);
				p_sternchen(160, 160, 1);
				for (v_i = 1; v_i <= 15; v_i += 1) {
					if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9999)) {
						a_aktive(v_i, g_akt_spieler).f_nr = 0;
						a_aktive(v_i, g_akt_spieler).f_staerke = 0;
						a_aktive(v_i, g_akt_spieler).f_dauer = 0;
					}
				}
				p_eintragen(v_spell, 1, 9999, 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "R\374ckenwind")) {
		v_spell = 40;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(160, 160, 5);
				p_eintragen(v_spell, 3, ((p_special_success(v_spell) * a_zauber(v_spell, g_akt_spieler).f_dauer) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "1000 Klingen")) {
		v_spell = 120;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(42);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Fliegen")) {
		v_spell = 48;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "\334bers Wasser gehen")) {
		v_spell = 49;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				p_sternchen(160, 160, 5);
				v_akt_power = p_special_success(v_spell);
				p_eintragen(v_spell, p_special_success(v_spell), ((a_zauber(v_spell, g_akt_spieler).f_dauer * p_special_success(v_spell)) * a_spieler(g_akt_spieler).f_spellweaving), 0);
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Totengold")) {
		v_spell = 8;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					for (v_j = 1; v_j <= 2; v_j += 1) {
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 190, 31, 31);
							p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
							p_flipbuffers(1);
							p_delay(90);
						}
					}
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if ((((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157)) || (v_testfeld == 163)) || (v_testfeld == 191))) {
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Tiere bannen")) {
		v_spell = 16;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1)) {
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
							p_nachricht7(v_willi, 2);
							p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							p_gott_check();
						} else {
							p_nachricht(189, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Untote bannen")) {
		v_spell = 17;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 3)) {
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
							p_nachricht7(v_willi, 2);
							p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							p_gott_check();
						} else {
							p_nachricht(190, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Geister bannen")) {
		v_spell = 111;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 10)) {
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
							p_nachricht7(v_willi, 2);
							p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							p_gott_check();
						} else {
							p_nachricht(602, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Pflanze zerst\366ren")) {
		v_spell = 132;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 4)) {
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
							p_nachricht7(v_willi, 2);
							p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							p_gott_check();
						} else {
							p_nachricht(601, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verdorren")) {
		v_spell = 149;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						p_mana_verlieren(v_spell);
						p_sound(20);
						p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
						a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] / 2);
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Dimensionentausch")) {
		v_spell = 144;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						p_mana_verlieren(v_spell);
						p_sound(15);
						p_laby_screen();
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
							p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
							p_flipbuffers(1);
							p_delay(90);
						}
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
							p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
							p_flipbuffers(1);
							p_delay(90);
						}
						p_laby_screen();
						a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level];
						a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_graphic[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_graphic[a_spieler(g_akt_spieler).f_level];
						a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lifepoints[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level];
						a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level];
						a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_duration[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_duration[a_spieler(g_akt_spieler).f_level];
						p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
						a_spieler(g_akt_spieler).f_character_x = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
						a_spieler(g_akt_spieler).f_character_y = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wasser stehlen")) {
		v_spell = 140;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 4)) {
							p_mana_verlieren(v_spell);
							p_sound(27);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							v_schaden = (p_random((p_special_success(v_spell) + 1)) + 1);
							v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
							if ((p_dispelled() == 1)) {
								p_nachricht(312, 2);
							} else {
								p_monsterschaden(v_schaden);
								a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - (v_schaden * 2));
								if ((a_spieler(g_akt_spieler).f_durst < 1)) {
									a_spieler(g_akt_spieler).f_durst = 0;
								}
							}
						} else {
							p_nachricht(601, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wegblasen")) {
		v_spell = 136;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						v_monsterart = a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art;
						if ((((v_monsterart != 4) && (v_monsterart != 7)) && (v_monsterart != 10))) {
							if ((p_immune(45) == 0)) {
								p_mana_verlieren(v_spell);
								p_sound(15);
								p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
								v_zaehler = 1;
								do {
									v_x = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
									v_y = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
									v_zaehler = (v_zaehler + 1);
								} while (!((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level)) || (v_zaehler > 500)));
								if ((v_zaehler <= 500)) {
									a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level];
									a_laby_monster(v_x, v_y).f_graphic[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_graphic[a_spieler(g_akt_spieler).f_level];
									a_laby_monster(v_x, v_y).f_lifepoints[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level];
									a_laby_monster(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level];
									a_laby_monster(v_x, v_y).f_duration[a_spieler(g_akt_spieler).f_level] = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_duration[a_spieler(g_akt_spieler).f_level];
									p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
								}
							} else {
								p_nachricht(834, 2);
							}
						} else {
							p_nachricht(611, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Mit Tieren reden")) {
		v_spell = 133;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1)) {
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
								p_nachricht(599, 2);
							} else {
								if ((p_random(100) > (45 + a_spieler(g_akt_spieler).f_level))) {
									a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 3;
									p_nachricht(603, 2);
									g_karten_typ = 5;
									p_karte(15, 15);
								} else {
									a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 1;
									p_nachricht(599, 2);
								}
							}
						} else {
							p_nachricht(189, 2);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Nexus")) {
		v_spell = 83;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
						if ((a_spieler(g_akt_spieler).f_nexus == 1)) {
							a_spieler(g_akt_spieler).f_nexus = 0;
							p_mana_verlieren(v_spell);
							p_sound(20);
							p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 8, 2, 0, 0);
						} else {
							p_nachricht(49, 2);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Anker erschaffen")) {
		v_spell = 138;
		if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) != 15)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
					p_zug_verlieren();
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						p_sound(20);
						p_sternchen(160, 160, 3);
						p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 205, 0, 0, 0);
						a_spieler(g_akt_spieler).f_anker_x = a_spieler(g_akt_spieler).f_character_x;
						a_spieler(g_akt_spieler).f_anker_y = a_spieler(g_akt_spieler).f_character_y;
						a_spieler(g_akt_spieler).f_anker_level = a_spieler(g_akt_spieler).f_level;
					} else {
						p_misslungen();
					}
				} else {
					p_nachricht(632, 2);
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(815, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Regen")) {
		v_spell = 164;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(27);
				p_sternchen(160, 160, 3);
				for (v_i = 1; v_i <= p_power(v_spell); v_i += 1) {
					v_zaehler = 1;
					do {
						v_x = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
						v_y = (p_random((a_groesse(a_spieler(g_akt_spieler).f_level) - 3)) + 2);
						v_zaehler = (v_zaehler + 1);
					} while (!((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level)) || (v_zaehler > 500)));
					if ((v_zaehler <= 500)) {
						p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 206, 0, 0, 0);
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wort des Todes")) {
		v_spell = 67;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 2)) {
								p_sound(20);
								p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
								v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
								p_nachricht7(v_willi, 2);
								p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vakuum")) {
		v_spell = 131;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							v_testwert = a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art;
							if (((((v_testwert != 3) && (v_testwert != 7)) && (v_testwert != 9)) && (v_testwert != 10))) {
								p_sound(15);
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 0, 31, 31);
									p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 31, 31, 31);
									p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
								p_nachricht7(v_willi, 2);
								p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							} else {
								p_nachricht(503, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Versteinern")) {
		v_spell = 62;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_immune(13) == 0)) {
								p_sound(20);
								p_versteinern();
								v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
								p_nachricht7(v_willi, 2);
								p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0);
							} else {
								p_nachricht(266, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Ewiger Winter")) {
		v_spell = 72;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_immune(18) == 0)) {
								p_sound(20);
								p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 7);
								p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
							} else {
								p_nachricht(267, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Falle zerst\366ren")) {
		v_spell = 55;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] >= 22) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] <= 39))) {
						p_sound(9);
						p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					}
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 208)) {
						p_sound(9);
						p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Gift neutralisieren")) {
		v_spell = 148;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 81) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 201))) {
						p_sound(9);
						p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Verhexen")) {
		v_spell = 51;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 9) == 1)) {
								p_sound(20);
								p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 3);
								a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 3;
							} else {
								p_nachricht(200, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Monster Auge")) {
		v_spell = 50;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				g_monsterauge = 1;
				p_monsterkunde();
				g_monsterauge = 0;
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Portal")) {
		v_spell = 21;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) != 14)) {
				if ((a_spieler(g_akt_spieler).f_portal == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1)) {
						p_nachricht(334, 2);
					} else {
						p_zug_verlieren();
						if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 20))) {
							p_mana_verlieren(v_spell);
							if ((p_erfolgreich(v_spell) == 1)) {
								p_sound(31);
								p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 4);
								p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
								a_spieler(g_akt_spieler).f_portal = 0;
							} else {
								p_misslungen();
							}
						} else {
							p_nachricht(264, 2);
						}
					}
				} else {
					p_nachricht(49, 2);
				}
			} else {
				p_nachricht(812, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Stein zerst\366ren")) {
		v_spell = 106;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 112)) {
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(31);
					p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 4);
					p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(264, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Federfall")) {
		v_spell = 15;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sternchen(160, 160, 6);
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 73)) {
					p_sound(18);
					p_nachricht(193, 2);
					if (((a_spieler(g_akt_spieler).f_level + 1) > a_spieler(g_akt_spieler).f_maxlevel)) {
						p_aufsteigen(1);
					}
					p_neuer_level();
					p_naechster();
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Dunkles Mana")) {
		v_spell = 66;
		p_zug_verlieren();
		if ((p_erfolgreich(v_spell) == 1)) {
			p_sound(25);
			for (v_j = 1; v_j <= 2; v_j += 1) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					p_clipsprite(37, ((v_i * 31) - 31), 190, 31, 31);
					p_displaytransparentsprite(37, 160, 160);
					p_flipbuffers(1);
					p_delay(90);
				}
			}
			v_testfeld = a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
			if ((((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157)) || (v_testfeld == 163)) || (v_testfeld == 191))) {
				v_gesetzt = 0;
				if ((v_testfeld == 191)) {
					v_gesetzt = 1;
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 94, 0, 0, 0);
				}
				if ((v_testfeld == 163)) {
					v_gesetzt = 1;
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 53, 0, 0, 0);
				}
				if ((v_gesetzt == 0)) {
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				}
				a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + p_random((p_special_success(v_spell) / 2)));
				if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
					a_spieler(g_akt_spieler).f_mana = p_maxmana();
				}
			}
		} else {
			p_misslungen();
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Dunkler Sog")) {
		v_spell = 25;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(25);
					p_sog();
					v_schaden = (p_random((p_special_success(v_spell) + 1)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						v_art = a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art;
						if ((((v_art != 3) && (v_art != 9)) && (v_art != 10))) {
							a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + v_schaden);
							if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
								a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
							}
							p_monsterschaden(v_schaden);
						} else {
							p_nachricht(735, 2);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Funke")) {
		v_spell = 5;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(1);
					v_schaden = (p_random((p_special_success(v_spell) + 1)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					p_feuerschaden(v_schaden);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Drachenfeuer")) {
		v_spell = 22;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(3);
					v_schaden = (p_random(((p_special_success(v_spell) * 3) + 8)) + 8);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					p_feuerschaden(v_schaden);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vergiften")) {
		v_spell = 125;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(10);
					p_attack_spell(10);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							v_dauer = ((p_special_success(v_spell) * a_zauber(v_spell, g_akt_spieler).f_dauer) * a_spieler(g_akt_spieler).f_spellweaving);
							if ((v_dauer > 99)) {
								v_dauer = 99;
							}
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = (4 + v_dauer);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Blenden")) {
		v_spell = 137;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(10);
					p_attack_spell(2);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							v_dauer = ((p_special_success(v_spell) * a_zauber(v_spell, g_akt_spieler).f_dauer) * a_spieler(g_akt_spieler).f_spellweaving);
							if ((v_dauer > 99)) {
								v_dauer = 99;
							}
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = (5 + v_dauer);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Schlaf")) {
		v_spell = 127;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(25);
					p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 6);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 29) == 0)) {
								p_nachricht(480, 2);
							} else {
								a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 2;
							}
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Insektenschwarm")) {
		v_spell = 155;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(25);
					p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 6);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							v_dauer = (p_special_success(v_spell) * a_spieler(g_akt_spieler).f_spellweaving);
							if ((v_dauer > 99)) {
								v_dauer = 99;
							}
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = (6 + v_dauer);
						}
					} else {
						p_nachricht(600, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Telekinesis")) {
		v_spell = 129;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(15);
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if ((v_testfeld == 9)) {
						p_gold((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
					}
					if ((((v_testfeld == 6) || (v_testfeld == 161)) || (v_testfeld == 192))) {
						p_truhe((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
					}
					if ((((v_testfeld == 68) || (v_testfeld == 194)) || (v_testfeld == 162))) {
						p_truhe((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
					}
					if ((a_laby_item((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
						p_objekt((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuerlanze")) {
		v_spell = 114;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					if ((g_spell_x > 0)) {
						for (v_x = 6; v_x <= 10; v_x += 1) {
							p_draw_tile(42, v_x, 5, 1, 1);
						}
					}
					if ((g_spell_x < 0)) {
						for (v_x = 0; v_x <= 4; v_x += 1) {
							p_draw_tile(42, v_x, 5, 1, 1);
						}
					}
					if ((g_spell_y > 0)) {
						for (v_y = 6; v_y <= 10; v_y += 1) {
							p_draw_tile(42, 5, v_y, 1, 1);
						}
					}
					if ((g_spell_y < 0)) {
						for (v_y = 0; v_y <= 4; v_y += 1) {
							p_draw_tile(42, 5, v_y, 1, 1);
						}
					}
					p_flipbuffers(1);
					p_delay(g_mydelay);
					p_laby_screen();
					v_akt_power = p_special_success(v_spell);
					v_schaden = (p_random(((v_akt_power * 2) + 3)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					v_xsave = g_spell_x;
					v_ysave = g_spell_y;
					if ((g_spell_x > 0)) {
						for (g_spell_x = 1; g_spell_x <= 5; g_spell_x += 1) {
							v_schaden = (p_random(((v_akt_power * 2) + 1)) + 2);
							v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
							p_feuerschaden(v_schaden);
						}
					}
					g_spell_x = v_xsave;
					g_spell_y = v_ysave;
					if ((g_spell_x < 0)) {
						for (g_spell_x = -1; g_spell_x >= -5; g_spell_x -= 1) {
							v_schaden = (p_random(((v_akt_power * 2) + 1)) + 2);
							v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
							p_feuerschaden(v_schaden);
						}
					}
					g_spell_x = v_xsave;
					g_spell_y = v_ysave;
					if ((g_spell_y > 0)) {
						for (g_spell_y = 1; g_spell_y <= 5; g_spell_y += 1) {
							v_schaden = (p_random(((v_akt_power * 2) + 1)) + 2);
							v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
							p_feuerschaden(v_schaden);
						}
					}
					g_spell_x = v_xsave;
					g_spell_y = v_ysave;
					if ((g_spell_y < 0)) {
						for (g_spell_y = -1; g_spell_y >= -5; g_spell_y -= 1) {
							v_schaden = (p_random(((v_akt_power * 2) + 1)) + 2);
							v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
							p_feuerschaden(v_schaden);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuerball")) {
		v_spell = 115;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(3);
					for (v_y = ((g_spell_y - 1) + 5); v_y <= ((g_spell_y + 1) + 5); v_y += 1) {
						for (v_x = ((g_spell_x - 1) + 5); v_x <= ((g_spell_x + 1) + 5); v_x += 1) {
							p_draw_tile(42, v_x, v_y, 1, 1);
						}
					}
					p_flipbuffers(1);
					p_delay(g_mydelay);
					p_laby_screen();
					v_akt_power = p_special_success(v_spell);
					v_schaden = (p_random(((v_akt_power * 3) + 3)) + 4);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					for (v_zaehl = 1; v_zaehl <= 9; v_zaehl += 1) {
						v_schaden = (p_random(((v_akt_power * 2) + 3)) + 4);
						v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
						switch (v_zaehl) {
						case 2:
							g_spell_x = (g_spell_x - 1);
							g_spell_y = (g_spell_y - 1);
							break;
						case 3:
							g_spell_x = (g_spell_x + 1);
							break;
						case 4:
							g_spell_x = (g_spell_x + 1);
							break;
						case 5:
							g_spell_y = (g_spell_y + 1);
							g_spell_x = (g_spell_x - 2);
							break;
						case 6:
							g_spell_x = (g_spell_x + 2);
							break;
						case 7:
							g_spell_y = (g_spell_y + 1);
							g_spell_x = (g_spell_x - 2);
							break;
						case 8:
							g_spell_x = (g_spell_x + 1);
							break;
						case 9:
							g_spell_x = (g_spell_x + 1);
							break;
						}
						p_feuerschaden(v_schaden);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Meteor")) {
		v_spell = 117;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(34);
				for (v_y = ((g_spell_y - 1) + 5); v_y <= ((g_spell_y + 1) + 5); v_y += 1) {
					for (v_x = ((g_spell_x - 1) + 5); v_x <= ((g_spell_x + 1) + 5); v_x += 1) {
						p_draw_tile(112, v_x, v_y, 1, 1);
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				p_laby_screen();
				v_akt_power = p_special_success(v_spell);
				v_schaden = (p_random(((v_akt_power * 3) + 3)) + 2);
				v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
				p_hydra_zauber(v_schaden);
				for (v_zaehl = 1; v_zaehl <= 9; v_zaehl += 1) {
					v_schaden = (p_random(((v_akt_power * 2) + 3)) + 3);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					switch (v_zaehl) {
					case 2:
						g_spell_x = (g_spell_x - 1);
						g_spell_y = (g_spell_y - 1);
						break;
					case 3:
						g_spell_x = (g_spell_x + 1);
						break;
					case 4:
						g_spell_x = (g_spell_x + 1);
						break;
					case 5:
						g_spell_y = (g_spell_y + 1);
						g_spell_x = (g_spell_x - 2);
						break;
					case 6:
						g_spell_x = (g_spell_x + 2);
						break;
					case 7:
						g_spell_y = (g_spell_y + 1);
						g_spell_x = (g_spell_x - 2);
						break;
					case 8:
						g_spell_x = (g_spell_x + 1);
						break;
					case 9:
						g_spell_x = (g_spell_x + 1);
						break;
					}
					p_feuerschaden(v_schaden);
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Todeswolke")) {
		v_spell = 150;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(40);
				for (v_y = ((g_spell_y - 1) + 5); v_y <= ((g_spell_y + 1) + 5); v_y += 1) {
					for (v_x = ((g_spell_x - 1) + 5); v_x <= ((g_spell_x + 1) + 5); v_x += 1) {
						p_draw_tile(5, v_x, v_y, 1, 1);
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				p_laby_screen();
				for (v_zaehl = 1; v_zaehl <= 9; v_zaehl += 1) {
					switch (v_zaehl) {
					case 2:
						g_spell_x = (g_spell_x - 1);
						g_spell_y = (g_spell_y - 1);
						break;
					case 3:
						g_spell_x = (g_spell_x + 1);
						break;
					case 4:
						g_spell_x = (g_spell_x + 1);
						break;
					case 5:
						g_spell_y = (g_spell_y + 1);
						g_spell_x = (g_spell_x - 2);
						break;
					case 6:
						g_spell_x = (g_spell_x + 2);
						break;
					case 7:
						g_spell_y = (g_spell_y + 1);
						g_spell_x = (g_spell_x - 2);
						break;
					case 8:
						g_spell_x = (g_spell_x + 1);
						break;
					case 9:
						g_spell_x = (g_spell_x + 1);
						break;
					}
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						p_clipsprite(38, 0, 224, 32, 32);
						p_displaytransparentsprite(38, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
						if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] < (p_special_success(v_spell) * 3))) {
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
							p_nachricht7(v_willi, 2);
							p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
							p_gott_check();
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuerschlag")) {
		v_spell = 65;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(3);
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 5)) + 5);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					p_feuerschaden(v_schaden);
				} else {
					p_misslungen();
				}
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Mentalschlag")) {
		v_spell = 113;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_clipsprite(37, ((v_i * 31) - 31), 0, 31, 31);
						p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
						p_flipbuffers(1);
						p_delay(90);
					}
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_clipsprite(37, ((v_i * 31) - 31), 31, 31, 31);
						p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
						p_flipbuffers(1);
						p_delay(90);
					}
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 1)) + 1);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							p_monsterschaden(v_schaden);
						}
					}
				} else {
					p_misslungen();
				}
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Desintegration")) {
		v_spell = 112;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					for (v_j = 1; v_j <= 3; v_j += 1) {
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 221, 31, 31);
							p_displaytransparentsprite(37, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
							p_flipbuffers(1);
							p_delay(90);
						}
					}
					v_schaden = (p_random(((p_special_success(v_spell) * 4) + 6)) + 4);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					p_feuerschaden(v_schaden);
				} else {
					p_misslungen();
				}
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vortex")) {
		v_spell = 57;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sog();
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 3)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							p_monsterschaden(v_schaden);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Blitzschlag")) {
		v_spell = 81;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(46);
					p_attack_spell(6);
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 3)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_immune(25) == 1)) {
							p_nachricht(329, 2);
						} else {
							if ((p_dispelled() == 1)) {
								p_nachricht(312, 2);
							} else {
								p_monsterschaden(v_schaden);
							}
						}
					}
				} else {
					p_misslungen();
				}
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Frostschlag")) {
		v_spell = 28;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(4);
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 3)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							p_eisschaden(v_schaden);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Teleport")) {
		v_spell = 58;
		if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) != 15)) {
			if ((a_spieler(g_akt_spieler).f_teleport == 1)) {
				a_spieler(g_akt_spieler).f_teleport = 0;
				v_okay = p_opfern();
				if ((v_okay > 0)) {
					if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
						p_zug_verlieren();
						g_spell_x = 0;
						g_spell_y = 0;
						p_feld_waehlen();
						p_mana_verlieren(v_spell);
						if ((p_erfolgreich(v_spell) == 1)) {
							p_sound(17);
							for (v_i = 1; v_i <= 8; v_i += 1) {
								p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
								p_displaytransparentsprite(37, 160, 160);
								p_flipbuffers(1);
								p_delay(90);
							}
							for (v_i = 1; v_i <= 8; v_i += 1) {
								p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
								p_displaytransparentsprite(37, 160, 160);
								p_flipbuffers(1);
								p_delay(90);
							}
							if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
								a_spieler(g_akt_spieler).f_character_x = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
								a_spieler(g_akt_spieler).f_character_y = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
								p_laby_screen();
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
									p_displaytransparentsprite(37, 160, 160);
									p_flipbuffers(1);
									p_delay(90);
								}
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
									p_displaytransparentsprite(37, 160, 160);
									p_flipbuffers(1);
									p_delay(90);
								}
								p_laby_screen();
							}
						} else {
							p_misslungen();
						}
					} else {
						p_nachricht(194, 2);
					}
				}
			} else {
				p_nachricht(49, 2);
			}
		} else {
			p_nachricht(815, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Anker Teleportation")) {
		v_spell = 139;
		if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) != 15)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				if ((((a_spieler(g_akt_spieler).f_anker_x > 0) && (a_spieler(g_akt_spieler).f_anker_y > 0)) && (a_spieler(g_akt_spieler).f_anker_level > 0))) {
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						p_sound(17);
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_flipbuffers(1);
							p_delay(90);
						}
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_flipbuffers(1);
							p_delay(90);
						}
						a_spieler(g_akt_spieler).f_character_x = a_spieler(g_akt_spieler).f_anker_x;
						a_spieler(g_akt_spieler).f_character_y = a_spieler(g_akt_spieler).f_anker_y;
						a_spieler(g_akt_spieler).f_level = a_spieler(g_akt_spieler).f_anker_level;
						p_laby_screen();
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_flipbuffers(1);
							p_delay(90);
						}
						for (v_i = 1; v_i <= 8; v_i += 1) {
							p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
							p_displaytransparentsprite(37, 160, 160);
							p_flipbuffers(1);
							p_delay(90);
						}
						p_laby_screen();
					} else {
						p_misslungen();
					}
				} else {
					p_nachricht(633, 2);
				}
			} else {
				p_nachricht(194, 2);
			}
		} else {
			p_nachricht(815, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Dehydration")) {
		v_spell = 29;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(25);
					p_sternchen((160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)), 6);
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 4)) + 3);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 7) == 0)) {
								p_monsterschaden(v_schaden);
							} else {
								p_nachricht(268, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Arkaner Schlag")) {
		v_spell = 19;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(13);
					p_attack_spell(2);
					v_schaden = (p_random(((p_special_success(v_spell) * 2) + 1)) + 2);
					v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
					p_hydra_zauber(v_schaden);
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							p_monsterschaden(v_schaden);
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "\326ffnen")) {
		v_spell = 27;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(19);
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
						if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
							p_nachricht(524, 2);
						} else {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
						}
					}
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 67)) {
						a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 68;
					}
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 62)) {
						a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 63;
					}
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 193)) {
						a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 194;
					}
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 210)) {
						a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 209;
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(255, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Furcht")) {
		v_spell = 24;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
						if ((p_dispelled() == 1)) {
							p_nachricht(312, 2);
						} else {
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 8) == 1)) {
								p_sound(25);
								p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
								v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, 1));
								p_nachricht7(v_willi, 2);
								p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
								p_gott_check();
							} else {
								p_nachricht(269, 2);
							}
						}
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Homunkulus beschw\366ren")) {
		v_spell = 91;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						p_get_creature(1);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Vogel beschw\366ren")) {
		v_spell = 147;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
					p_get_creature(11);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Skelett beschw\366ren")) {
		v_spell = 92;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if (((((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157)) || (v_testfeld == 163)) || (v_testfeld == 191)) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(22);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(2);
					} else {
						p_nachricht(182, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Todesritter beschw\366ren")) {
		v_spell = 93;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if (((((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157)) || (v_testfeld == 163)) || (v_testfeld == 191)) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(42);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(3);
					} else {
						p_nachricht(182, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sternenfee beschw\366ren")) {
		v_spell = 94;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(109);
						p_get_creature(4);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Tiger beschw\366ren")) {
		v_spell = 95;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(75);
						p_get_creature(5);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Mumie beschw\366ren")) {
		v_spell = 96;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if (((((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157)) || (v_testfeld == 163)) || (v_testfeld == 191)) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(66);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(6);
					} else {
						p_nachricht(182, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Golem beschw\366ren")) {
		v_spell = 152;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8)) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(28);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(12);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Satyr beschw\366ren")) {
		v_spell = 153;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8)) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(49);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(13);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Feuerelementar beschw\366ren")) {
		v_spell = 162;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8)) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(29);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(14);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wasserelementar beschw\366ren")) {
		v_spell = 163;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8)) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(56);
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
						p_get_creature(15);
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "D\344mon beschw\366ren")) {
		v_spell = 97;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					p_sound(20);
					p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
					g_xmod = g_spell_x;
					g_ymod = g_spell_y;
					p_aufstehen(118);
					p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					p_get_creature(7);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Engel beschw\366ren")) {
		v_spell = 98;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
					g_xmod = g_spell_x;
					g_ymod = g_spell_y;
					p_aufstehen(97);
					p_get_creature(8);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Drache beschw\366ren")) {
		v_spell = 99;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(20);
					p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
					g_xmod = g_spell_x;
					g_ymod = g_spell_y;
					p_aufstehen(33);
					p_get_creature(9);
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Doppelg\344nger")) {
		v_spell = 103;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				p_zug_verlieren();
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 8) || (g_schriftrolle == 1))) {
						p_sound(20);
						p_sternchen((156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)), 7);
						g_xmod = g_spell_x;
						g_ymod = g_spell_y;
						p_aufstehen(85);
						p_get_creature(10);
						a_spieler(g_akt_spieler).f_creature_lifepoints = p_maxlife();
						a_spieler(g_akt_spieler).f_creature_speed = p_maxspeed();
						a_spieler(g_akt_spieler).f_creature_maxspeed = p_maxspeed();
					} else {
						p_nachricht(183, 2);
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Erdbeben")) {
		v_spell = 63;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				v_zittern = 3;
				p_laby_screen();
				for (v_i = 1; v_i <= 20; v_i += 1) {
					for (v_y = -1; v_y <= 11; v_y += 1) {
						for (v_x = -1; v_x <= 11; v_x += 1) {
							if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) < 1) || (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) < 1))) {
								p_draw_tile(1, v_x, v_y, v_x_offset, v_y_offset);
							} else {
								p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, (v_x_offset + v_zittern), (v_y_offset + v_zittern));
							}
						}
					}
					p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
					p_show_sight();
					p_flipbuffers(1);
					if ((v_zittern == 3)) {
						v_zittern = -3;
					} else {
						v_zittern = 3;
					}
					p_delay(20);
				}
				p_delay(g_mydelay);
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 1) == 0)) {
									v_schaden = (p_random((v_akt_power + 1)) + 2);
									v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
									p_monsterschaden(v_schaden);
								}
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Flammenmeer")) {
		v_spell = 23;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				for (v_y = -1; v_y <= 10; v_y += 1) {
					for (v_x = -1; v_x <= 10; v_x += 1) {
						p_draw_tile(42, v_x, v_y, 1, 1);
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				p_laby_screen();
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								v_schaden = (p_random((v_akt_power + 1)) + 2);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 11) == 1)) {
									v_schaden = (v_schaden * 2);
								}
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 12) == 0)) {
									p_monsterschaden(v_schaden);
								} else {
									p_nachricht(265, 2);
								}
							}
							if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 80)) {
								v_schaden = (p_random((v_akt_power + 1)) + 2);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								if ((v_schaden > 3)) {
									p_sound(23);
									p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
								}
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Armageddon")) {
		v_spell = 116;
		if ((a_spieler(g_akt_spieler).f_armageddon == 1)) {
			v_okay = p_opfern();
			if ((v_okay > 0)) {
				if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
					p_zug_verlieren();
					p_leeren(v_okay);
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						a_spieler(g_akt_spieler).f_armageddon = 0;
						p_sound(13);
						p_laby_screen();
						for (v_y = -1; v_y <= 10; v_y += 1) {
							for (v_x = -1; v_x <= 10; v_x += 1) {
								p_draw_tile(42, v_x, v_y, 1, 1);
							}
						}
						p_flipbuffers(1);
						p_delay(g_mydelay);
						p_laby_screen();
						v_akt_power = p_special_success(v_spell);
						for (g_spell_x = 1; g_spell_x <= a_groesse(a_spieler(g_akt_spieler).f_level); g_spell_x += 1) {
							for (g_spell_y = 1; g_spell_y <= a_groesse(a_spieler(g_akt_spieler).f_level); g_spell_y += 1) {
								if ((p_istmonster(g_spell_x, g_spell_y) == 1)) {
									v_schaden = (p_random((v_akt_power + 1)) + 2);
									v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
									if ((p_hat_eigenschaft(g_spell_x, g_spell_y, 11) == 1)) {
										v_schaden = (v_schaden * 2);
									}
									if ((p_hat_eigenschaft(g_spell_x, g_spell_y, 12) == 0)) {
										v_savex = g_spell_x;
										v_savey = g_spell_y;
										g_spell_x = (g_spell_x - a_spieler(g_akt_spieler).f_character_x);
										g_spell_y = (g_spell_y - a_spieler(g_akt_spieler).f_character_y);
										p_monsterschaden(v_schaden);
										g_spell_x = v_savex;
										g_spell_y = v_savey;
									} else {
										p_nachricht(265, 2);
									}
								}
								if ((a_labyrinth(g_spell_x, g_spell_y).f_feld[a_spieler(g_akt_spieler).f_level] == 80)) {
									v_schaden = (p_random((v_akt_power + 1)) + 2);
									v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
									if ((v_schaden > 3)) {
										p_sound(23);
										p_setlaby(g_spell_x, g_spell_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
									}
								}
							}
						}
					} else {
						p_misslungen();
					}
				} else {
					p_nachricht(194, 2);
				}
			}
		} else {
			p_nachricht(35, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Pestilence")) {
		v_spell = 128;
		if ((a_spieler(g_akt_spieler).f_pestilence == 1)) {
			v_okay = p_opfern();
			if ((v_okay > 0)) {
				if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
					p_zug_verlieren();
					p_leeren(v_okay);
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						a_spieler(g_akt_spieler).f_pestilence = 0;
						p_sound(40);
						p_laby_screen();
						for (v_y = -1; v_y <= 10; v_y += 1) {
							for (v_x = -1; v_x <= 10; v_x += 1) {
								p_draw_tile(5, v_x, v_y, 1, 1);
							}
						}
						p_flipbuffers(1);
						p_delay(g_mydelay);
						p_laby_screen();
						v_akt_power = p_special_success(v_spell);
						for (g_spell_x = 1; g_spell_x <= a_groesse(a_spieler(g_akt_spieler).f_level); g_spell_x += 1) {
							for (g_spell_y = 1; g_spell_y <= a_groesse(a_spieler(g_akt_spieler).f_level); g_spell_y += 1) {
								if ((p_istmonster(g_spell_x, g_spell_y) == 1)) {
									v_schaden = (p_random((v_akt_power + 1)) + 2);
									v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
									v_typtest = a_monster(a_labyrinth(g_spell_x, g_spell_y).f_objekt[a_spieler(g_akt_spieler).f_level]).f_art;
									if (((((((v_typtest != 3) && (v_typtest != 7)) && (v_typtest != 9)) && (v_typtest != 10)) && (a_labyrinth(g_spell_x, g_spell_y).f_objekt[a_spieler(g_akt_spieler).f_level] != 123)) && (a_labyrinth(g_spell_x, g_spell_y).f_objekt[a_spieler(g_akt_spieler).f_level] != 65))) {
										v_savex = g_spell_x;
										v_savey = g_spell_y;
										g_spell_x = (g_spell_x - a_spieler(g_akt_spieler).f_character_x);
										g_spell_y = (g_spell_y - a_spieler(g_akt_spieler).f_character_y);
										p_monsterschaden(v_schaden);
										g_spell_x = v_savex;
										g_spell_y = v_savey;
									}
								}
							}
						}
					} else {
						p_misslungen();
					}
				} else {
					p_nachricht(194, 2);
				}
			}
		} else {
			p_nachricht(35, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Den Tod austricksen")) {
		v_spell = 146;
		v_okay = p_opfern3();
		if ((v_okay > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_leeren(v_okay);
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(9);
					p_laby_screen();
					v_i = 0;
					do {
						v_i = (v_i + 1);
					} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
					if ((v_i <= 50)) {
						a_inventory(v_i, g_akt_spieler).f_name = 146;
						a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(146).f_art;
						a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(146).f_attri1;
						a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(146).f_attri2;
						a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(146).f_attri3;
						a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(146).f_attri4;
					}
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Energie der Steine")) {
		v_spell = 134;
		v_okay = p_opfern2();
		if ((v_okay > 0)) {
			if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
				p_zug_verlieren();
				p_leeren(v_okay);
				p_mana_verlieren(v_spell);
				if ((p_erfolgreich(v_spell) == 1)) {
					p_sound(9);
					p_nachricht(43, 2);
					a_spieler(g_akt_spieler).f_mana = p_maxmana();
				} else {
					p_misslungen();
				}
			} else {
				p_nachricht(194, 2);
			}
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Sternenfeuer")) {
		v_spell = 76;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				for (v_y = -1; v_y <= 10; v_y += 1) {
					for (v_x = -1; v_x <= 10; v_x += 1) {
						p_draw_tile(44, v_x, v_y, 1, 1);
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				p_laby_screen();
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								v_schaden = (p_random((v_akt_power + 2)) + 3);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 12) == 0)) {
									p_monsterschaden(v_schaden);
								} else {
									p_nachricht(265, 2);
								}
							}
							if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 80)) {
								v_schaden = (p_random((v_akt_power + 2)) + 2);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								if ((v_schaden > 3)) {
									p_sound(23);
									p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
								}
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Flutwelle")) {
		v_spell = 73;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				for (v_y = -1; v_y <= 10; v_y += 1) {
					for (v_x = -1; v_x <= 10; v_x += 1) {
						p_draw_tile(53, v_x, v_y, 1, 1);
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				p_laby_screen();
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 1) == 0)) {
									v_schaden = (p_random((p_special_success(v_spell) + 1)) + 2);
									v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
									p_monsterschaden(v_schaden);
								}
							}
							if (((((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 40) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 41)) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 42)) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 65))) {
								v_schaden = (p_random((v_akt_power + 1)) + 2);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								if ((v_schaden > 3)) {
									p_sound(27);
									p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
								}
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Prismatisches Spray")) {
		v_spell = 56;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(13);
				p_spraygrafik(360, 10);
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								v_schaden = (p_random((v_akt_power * 2)) + 2);
								v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
								p_monsterschaden(v_schaden);
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Winde rufen")) {
		v_spell = 39;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			p_zug_verlieren();
			p_mana_verlieren(v_spell);
			if ((p_erfolgreich(v_spell) == 1)) {
				p_sound(15);
				for (v_y = -1; v_y <= 10; v_y += 1) {
					for (v_x = -1; v_x <= 10; v_x += 1) {
						p_clipsprite(8, 480, 384, 32, 32);
						p_displaysprite(8, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
					}
				}
				p_flipbuffers(1);
				p_delay(g_mydelay);
				v_akt_power = p_special_success(v_spell);
				for (g_spell_x = -5; g_spell_x <= 5; g_spell_x += 1) {
					for (g_spell_y = -5; g_spell_y <= 5; g_spell_y += 1) {
						if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
							if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
								if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 1) == 1)) {
									if ((p_immune(45) == 0)) {
										v_schaden = (p_random((v_akt_power + 1)) + 1);
										v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
										p_monsterschaden(v_schaden);
									} else {
										p_nachricht(834, 2);
									}
								}
							}
						}
					}
				}
			} else {
				p_misslungen();
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Wirbelwind")) {
		v_spell = 2;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			if ((g_schriftrolle == 0)) {
				g_spell_x = 0;
				g_spell_y = 0;
				p_feld_waehlen();
				g_blocked = 0;
				p_los();
				if ((g_blocked == 0)) {
					p_zug_verlieren();
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						p_sound(15);
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 2; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 40, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(90);
							}
						}
						v_schaden = (p_random((p_special_success(v_spell) + 1)) + 1);
						v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
						p_hydra_zauber(v_schaden);
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
							if ((p_immune(45) == 0)) {
								if ((p_dispelled() == 1)) {
									p_nachricht(312, 2);
								} else {
									p_monsterschaden(v_schaden);
								}
							} else {
								p_nachricht(834, 2);
							}
						}
					} else {
						p_misslungen();
					}
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
	if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] == "Orkan")) {
		v_spell = 108;
		if (((a_spieler(g_akt_spieler).f_mana > (p_zauberkosten(v_spell) - 1)) || (g_schriftrolle == 1))) {
			if ((g_schriftrolle == 0)) {
				g_spell_x = 0;
				g_spell_y = 0;
				p_feld_waehlen();
				g_blocked = 0;
				p_los();
				if ((g_blocked == 0)) {
					p_zug_verlieren();
					p_mana_verlieren(v_spell);
					if ((p_erfolgreich(v_spell) == 1)) {
						p_sound(15);
						for (v_j = 1; v_j <= 5; v_j += 1) {
							for (v_i = 1; v_i <= 2; v_i += 1) {
								p_clipsprite(17, ((v_i * 40) - 40), 40, 39, 39);
								p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
								p_flipbuffers(1);
								p_delay(90);
							}
						}
						v_schaden = (p_random((p_special_success(v_spell) * 2)) + 1);
						v_schaden = (v_schaden * a_spieler(g_akt_spieler).f_spellweaving);
						p_hydra_zauber(v_schaden);
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
							if ((p_immune(45) == 0)) {
								if ((p_dispelled() == 1)) {
									p_nachricht(312, 2);
								} else {
									p_monsterschaden(v_schaden);
								}
							} else {
								p_nachricht(834, 2);
							}
						}
					} else {
						p_misslungen();
					}
				}
			} else {
				p_nachricht(233, 2);
			}
		} else {
			p_nachricht(194, 2);
		}
	}
}

static int32_t p_character_info() {
	int32_t v_b = 0;
	int32_t v_g = 0;
	int32_t v_i = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_r = 0;
	int32_t v_result = 0;
	std::string v_waffenl;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
		}
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaytransparentsprite(55, 0, 0);
		p_clipsprite(63, 0, 0, 640, 17);
		p_displaysprite(63, 0, 46);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaytransparentsprite(58, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		v_x = 55;
		v_y = 80;
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(220, 25, a_nachricht_text(92, (1 + g_sprache)), -1, 0);
		if ((g_cinfo_menu == 1)) {
			p_frontcolor(p_rgb(247, 36, 61));
			p_drawtext(v_x, v_y, a_nachricht_text(55, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_lifepoints) + " (") + p_str(p_maxlife())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(130, 125, 250));
			p_drawtext(v_x, v_y, a_nachricht_text(59, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_mana) + " (") + p_str(p_maxmana())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, a_nachricht_text(52, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_attack) + " (") + p_str(p_angriff())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(53, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_dexterity) + " (") + p_str(p_reflexe())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(54, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_strength) + " (") + p_str((((p_staerke() + p_habich(35)) + p_habich(85)) + a_spieler(g_akt_spieler).f_damagegegenstand))) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(239, 131, 44));
			p_drawtext(v_x, v_y, a_nachricht_text(56, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_maxspeed) + " (") + p_str(p_maxspeed())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, a_nachricht_text(57, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_perception) + " (") + p_str(p_wahrnehmung())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(58, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_luck_score) + " (") + p_str(p_luck())) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(91, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(a_spieler(g_akt_spieler).f_power_score) + " (") + p_str(p_power(0))) + ")"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(61, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_circle), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(1, 1, 255));
			p_drawtext(v_x, v_y, a_nachricht_text(90, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_hunger), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(89, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_durst), -1, 0);
			v_y = (v_y + 15);
			v_waffenl = "";
			if ((p_ich_trage(10) == 0)) {
				v_waffenl = a_nachricht_text(636, (g_sprache + 1));
			}
			p_frontcolor(p_rgb(255, 1, 1));
			p_drawtext(v_x, v_y, a_nachricht_text(88, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((p_str(p_schaden_min()) + "-") + p_str(p_schaden_max())) + v_waffenl), -1, 0);
			v_y = (v_y + 15);
			p_schutz();
			p_drawtext(v_x, v_y, a_nachricht_text(87, (1 + g_sprache)), -1, 0);
			p_schutz();
			p_drawtext((v_x + 170), v_y, ((p_str(g_schutz_min) + "-") + p_str(g_schutz_max)), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, a_nachricht_text(86, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(g_behinderung), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 1, 1));
			p_drawtext(v_x, v_y, a_nachricht_text(84, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_mks), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 255, 1));
			p_drawtext(v_x, v_y, a_nachricht_text(85, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(p_gold_anzahl()), -1, 0);
			v_y = (v_y + 15);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, a_nachricht_text(239, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, (((((p_str(a_spieler(g_akt_spieler).f_stabteile) + " ( + ") + p_str((100 * a_spieler(g_akt_spieler).f_stabteile))) + " ") + a_nachricht_text(93, (1 + g_sprache))) + " )"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(436, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_moves), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(93, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(p_punkte()), -1, 0);
			v_y = (v_y + 15);
			v_x = 350;
			v_y = 80;
			for (v_i = 1; v_i <= 141; v_i += 1) {
				if (((a_skills(v_i, g_akt_spieler).f_gewaehlt == 1) && (a_skills(v_i, g_akt_spieler).f_kosten != 0))) {
					if (((((v_mmouse_x > v_x) && (v_mmouse_x < (v_x + 100))) && (v_mmouse_y > v_y)) && (v_mmouse_y < (v_y + 14)))) {
						p_frontcolor(p_rgb(255, 255, 255));
						p_drawtext(30, 430, (((a_skills(v_i, g_akt_spieler).f_beschreibung_1[(1 + g_sprache)] + " (") + p_str(a_skills(v_i, g_akt_spieler).f_kosten)) + " CP)"), -1, 0);
						p_drawtext(30, 445, a_skills(v_i, g_akt_spieler).f_beschreibung_2[(1 + g_sprache)], -1, 0);
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 1)) {
						v_r = 255;
						v_g = 1;
						v_b = 1;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 2)) {
						v_r = 138;
						v_g = 11;
						v_b = 88;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 3)) {
						v_r = 255;
						v_g = 1;
						v_b = 255;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 4)) {
						v_r = 1;
						v_g = 1;
						v_b = 255;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 5)) {
						v_r = 1;
						v_g = 255;
						v_b = 1;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 6)) {
						v_r = 1;
						v_g = 255;
						v_b = 255;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 7)) {
						v_r = 130;
						v_g = 115;
						v_b = 32;
					}
					if ((a_skills(v_i, g_akt_spieler).f_gruppe == 8)) {
						v_r = 150;
						v_g = 150;
						v_b = 150;
					}
					p_frontcolor(p_rgb(v_r, v_g, v_b));
					p_drawtext(v_x, v_y, a_skills(v_i, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
					v_y = (v_y + 15);
				}
			}
		} else {
			p_drawtext(v_x, v_y, a_nachricht_text(615, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(p_spieler_angriffswert()) + "%"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(612, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(p_schaden_critical()) + "%"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, (a_nachricht_text(574, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(p_schleichen()) + "%"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(614, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(p_entdecken()) + "%"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(613, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(p_ausweichen()) + "%"), -1, 0);
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(629, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str((p_reflexe() * 10)) + "%"), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 15);
			p_drawtext(v_x, v_y, a_nachricht_text(703, (1 + g_sprache)), -1, 0);
			p_drawtext((v_x + 190), v_y, (p_str(a_spieler(g_akt_spieler).f_magieresistenz) + "%"), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 15);
			v_x = 350;
			v_y = 80;
			p_clipsprite(9, 32, 192, 32, 32);
			p_displaytransparentsprite(9, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(618, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_goblinlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(9, 160, 448, 32, 32);
			p_displaytransparentsprite(9, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(619, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_spinnenlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(9, 32, 128, 32, 32);
			p_displaytransparentsprite(9, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(620, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_untotenlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(9, 0, 0, 32, 32);
			p_displaytransparentsprite(9, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(621, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_tierkunde), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(9, 256, 0, 32, 32);
			p_displaytransparentsprite(9, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(628, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_pflanzenlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(1, 32, 96, 32, 32);
			p_displaytransparentsprite(1, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(622, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_fallenlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
			p_clipsprite(8, 448, 160, 32, 32);
			p_displaytransparentsprite(8, (v_x - 36), (v_y - 10));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, (a_nachricht_text(623, (1 + g_sprache)) + ":"), -1, 0);
			p_drawtext((v_x + 170), v_y, p_str(a_spieler(g_akt_spieler).f_giftlehre), -1, 0);
			p_stopdrawing();
			v_y = (v_y + 32);
		}
		p_stopdrawing();
		p_clipsprite(0, 128, ((a_spieler(g_akt_spieler).f_maennchen * 32) - 32), 32, 32);
		p_displaytransparentsprite(0, 310, 395);
		p_examinekeyboard();
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		if ((g_cinfo_menu == 2)) {
			if ((((((v_mmouse_x > 550) && (v_mmouse_x < 582)) && (v_mmouse_y > 350)) && (v_mmouse_y < 382)) || p_keyboardpushed(276))) {
				p_clipsprite(6, 96, 0, 31, 31);
				if (((v_mmouse_links == 1) || p_keyboardpushed(276))) {
					g_cinfo_menu = 1;
				}
			} else {
				p_clipsprite(6, 32, 0, 31, 31);
			}
		} else {
			p_clipsprite(6, 288, 0, 31, 31);
		}
		p_displaytransparentsprite(6, 550, 350);
		if ((g_cinfo_menu == 1)) {
			if ((((((v_mmouse_x > 584) && (v_mmouse_x < 616)) && (v_mmouse_y > 350)) && (v_mmouse_y < 382)) || p_keyboardpushed(275))) {
				p_clipsprite(6, 63, 0, 31, 31);
				if (((v_mmouse_links == 1) || p_keyboardpushed(275))) {
					g_cinfo_menu = 2;
				}
			} else {
				p_clipsprite(6, 0, 0, 31, 31);
			}
		} else {
			p_clipsprite(6, 256, 0, 31, 31);
		}
		p_displaytransparentsprite(6, 584, 350);
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
	} while (!((v_mmouse_rechts == 1) || p_keyboardpushed(27)));
}

static int32_t p_creature_attacke() {
	int16_t v_akt_attack = 0;
	v_akt_attack = a_spieler(g_akt_spieler).f_creature_attack;
	if ((p_habich(168) > 0)) {
		v_akt_attack = (v_akt_attack + 1);
	}
	if ((p_habich(169) > 0)) {
		v_akt_attack = (v_akt_attack + 2);
	}
	if ((p_habich(170) > 0)) {
		v_akt_attack = (v_akt_attack + 3);
	}
	if ((p_habich(171) > 0)) {
		v_akt_attack = (v_akt_attack + 4);
	}
	return v_akt_attack;
}

static int32_t p_creature_bewegen() {
	int16_t v_angriff = 0;
	int32_t v_counter = 0;
	int32_t v_elapsedtime3 = 0;
	int32_t v_frame = 0;
	int32_t v_framestep = 0;
	int8_t v_gesetzt = 0;
	int32_t v_hugo = 0;
	int16_t v_hydra = 0;
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int32_t v_kaempfen = 0;
	int32_t v_level = 0;
	int32_t v_maxi = 0;
	int32_t v_mini = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_x_old = 0;
	int32_t v_mouse_y_old = 0;
	int32_t v_nach_kampf = 0;
	int32_t v_neue_koepfe = 0;
	int16_t v_new_monster = 0;
	int16_t v_okay = 0;
	int32_t v_result = 0;
	int32_t v_schaden = 0;
	int16_t v_schaden_max = 0;
	int16_t v_schaden_min = 0;
	int32_t v_schongemalt = 0;
	int16_t v_setx = 0;
	int16_t v_sety = 0;
	int32_t v_sprite_x = 0;
	int32_t v_sprite_y = 0;
	int32_t v_starttime3 = 0;
	int16_t v_testfeld = 0;
	int16_t v_treffer = 0;
	std::string v_willi;
	int32_t v_wohin = 0;
	int16_t v_x = 0;
	int32_t v_xmod_save = 0;
	int32_t v_xsave = 0;
	int16_t v_xx = 0;
	int32_t v_xxx = 0;
	int16_t v_y = 0;
	int32_t v_ymod_save = 0;
	int16_t v_yy = 0;
	int32_t v_yyy = 0;
	int16_t v_zw = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	g_xmod = 0;
	g_ymod = 0;
	p_examinekeyboard();
	v_result = p_examinemouse();
	v_mmouse_x = p_mousex();
	v_mmouse_y = p_mousey();
	v_mmouse_links = p_mousebutton(1);
	v_jax = 0;
	v_jay = 0;
	if ((g_joystick_used == 1)) {
		p_examinejoystick();
		v_jax = p_joystickaxisx();
		v_jay = p_joystickaxisy();
	}
	if ((p_keyboardpushed(275) || (v_jax == 1))) {
		a_spieler(g_akt_spieler).f_creature_heading = 1;
		g_xmod = 1;
		g_ymod = 0;
	}
	if ((p_keyboardpushed(276) || (v_jax == -1))) {
		a_spieler(g_akt_spieler).f_creature_heading = 3;
		g_xmod = -1;
		g_ymod = 0;
	}
	if ((p_keyboardpushed(273) || (v_jay == -1))) {
		a_spieler(g_akt_spieler).f_creature_heading = 0;
		g_ymod = -1;
		g_xmod = 0;
	}
	if ((p_keyboardpushed(274) || (v_jay == 1))) {
		a_spieler(g_akt_spieler).f_creature_heading = 2;
		g_ymod = 1;
		g_xmod = 0;
	}
	if ((v_mmouse_links == 1)) {
		if (((((v_mmouse_x > 176) && (v_mmouse_x < 352)) && (v_mmouse_y >= 160)) && (v_mmouse_y <= 192))) {
			a_spieler(g_akt_spieler).f_creature_heading = 1;
			g_xmod = 1;
			g_ymod = 0;
		}
		if ((((v_mmouse_x < 176) && (v_mmouse_y >= 160)) && (v_mmouse_y <= 192))) {
			a_spieler(g_akt_spieler).f_creature_heading = 3;
			g_xmod = -1;
			g_ymod = 0;
		}
		if (((((v_mmouse_y > 176) && (v_mmouse_y < 352)) && (v_mmouse_x >= 160)) && (v_mmouse_x <= 192))) {
			a_spieler(g_akt_spieler).f_creature_heading = 2;
			g_ymod = 1;
			g_xmod = 0;
		}
		if ((((v_mmouse_y < 176) && (v_mmouse_x >= 160)) && (v_mmouse_x <= 192))) {
			a_spieler(g_akt_spieler).f_creature_heading = 0;
			g_ymod = -1;
			g_xmod = 0;
		}
	}
	v_kaempfen = 0;
	if (((g_xmod != 0) || (g_ymod != 0))) {
		g_bewegt = 1;
		v_hydra = 0;
		if (((p_istmonster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)) == 1) || (p_isthydra((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)) == 1))) {
			if ((p_isthydra((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)) == 1)) {
				v_kaempfen = 1;
				v_hydra = 1;
				v_angriff = p_creature_attacke();
				v_mini = a_spieler(g_akt_spieler).f_creature_schaden_min;
				v_maxi = a_spieler(g_akt_spieler).f_creature_schaden_max;
				v_treffer = (p_random(99) + 1);
				if ((v_treffer < v_angriff)) {
					p_clipsprite(38, 0, 224, 32, 32);
					p_displaysprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
					v_counter = 1;
					do {
						v_schaden = (p_random((v_maxi - 1)) + 1);
						v_counter = (v_counter + 1);
					} while (!((v_schaden >= v_mini) || (v_counter > 500)));
					if ((v_counter > 500)) {
						v_schaden = 1;
					}
					if ((v_schaden > p_min(p_max(((v_level / 2) + 1), 6), 15))) {
						a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
						p_nachricht(287, 3);
						p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
						if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						}
					} else {
						v_neue_koepfe = (p_random(1) + 1);
						a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] + v_neue_koepfe);
						if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] > 9)) {
							a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 9;
						}
						p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
					}
				} else {
					p_nachricht(286, 3);
				}
				g_xmod = 0;
				g_ymod = 0;
			} else {
				if ((a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_x + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] != 3)) {
					v_kaempfen = 1;
					v_zw = a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_graphic[a_spieler(g_akt_spieler).f_level];
					v_sprite_x = v_zw;
					v_sprite_y = 0;
					if ((v_sprite_x > 10)) {
						do {
							v_sprite_y = (v_sprite_y + 1);
							v_sprite_x = (v_sprite_x - 10);
						} while (!(v_sprite_x < 11));
					}
					v_angriff = a_spieler(g_akt_spieler).f_creature_attack;
					v_schaden_min = a_spieler(g_akt_spieler).f_creature_schaden_min;
					v_schaden_max = a_spieler(g_akt_spieler).f_creature_schaden_max;
					v_treffer = (p_random(99) + 1);
					if ((v_treffer < v_angriff)) {
						p_clipsprite(38, 0, 224, 32, 32);
						p_displaytransparentsprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
						v_okay = 0;
						if ((a_spieler(g_akt_spieler).f_creature_typ == 4)) {
							p_sound(37);
							v_okay = 1;
						}
						if ((a_spieler(g_akt_spieler).f_creature_typ == 5)) {
							p_sound(35);
							v_okay = 1;
						}
						if ((a_spieler(g_akt_spieler).f_creature_typ == 6)) {
							p_sound(45);
							v_okay = 1;
						}
						if ((a_spieler(g_akt_spieler).f_creature_typ == 7)) {
							p_sound(44);
							v_okay = 1;
						}
						if ((a_spieler(g_akt_spieler).f_creature_typ == 8)) {
							p_sound(38);
							v_okay = 1;
						}
						if ((a_spieler(g_akt_spieler).f_creature_typ == 9)) {
							p_sound(44);
							v_okay = 1;
						}
						if ((v_okay == 0)) {
							p_sound((p_random(6) + 1));
						}
						do {
							v_schaden = (p_random((v_schaden_max - 1)) + 1);
						} while (!(v_schaden > v_schaden_min));
						v_wohin = p_screenoutput();
						p_startdrawing(v_wohin);
						p_drawingmode(1);
						p_frontcolor(p_rgb(255, 255, 255));
						v_xxx = (172 + (g_xmod * 32));
						v_yyy = (168 + (g_ymod * 32));
						if ((v_schaden < 10)) {
							v_xxx = (172 + (g_xmod * 32));
							v_yyy = (168 + (g_ymod * 32));
						}
						if ((v_schaden >= 10)) {
							v_xxx = (166 + (g_xmod * 32));
							v_yyy = (168 + (g_ymod * 32));
						}
						if ((v_schaden >= 100)) {
							v_xxx = (163 + (g_xmod * 32));
							v_yyy = (168 + (g_ymod * 32));
						}
						p_drawtext(v_xxx, v_yyy, p_str(v_schaden), -1, 0);
						p_stopdrawing();
						p_flipbuffers(1);
						p_delay(g_mydelay);
						a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] - v_schaden);
						if ((a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
							v_willi = " ";
							v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, (1 + g_sprache)));
							p_nachricht7(v_willi, 3);
							a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
							p_setmonster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
						} else {
							p_clipsprite(1, (v_inhalt_x * 32), (v_inhalt_y * 32), 32, 32);
							p_displaysprite(1, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
							p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
							p_displaytransparentsprite(9, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
							v_gesetzt = 0;
							v_xmod_save = g_xmod;
							v_ymod_save = g_ymod;
							if ((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), 6) == 1) && (p_random(10) > 4)) || (g_test == 1))) {
								v_new_monster = a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level];
								if ((a_laby_monster((a_spieler(g_akt_spieler).f_creature_x + 1), a_spieler(g_akt_spieler).f_creature_y).f_name[a_spieler(g_akt_spieler).f_level] == 0)) {
									v_gesetzt = 1;
									g_xmod = 1;
									g_ymod = 0;
									p_aufstehen3(a_monster(v_new_monster).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_creature_x + 1), a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, v_new_monster, a_monster(v_new_monster).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if ((a_labyrinth((a_spieler(g_akt_spieler).f_creature_x - 1), a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 0)) {
									v_gesetzt = 1;
									g_xmod = -1;
									g_ymod = 0;
									p_aufstehen3(a_monster(v_new_monster).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_creature_x - 1), a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, v_new_monster, a_monster(v_new_monster).f_nr, a_monster(v_new_monster).f_lebenspunkte, 0, 0);
								}
								if ((a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 0)) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = 1;
									p_aufstehen3(a_monster(v_new_monster).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y + 1), a_spieler(g_akt_spieler).f_level, v_new_monster, a_monster(v_new_monster).f_nr, a_monster(v_new_monster).f_lebenspunkte, 0, 0);
								}
								if ((a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 0)) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = -1;
									p_aufstehen3(a_monster(v_new_monster).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y - 1), a_spieler(g_akt_spieler).f_level, v_new_monster, a_monster(v_new_monster).f_nr, a_monster(v_new_monster).f_lebenspunkte, 0, 0);
								}
							}
							g_xmod = v_xmod_save;
							g_ymod = v_ymod_save;
							if ((v_gesetzt == 1)) {
								p_nachricht(36, 3);
								p_laby_screen3();
							}
						}
						p_laby_screen3();
					} else {
						p_sound(29);
						p_nachricht(300, 3);
						p_flipbuffers(1);
						p_delay(g_mydelay);
					}
					g_xmod = 0;
					g_ymod = 0;
				}
			}
		}
		switch (a_labyrinth((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level]) {
		case 80:
			if ((p_random(100) < a_spieler(g_akt_spieler).f_creature_attack)) {
				p_sound(23);
				p_setlaby((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_laby_screen3();
				p_delay(g_mydelay);
			} else {
				p_nachricht(3, 2);
				p_creature_schaden(1);
			}
			a_spieler(g_akt_spieler).f_creature_speed = 0;
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 47:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 164:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 1:
			if ((((a_spieler(g_akt_spieler).f_creature_typ != 4) || ((a_spieler(g_akt_spieler).f_creature_x + g_xmod) > a_groesse(a_spieler(g_akt_spieler).f_level))) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) > a_groesse(a_spieler(g_akt_spieler).f_level)))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 101:
			if ((((a_spieler(g_akt_spieler).f_creature_typ != 4) || ((a_spieler(g_akt_spieler).f_creature_x + g_xmod) > a_groesse(a_spieler(g_akt_spieler).f_level))) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) > a_groesse(a_spieler(g_akt_spieler).f_level)))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 102:
			if ((((a_spieler(g_akt_spieler).f_creature_typ != 4) || ((a_spieler(g_akt_spieler).f_creature_x + g_xmod) > a_groesse(a_spieler(g_akt_spieler).f_level))) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) > a_groesse(a_spieler(g_akt_spieler).f_level)))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 103:
			if ((((a_spieler(g_akt_spieler).f_creature_typ != 4) || ((a_spieler(g_akt_spieler).f_creature_x + g_xmod) > a_groesse(a_spieler(g_akt_spieler).f_level))) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) > a_groesse(a_spieler(g_akt_spieler).f_level)))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 104:
			if ((((a_spieler(g_akt_spieler).f_creature_typ != 4) || ((a_spieler(g_akt_spieler).f_creature_x + g_xmod) > a_groesse(a_spieler(g_akt_spieler).f_level))) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) > a_groesse(a_spieler(g_akt_spieler).f_level)))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 42:
			if ((a_spieler(g_akt_spieler).f_creature_typ != 14)) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 53:
			if (((a_spieler(g_akt_spieler).f_creature_typ != 11) && (a_spieler(g_akt_spieler).f_creature_typ != 15))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 72:
			if (((a_spieler(g_akt_spieler).f_creature_typ != 11) && (a_spieler(g_akt_spieler).f_creature_typ != 15))) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 56:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 57:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 15:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 16:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 17:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 18:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 78:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 165:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 159:
			p_nachricht(648, 6);
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 210:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 20:
			if ((a_spieler(g_akt_spieler).f_creature_typ != 4)) {
				g_xmod = 0;
				g_ymod = 0;
			}
			break;
		case 70:
			if ((a_spieler(g_akt_spieler).f_creature_typ == 9)) {
				p_sound(31);
				p_setlaby((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_laby_screen3();
				p_delay(g_mydelay);
			}
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 136:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 112:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 88:
			g_xmod = 0;
			g_ymod = 0;
			break;
		case 199:
			g_xmod = 0;
			g_ymod = 0;
			break;
		}
		v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level];
		if ((a_spieler(g_akt_spieler).f_creature_typ != 11)) {
			if ((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157))) {
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1)) {
					p_sound(16);
					p_aufstehen3(22);
					p_setlaby((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					p_setmonster((a_spieler(g_akt_spieler).f_creature_x + g_xmod), (a_spieler(g_akt_spieler).f_creature_y + g_ymod), a_spieler(g_akt_spieler).f_level, 4, a_monster(4).f_nr, a_monster(4).f_lebenspunkte, 0, 0);
					g_xmod = 0;
					g_ymod = 0;
					p_laby_screen3();
					v_kaempfen = 1;
				}
			}
		}
		if ((((a_spieler(g_akt_spieler).f_creature_x + g_xmod) < 1) || ((a_spieler(g_akt_spieler).f_creature_y + g_ymod) < 1))) {
			g_xmod = 0;
			g_ymod = 0;
		}
	} else {
		g_bewegt = 0;
	}
	g_spielerwechsel = 0;
	v_schongemalt = 0;
	if (((g_xmod != 0) || (g_ymod != 0))) {
		v_schongemalt = 1;
		a_spieler(g_akt_spieler).f_creature_speed = (a_spieler(g_akt_spieler).f_creature_speed - 1);
		if ((a_spieler(g_akt_spieler).f_creature_speed == 0)) {
			g_spielerwechsel = 1;
		}
		for (v_i = 4; v_i <= 32; v_i += 4) {
			v_starttime3 = p_elapsedmilliseconds();
			v_framestep = (v_framestep + 1);
			if ((v_framestep > 3)) {
				v_framestep = 0;
				if ((v_frame == 0)) {
					v_frame = 1;
				} else {
					v_frame = 0;
				}
			}
			p_clearscreen(p_rgb(0, 0, 0));
			p_draw_screen2(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
			p_draw_screen5(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
			p_draw_screen6(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
			p_draw_screen8(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
			p_draw_creature(v_frame, 0);
			p_show_sight2();
			p_laby_rahmen();
			p_show_logo();
			p_show_varys2();
			p_show_buttons2();
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
			v_elapsedtime3 = (p_elapsedmilliseconds() - v_starttime3);
			if ((v_elapsedtime3 < 15)) {
				p_delay((15 - v_elapsedtime3));
			}
			p_flipbuffers(1);
			p_delay(g_mydelay2);
		}
		a_spieler(g_akt_spieler).f_creature_x = (a_spieler(g_akt_spieler).f_creature_x + g_xmod);
		a_spieler(g_akt_spieler).f_creature_y = (a_spieler(g_akt_spieler).f_creature_y + g_ymod);
		g_bewegt = 1;
		p_update_automap2();
		v_okay = 0;
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 74))) {
			v_okay = 1;
			if ((g_bewegt == 1)) {
				p_sound(9);
				p_sternchen2(156, 156, 4);
				v_xsave = a_spieler(g_akt_spieler).f_creature_x;
				a_spieler(g_akt_spieler).f_creature_x = a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level];
				a_spieler(g_akt_spieler).f_creature_y = a_labyrinth(v_xsave, a_spieler(g_akt_spieler).f_creature_y).f_objekt[a_spieler(g_akt_spieler).f_level];
				p_update_automap2();
				p_laby_screen3();
				v_nach_kampf = 1;
			}
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 9))) {
			v_okay = 1;
			p_gold(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y);
			v_kaempfen = 1;
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 6))) {
			v_okay = 1;
			p_truhe(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y);
			v_kaempfen = 1;
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 68))) {
			v_okay = 1;
			p_truhe(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y);
			v_kaempfen = 1;
		}
		if (((v_okay == 0) && (a_laby_item(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_name[a_spieler(g_akt_spieler).f_level] > 0))) {
			v_okay = 1;
			p_objekt(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y);
			v_kaempfen = 1;
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 208))) {
			v_okay = 1;
			p_creature_schaden(1);
			p_nachricht(833, 3);
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 209))) {
			v_okay = 1;
			p_sound(38);
			p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, 210, 0, 0, 0);
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 149))) {
			v_okay = 1;
			p_nachricht(498, 6);
			a_spieler(g_akt_spieler).f_creature_typ = 0;
			a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
			a_spieler(g_akt_spieler).f_creature_speed = 0;
			a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
			p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		if (((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] == 158))) {
			v_okay = 1;
			p_nachricht(499, 6);
			p_creature_schaden((p_random(a_spieler(g_akt_spieler).f_level) + 5));
			p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		if ((((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] >= 31)) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] <= 39))) {
			v_okay = 1;
			p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] - 9), 0, 0, 0);
		}
		if ((((v_okay == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] >= 22)) && (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] <= 30))) {
			switch (a_labyrinth(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level]) {
			case 22:
				v_zw = (p_random(6) + 1);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				a_spieler(g_akt_spieler).f_creature_lifepoints = (a_spieler(g_akt_spieler).f_creature_lifepoints - v_zw);
				p_nachricht(17, 3);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				break;
			case 29:
				v_zw = (p_random(6) + 6);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				a_spieler(g_akt_spieler).f_creature_lifepoints = (a_spieler(g_akt_spieler).f_creature_lifepoints - v_zw);
				p_nachricht(18, 3);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				break;
			case 23:
				v_zw = (p_random(6) + 1);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				a_spieler(g_akt_spieler).f_creature_lifepoints = (a_spieler(g_akt_spieler).f_creature_lifepoints - v_zw);
				p_nachricht(19, 3);
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				break;
			case 24:
				if ((a_spieler(g_akt_spieler).f_creature_typ != 11)) {
					p_nachricht(195, 3);
					p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					a_spieler(g_akt_spieler).f_creature_typ = 0;
					a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
					a_spieler(g_akt_spieler).f_creature_speed = 0;
					a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
				}
				break;
			case 25:
				p_nachricht(20, 6);
				p_sound(25);
				p_sternchen2(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_creature_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_creature_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 81, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, 81, 0, 0, 0);
				p_laby_screen3();
				break;
			case 26:
				p_nachricht(20, 3);
				p_sound(25);
				p_sternchen2(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_creature_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_creature_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 41, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, 41, 0, 0, 0);
				p_laby_screen3();
				break;
			case 27:
				p_nachricht(20, 2);
				p_sound(25);
				p_sternchen2(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_creature_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_creature_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 80, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_laby_screen3();
				break;
			}
			p_nachricht(188, 3);
			if ((p_creature_lebenspunkte() < 1)) {
				a_spieler(g_akt_spieler).f_creature_typ = 0;
				a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
				a_spieler(g_akt_spieler).f_creature_speed = 0;
				a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
				p_nachricht(191, 3);
			}
			a_spieler(g_akt_spieler).f_creature_speed = 0;
		}
	}
	v_result = p_examinemouse();
	v_mmouse_x = p_mousex();
	v_mmouse_y = p_mousey();
	v_mmouse_links = p_mousebutton(1);
	v_mmouse_rechts = p_mousebutton(2);
	if (((v_kaempfen == 1) && (p_creature_lebenspunkte() > 0))) {
		a_spieler(g_akt_spieler).f_creature_speed = 0;
		if ((v_hydra == 1)) {
			v_angriff = 80;
			if (((p_random(99) + 1) < v_angriff)) {
				v_schaden = (p_random(15) + 1);
				p_creature_schaden(v_schaden);
			} else {
				p_nachricht(291, 3);
			}
		} else {
			v_xx = a_spieler(g_akt_spieler).f_creature_x;
			v_yy = (a_spieler(g_akt_spieler).f_creature_y + 1);
			if ((p_istmonster(v_xx, v_yy) == 1)) {
				g_von_ferne = 0;
				v_x = 5;
				v_y = 6;
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, -3);
				p_monster_angriff2(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y + 1));
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				if ((a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, 0);
				}
			}
			v_xx = a_spieler(g_akt_spieler).f_creature_x;
			v_yy = (a_spieler(g_akt_spieler).f_creature_y - 1);
			if ((p_istmonster(v_xx, v_yy) == 1)) {
				g_von_ferne = 0;
				v_x = 5;
				v_y = 4;
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				if ((a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, -3);
				}
				p_monster_angriff2(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y - 1));
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, 0);
			}
			v_xx = (a_spieler(g_akt_spieler).f_creature_x + 1);
			v_yy = a_spieler(g_akt_spieler).f_creature_y;
			if ((p_istmonster(v_xx, v_yy) == 1)) {
				g_von_ferne = 0;
				v_x = 6;
				v_y = 5;
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				if ((a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, -3);
				}
				p_monster_angriff2((a_spieler(g_akt_spieler).f_creature_x + 1), a_spieler(g_akt_spieler).f_creature_y);
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, 0);
			}
			v_xx = (a_spieler(g_akt_spieler).f_creature_x - 1);
			v_yy = a_spieler(g_akt_spieler).f_creature_y;
			if ((p_istmonster(v_xx, v_yy) == 1)) {
				g_von_ferne = 0;
				v_x = 4;
				v_y = 5;
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				if ((a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, -3);
				}
				p_monster_angriff2((a_spieler(g_akt_spieler).f_creature_x - 1), a_spieler(g_akt_spieler).f_creature_y);
				p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				p_draw_monster2(v_x, v_y, a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], 0, 0);
			}
		}
	}
	if ((v_schongemalt == 0)) {
		p_clearscreen(p_rgb(0, 0, 0));
		p_draw_screen2(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
		p_draw_screen5(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
		p_draw_screen6(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
		p_draw_screen8(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
		p_draw_creature(v_frame, 0);
		p_show_sight2();
		p_laby_rahmen();
		p_show_logo();
		p_show_varys2();
		p_show_buttons2();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		v_mouse_x_old = v_mmouse_x;
		v_mouse_y_old = v_mmouse_y;
	}
	if ((g_spielerwechsel == 1)) {
		p_delay(g_mydelay);
	}
}

static int32_t p_creature_lebenspunkte() {
	int16_t v_akt_lp = 0;
	v_akt_lp = a_spieler(g_akt_spieler).f_creature_lifepoints;
	if ((p_habich(168) > 0)) {
		v_akt_lp = (v_akt_lp + 1);
	}
	if ((p_habich(169) > 0)) {
		v_akt_lp = (v_akt_lp + 2);
	}
	if ((p_habich(170) > 0)) {
		v_akt_lp = (v_akt_lp + 3);
	}
	if ((p_habich(171) > 0)) {
		v_akt_lp = (v_akt_lp + 4);
	}
	return v_akt_lp;
}

static int32_t p_creature_schaden(int16_t v_wieviel) {
	int32_t v_wohin = 0;
	int32_t v_xmod = 0;
	int32_t v_xx = 0;
	int32_t v_ymod = 0;
	int32_t v_yy = 0;
	p_clipsprite(38, 0, 224, 32, 32);
	p_displaytransparentsprite(38, 160, 160);
	p_sound((p_random(6) + 1));
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	v_xx = (172 + (v_xmod * 32));
	v_yy = (168 + (v_ymod * 32));
	if ((v_wieviel < 10)) {
		v_xx = 172;
		v_yy = 168;
	}
	if ((v_wieviel >= 10)) {
		v_xx = 166;
		v_yy = 168;
	}
	if ((v_wieviel >= 100)) {
		v_xx = 163;
		v_yy = 168;
	}
	p_drawtext(v_xx, v_yy, p_str(v_wieviel), -1, 0);
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(g_mydelay);
	a_spieler(g_akt_spieler).f_creature_lifepoints = (a_spieler(g_akt_spieler).f_creature_lifepoints - v_wieviel);
	if ((p_creature_lebenspunkte() < 1)) {
		a_spieler(g_akt_spieler).f_creature_typ = 0;
		a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
		a_spieler(g_akt_spieler).f_creature_speed = 0;
		a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
		p_nachricht(191, 3);
	}
}

static int32_t p_creature_speed() {
	int16_t v_akt_speed = 0;
	v_akt_speed = a_spieler(g_akt_spieler).f_creature_maxspeed;
	if ((p_habich(169) > 0)) {
		v_akt_speed = (v_akt_speed + 1);
	}
	if ((p_habich(170) > 0)) {
		v_akt_speed = (v_akt_speed + 2);
	}
	if ((p_habich(171) > 0)) {
		v_akt_speed = (v_akt_speed + 3);
	}
	return v_akt_speed;
}

static int32_t p_credit(int32_t v_nummer, std::string v_text, int32_t v_abstand) {
	a_credits(v_nummer).f_text = v_text;
	a_credits(v_nummer).f_y = (a_credits((v_nummer - 1)).f_y + v_abstand);
}

static int32_t p_details(int16_t v_geg) {
	int16_t v_weg = 0;
	v_weg = 0;
	if ((a_gegenstand(v_geg).f_art == 1)) {
		v_weg = 1;
	}
	if ((a_gegenstand(v_geg).f_art == 13)) {
		v_weg = 1;
	}
	if (((a_gegenstand(v_geg).f_art >= 6) && (a_gegenstand(v_geg).f_art <= 11))) {
		v_weg = 1;
	}
	return v_weg;
}

static int32_t p_diagonal(int16_t v_akt_level) {
	int16_t v_gef = 0;
	int16_t v_hugo = 0;
	int32_t v_i = 0;
	int16_t v_j = 0;
	int16_t v_save = 0;
	int16_t v_save_anzahl = 0;
	int16_t v_save_duration = 0;
	int16_t v_save_feld = 0;
	int16_t v_save_graphic = 0;
	int16_t v_save_lebenspunkte = 0;
	int16_t v_save_lifepoints = 0;
	int16_t v_save_name = 0;
	int16_t v_save_name2 = 0;
	int16_t v_save_objekt = 0;
	int16_t v_save_status = 0;
	int16_t v_save_status2 = 0;
	int32_t v_xxx = 0;
	int16_t v_yyy = 0;
	v_j = 1;
	v_hugo = 1;
	do {
		v_i = (1 + v_hugo);
		do {
			v_save_feld = a_labyrinth(v_i, v_j).f_feld[v_akt_level];
			v_save_lebenspunkte = a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level];
			v_save_objekt = a_labyrinth(v_i, v_j).f_objekt[v_akt_level];
			v_save_status = a_labyrinth(v_i, v_j).f_status[v_akt_level];
			v_save_name = a_laby_monster(v_i, v_j).f_name[v_akt_level];
			v_save_graphic = a_laby_monster(v_i, v_j).f_graphic[v_akt_level];
			v_save_lifepoints = a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level];
			v_save_status = a_laby_monster(v_i, v_j).f_status[v_akt_level];
			v_save_duration = a_laby_monster(v_i, v_j).f_duration[v_akt_level];
			v_save_name2 = a_laby_item(v_i, v_j).f_name[v_akt_level];
			v_save_anzahl = a_laby_item(v_i, v_j).f_anzahl[v_akt_level];
			v_save_status2 = a_laby_item(v_i, v_j).f_status[v_akt_level];
			a_labyrinth(v_i, v_j).f_feld[v_akt_level] = a_labyrinth(v_j, v_i).f_feld[v_akt_level];
			a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level] = a_labyrinth(v_j, v_i).f_lebenspunkte[v_akt_level];
			a_labyrinth(v_i, v_j).f_objekt[v_akt_level] = a_labyrinth(v_j, v_i).f_objekt[v_akt_level];
			a_labyrinth(v_i, v_j).f_status[v_akt_level] = a_labyrinth(v_j, v_i).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_name[v_akt_level] = a_laby_monster(v_j, v_i).f_name[v_akt_level];
			a_laby_monster(v_i, v_j).f_graphic[v_akt_level] = a_laby_monster(v_j, v_i).f_graphic[v_akt_level];
			a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level] = a_laby_monster(v_j, v_i).f_lifepoints[v_akt_level];
			a_laby_monster(v_i, v_j).f_status[v_akt_level] = a_laby_monster(v_j, v_i).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_duration[v_akt_level] = a_laby_monster(v_j, v_i).f_duration[v_akt_level];
			a_laby_item(v_i, v_j).f_name[v_akt_level] = a_laby_item(v_j, v_i).f_name[v_akt_level];
			a_laby_item(v_i, v_j).f_anzahl[v_akt_level] = a_laby_item(v_j, v_i).f_anzahl[v_akt_level];
			a_laby_item(v_i, v_j).f_status[v_akt_level] = a_laby_item(v_j, v_i).f_status[v_akt_level];
			a_labyrinth(v_j, v_i).f_feld[v_akt_level] = v_save_feld;
			a_labyrinth(v_j, v_i).f_lebenspunkte[v_akt_level] = v_save_lebenspunkte;
			a_labyrinth(v_j, v_i).f_objekt[v_akt_level] = v_save_objekt;
			a_labyrinth(v_j, v_i).f_status[v_akt_level] = v_save_status;
			a_laby_monster(v_j, v_i).f_name[v_akt_level] = v_save_name;
			a_laby_monster(v_j, v_i).f_graphic[v_akt_level] = v_save_graphic;
			a_laby_monster(v_j, v_i).f_lifepoints[v_akt_level] = v_save_lifepoints;
			a_laby_monster(v_j, v_i).f_status[v_akt_level] = v_save_status;
			a_laby_monster(v_j, v_i).f_duration[v_akt_level] = v_save_duration;
			a_laby_item(v_j, v_i).f_name[v_akt_level] = v_save_name2;
			a_laby_item(v_j, v_i).f_anzahl[v_akt_level] = v_save_anzahl;
			a_laby_item(v_j, v_i).f_status[v_akt_level] = v_save_status2;
			v_i = (v_i + 1);
		} while (!(v_i > a_groesse(v_akt_level)));
		v_hugo = (v_hugo + 1);
		v_j = (v_j + 1);
	} while (!(v_j > a_groesse(v_akt_level)));
	for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
		for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
			if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 74)) {
				v_save = a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level];
				a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level] = a_labyrinth(v_i, v_j).f_objekt[v_akt_level];
				a_labyrinth(v_i, v_j).f_objekt[v_akt_level] = v_save;
			}
		}
	}
	v_yyy = 1;
	v_gef = 0;
	do {
		v_yyy = 0;
		do {
			if ((a_labyrinth(v_xxx, v_yyy).f_feld[v_akt_level] == 47)) {
				v_gef = 1;
			}
			v_yyy = (v_yyy + 1);
		} while (!((v_gef == 1) || (v_yyy > a_groesse(v_akt_level))));
		v_xxx = (v_xxx + 1);
	} while (!((v_gef == 1) || (v_xxx > a_groesse(v_akt_level))));
	a_raumx(v_akt_level) = (v_xxx - 2);
	a_raumy(v_akt_level) = (v_yyy - 2);
	v_save = a_ausgangy(v_akt_level);
	a_ausgangy(v_akt_level) = a_ausgangx(v_akt_level);
	a_ausgangx(v_akt_level) = v_save;
}

static int32_t p_dieb() {
	p_waehlen(5);
	p_waehlen(20);
	p_waehlen(71);
	p_waehlen(73);
	p_waehlen(75);
	p_waehlen(76);
	p_waehlen(79);
	p_waehlen(83);
	p_waehlen(85);
	p_waehlen(44);
	p_waehlen(94);
	p_waehlen(121);
	p_waehlen(132);
	p_waehlen(133);
	p_waehlen(124);
}

static int32_t p_dispelled() {
	int16_t v_disp = 0;
	v_disp = 0;
	if ((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 15) == 1) && (p_random(100) > 50)) && (p_habich(160) == 0))) {
		v_disp = 1;
	}
	return v_disp;
}

static int32_t p_display(std::string v_was) {
	int16_t v_but_x = 0;
	int16_t v_but_y = 0;
	int32_t v_i = 0;
	int32_t v_maxlines = 0;
	int16_t v_mmouse_links = 0;
	int16_t v_mmouse_rechts = 0;
	int16_t v_mmouse_x = 0;
	int16_t v_mmouse_y = 0;
	int32_t v_offset = 0;
	int16_t v_raus = 0;
	int16_t v_result = 0;
TypedList<std::string> ll_text;
	v_offset = 0;
	v_raus = 0;
	if (p_readfile(0, ("./" + v_was))) {
		while ((p_eof(0) == 0)) {
			p_addelement(&ll_text);
			LIST_CURRENT(&ll_text,std::string) = p_readstring(0);
		}
		p_closefile(0);
	}
	v_maxlines = p_countlist(&ll_text);
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_selectelement(&ll_text, v_offset);
		for (v_i = 1; v_i <= 30; v_i += 1) {
			p_drawbitmapfont(69, 20, ((v_i * 12) + 5), 6, 11, LIST_CURRENT(&ll_text,std::string));
			if ((p_nextelement(&ll_text) == 0)) {
				break;
			}
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		v_but_x = 590;
		v_but_y = 400;
		if (((((v_mmouse_x >= v_but_x) && (v_mmouse_x <= (v_but_x + 32))) && (v_mmouse_y >= v_but_y)) && (v_mmouse_y <= (v_but_y + 32)))) {
			p_clipsprite(6, 192, 0, 31, 31);
			p_displaytransparentsprite(6, v_but_x, v_but_y);
			if ((v_mmouse_links == 1)) {
				if ((v_offset > 0)) {
					v_offset = (v_offset - 1);
					if ((v_offset <= 0)) {
						v_offset = 0;
					}
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 31, 31);
			p_displaytransparentsprite(6, v_but_x, v_but_y);
		}
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaysprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaysprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaysprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaysprite(59, 624, 0);
		if (((((v_mmouse_x > v_but_x) && (v_mmouse_x < (v_but_x + 32))) && (v_mmouse_y > (v_but_y + 32))) && (v_mmouse_y < ((v_but_y + 32) + 32)))) {
			p_clipsprite(6, 224, 0, 31, 31);
			p_displaytransparentsprite(6, v_but_x, (v_but_y + 32));
			if ((v_mmouse_links == 1)) {
				v_offset = (v_offset + 1);
				if ((v_offset >= (v_maxlines - 30))) {
					v_offset = (v_maxlines - 30);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 31, 31);
			p_displaytransparentsprite(6, v_but_x, (v_but_y + 32));
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!((p_keyboardpushed(13) || (v_mmouse_rechts == 1)) || (v_raus == 1)));
	p_clearlist(&ll_text);
}

static int32_t p_doubleclick(int8_t v_main) {
	static int8_t v_combo;
	int32_t v_dcmmouse_links = 0;
	static int8_t v_output;
	int32_t v_result = 0;
	if ((v_main == 1)) {
		v_result = p_examinemouse();
		v_dcmmouse_links = p_mousebutton(1);
		if ((v_combo == 0)) {
			if ((v_dcmmouse_links == 1)) {
				v_combo += 1;
				v_output = 1;
			}
		}
		if ((v_combo == 1)) {
			if ((v_dcmmouse_links == 0)) {
				v_combo += 1;
				a_addelaymax(11) = 20;
				p_autodelay(11, 2, -2);
				v_output = 2;
			}
		}
		if ((v_combo == 3)) {
			if ((v_dcmmouse_links == 1)) {
				v_combo += 1;
				v_output = 3;
				a_addelaymax(11) = 20;
				p_autodelay(11, 2, -2);
			}
		}
	}
	if ((v_main == 1)) {
		p_autodelay(11, 1, -2);
	}
	if (p_autodelay(11, 4, -2)) {
		switch (v_combo) {
		case 2:
			v_combo += 1;
			a_addelaymax(11) = 100;
			p_autodelay(11, 2, -2);
			break;
		case 3:
			v_combo = 0;
			break;
		case 4:
			v_combo += 1;
			a_addelaymax(11) = 100;
			p_autodelay(11, 2, -2);
			break;
		case 5:
			v_combo = 0;
			break;
		}
		v_output = 0;
	}
	return v_output;
}

static int32_t p_draw_advancements() {
	int32_t v_aktuell = 0;
	int32_t v_i = 0;
	int32_t v_mauszauber = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_yy = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	v_x = 90;
	v_y = 101;
	p_drawtext(v_x, v_y, a_nachricht_text(50, (1 + g_sprache)), -1, 0);
	v_y = (v_y + g_yplus);
	p_drawtext(v_x, v_y, a_nachricht_text(51, (1 + g_sprache)), -1, 0);
	v_y = ((v_y + g_yplus) + g_yplus);
	v_result = p_examinemouse();
	v_mmouse_x = p_mousex();
	v_mmouse_y = p_mousey();
	v_mouse_links = p_mousebutton(1);
	v_mouse_rechts = p_mousebutton(2);
	v_mauszauber = 0;
	g_mauszauber2 = 0;
	v_aktuell = 1;
	v_yy = v_y;
	if (((v_mmouse_x > 25) && (v_mmouse_x < 350))) {
		for (v_i = 1; v_i <= g_anzz; v_i += 1) {
			if (((v_mmouse_y >= v_yy) && (v_mmouse_y <= (v_yy + g_yplus)))) {
				v_mauszauber = v_aktuell;
				if ((v_mouse_links == 1)) {
					g_mauszauber2 = v_aktuell;
				}
			}
			v_yy = (v_yy + g_yplus);
			v_aktuell = (v_aktuell + 1);
		}
	}
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 1)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(52, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_attack), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 2)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(53, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_dexterity), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 3)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(54, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_strength), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 4)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(55, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_maxlifepoints), -1, 0);
	p_drawtext((v_x + 165), v_y, ("+" + p_str(a_spieler(g_akt_spieler).f_lifegain)), -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 5)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(56, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_maxspeed), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 6)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(57, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_perception), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 7)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(58, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_luck_score), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 8)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(59, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_maxmana), -1, 0);
	p_drawtext((v_x + 165), v_y, ("+" + p_str(a_spieler(g_akt_spieler).f_managain)), -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 9)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(60, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_power_score), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	v_y = (v_y + g_yplus);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mauszauber == 10)) {
		p_frontcolor(p_rgb(1, 1, 255));
	}
	p_drawtext(v_x, v_y, a_nachricht_text(61, (1 + g_sprache)), -1, 0);
	p_drawtext((v_x + 135), v_y, p_str(a_spieler(g_akt_spieler).f_circle), -1, 0);
	p_drawtext((v_x + 165), v_y, "+1", -1, 0);
	p_stopdrawing();
}

static int32_t p_draw_character(int8_t v_face, int8_t v_frame, int16_t v_offset) {
	int16_t v_testfeld = 0;
	int16_t v_uebermalen = 0;
	v_uebermalen = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
		p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 0, 32, 32);
		p_displaytransparentsprite(34, 160, (160 + v_offset));
		v_uebermalen = 1;
	} else {
		if (p_habich(86)) {
			p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 128, 32, 32);
			p_displaytransparentsprite(34, 160, (160 + v_offset));
		} else {
			if (p_habich(87)) {
				p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 64, 32, 32);
				p_displaytransparentsprite(34, 160, (160 + v_offset));
				v_uebermalen = 1;
			} else {
				if (p_habich(88)) {
					p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 96, 32, 32);
					p_displaytransparentsprite(34, 160, (160 + v_offset));
				} else {
					if (p_habich(89)) {
						p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 32, 32, 32);
						p_displaytransparentsprite(34, 160, (160 + v_offset));
						v_uebermalen = 1;
					} else {
						if (p_habich(90)) {
							p_clipsprite(34, (((v_face * 32) * 2) + (v_frame * 32)), 160, 32, 32);
							p_displaytransparentsprite(34, 160, (160 + v_offset));
							v_uebermalen = 1;
						} else {
							p_clipsprite(0, (((v_face * 32) * 2) + (v_frame * 32)), ((a_spieler(g_akt_spieler).f_maennchen * 32) - 32), 32, 32);
							p_displaytransparentsprite(0, 160, (160 + v_offset));
							v_uebermalen = 1;
						}
					}
				}
			}
		}
	}
	if ((v_uebermalen == 1)) {
		v_testfeld = a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
		if ((((((v_testfeld == 53) || (v_testfeld == 161)) || (v_testfeld == 163)) || (v_testfeld == 160)) || (v_testfeld == 162))) {
			p_clipsprite(1, 192, 224, 32, 32);
			p_displaytransparentsprite(1, 160, (160 + v_offset));
		}
	}
}

static int32_t p_draw_creature(int8_t v_frame, int16_t v_offset) {
	if ((a_spieler(g_akt_spieler).f_creature_typ == 1)) {
		p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 256, 32, 32);
		p_displaytransparentsprite(34, 160, (160 + v_offset));
	} else {
		if ((a_spieler(g_akt_spieler).f_creature_typ == 2)) {
			p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 192, 32, 32);
			p_displaytransparentsprite(34, 160, (160 + v_offset));
		} else {
			if ((a_spieler(g_akt_spieler).f_creature_typ == 3)) {
				p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 352, 32, 32);
				p_displaytransparentsprite(34, 160, (160 + v_offset));
			} else {
				if ((a_spieler(g_akt_spieler).f_creature_typ == 4)) {
					p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 384, 32, 32);
					p_displaytransparentsprite(34, 160, (160 + v_offset));
				} else {
					if ((a_spieler(g_akt_spieler).f_creature_typ == 5)) {
						p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 416, 32, 32);
						p_displaytransparentsprite(34, 160, (160 + v_offset));
					} else {
						if ((a_spieler(g_akt_spieler).f_creature_typ == 6)) {
							p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 320, 32, 32);
							p_displaytransparentsprite(34, 160, (160 + v_offset));
						} else {
							if ((a_spieler(g_akt_spieler).f_creature_typ == 7)) {
								p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 224, 32, 32);
								p_displaytransparentsprite(34, 160, (160 + v_offset));
							} else {
								if ((a_spieler(g_akt_spieler).f_creature_typ == 8)) {
									p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 288, 32, 32);
									p_displaytransparentsprite(34, 160, (160 + v_offset));
								} else {
									if ((a_spieler(g_akt_spieler).f_creature_typ == 9)) {
										p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 160, 32, 32);
										p_displaytransparentsprite(34, 160, (160 + v_offset));
									} else {
										if ((a_spieler(g_akt_spieler).f_creature_typ == 10)) {
											p_clipsprite(0, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), ((a_spieler(g_akt_spieler).f_maennchen * 32) - 32), 32, 32);
											p_displaytransparentsprite(0, 160, (160 + v_offset));
										} else {
											if ((a_spieler(g_akt_spieler).f_creature_typ == 11)) {
												p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 96, 32, 32);
												p_displaytransparentsprite(34, 160, (160 + v_offset));
											} else {
												if ((a_spieler(g_akt_spieler).f_creature_typ == 12)) {
													p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 480, 32, 32);
													p_displaytransparentsprite(34, 160, (160 + v_offset));
												} else {
													if ((a_spieler(g_akt_spieler).f_creature_typ == 13)) {
														p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 512, 32, 32);
														p_displaytransparentsprite(34, 160, (160 + v_offset));
													} else {
														if ((a_spieler(g_akt_spieler).f_creature_typ == 14)) {
															p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 544, 32, 32);
															p_displaytransparentsprite(34, 160, (160 + v_offset));
														} else {
															if ((a_spieler(g_akt_spieler).f_creature_typ == 15)) {
																p_clipsprite(34, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 576, 32, 32);
																p_displaytransparentsprite(34, 160, (160 + v_offset));
															} else {
																if ((a_spieler(g_akt_spieler).f_creature_typ == 20)) {
																	p_clipsprite(0, (((a_spieler(g_akt_spieler).f_creature_heading * 32) * 2) + (v_frame * 32)), 608, 32, 32);
																	p_displaytransparentsprite(0, 160, (160 + v_offset));
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
	}
}

static int32_t p_draw_item(int16_t v_name, int16_t v_x, int16_t v_y, int8_t v_offset_x, int8_t v_offset_y) {
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	if ((((a_skills(123, g_akt_spieler).f_gewaehlt == 1) && (v_name >= 65)) && (v_name <= 75))) {
	} else {
		v_sprite_x = v_name;
		v_sprite_y = 0;
		if ((v_sprite_x > 16)) {
			do {
				v_sprite_y = (v_sprite_y + 1);
				v_sprite_x = (v_sprite_x - 16);
			} while (!(v_sprite_x < 17));
		}
		p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(8, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
	}
}

static int32_t p_draw_monster(int16_t v_name, int16_t v_nr, int16_t v_x, int16_t v_y, int8_t v_offset_x, int8_t v_offset_y) {
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int16_t v_testfeld = 0;
	if ((((p_hat_eigenschaft2(v_name, 19) == 1) && (p_habich(109) == 0)) && (p_habich(121) == 0))) {
	} else {
		v_sprite_x = v_nr;
		v_sprite_y = 0;
		if ((v_sprite_x > 10)) {
			do {
				v_sprite_y = (v_sprite_y + 1);
				v_sprite_x = (v_sprite_x - 10);
			} while (!(v_sprite_x < 11));
		}
		p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(9, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
		v_testfeld = a_laby_monster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_status[a_spieler(g_akt_spieler).f_level];
		if ((v_testfeld == 1)) {
			p_clipsprite(47, 0, 0, 8, 9);
			p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
		} else {
			if ((v_testfeld == 2)) {
				p_clipsprite(47, 8, 0, 8, 9);
				p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
			} else {
				if ((v_testfeld == 3)) {
					p_clipsprite(47, 16, 0, 8, 9);
					p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
				} else {
					if ((v_testfeld == 4)) {
						p_clipsprite(47, 24, 0, 8, 9);
						p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
					} else {
						if ((v_testfeld == 5)) {
							p_clipsprite(47, 32, 0, 8, 9);
							p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
						} else {
							if ((v_testfeld == 6)) {
								p_clipsprite(37, 0, 448, 32, 32);
								p_displaytransparentsprite(37, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
							}
						}
					}
				}
			}
		}
	}
}

static int32_t p_draw_monster2(int16_t v_x, int16_t v_y, int16_t v_nr, int16_t v_offset_x, int16_t v_offset_y) {
	int32_t v_name = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int16_t v_testfeld = 0;
	if ((p_hat_eigenschaft2(v_name, 19) == 1)) {
	} else {
		v_sprite_x = v_nr;
		v_sprite_y = 0;
		if ((v_sprite_x > 10)) {
			do {
				v_sprite_y = (v_sprite_y + 1);
				v_sprite_x = (v_sprite_x - 10);
			} while (!(v_sprite_x < 11));
		}
		p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(9, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
		v_testfeld = a_laby_monster(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_status[a_spieler(g_akt_spieler).f_level];
		if ((v_testfeld == 1)) {
			p_clipsprite(47, 0, 0, 8, 9);
			p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
		} else {
			if ((v_testfeld == 2)) {
				p_clipsprite(47, 8, 0, 8, 9);
				p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
			} else {
				if ((v_testfeld == 3)) {
					p_clipsprite(47, 16, 0, 8, 9);
					p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
				} else {
					if ((v_testfeld == 4)) {
						p_clipsprite(47, 24, 0, 8, 9);
						p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
					} else {
						if ((v_testfeld == 5)) {
							p_clipsprite(47, 32, 0, 8, 9);
							p_displaytransparentsprite(47, (((v_x * 32) + v_offset_x) + 23), ((v_y * 32) + v_offset_y));
						} else {
							if ((v_testfeld == 6)) {
								p_clipsprite(37, 0, 448, 32, 32);
								p_displaytransparentsprite(37, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
							}
						}
					}
				}
			}
		}
	}
}

static int32_t p_draw_screen(int8_t v_x_offset, int8_t v_y_offset) {
	int32_t v_okay = 0;
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int32_t v_uebermalen = 0;
	int32_t v_x = 0;
	int32_t v_xx = 0;
	int32_t v_y = 0;
	p_erstelle_matrix(1);
	v_radius = p_radius();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
				if ((((((((((v_testfeld != 1) && (v_testfeld != 20)) && (v_testfeld != 9)) && (v_testfeld != 67)) && (v_testfeld != 68)) && (v_testfeld != 75)) && (v_testfeld != 6)) && (v_testfeld != 93)) && (v_testfeld != 69))) {
					p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
				if ((a_laby_item(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
				for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
					if ((v_xx != g_akt_spieler)) {
						if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) == a_spieler(v_xx).f_character_x) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) == a_spieler(v_xx).f_character_y))) {
							if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level))) {
								v_okay = 0;
								v_uebermalen = 0;
								if (((a_spieler(v_xx).f_fluch == 23) && (v_okay == 0))) {
									v_uebermalen = 1;
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 0, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((p_hater(86, v_xx) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 128, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((p_hater(87, v_xx) && (v_okay == 0))) {
									v_uebermalen = 1;
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 64, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((p_hater(88, v_xx) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 96, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((p_hater(89, v_xx) && (v_okay == 0))) {
									v_uebermalen = 1;
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 32, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((p_hater(90, v_xx) && (v_okay == 0))) {
									v_uebermalen = 1;
									p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 160, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if ((v_okay == 0)) {
									v_uebermalen = 1;
									p_clipsprite(0, ((a_spieler(v_xx).f_face * 32) * 2), ((a_spieler(v_xx).f_maennchen * 32) - 32), 32, 32);
									p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								}
								if ((v_uebermalen == 1)) {
									v_testfeld = a_labyrinth(a_spieler(v_xx).f_character_x, a_spieler(v_xx).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
									if ((((((v_testfeld == 53) || (v_testfeld == 161)) || (v_testfeld == 163)) || (v_testfeld == 160)) || (v_testfeld == 162))) {
										p_clipsprite(1, 192, 224, 32, 32);
										p_displaytransparentsprite(1, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									}
								}
							}
						}
					}
				}
				for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
					if ((a_spieler(v_xx).f_creature_typ > 0)) {
						if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) == a_spieler(v_xx).f_creature_x) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) == a_spieler(v_xx).f_creature_y))) {
							v_okay = 0;
							if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level))) {
								if (((a_spieler(v_xx).f_creature_typ == 1) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 256, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 2) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 192, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 3) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 352, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 4) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 384, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 5) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 416, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 6) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 320, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 7) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 224, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 8) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 288, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 9) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 160, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 10) && (v_okay == 0))) {
									p_clipsprite(0, ((a_spieler(v_xx).f_creature_heading * 32) * 2), ((a_spieler(v_xx).f_maennchen * 32) - 32), 32, 32);
									p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 11) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 96, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 12) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 480, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 13) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 512, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 14) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 544, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 15) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 576, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 20) && (v_okay == 0))) {
									p_clipsprite(0, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 608, 32, 32);
									p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
							}
						}
					}
				}
			}
		}
	}
}

static int32_t p_draw_screen2(int8_t v_x_offset, int8_t v_y_offset) {
	int32_t v_okay = 0;
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int32_t v_uebermalen = 0;
	int8_t v_x = 0;
	int32_t v_xx = 0;
	int8_t v_y = 0;
	p_erstelle_matrix(2);
	v_radius = p_radius2();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
				if ((((((((((v_testfeld != 1) && (v_testfeld != 20)) && (v_testfeld != 9)) && (v_testfeld != 67)) && (v_testfeld != 68)) && (v_testfeld != 75)) && (v_testfeld != 6)) && (v_testfeld != 93)) && (v_testfeld != 69))) {
					p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
				if ((a_laby_item(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
				for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
					if (((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) == a_spieler(v_xx).f_character_x) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) == a_spieler(v_xx).f_character_y))) {
						if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level))) {
							v_okay = 0;
							v_uebermalen = 0;
							if (((a_spieler(v_xx).f_fluch == 23) && (v_okay == 0))) {
								v_uebermalen = 1;
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 0, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((p_hater(86, v_xx) && (v_okay == 0))) {
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 128, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((p_hater(87, v_xx) && (v_okay == 0))) {
								v_uebermalen = 1;
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 64, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((p_hater(88, v_xx) && (v_okay == 0))) {
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 96, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((p_hater(89, v_xx) && (v_okay == 0))) {
								v_uebermalen = 1;
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 32, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((p_hater(90, v_xx) && (v_okay == 0))) {
								v_uebermalen = 1;
								p_clipsprite(34, ((a_spieler(v_xx).f_face * 32) * 2), 160, 32, 32);
								p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								v_okay = 1;
							}
							if ((v_okay == 0)) {
								v_uebermalen = 1;
								p_clipsprite(0, ((a_spieler(v_xx).f_face * 32) * 2), ((a_spieler(v_xx).f_maennchen * 32) - 32), 32, 32);
								p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
							}
							if ((v_uebermalen == 1)) {
								v_testfeld = a_labyrinth(a_spieler(v_xx).f_character_x, a_spieler(v_xx).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
								if ((((((v_testfeld == 53) || (v_testfeld == 161)) || (v_testfeld == 163)) || (v_testfeld == 160)) || (v_testfeld == 162))) {
									p_clipsprite(1, 192, 224, 32, 32);
									p_displaytransparentsprite(1, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
								}
							}
						}
					}
				}
				for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
					if (((a_spieler(v_xx).f_creature_typ > 0) && (g_akt_spieler != v_xx))) {
						if (((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) == a_spieler(v_xx).f_creature_x) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) == a_spieler(v_xx).f_creature_y))) {
							if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level))) {
								v_okay = 0;
								if (((a_spieler(v_xx).f_creature_typ == 1) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 256, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 2) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 192, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 3) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 352, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 4) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 384, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 5) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 416, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 6) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 320, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 7) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 224, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 8) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 288, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 9) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 160, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 10) && (v_okay == 0))) {
									p_clipsprite(0, ((a_spieler(v_xx).f_creature_heading * 32) * 2), ((a_spieler(v_xx).f_maennchen * 32) - 32), 32, 32);
									p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 11) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 96, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 12) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 480, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 13) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 512, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 14) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 544, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 15) && (v_okay == 0))) {
									p_clipsprite(34, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 576, 32, 32);
									p_displaytransparentsprite(34, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
								if (((a_spieler(v_xx).f_creature_typ == 20) && (v_okay == 0))) {
									p_clipsprite(0, ((a_spieler(v_xx).f_creature_heading * 32) * 2), 608, 32, 32);
									p_displaytransparentsprite(0, ((v_x * 32) + v_x_offset), ((v_y * 32) + v_y_offset));
									v_okay = 1;
								}
							}
						}
					}
				}
			}
		}
	}
}

static int32_t p_draw_screen3(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((a_matrix((v_x + 1), (v_y + 1)) <= v_radius)) {
				if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) < 1) || (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) < 1))) {
					p_draw_tile(a_mit_was(a_spieler(g_akt_spieler).f_level), v_x, v_y, v_x_offset, v_y_offset);
				} else {
					v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if (((v_testfeld == a_mit_was(a_spieler(g_akt_spieler).f_level)) || (v_testfeld == 20))) {
						p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
					}
				}
			}
		}
	}
}

static int32_t p_draw_screen4(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
				if ((((((((v_testfeld == 9) || (v_testfeld == 67)) || (v_testfeld == 68)) || (v_testfeld == 6)) || (v_testfeld == 75)) || (v_testfeld == 93)) || (v_testfeld == 69))) {
					if (((v_testfeld == 75) && (a_skills(79, g_akt_spieler).f_gewaehlt == 1))) {
						p_setlaby(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y), a_spieler(g_akt_spieler).f_level, 69, 0, 0, 0);
					}
					p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
			}
		}
	}
}

static int32_t p_draw_screen5(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius2();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((a_matrix((v_x + 1), (v_y + 1)) <= v_radius)) {
				if (((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) < 1) || (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) < 1))) {
					p_draw_tile(a_mit_was(a_spieler(g_akt_spieler).f_level), v_x, v_y, v_x_offset, v_y_offset);
				} else {
					v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if (((v_testfeld == a_mit_was(a_spieler(g_akt_spieler).f_level)) || (v_testfeld == 20))) {
						p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
					}
				}
			}
		}
	}
}

static int32_t p_draw_screen6(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius2();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
				if ((((((((v_testfeld == 9) || (v_testfeld == 67)) || (v_testfeld == 68)) || (v_testfeld == 6)) || (v_testfeld == 75)) || (v_testfeld == 93)) || (v_testfeld == 69))) {
					p_draw_tile(a_labyrinth(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
			}
		}
	}
}

static int32_t p_draw_screen7(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				if ((a_laby_monster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
			}
		}
	}
}

static int32_t p_draw_screen8(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_radius = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	v_radius = p_radius2();
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if ((((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) > 0)) && (a_matrix((v_x + 1), (v_y + 1)) <= v_radius))) {
				if ((a_laby_monster(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y)).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
				}
			}
		}
	}
}

static int32_t p_draw_screen_total() {
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_ok_button = 0;
	int32_t v_result = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_draw_screen(0, 0);
	p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
	v_result = p_examinemouse();
	v_mouse_x = p_mousex();
	v_mouse_y = p_mousey();
	v_mouse_links = 0;
	v_mouse_rechts = 0;
	v_mouse_links = p_mousebutton(1);
	v_mouse_rechts = p_mousebutton(2);
	v_ok_button = 0;
	p_clipsprite(8, 192, 288, 32, 32);
	p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
	p_flipbuffers(1);
}

static int32_t p_draw_skills(int32_t v_spalte, int32_t v_zeile, int32_t v_pos_aktuell, int32_t v_besch, int32_t v_punkte) {
	int32_t v_aktuell = 0;
	int32_t v_b = 0;
	int32_t v_g = 0;
	int32_t v_j_art = 0;
	int32_t v_lighting = 0;
	int32_t v_r = 0;
	int32_t v_shortcut_temp = 0;
	int32_t v_spalte_temp = 0;
	int16_t v_temp = 0;
	int32_t v_upsidedown_offset = 0;
	int32_t v_welche = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_zeile_temp = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_clipsprite(55, 0, 0, 640, 17);
	p_displaytransparentsprite(55, 0, 0);
	p_clipsprite(63, 0, 0, 640, 17);
	p_displaysprite(63, 0, 33);
	p_clipsprite(58, 0, 0, 640, 17);
	p_displaytransparentsprite(58, 0, 464);
	p_clipsprite(56, 0, 0, 17, 480);
	p_displaytransparentsprite(56, 0, 0);
	p_clipsprite(59, 0, 0, 17, 480);
	p_displaytransparentsprite(59, 624, 0);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 1));
	p_drawtext(170, 15, p_nachricht4(114), -1, 0);
	p_drawtext(500, 15, (p_str(g_akt_spieler) + ") :"), -1, 0);
	p_stopdrawing();
	a_skilltyp_range.dim(10);
	a_skilltyp_offset.dim(10);
	g_skillrow_offset = 13;
	v_upsidedown_offset = 22;
	a_skilltyp_offset(0) = 0;
	a_skilltyp_range(0) = 66;
	a_skilltyp_range(1) = 28;
	a_skilltyp_range(2) = 4;
	a_skilltyp_range(3) = 33;
	a_skilltyp_range(4) = 13;
	a_skilltyp_range(5) = 18;
	a_skilltyp_range(6) = 7;
	a_skilltyp_range(7) = 10;
	a_skilltyp_range(8) = 16;
	a_skilltyp_range(9) = 3;
	a_skilltyp_offset(1) = 0;
	a_skilltyp_offset(2) = ((a_skilltyp_offset(1) + a_skilltyp_range(1)) + 1);
	a_skilltyp_offset(3) = ((a_skilltyp_offset(2) + a_skilltyp_range(2)) + 1);
	a_skilltyp_offset(4) = ((a_skilltyp_offset(3) + a_skilltyp_range(3)) + 1);
	a_skilltyp_offset(5) = ((a_skilltyp_offset(4) + a_skilltyp_range(4)) + 1);
	a_skilltyp_offset(6) = ((a_skilltyp_offset(5) + a_skilltyp_range(5)) + 1);
	a_skilltyp_offset(7) = ((a_skilltyp_offset(6) + a_skilltyp_range(6)) + 1);
	a_skilltyp_offset(8) = ((a_skilltyp_offset(7) + a_skilltyp_range(7)) + 1);
	a_skilltyp_offset(9) = ((a_skilltyp_offset(8) + a_skilltyp_range(8)) + 1);
	v_x = 70;
	v_y = 50;
	for (v_shortcut_temp = -1; v_shortcut_temp <= 9; v_shortcut_temp += 1) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		v_temp = 1;
		if ((v_shortcut_temp == 0)) {
			v_welche = 0;
			p_frontcolor(p_rgb(255, 255, 255));
			v_j_art = 1;
		}
		if ((v_shortcut_temp == 1)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(255, 1, 1));
			v_j_art = 1;
		}
		v_temp = (v_temp + 28);
		if ((v_shortcut_temp == 2)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(138, 11, 88));
			v_j_art = 8;
		}
		v_temp = (v_temp + 4);
		if ((v_shortcut_temp == 3)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(255, 1, 255));
			v_j_art = 2;
		}
		v_temp = (v_temp + 33);
		if ((v_shortcut_temp == 4)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(1, 1, 255));
			v_j_art = 4;
		}
		v_temp = (v_temp + 13);
		if ((v_shortcut_temp == 5)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(1, 255, 1));
			v_j_art = 3;
		}
		v_temp = (v_temp + 18);
		if ((v_shortcut_temp == 6)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(1, 255, 255));
			v_j_art = 6;
		}
		v_temp = (v_temp + 7);
		if ((v_shortcut_temp == 7)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(130, 115, 32));
			v_j_art = 7;
		}
		v_temp = (v_temp + 10);
		if ((v_shortcut_temp == 8)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(150, 150, 150));
			v_j_art = 5;
		}
		v_temp = (v_temp + 16);
		if ((v_shortcut_temp == 9)) {
			v_welche = v_temp;
			p_frontcolor(p_rgb(97, 56, 36));
			v_j_art = 9;
		}
		if ((v_shortcut_temp >= 1)) {
			v_welche = a_skilltyp_offset(v_shortcut_temp);
		}
		if ((v_shortcut_temp >= 1)) {
			p_drawtext(v_x, v_y, a_skills(v_welche, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
		}
		if ((v_shortcut_temp == 0)) {
			p_drawtext(v_x, v_y, a_nachricht_text(639, (1 + g_sprache)), -1, 0);
		}
		p_frontcolor(p_rgb(v_r, v_g, v_b));
		p_stopdrawing();
		if ((v_shortcut_temp >= 1)) {
			if ((v_shortcut_temp != g_currentstyp)) {
				p_clipsprite(11, ((v_j_art * 16) - 16), 1, 15, 15);
				p_displaysprite(11, (v_x - 20), (v_y + 2));
			}
			if ((v_shortcut_temp == g_currentstyp)) {
				p_clipsprite(11, ((v_j_art * 16) - 16), 33, 15, 15);
				p_displaysprite(11, (v_x - 20), (v_y + 2));
			}
		}
		if ((v_shortcut_temp == 0)) {
			if ((v_shortcut_temp != g_currentstyp)) {
				p_clipsprite(11, 192, 1, 15, 15);
				p_displaysprite(11, (v_x - 20), (v_y + 2));
			}
			if ((v_shortcut_temp == g_currentstyp)) {
				p_clipsprite(11, 192, 33, 15, 15);
				p_displaysprite(11, (v_x - 20), (v_y + 2));
			}
		}
		v_y = (v_y + 14);
	}
	v_welche = a_skilltyp_offset(g_currentstyp);
	v_x = 70;
	v_y = 50;
	v_aktuell = 1;
	if ((g_currentstyp == 0)) {
		v_welche = (27 * (g_skills_menu - 1));
	}
	v_aktuell = 0;
	for (v_spalte_temp = 1; v_spalte_temp <= 3; v_spalte_temp += 1) {
		for (v_zeile_temp = 1; v_zeile_temp <= 27; v_zeile_temp += 1) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			if (((v_zeile_temp < g_skillrow_offset) && (v_spalte_temp == 1))) {
				v_zeile_temp = g_skillrow_offset;
				v_y = (50 + (14 * (g_skillrow_offset - 1)));
				v_aktuell = g_skillrow_offset;
			}
			p_frontcolor(p_rgb(v_r, v_g, v_b));
			if ((v_besch == 2)) {
				if ((a_skills(v_pos_aktuell, g_akt_spieler).f_kosten != 0)) {
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawtext(30, 430, (((a_skills(v_pos_aktuell, g_akt_spieler).f_beschreibung_1[(1 + g_sprache)] + " (") + p_str(a_skills(v_pos_aktuell, g_akt_spieler).f_kosten)) + " CP)"), -1, 0);
					p_drawtext(30, 445, a_skills(v_pos_aktuell, g_akt_spieler).f_beschreibung_2[(1 + g_sprache)], -1, 0);
					p_frontcolor(p_rgb(v_r, v_g, v_b));
				}
			} else {
				if ((((v_spalte_temp == v_spalte) && (v_zeile_temp == v_zeile)) && (a_skills(v_welche, g_akt_spieler).f_kosten != 0))) {
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawtext(30, 430, (((a_skills(v_welche, g_akt_spieler).f_beschreibung_1[(1 + g_sprache)] + " (") + p_str(a_skills(v_welche, g_akt_spieler).f_kosten)) + " CP)"), -1, 0);
					p_drawtext(30, 445, a_skills(v_welche, g_akt_spieler).f_beschreibung_2[(1 + g_sprache)], -1, 0);
				}
			}
			if ((v_welche > a_skilltyp_offset(1))) {
				v_r = 255;
				v_g = 1;
				v_b = 1;
				v_j_art = 1;
			}
			if ((v_welche > a_skilltyp_offset(2))) {
				v_r = 138;
				v_g = 11;
				v_b = 88;
				v_j_art = 8;
			}
			if ((v_welche > a_skilltyp_offset(3))) {
				v_r = 255;
				v_g = 1;
				v_b = 255;
				v_j_art = 2;
			}
			if ((v_welche > a_skilltyp_offset(4))) {
				v_r = 1;
				v_g = 1;
				v_b = 255;
				v_j_art = 4;
			}
			if ((v_welche > a_skilltyp_offset(5))) {
				v_r = 1;
				v_g = 255;
				v_b = 1;
				v_j_art = 3;
			}
			if ((v_welche > a_skilltyp_offset(6))) {
				v_r = 1;
				v_g = 255;
				v_b = 255;
				v_j_art = 6;
			}
			if ((v_welche > a_skilltyp_offset(7))) {
				v_r = 130;
				v_g = 115;
				v_b = 32;
				v_j_art = 7;
			}
			if ((v_welche > a_skilltyp_offset(8))) {
				v_r = 150;
				v_g = 150;
				v_b = 150;
				v_j_art = 5;
			}
			if ((v_welche > a_skilltyp_offset(9))) {
				v_r = 97;
				v_g = 56;
				v_b = 36;
				v_j_art = 9;
			}
			p_frontcolor(p_rgb(v_r, v_g, v_b));
			if ((a_skills(v_welche, g_akt_spieler).f_kosten == 0)) {
				p_frontcolor(p_rgb(255, 255, 1));
			}
			if ((((v_spalte_temp == v_spalte) && (v_zeile_temp == v_zeile)) || (v_welche == v_pos_aktuell))) {
				p_frontcolor(p_rgb(255, 255, 255));
				v_lighting = 1;
			} else {
				v_lighting = 0;
			}
			p_drawtext(v_x, v_y, a_skills(v_welche, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
			p_frontcolor(p_rgb(v_r, v_g, v_b));
			p_stopdrawing();
			if ((a_skills(v_welche, g_akt_spieler).f_gelocked == 0)) {
				if (((a_skills(v_welche, g_akt_spieler).f_kosten != 0) && (a_skills(v_welche, g_akt_spieler).f_gewaehlt == 0))) {
					p_clipsprite(11, ((v_j_art * 16) - 16), 1, 15, 15);
					p_displaytransparentsprite(11, (v_x - 20), (v_y + 2));
				}
				if (((a_skills(v_welche, g_akt_spieler).f_kosten != 0) && (a_skills(v_welche, g_akt_spieler).f_gewaehlt == 1))) {
					p_clipsprite(11, ((v_j_art * 16) - 16), 33, 15, 15);
					p_displaytransparentsprite(11, (v_x - 20), (v_y + 2));
				}
			}
			v_y = (v_y + 14);
			v_welche = (v_welche + 1);
			v_aktuell = (v_aktuell + 1);
			if (((v_welche > 140) || (v_aktuell > (a_skilltyp_range(g_currentstyp) + g_skillrow_offset)))) {
				goto L_raushier;
			}
		}
		v_x = (v_x + 180);
		v_y = 50;
	}
L_raushier: ;
}

static int32_t p_draw_small_monster(int16_t v_nr, int16_t v_x, int16_t v_y, int8_t v_offset_x, int8_t v_offset_y) {
	int16_t v_zw = 0;
	g_sprite_x = v_nr;
	g_sprite_y = 0;
	if ((g_sprite_x > 10)) {
		do {
			g_sprite_y = (g_sprite_y + 1);
			g_sprite_x = (g_sprite_x - 10);
		} while (!(g_sprite_x < 11));
	}
	if ((g_sprite_x == 10)) {
		g_sprite_x = 0;
		g_sprite_y = (g_sprite_y + 1);
	}
	if (((g_karten_typ == 2) && (a_laby_monster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_name[a_spieler(g_akt_spieler).f_level] > 0))) {
		if ((p_hat_eigenschaft2(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level], 19) == 0)) {
			p_clipsprite(23, ((g_sprite_x * 16) - 16), (g_sprite_y * 16), 16, 16);
			p_displaytransparentsprite(23, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
		}
	}
}

static int32_t p_draw_small_tile(int16_t v_nr, int16_t v_x, int16_t v_y, int8_t v_offset_x, int8_t v_offset_y) {
	int16_t v_zw = 0;
	if (((v_nr == 75) || ((v_nr >= 22) && (v_nr <= 30)))) {
		v_nr = a_inhalt(a_spieler(g_akt_spieler).f_level);
	}
	if ((v_nr == 20)) {
		v_nr = a_mit_was(a_spieler(g_akt_spieler).f_level);
	}
	if (((v_nr == 2) && (g_karten_typ == 5))) {
		g_sprite_x = 2;
		g_sprite_y = 0;
		p_clipsprite(22, (g_sprite_x * 16), (g_sprite_y * 16), 16, 16);
		p_displaysprite(22, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
	}
	g_sprite_x = v_nr;
	g_sprite_y = 0;
	if ((g_sprite_x > 10)) {
		do {
			g_sprite_y = (g_sprite_y + 1);
			g_sprite_x = (g_sprite_x - 10);
		} while (!(g_sprite_x < 11));
	}
	if ((g_sprite_x == 10)) {
		g_sprite_x = 0;
		g_sprite_y = (g_sprite_y + 1);
	}
	if ((v_nr == 1)) {
		p_clipsprite(22, (g_sprite_x * 16), (g_sprite_y * 16), 16, 16);
		p_displaysprite(22, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
	}
	if (((g_karten_typ == 2) || (g_schriftrolle == 1))) {
		p_clipsprite(22, (g_sprite_x * 16), (g_sprite_y * 16), 16, 16);
		p_displaysprite(22, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
	}
	if (((v_nr == 8) && (g_karten_typ == 3))) {
		g_sprite_x = 8;
		g_sprite_y = 0;
		p_clipsprite(22, (g_sprite_x * 16), (g_sprite_y * 16), 16, 16);
		p_displaysprite(22, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
	}
	if (((v_nr == 7) && (g_karten_typ == 4))) {
		g_sprite_x = 7;
		g_sprite_y = 0;
		p_clipsprite(22, (g_sprite_x * 16), (g_sprite_y * 16), 16, 16);
		p_displaysprite(22, ((v_x * 16) + v_offset_x), ((v_y * 16) + v_offset_y));
	}
}

static int32_t p_draw_tile(int16_t v_nr, int16_t v_x, int16_t v_y, int8_t v_offset_x, int8_t v_offset_y) {
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int16_t v_zw = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	if (((v_nr == 75) || ((v_nr >= 22) && (v_nr <= 30)))) {
		v_nr = a_inhalt(a_spieler(g_akt_spieler).f_level);
	}
	if ((v_nr == 20)) {
		v_nr = a_mit_was(a_spieler(g_akt_spieler).f_level);
	}
	p_clipsprite(1, (v_inhalt_x * 32), (v_inhalt_y * 32), 32, 32);
	p_displaysprite(1, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
	v_sprite_x = v_nr;
	v_sprite_y = 0;
	if ((v_sprite_x > 10)) {
		do {
			v_sprite_y = (v_sprite_y + 1);
			v_sprite_x = (v_sprite_x - 10);
		} while (!(v_sprite_x < 11));
	}
	if ((v_sprite_x == 10)) {
		v_sprite_x = 0;
		v_sprite_y = (v_sprite_y + 1);
	}
	p_clipsprite(1, (v_sprite_x * 32), (v_sprite_y * 32), 32, 32);
	p_displaytransparentsprite(1, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
	if ((v_nr == 9)) {
		p_clipsprite(1, 288, 0, 32, 32);
		p_displaytransparentsprite(1, ((v_x * 32) + v_offset_x), ((v_y * 32) + v_offset_y));
	}
}

static int32_t p_drawbitmapfont(int32_t v_s, int32_t v_x, int32_t v_y, int32_t v_w, int32_t v_h, std::string v_t) {
	int32_t v_a = 0;
	uint8_t v_b = 0;
	v_a = 0;
	do {
		v_b = p_peekc(((char *) v_t.data() + v_a));
		p_clipsprite(v_s, ((v_b - 32) * v_w), 0, v_w, v_h);
		p_displaytransparentsprite(v_s, (v_x + (v_a * v_w)), v_y);
		v_a += 1;
	} while (!(v_b == 0));
}

static int32_t p_drawbuttonnotpressed(int32_t v_s, int32_t v_x, int32_t v_y, int32_t v_w, int32_t v_h, std::string v_t) {
	p_startdrawing(p_screenoutput());
	p_line((v_x - 6), (v_y - 6), ((p_len(v_t) * v_w) + 10), 0, 11184810);
	p_line((v_x - 6), ((v_y - 6) + v_h), ((p_len(v_t) * v_w) + 10), 0, 3355443);
	p_line((v_x - 6), (v_y - 6), 0, v_h, 11184810);
	p_line((((v_x - 6) + (p_len(v_t) * v_w)) + 10), (v_y - 6), 0, v_h, 3355443);
	p_box((((v_x - 6) + (p_len(v_t) * v_w)) + 10), (v_y - 6), 0, v_h, 8947848);
	p_stopdrawing();
	p_drawbitmapfont(v_s, v_x, v_y, v_w, v_h, v_t);
}

static int32_t p_drawbuttonpressed(int32_t v_s, int32_t v_x, int32_t v_y, int32_t v_w, int32_t v_h, std::string v_t) {
	p_startdrawing(p_screenoutput());
	p_box((v_x - 6), (v_y - 6), ((p_len(v_t) * v_w) + 10), v_h, 4473924);
	p_stopdrawing();
	p_drawbitmapfont(v_s, v_x, v_y, v_w, v_h, v_t);
}

static int32_t p_drawcentered(int32_t v_posx, int32_t v_posy, int32_t v_obwidth, std::string v_text, int32_t v_farbe) {
	if ((v_farbe > -1)) {
		p_drawtext(((v_posx + (v_obwidth / 2)) - (p_textwidth(v_text) / 2)), v_posy, v_text, v_farbe, 0);
	} else {
		p_drawtext(((v_posx + (v_obwidth / 2)) - (p_textwidth(v_text) / 2)), v_posy, v_text, -1, 0);
	}
}

static int32_t p_drawtooltip(int32_t v_s, int32_t v_x, int32_t v_y, int32_t v_w, int32_t v_h, std::string v_t) {
	int32_t v_a = 0;
	p_startdrawing(p_screenoutput());
	p_box((v_x - 6), (v_y - 6), ((p_len(v_t) * v_w) + 10), v_h, 16711680);
	p_stopdrawing();
	v_a = 0;
	p_drawbitmapfont(v_s, v_x, v_y, v_w, v_h, v_t);
}

static int32_t p_duplizieren() {
	int32_t v_i = 0;
	int16_t v_verkauf = 0;
	v_verkauf = p_select_inventory(875);
	if ((a_inventory(v_verkauf, g_akt_spieler).f_name == 38)) {
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
		if ((v_i <= 50)) {
			a_inventory(v_i, g_akt_spieler).f_name = a_inventory(v_verkauf, g_akt_spieler).f_name;
			a_inventory(v_i, g_akt_spieler).f_art = a_inventory(v_verkauf, g_akt_spieler).f_art;
			a_inventory(v_i, g_akt_spieler).f_anzahl = 0;
			a_inventory(v_i, g_akt_spieler).f_status = a_inventory(v_verkauf, g_akt_spieler).f_status;
			a_inventory(v_i, g_akt_spieler).f_attri1 = a_inventory(v_verkauf, g_akt_spieler).f_attri1;
			a_inventory(v_i, g_akt_spieler).f_attri2 = a_inventory(v_verkauf, g_akt_spieler).f_attri2;
			a_inventory(v_i, g_akt_spieler).f_attri3 = 0;
			a_inventory(v_i, g_akt_spieler).f_attri4 = 0;
			a_inventory(v_i, g_akt_spieler).f_attri5 = 0;
			p_nachricht(877, 5);
		} else {
			p_nachricht(428, 5);
		}
	} else {
		p_nachricht(876, 5);
	}
}

static int32_t p_eintragen(int16_t v_nr, int16_t v_staerke, int16_t v_dauer, int16_t v_source) {
	int32_t v_i = 0;
	int32_t v_pos = 0;
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_aktive(v_i, g_akt_spieler).f_nr == v_nr) && (a_aktive(v_i, g_akt_spieler).f_source == v_source))) {
			a_aktive(v_i, g_akt_spieler).f_nr = 0;
			a_aktive(v_i, g_akt_spieler).f_staerke = 0;
			a_aktive(v_i, g_akt_spieler).f_dauer = 0;
		}
	}
	if (((v_nr >= 86) && (v_nr <= 90))) {
		for (v_i = 1; v_i <= 15; v_i += 1) {
			if ((((((a_aktive(v_i, g_akt_spieler).f_nr == 86) || (a_aktive(v_i, g_akt_spieler).f_nr == 87)) || (a_aktive(v_i, g_akt_spieler).f_nr == 88)) || (a_aktive(v_i, g_akt_spieler).f_nr == 89)) || (a_aktive(v_i, g_akt_spieler).f_nr == 90))) {
				a_aktive(v_i, g_akt_spieler).f_nr = 0;
				a_aktive(v_i, g_akt_spieler).f_staerke = 0;
				a_aktive(v_i, g_akt_spieler).f_dauer = 0;
			}
		}
	}
	if (((v_nr >= 168) && (v_nr <= 171))) {
		for (v_i = 1; v_i <= 15; v_i += 1) {
			if (((((a_aktive(v_i, g_akt_spieler).f_nr == 168) || (a_aktive(v_i, g_akt_spieler).f_nr == 169)) || (a_aktive(v_i, g_akt_spieler).f_nr == 170)) || (a_aktive(v_i, g_akt_spieler).f_nr == 171))) {
				a_aktive(v_i, g_akt_spieler).f_nr = 0;
				a_aktive(v_i, g_akt_spieler).f_staerke = 0;
				a_aktive(v_i, g_akt_spieler).f_dauer = 0;
			}
		}
	}
	v_i = 1;
	v_pos = 0;
	do {
		if ((a_aktive(v_i, g_akt_spieler).f_nr == 0)) {
			v_pos = v_i;
		}
		v_i = (v_i + 1);
	} while (!((v_i > 15) || (v_pos > 0)));
	if ((v_i <= 15)) {
		a_aktive(v_pos, g_akt_spieler).f_nr = v_nr;
		a_aktive(v_pos, g_akt_spieler).f_staerke = v_staerke;
		if ((v_dauer == 9998)) {
			a_aktive(v_pos, g_akt_spieler).f_dauer = 9998;
		} else {
			if ((v_dauer != 9999)) {
				if ((p_habich(157) > 0)) {
					v_dauer = (v_dauer * 2);
				}
				if ((a_skills(61, g_akt_spieler).f_gewaehlt == 1)) {
					v_dauer = (v_dauer * 2);
				}
				if ((a_skills(134, g_akt_spieler).f_gewaehlt == 1)) {
					v_dauer = (v_dauer / 2);
				}
				if ((a_spieler(g_akt_spieler).f_fluch == 20)) {
					v_dauer = (v_dauer / 2);
				}
			}
			a_aktive(v_pos, g_akt_spieler).f_dauer = v_dauer;
			a_aktive(v_pos, g_akt_spieler).f_source = v_source;
		}
	}
}

static int32_t p_eisschaden(int16_t v_schaden) {
	int16_t v_testfeld = 0;
	if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
		if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
			if ((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 15) == 1) && (p_random(100) > 50)) && (p_habich(160) == 0))) {
				p_nachricht(312, 2);
			} else {
				if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 18) == 0) || (p_habich(160) > 0))) {
					p_monsterschaden(v_schaden);
				} else {
					p_nachricht(267, 3);
				}
			}
		}
		v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
		if ((((v_testfeld == 40) || (v_testfeld == 41)) || (v_testfeld == 42))) {
			if ((v_schaden > 3)) {
				p_sound(27);
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_delay(g_mydelay);
				p_laby_screen();
			}
		}
	}
}

static int32_t p_ende() {
	int32_t v_aktiv = 0;
	int32_t v_anaktiv = 0;
	int8_t v_eintrag = 0;
	std::string v_endezeit;
	int32_t v_i = 0;
	int32_t v_inaktiv = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int32_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_k = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_x_old = 0;
	int32_t v_mouse_y_old = 0;
	int32_t v_result = 0;
	int32_t v_tot = 0;
	int16_t v_warten = 0;
	int32_t v_wohin = 0;
	int32_t v_x1 = 0;
	int32_t v_x2 = 0;
	int32_t v_x3 = 0;
	int16_t v_xx = 0;
	int16_t v_yy = 0;
	int32_t v_zaehler = 0;
	g_myname = "";
	a_spieler(g_akt_spieler).f_status = 3;
	a_spieler(g_akt_spieler).f_creature_typ = 0;
	a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
	v_x1 = (g_level * 10);
	v_x2 = (p_gold_anzahl() / 10);
	v_x3 = (a_spieler(g_akt_spieler).f_mks / 5);
	if ((v_x2 > v_x1)) {
		v_x2 = v_x1;
	}
	if ((v_x3 > v_x1)) {
		v_x3 = v_x1;
	}
	g_punkte = ((v_x1 + v_x2) + v_x3);
	g_punkte = (g_punkte + 1000);
	v_eintrag = 0;
	v_i = 1;
	do {
		if ((g_punkte > a_hscores(v_i).f_punkte)) {
			v_eintrag = v_i;
		}
		v_i = (v_i + 1);
	} while (!((v_i > 30) || (v_eintrag > 0)));
	if ((v_eintrag > 0)) {
		v_warten = 0;
		v_xx = 100;
		v_yy = 115;
		do {
			p_fenster(0);
			p_clearscreen(p_rgb(0, 0, 0));
			p_laby_rahmen();
			p_show_logo();
			p_show_varys();
			p_clipsprite(33, 1, 1, 335, 335);
			p_displaytransparentsprite(33, 16, 16);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(0, 0, 0));
			p_box(v_xx, v_yy, 150, 17, -1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(130, 25, a_nachricht_text(240, (1 + g_sprache)), -1, 0);
			p_drawtext(40, 40, a_nachricht_text(241, (1 + g_sprache)), -1, 0);
			p_drawtext(40, 55, a_nachricht_text(242, (1 + g_sprache)), -1, 0);
			p_drawtext(40, 70, a_nachricht_text(243, (1 + g_sprache)), -1, 0);
			p_drawtext(40, 85, a_nachricht_text(244, (1 + g_sprache)), -1, 0);
			p_drawtext(40, 100, a_nachricht_text(245, (1 + g_sprache)), -1, 0);
			p_drawtext(v_xx, v_yy, g_myname, -1, 0);
			p_stopdrawing();
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
			v_mouse_x_old = v_mmouse_x;
			v_mouse_y_old = v_mmouse_y;
			p_examinekeyboard();
			if ((g_joystick_used == 1)) {
				v_jax = 0;
				v_jay = 0;
				v_jb2 = 0;
				p_examinejoystick();
				v_jax = p_joystickaxisx();
				v_jay = p_joystickaxisy();
				v_jb2 = p_joystickbutton(2);
			}
			g_myname = p_keyboard_string(g_myname, 0);
			if ((p_len(g_myname) > 25)) {
				g_myname = p_mid(g_myname, 1, 25);
			}
			v_warten = (v_warten + 1);
			if ((v_warten < 3)) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_line((v_xx + p_textwidth(g_myname)), v_yy, 0, 15, -1);
				p_line(((v_xx + 1) + p_textwidth(g_myname)), v_yy, 0, 15, -1);
				p_stopdrawing();
			}
			if ((v_warten > 4)) {
				v_warten = 0;
			}
			p_flipbuffers(1);
			p_delay(20);
		} while (!((p_keyboardpushed(13) || (v_jb1 == 1)) && (g_myname != "")));
		v_j = 30;
		while ((v_j > v_eintrag)) {
			a_hscores(v_j).f_name = a_hscores((v_j - 1)).f_name;
			a_hscores(v_j).f_level = a_hscores((v_j - 1)).f_level;
			a_hscores(v_j).f_gold = a_hscores((v_j - 1)).f_gold;
			a_hscores(v_j).f_mks = a_hscores((v_j - 1)).f_mks;
			a_hscores(v_j).f_punkte = a_hscores((v_j - 1)).f_punkte;
			a_hscores(v_j).f_maennchen = a_hscores((v_j - 1)).f_maennchen;
			a_hscores(v_j).f_anfangszeit = a_hscores((v_j - 1)).f_anfangszeit;
			a_hscores(v_j).f_endezeit = a_hscores((v_j - 1)).f_endezeit;
			a_hscores(v_j).f_maxlifepoints = a_hscores((v_j - 1)).f_maxlifepoints;
			a_hscores(v_j).f_maxmana = a_hscores((v_j - 1)).f_maxmana;
			a_hscores(v_j).f_attack = a_hscores((v_j - 1)).f_attack;
			a_hscores(v_j).f_dexterity = a_hscores((v_j - 1)).f_dexterity;
			a_hscores(v_j).f_strength = a_hscores((v_j - 1)).f_strength;
			a_hscores(v_j).f_maxspeed = a_hscores((v_j - 1)).f_maxspeed;
			a_hscores(v_j).f_perception = a_hscores((v_j - 1)).f_perception;
			a_hscores(v_j).f_luck_score = a_hscores((v_j - 1)).f_luck_score;
			a_hscores(v_j).f_power_score = a_hscores((v_j - 1)).f_power_score;
			a_hscores(v_j).f_circle = a_hscores((v_j - 1)).f_circle;
			a_hscores(v_j).f_stabteile = a_hscores((v_j - 1)).f_stabteile;
			for (v_k = 1; v_k <= 3; v_k += 1) {
				a_hscores(v_j).f_sterbegrund[v_k] = a_hscores((v_j - 1)).f_sterbegrund[v_k];
			}
			for (v_k = 1; v_k <= 30; v_k += 1) {
				a_hscores(v_j).f_skills[v_k] = a_hscores((v_j - 1)).f_skills[v_k];
			}
			v_j = (v_j - 1);
		}
		g_letzter_eintrag = v_eintrag;
		if ((v_eintrag > 0)) {
			v_endezeit = p_formatdate("%yyyy%mm%dd%hh%ii%ss", p_date());
			a_hscores(v_eintrag).f_name = g_myname;
			a_hscores(v_eintrag).f_level = g_level;
			a_hscores(v_eintrag).f_gold = p_gold_anzahl();
			a_hscores(v_eintrag).f_mks = a_spieler(g_akt_spieler).f_mks;
			a_hscores(v_eintrag).f_punkte = g_punkte;
			a_hscores(v_eintrag).f_maennchen = a_spieler(g_akt_spieler).f_maennchen;
			a_hscores(v_eintrag).f_anfangszeit = g_anfangszeit;
			a_hscores(v_eintrag).f_endezeit = v_endezeit;
			a_hscores(v_eintrag).f_maxlifepoints = a_spieler(g_akt_spieler).f_maxlifepoints;
			a_hscores(v_eintrag).f_maxmana = a_spieler(g_akt_spieler).f_maxmana;
			a_hscores(v_eintrag).f_attack = a_spieler(g_akt_spieler).f_attack;
			a_hscores(v_eintrag).f_dexterity = a_spieler(g_akt_spieler).f_dexterity;
			a_hscores(v_eintrag).f_strength = a_spieler(g_akt_spieler).f_strength;
			a_hscores(v_eintrag).f_maxspeed = a_spieler(g_akt_spieler).f_maxspeed;
			a_hscores(v_eintrag).f_perception = a_spieler(g_akt_spieler).f_perception;
			a_hscores(v_eintrag).f_luck_score = a_spieler(g_akt_spieler).f_luck_score;
			a_hscores(v_eintrag).f_power_score = a_spieler(g_akt_spieler).f_power_score;
			a_hscores(v_eintrag).f_circle = a_spieler(g_akt_spieler).f_circle;
			a_hscores(v_eintrag).f_stabteile = a_spieler(g_akt_spieler).f_stabteile;
			for (v_k = 1; v_k <= 3; v_k += 1) {
				a_hscores(v_eintrag).f_sterbegrund[v_k] = a_nachricht_text(693, v_k);
			}
			a_high_skill.dim(31);
			for (v_i = 1; v_i <= 30; v_i += 1) {
				a_high_skill(v_i) = 0;
			}
			v_zaehler = 1;
			for (v_i = 2; v_i <= 141; v_i += 1) {
				if ((a_skills(v_i, g_akt_spieler).f_gewaehlt == 1)) {
					a_high_skill(v_zaehler) = a_skills(v_i, g_akt_spieler).f_nummer;
					v_zaehler = (v_zaehler + 1);
				}
			}
			for (v_k = 1; v_k <= 30; v_k += 1) {
				if ((a_high_skill(v_k) > 0)) {
					a_hscores(v_eintrag).f_skills[v_k] = a_high_skill(v_k);
				}
			}
			p_new_highscore();
			p_show_highscore();
		}
	} else {
		do {
			p_fenster(0);
			p_clearscreen(p_rgb(0, 0, 0));
			p_laby_rahmen();
			p_show_logo();
			p_show_varys();
			p_clipsprite(19, 1, 1, 335, 335);
			p_displaytransparentsprite(19, 16, 16);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(130, 25, p_nachricht4(83), -1, 0);
			p_stopdrawing();
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
			v_mouse_x_old = v_mmouse_x;
			v_mouse_y_old = v_mmouse_y;
			p_examinekeyboard();
			p_flipbuffers(1);
		} while (!(((v_mmouse_links == 1) || p_keyboardpushed(13)) || (v_jb1 == 1)));
	}
	v_aktiv = 0;
	for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
		if ((a_spieler(v_i).f_status == 1)) {
			v_aktiv = 1;
		}
	}
	if ((v_aktiv == 1)) {
		p_naechster();
	} else {
		v_tot = 1;
		for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
			if ((a_spieler(v_i).f_status < 3)) {
				v_tot = 0;
			}
		}
		if ((v_tot == 1)) {
			throw Lv_again;
		} else {
			v_inaktiv = 1;
			for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
				if (((a_spieler(v_i).f_status == 1) || (a_spieler(v_i).f_status == 3))) {
					v_anaktiv = 0;
				}
			}
			if ((v_inaktiv == 1)) {
				p_neuer_level();
			}
		}
	}
}

static int32_t p_entdecken() {
	int32_t v_akt_entdecken = 0;
	v_akt_entdecken = (p_wahrnehmung() * 10);
	v_akt_entdecken = (v_akt_entdecken - a_spieler(g_akt_spieler).f_level);
	if ((a_skills(123, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_entdecken = 0;
	}
	return v_akt_entdecken;
}

static int32_t p_erfolgreich(int16_t v_spell) {
	int16_t v_okay = 0;
	v_okay = 0;
	if (((p_random(100) < p_zauberchance(v_spell)) || (g_schriftrolle == 1))) {
		v_okay = 1;
		if ((a_zauber(v_spell, g_akt_spieler).f_chance < 100)) {
			a_zauber(v_spell, g_akt_spieler).f_chance = (a_zauber(v_spell, g_akt_spieler).f_chance + 5);
		}
	}
	return v_okay;
}

static int32_t p_erstelle_liste() {
	int16_t v_i = 0;
	int32_t v_k = 0;
	int16_t v_nehmen = 0;
	p_liste_leeren();
	g_anz_zauber = 1;
	for (v_i = 1; v_i <= 177; v_i += 1) {
		v_nehmen = p_zauber_nehmen(v_i);
		if ((a_zauber(v_i, g_akt_spieler).f_erlernt == 1)) {
			v_nehmen = 1;
		}
		if ((((a_spieler(g_akt_spieler).f_schule == "frei") && (a_zauber(v_i, g_akt_spieler).f_erlernt == 1)) || ((a_spieler(g_akt_spieler).f_schule == "beschw\357\277\275er") && (a_summoning(v_i) == 1)))) {
		} else {
			if ((a_spieler(g_akt_spieler).f_schule != "")) {
				if ((a_zauber(v_i, g_akt_spieler).f_art != a_spieler(g_akt_spieler).f_schule)) {
					v_nehmen = 0;
				}
			}
		}
		if ((v_nehmen == 1)) {
			for (v_k = 1; v_k <= 3; v_k += 1) {
				a_zauberliste((g_anz_zauber + g_akt_zauber_offset2)).f_name[v_k] = a_zauber(v_i, g_akt_spieler).f_name[v_k];
			}
			g_anz_zauber = (g_anz_zauber + 1);
		}
	}
	p_bubblesort();
	for (v_k = 1; v_k <= 3; v_k += 1) {
		a_zauberliste((g_anz_zauber + g_akt_zauber_offset2)).f_name[v_k] = a_nachricht_text(650, v_k);
	}
}

static int32_t p_erstelle_matrix(int16_t v_wer) {
	int16_t v_einschalten = 0;
	int32_t v_i = 0;
	int16_t v_radius = 0;
	int16_t v_testfeld = 0;
	int8_t v_x = 0;
	int8_t v_y = 0;
	if (((((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 9) || (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 6)) || (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 11)) || (p_habich(200) == 9999))) {
		for (v_x = 1; v_x <= 12; v_x += 1) {
			for (v_y = 1; v_y <= 12; v_y += 1) {
				a_matrix(v_x, v_y) = 1;
			}
		}
	} else {
		for (v_x = 1; v_x <= 12; v_x += 1) {
			for (v_y = 1; v_y <= 12; v_y += 1) {
				a_matrix(v_x, v_y) = 9999;
			}
		}
		if ((v_wer == 1)) {
			v_radius = p_radius();
			p_kopiere_matrix();
		} else {
			v_radius = p_radius2();
			p_kopiere_matrix2();
		}
		a_matrix(6, 6) = 1;
		for (v_i = 1; v_i <= v_radius; v_i += 1) {
			for (v_x = (6 - v_radius); v_x <= (6 + v_radius); v_x += 1) {
				for (v_y = (6 - v_radius); v_y <= (6 + v_radius); v_y += 1) {
					if (((v_x > 0) && (v_y > 0))) {
						if ((a_matrix(v_x, v_y) == 9998)) {
							if (((a_matrix((v_x - 1), v_y) < 9998) && ((v_x - 1) > 0))) {
								a_matrix(v_x, v_y) = (a_matrix((v_x - 1), v_y) + 1);
							}
							if (((a_matrix((v_x + 1), v_y) < 9998) && ((v_x + 1) <= 12))) {
								a_matrix(v_x, v_y) = (a_matrix((v_x + 1), v_y) + 1);
							}
							if (((a_matrix(v_x, (v_y - 1)) < 9998) && ((v_y - 1) > 0))) {
								a_matrix(v_x, v_y) = (a_matrix(v_x, (v_y - 1)) + 1);
							}
							if (((a_matrix(v_x, (v_y + 1)) < 9998) && ((v_y + 1) <= 12))) {
								a_matrix(v_x, v_y) = (a_matrix(v_x, (v_y + 1)) + 1);
							}
						}
					}
				}
			}
		}
		for (v_x = 1; v_x <= 12; v_x += 1) {
			for (v_y = 1; v_y <= 12; v_y += 1) {
				a_matrix2(v_x, v_y) = 0;
			}
		}
		for (v_x = 1; v_x <= 12; v_x += 1) {
			for (v_y = 1; v_y <= 12; v_y += 1) {
				v_einschalten = 0;
				if (((v_x - 1) > 0)) {
					if ((a_matrix((v_x - 1), v_y) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if (((v_x + 1) <= 12)) {
					if ((a_matrix((v_x + 1), v_y) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if (((v_y - 1) > 0)) {
					if ((a_matrix(v_x, (v_y - 1)) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if (((v_y + 1) <= 12)) {
					if ((a_matrix(v_x, (v_y + 1)) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if ((a_matrix((v_x + 1), (v_y + 1)) <= v_radius)) {
					v_einschalten = 1;
				}
				if (((v_x - 1) > 0)) {
					if ((a_matrix((v_x - 1), (v_y + 1)) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if (((v_y - 1) > 0)) {
					if ((a_matrix((v_x + 1), (v_y - 1)) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if ((((v_x - 1) > 0) && ((v_y - 1) > 0))) {
					if ((a_matrix((v_x - 1), (v_y - 1)) <= v_radius)) {
						v_einschalten = 1;
					}
				}
				if ((v_einschalten == 1)) {
					a_matrix2(v_x, v_y) = 1;
				}
			}
		}
		for (v_x = 1; v_x <= 12; v_x += 1) {
			for (v_y = 1; v_y <= 12; v_y += 1) {
				if ((a_matrix2(v_x, v_y) == 1)) {
					a_matrix(v_x, v_y) = v_radius;
				}
			}
		}
		for (v_x = -1; v_x <= 11; v_x += 1) {
			for (v_y = -1; v_y <= 11; v_y += 1) {
				if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) > 0))) {
					v_testfeld = a_labyrinth(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)).f_feld[a_spieler(g_akt_spieler).f_level];
					if ((a_skills(80, g_akt_spieler).f_gewaehlt == 1)) {
						if (((v_testfeld == 1) || (v_testfeld == 20))) {
							a_matrix((v_x + 1), (v_y + 1)) = v_radius;
						}
					}
					if ((a_skills(79, g_akt_spieler).f_gewaehlt == 1)) {
						if ((((((((v_testfeld == 9) || (v_testfeld == 67)) || (v_testfeld == 68)) || (v_testfeld == 75)) || (v_testfeld == 6)) || (v_testfeld == 93)) || (v_testfeld == 69))) {
							a_matrix((v_x + 1), (v_y + 1)) = v_radius;
						}
					}
					if ((a_skills(81, g_akt_spieler).f_gewaehlt == 1)) {
						if ((p_istmonster(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y)) == 1)) {
							a_matrix((v_x + 1), (v_y + 1)) = v_radius;
						}
					}
				}
			}
		}
	}
}

static int32_t p_explain(int16_t v_was, int16_t v_pos) {
	int32_t v_nr = 0;
	switch (v_was) {
	case 1:
		v_nr = 349;
		break;
	case 2:
		v_nr = 350;
		break;
	case 3:
		v_nr = 351;
		break;
	case 4:
		v_nr = 352;
		break;
	case 5:
		v_nr = 353;
		break;
	case 6:
		v_nr = 354;
		break;
	case 7:
		v_nr = 355;
		break;
	case 8:
		v_nr = 356;
		break;
	case 9:
		v_nr = 357;
		break;
	case 10:
		v_nr = 358;
		break;
	case 11:
		v_nr = 359;
		break;
	case 12:
		v_nr = 360;
		break;
	case 13:
		v_nr = 361;
		break;
	case 14:
		v_nr = 362;
		break;
	case 15:
		v_nr = 363;
		break;
	case 16:
		v_nr = 364;
		break;
	case 17:
		v_nr = 365;
		break;
	case 18:
		v_nr = 366;
		break;
	case 19:
		v_nr = 367;
		break;
	case 20:
		v_nr = 368;
		break;
	case 21:
		v_nr = 369;
		break;
	case 22:
		v_nr = 370;
		break;
	case 23:
		v_nr = 371;
		break;
	case 24:
		v_nr = 372;
		break;
	case 25:
		v_nr = 373;
		break;
	case 26:
		v_nr = 374;
		break;
	case 27:
		v_nr = 375;
		break;
	case 28:
		v_nr = 376;
		break;
	case 29:
		v_nr = 481;
		break;
	case 30:
		v_nr = 668;
		break;
	case 31:
		v_nr = 669;
		break;
	case 32:
		v_nr = 670;
		break;
	case 33:
		v_nr = 671;
		break;
	case 34:
		v_nr = 672;
		break;
	case 35:
		v_nr = 673;
		break;
	case 36:
		v_nr = 674;
		break;
	case 37:
		v_nr = 675;
		break;
	case 38:
		v_nr = 676;
		break;
	case 39:
		v_nr = 677;
		break;
	case 40:
		v_nr = 678;
		break;
	case 41:
		v_nr = 821;
		break;
	case 42:
		v_nr = 822;
		break;
	case 43:
		v_nr = 823;
		break;
	case 44:
		v_nr = 824;
		break;
	case 45:
		v_nr = 834;
		break;
	}
	p_drawtext(175, v_pos, p_nachricht4(v_nr), -1, 0);
}

static int32_t p_explodiert() {
	int16_t v_save_akt_spieler = 0;
	int16_t v_save_spell_x = 0;
	int16_t v_save_spell_y = 0;
	int16_t v_vergl_x = 0;
	int16_t v_vergl_y = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_zaehl = 0;
	p_nachricht(706, 3);
	p_sound(34);
	for (v_y = ((g_spell_y - 1) + 5); v_y <= ((g_spell_y + 1) + 5); v_y += 1) {
		for (v_x = ((g_spell_x - 1) + 5); v_x <= ((g_spell_x + 1) + 5); v_x += 1) {
			p_draw_tile(42, v_x, v_y, 1, 1);
		}
	}
	p_flipbuffers(1);
	p_delay(g_mydelay);
	p_laby_screen();
	v_save_akt_spieler = g_akt_spieler;
	v_vergl_x = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
	v_vergl_y = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
	for (g_akt_spieler = 1; g_akt_spieler <= g_anz_spieler; g_akt_spieler += 1) {
		if (((((a_spieler(g_akt_spieler).f_character_x >= (v_vergl_x - 1)) && (a_spieler(g_akt_spieler).f_character_x <= (v_vergl_x + 1))) && (a_spieler(g_akt_spieler).f_character_y >= (v_vergl_y - 1))) && (a_spieler(g_akt_spieler).f_character_y <= (v_vergl_y + 1)))) {
			p_spielerschaden(2, 1, 14);
		}
	}
	g_akt_spieler = v_save_akt_spieler;
	v_save_spell_x = g_spell_x;
	v_save_spell_y = g_spell_y;
	for (v_zaehl = 1; v_zaehl <= 9; v_zaehl += 1) {
		switch (v_zaehl) {
		case 1:
			g_spell_x = (g_spell_x - 1);
			g_spell_y = (g_spell_y - 1);
			break;
		case 2:
			g_spell_x = (g_spell_x + 1);
			break;
		case 3:
			g_spell_x = (g_spell_x + 1);
			break;
		case 4:
			g_spell_y = (g_spell_y + 1);
			g_spell_x = (g_spell_x - 2);
			break;
		case 5:
			g_spell_x = (g_spell_x + 1);
			break;
		case 6:
			g_spell_x = (g_spell_x + 1);
			break;
		case 7:
			g_spell_y = (g_spell_y + 1);
			g_spell_x = (g_spell_x - 2);
			break;
		case 8:
			g_spell_x = (g_spell_x + 1);
			break;
		case 9:
			g_spell_x = (g_spell_x + 1);
			break;
		}
		p_feuerschaden(2);
	}
	g_spell_x = v_save_spell_x;
	g_spell_y = v_save_spell_y;
}

static int32_t p_faechergrafik() {
	int32_t v_a = 0;
	int32_t v_i = 0;
	int32_t v_s = 0;
	int32_t v_wohin = 0;
	v_a = 1;
	v_s = 5;
	while ((192 > (v_a * v_s))) {
		p_laby_screen2();
		for (v_i = 1; v_i <= v_a; v_i += 1) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_linexy((177 - (v_i * v_s)), (177 - (v_i * v_s)), (177 + (v_i * v_s)), (177 - (v_i * v_s)));
			p_linexy((177 + (v_i * v_s)), (177 - (v_i * v_s)), (177 + (v_i * v_s)), (177 + (v_i * v_s)));
			p_linexy((177 + (v_i * v_s)), (177 + (v_i * v_s)), (177 - (v_i * v_s)), (177 + (v_i * v_s)));
			p_linexy((177 - (v_i * v_s)), (177 + (v_i * v_s)), (177 - (v_i * v_s)), (177 - (v_i * v_s)));
			p_stopdrawing();
		}
		p_flipbuffers(1);
		p_delay(25);
		v_a = (v_a + 1);
	}
}

static int32_t p_falle() {
	int32_t v_ausweichen = 0;
	int32_t v_counter = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_levelmod = 0;
	int16_t v_new_level = 0;
	int32_t v_okay = 0;
	int16_t v_setx = 0;
	int16_t v_sety = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_zw = 0;
	v_ausweichen = p_ausweichen();
	if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] >= 31) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] <= 39))) {
		v_ausweichen = (v_ausweichen + 30);
		if ((a_skills(69, g_akt_spieler).f_gewaehlt == 1)) {
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_sound(17);
			p_laby_screen();
		} else {
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] - 9), 0, 0, 0);
		}
		g_aktion = 1;
	}
	switch (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level]) {
	case 22:
		v_okay = 0;
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 1;
			g_spell_y = 0;
			p_fernangriff_monster(6);
		}
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = -1;
			g_spell_y = 0;
			p_fernangriff_monster(6);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = 1;
			p_fernangriff_monster(6);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = -1;
			p_fernangriff_monster(6);
		}
		if ((p_random(100) < v_ausweichen)) {
			p_nachricht(180, 1);
			if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_fallenlehre))) {
				a_spieler(g_akt_spieler).f_fallenlehre = (a_spieler(g_akt_spieler).f_fallenlehre + 1);
				p_nachricht(625, 2);
			}
		} else {
			p_schutz();
			v_zw = ((p_random((a_spieler(g_akt_spieler).f_level / 2)) + 1) - g_schutz_min);
			if ((v_levelmod == 2)) {
				v_zw = (v_zw * 2);
			}
			if ((v_zw < 1)) {
				v_zw = 0;
			}
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
			} else {
				p_spielerschaden(v_zw, 1, 1);
				p_nachricht(17, 3);
			}
		}
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		g_aktion = 1;
		break;
	case 29:
		v_okay = 0;
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 1;
			g_spell_y = 0;
			p_fernangriff_monster(7);
		}
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = -1;
			g_spell_y = 0;
			p_fernangriff_monster(7);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = 1;
			p_fernangriff_monster(7);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = -1;
			p_fernangriff_monster(7);
		}
		if ((p_random(100) < v_ausweichen)) {
			p_nachricht(180, 1);
			if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_fallenlehre))) {
				a_spieler(g_akt_spieler).f_fallenlehre = (a_spieler(g_akt_spieler).f_fallenlehre + 1);
				p_nachricht(625, 2);
			}
		} else {
			p_schutz();
			v_zw = ((p_random(a_spieler(g_akt_spieler).f_level) + 6) - g_schutz_min);
			if ((v_levelmod == 2)) {
				v_zw = (v_zw * 2);
			}
			if ((v_zw < 1)) {
				v_zw = 0;
			}
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
			} else {
				p_spielerschaden(v_zw, 1, 2);
				p_nachricht(18, 3);
			}
		}
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		g_aktion = 1;
		break;
	case 23:
		v_okay = 0;
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 1;
			g_spell_y = 0;
			p_fernangriff_monster(8);
		}
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = -1;
			g_spell_y = 0;
			p_fernangriff_monster(8);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = 1;
			p_fernangriff_monster(8);
		}
		if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_mit_was(a_spieler(g_akt_spieler).f_level)) && (v_okay == 0))) {
			v_okay = 1;
			g_spell_x = 0;
			g_spell_y = -1;
			p_fernangriff_monster(8);
		}
		if ((p_random(100) < v_ausweichen)) {
			p_nachricht(180, 1);
			if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_fallenlehre))) {
				a_spieler(g_akt_spieler).f_fallenlehre = (a_spieler(g_akt_spieler).f_fallenlehre + 1);
				p_nachricht(625, 2);
			}
		} else {
			p_schutz();
			v_zw = (p_random(3) - g_schutz_min);
			if ((v_levelmod == 2)) {
				v_zw = (v_zw * 2);
			}
			if ((v_zw < 1)) {
				v_zw = 0;
			}
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
			} else {
				p_spielerschaden(v_zw, 1, 2);
				p_nachricht(19, 4);
				a_spieler(g_akt_spieler).f_gift = 1;
				a_spieler(g_akt_spieler).f_giftdauer = 10;
			}
		}
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		g_aktion = 1;
		break;
	case 30:
		if ((g_bewegt == 1)) {
			if ((p_habich(79) == 0)) {
				g_aktion = 1;
				p_sternchen(156, 156, 6);
				if ((p_random(100) > 85)) {
					p_nachricht(663, 1);
					v_new_level = (a_spieler(g_akt_spieler).f_level - (p_random(1) + 1));
					v_counter = 1;
					do {
						v_x = (p_random((a_groesse(v_new_level) - 3)) + 2);
						v_y = (p_random((a_groesse(v_new_level) - 3)) + 2);
						v_counter = (v_counter + 1);
					} while (!((a_labyrinth(v_x, v_y).f_feld[v_new_level] == a_inhalt(v_new_level)) || (v_counter > 500)));
					if ((v_counter <= 500)) {
						a_spieler(g_akt_spieler).f_level = v_new_level;
						a_spieler(g_akt_spieler).f_character_x = v_x;
						a_spieler(g_akt_spieler).f_character_y = v_y;
						p_laby_screen();
					}
				} else {
					p_nachricht(20, 6);
					a_spieler(g_akt_spieler).f_fluch = (p_random(25) + 1);
					a_spieler(g_akt_spieler).f_fluchdauer = (p_random(18) + 4);
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
						p_sound(30);
					} else {
						p_sound(25);
					}
					p_laby_screen();
				}
			} else {
				p_nachricht(21, 2);
			}
		}
		break;
	case 24:
		if ((g_bewegt == 1)) {
			if ((((p_habich(48) == 0) && (p_habich(86) == 0)) && (p_habich(88) == 0))) {
				if ((p_random(100) < v_ausweichen)) {
					p_nachricht(180, 1);
					if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_fallenlehre))) {
						a_spieler(g_akt_spieler).f_fallenlehre = (a_spieler(g_akt_spieler).f_fallenlehre + 1);
						p_nachricht(625, 2);
					}
				} else {
					v_zw = p_random(6);
					if ((v_levelmod == 2)) {
						v_zw = (v_zw * 2);
					}
					if ((v_zw < 1)) {
						v_zw = 1;
					}
					p_sound(18);
					if ((p_habich(124) > 0)) {
						p_nachricht(431, 2);
					} else {
						p_spielerschaden(v_zw, 1, 4);
						p_nachricht(22, 3);
					}
					if ((a_skills(90, g_akt_spieler).f_gewaehlt == 1)) {
						a_spieler(g_akt_spieler).f_weisheit = (a_spieler(g_akt_spieler).f_weisheit + 1);
					}
					for (v_i = 1; v_i <= 40; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 4) && (p_random(100) > 80))) {
							p_leeren(v_i);
							p_sound(23);
							p_nachricht(348, 1);
						}
					}
					p_delay(g_mydelay);
					g_bewegt = 0;
					p_neuer_level();
					p_naechster();
					p_laby_screen();
				}
			}
		}
		break;
	case 25:
		if ((g_bewegt == 1)) {
			if ((p_habich(79) == 0)) {
				g_aktion = 1;
				p_nachricht(20, 4);
				p_sound(25);
				p_sternchen(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_character_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_character_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 81, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 81, 0, 0, 0);
				p_laby_screen();
			} else {
				p_nachricht(21, 2);
			}
		}
		break;
	case 26:
		if ((g_bewegt == 1)) {
			if ((p_habich(79) == 0)) {
				g_aktion = 1;
				p_nachricht(20, 3);
				p_sound(25);
				p_sternchen(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_character_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_character_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 41, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 41, 0, 0, 0);
				p_laby_screen();
			} else {
				p_nachricht(21, 2);
			}
		}
		break;
	case 27:
		if ((g_bewegt == 1)) {
			if ((p_habich(79) == 0)) {
				g_aktion = 1;
				p_nachricht(20, 2);
				p_sound(25);
				p_sternchen(156, 156, 6);
				for (v_i = 1; v_i <= 11; v_i += 1) {
					for (v_j = 1; v_j <= 11; v_j += 1) {
						v_setx = ((a_spieler(g_akt_spieler).f_character_x - 6) + v_i);
						if ((v_setx < 1)) {
							v_setx = 1;
						}
						if ((v_setx > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_setx = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						v_sety = ((a_spieler(g_akt_spieler).f_character_y - 6) + v_j);
						if ((v_sety < 1)) {
							v_sety = 1;
						}
						if ((v_sety > a_groesse(a_spieler(g_akt_spieler).f_level))) {
							v_sety = a_groesse(a_spieler(g_akt_spieler).f_level);
						}
						if ((a_labyrinth(v_setx, v_sety).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
							p_setlaby(v_setx, v_sety, a_spieler(g_akt_spieler).f_level, 80, 0, 0, 0);
						}
					}
				}
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_laby_screen();
			} else {
				p_nachricht(21, 2);
			}
		}
		break;
	case 28:
		p_sound(25);
		p_nachricht(23, 2);
		p_sternchen(156, 156, 4);
		a_spieler(g_akt_spieler).f_mana = 0;
		p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		g_aktion = 1;
		break;
	}
}

static int32_t p_feld_waehlen() {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int32_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int16_t v_mouse_x_old = 0;
	int16_t v_mouse_y_old = 0;
	int32_t v_mouseklick = 0;
	int32_t v_result = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_result = p_examinemouse();
	v_mouse_x_old = p_mousex();
	v_mouse_y_old = p_mousey();
	do {
		p_fenster(0);
		p_examinekeyboard();
		v_jax = 0;
		v_jay = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		a_addelaymax(1) = g_selectdelay;
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			if (p_autodelay(1, 1, -2)) {
				p_autodelay(1, 2, -2);
				g_spell_y = (g_spell_y - 1);
			}
		} else {
			if ((p_keyboardpushed(274) || (v_jay == 1))) {
				if (p_autodelay(1, 1, -2)) {
					p_autodelay(1, 2, -2);
					g_spell_y = (g_spell_y + 1);
				}
			} else {
				if ((p_keyboardpushed(276) || (v_jax == -1))) {
					if (p_autodelay(1, 1, -2)) {
						p_autodelay(1, 2, -2);
						g_spell_x = (g_spell_x - 1);
					}
				} else {
					if ((p_keyboardpushed(275) || (v_jax == 1))) {
						if (p_autodelay(1, 1, -2)) {
							p_autodelay(1, 2, -2);
							g_spell_x = (g_spell_x + 1);
						}
					} else {
						p_autodelay(1, 3, -2);
					}
				}
			}
		}
		if ((g_spell_x > 4)) {
			g_spell_x = 4;
		}
		if ((g_spell_y > 4)) {
			g_spell_y = 4;
		}
		if ((g_spell_x < -4)) {
			g_spell_x = -4;
		}
		if ((g_spell_y < -4)) {
			g_spell_y = -4;
		}
		p_laby_screen2();
		v_x = 30;
		v_y = 30;
		v_mouseklick = 0;
		for (v_i = 1; v_i <= 9; v_i += 1) {
			for (v_j = 1; v_j <= 9; v_j += 1) {
				if (((((g_mmouse_x >= ((v_x + (v_i * 32)) - 32)) && (g_mmouse_x <= (v_x + (v_i * 32)))) && (g_mmouse_y >= ((v_y + (v_j * 32)) - 32))) && (g_mmouse_y <= (v_y + (v_j * 32))))) {
					if (((g_mmouse_x != v_mouse_x_old) || (g_mmouse_y != v_mouse_y_old))) {
						v_mouse_x_old = g_mmouse_x;
						v_mouse_y_old = g_mmouse_y;
						g_spell_x = (v_i - 5);
						g_spell_y = (v_j - 5);
					}
					if ((g_mmouse_links == 1)) {
						v_mouseklick = 1;
					}
				}
			}
		}
		p_clipsprite(1, 0, 32, 32, 32);
		p_displaytransparentsprite(1, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, g_mmouse_x, g_mmouse_y);
		p_flipbuffers(1);
	} while (!((p_keyboardpushed(32) || (v_mouseklick == 1)) || (v_jb1 != 0)));
	p_autodelay(-1, 5, -2);
}

static int32_t p_fenster(int32_t v_typ) {
	if ((g_windowsfenster || v_typ)) {
	}
}

static int32_t p_fernangriff_monster(int16_t v_aussehen) {
	int32_t v_akt_frame = 0;
	int32_t v_i = 0;
	int32_t v_startx = 0;
	int32_t v_starty = 0;
	int32_t v_zw_frame = 0;
	if ((g_spell_x > 0)) {
		v_startx = (32 * g_spell_x);
	}
	if ((g_spell_x < 0)) {
		v_startx = (-32 * g_spell_x);
	}
	if ((g_spell_y > 0)) {
		v_starty = (32 * g_spell_y);
	}
	if ((g_spell_y < 0)) {
		v_starty = (-32 * g_spell_y);
	}
	if ((g_spell_x > 0)) {
		v_i = v_startx;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 96, 96, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 5)) {
				p_clipsprite(38, 32, 256, 32, 32);
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 6)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				p_delay(20);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 + v_i), 160);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 8)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 160, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 160, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 9)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, (160 + v_i), 160);
				v_i = (v_i - 2);
			}
			v_i = (v_i - g_mydelay4);
			p_flipbuffers(1);
		} while (!(v_i <= 0));
	}
	if ((g_spell_x < 0)) {
		v_i = v_startx;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 32, 96, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 5)) {
				p_clipsprite(38, 32, 256, 32, 32);
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 6)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				p_delay(20);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, (160 - v_i), 160);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 8)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 160, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 160, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 9)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, (160 - v_i), 160);
				v_i = (v_i - 2);
			}
			v_i = (v_i - g_mydelay4);
			p_flipbuffers(1);
		} while (!(v_i <= 0));
	}
	if ((g_spell_y > 0)) {
		v_i = v_starty;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 0, 96, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 5)) {
				p_clipsprite(38, 32, 256, 32, 32);
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 6)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				p_delay(20);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 + v_i));
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 8)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 160, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 160, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 9)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, 160, (160 + v_i));
				v_i = (v_i - 2);
			}
			v_i = (v_i - g_mydelay4);
			p_flipbuffers(1);
		} while (!(v_i <= 0));
	}
	if ((g_spell_y < 0)) {
		v_i = v_starty;
		do {
			p_fenster(0);
			p_laby_screen2();
			if ((v_aussehen == 1)) {
				p_clipsprite(38, 0, 192, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 2)) {
				p_clipsprite(38, 64, 96, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 3)) {
				p_clipsprite(38, 32, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 4)) {
				p_clipsprite(38, 64, 128, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 5)) {
				p_clipsprite(38, 32, 256, 32, 32);
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			if ((v_aussehen == 6)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 64, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 64, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 64, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 7)) {
				p_clipsprite(38, ((v_akt_frame * 32) - 32), 32, 32, 32);
				v_zw_frame = (v_zw_frame + 1);
				p_delay(20);
				if ((v_zw_frame > 3)) {
					v_akt_frame = (v_akt_frame + 1);
					if ((v_akt_frame > 4)) {
						v_akt_frame = 1;
					}
					v_zw_frame = 1;
				}
				p_displaytransparentsprite(38, 160, (160 - v_i));
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 8)) {
				if ((g_spell_x > 0)) {
					p_clipsprite(38, 96, 160, 32, 32);
					p_displaytransparentsprite(38, (160 + v_i), 160);
				}
				if ((g_spell_x < 0)) {
					p_clipsprite(38, 32, 160, 32, 32);
					p_displaytransparentsprite(38, (160 - v_i), 160);
				}
				if ((g_spell_y > 0)) {
					p_clipsprite(38, 0, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 + v_i));
				}
				if ((g_spell_y < 0)) {
					p_clipsprite(38, 64, 160, 32, 32);
					p_displaytransparentsprite(38, 160, (160 - v_i));
				}
				p_delay(20);
				v_i = (v_i - 1);
			}
			if ((v_aussehen == 9)) {
				p_clipsprite(8, 96, 576, 32, 32);
				p_displaytransparentsprite(8, 160, (160 - v_i));
				v_i = (v_i - 2);
			}
			v_i = (v_i - g_mydelay4);
			p_flipbuffers(1);
		} while (!(v_i <= 0));
	}
}

static int32_t p_fernattack(int16_t v_x, int16_t v_y, int16_t v_i) {
	int32_t v_angegriffen = 0;
	int32_t v_ausgewichen = 0;
	int32_t v_ausw = 0;
	int16_t v_chance = 0;
	int16_t v_counter = 0;
	int8_t v_geg = 0;
	int16_t v_geklaut = 0;
	int32_t v_gew_zauber = 0;
	int32_t v_j = 0;
	int32_t v_k = 0;
	int16_t v_killhim = 0;
	int16_t v_schaden = 0;
	int16_t v_wasele = 0;
	int16_t v_weg = 0;
	if ((a_laby_monster(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level] == 5)) {
		p_nachricht(616, 2);
		g_blocked = 1;
	}
	if ((a_spieler(g_akt_spieler).f_schleichen > 0)) {
		if ((a_skills(73, g_akt_spieler).f_gewaehlt == 1)) {
			v_chance = ((p_reflexe() + p_luck()) * 2);
		} else {
			v_chance = (p_reflexe() + p_luck());
		}
		if ((a_laby_monster(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level] == 5)) {
			v_chance = (v_chance * 2);
		}
		if ((v_chance > 90)) {
			v_chance = 90;
		}
		if (((p_random(100) <= v_chance) && (a_laby_monster(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level] != 1))) {
			g_blocked = 1;
			p_nachricht(701, 2);
		}
	}
	if ((((g_blocked == 0) && (a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_reichweite >= v_i)) && (v_i > 1))) {
		v_ausw = ((p_reflexe() / 2) + ((p_luck() / 2) * 3));
		if ((v_ausw > 50)) {
			v_ausw = 50;
		}
		v_ausgewichen = 0;
		if ((((a_skills(6, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) > 50)) || (p_random(100) < v_ausw))) {
			v_ausgewichen = 1;
		}
		v_angegriffen = 0;
		if (((p_hat_eigenschaft(v_x, v_y, 5) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_nachricht(24, 3);
			p_sound(26);
			p_fernangriff_monster(2);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if (((p_habich(46) > 0) && (v_weg == 0))) {
				p_nachricht(25, 2);
				v_weg = 1;
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				g_von_ferne = 1;
				p_monster_angriff(v_x, v_y);
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 41) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_nachricht(679, 3);
			p_sound(26);
			p_fernangriff_monster(9);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if (((p_habich(46) > 0) && (v_weg == 0))) {
				p_nachricht(25, 2);
				v_weg = 1;
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				g_von_ferne = 1;
				p_monster_angriff(v_x, v_y);
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 20) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_sound(13);
			p_nachricht(313, 3);
			p_fernangriff_monster(1);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if (((p_habich(7) == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_nachricht(28, 2);
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke + 1)) + 2);
				p_spielerschaden(v_schaden, 1, 5);
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 23) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_sound(13);
			p_nachricht(314, 2);
			p_fernangriff_monster(3);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if (((p_habich(68) == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_nachricht(315, 2);
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke + 1)) + 2);
				p_spielerschaden(v_schaden, 1, 5);
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 21) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_sound(13);
			p_nachricht(316, 4);
			p_fernangriff_monster(4);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if ((p_habich(130) > 0)) {
				p_nachricht(256, 2);
				v_weg = 1;
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				if ((a_spieler(g_akt_spieler).f_gift == 0)) {
					a_spieler(g_akt_spieler).f_gift = 1;
					a_spieler(g_akt_spieler).f_giftdauer = a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke;
				} else {
					a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer + 3);
				}
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 14) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_sound(46);
			p_nachricht(317, 2);
			p_fernangriff_monster(5);
			v_weg = 0;
			if ((p_habich(124) > 0)) {
				p_nachricht(431, 2);
				v_weg = 1;
			}
			if (((p_habich(118) == 1) && (v_weg == 0))) {
				p_nachricht(427, 2);
				v_weg = 1;
			}
			if (((v_ausgewichen == 1) && (v_weg == 0))) {
				v_weg = 1;
				p_sound(29);
				p_nachricht(178, 3);
			}
			if ((v_weg == 0)) {
				v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke + 1)) + 2);
				p_spielerschaden(v_schaden, 1, 5);
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 22) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			if ((((p_habich(45) > 0) || (p_habich(119) > 0)) || (p_random(100) < a_spieler(g_akt_spieler).f_magieresistenz))) {
				p_nachricht(187, 6);
			} else {
				v_killhim = (p_luck() * 10);
				if ((v_killhim > 90)) {
					v_killhim = 90;
				}
				if ((p_random(100) < v_killhim)) {
					p_nachricht(429, 3);
				} else {
					p_sound(31);
					g_spell_x = 0;
					g_spell_y = 0;
					p_versteinern();
					p_nachricht(318, 3);
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_spieler(g_akt_spieler).f_sterbegrund[v_k] = a_nachricht_text(630, v_k);
					}
					p_tot();
				}
			}
		}
		if (((p_hat_eigenschaft(v_x, v_y, 24) == 1) && (v_angegriffen == 0))) {
			v_angegriffen = 1;
			p_sound(25);
			p_sternchen(156, 156, 2);
			v_killhim = (p_luck() * 5);
			if ((v_killhim > 90)) {
				v_killhim = 90;
			}
			if ((p_random(100) < v_killhim)) {
				p_nachricht(430, 3);
			} else {
				p_sound(31);
				g_spell_x = 0;
				g_spell_y = 0;
				p_todesblick();
				p_nachricht(319, 3);
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_spieler(g_akt_spieler).f_sterbegrund[v_k] = a_nachricht_text(372, v_k);
				}
				p_tot();
			}
		}
		if ((v_angegriffen == 0)) {
			if (((p_habich(45) > 0) || (p_random(100) < a_spieler(g_akt_spieler).f_magieresistenz))) {
				p_nachricht(187, 2);
			} else {
				if ((p_random(100) > 80)) {
					v_gew_zauber = (p_random(7) + 1);
				} else {
					v_gew_zauber = a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauber;
				}
				switch (v_gew_zauber) {
				case 1:
					p_sound(13);
					p_nachricht(27, 2);
					p_fernangriff_monster(1);
					v_weg = 0;
					if ((p_habich(124) > 0)) {
						p_nachricht(431, 2);
						v_weg = 1;
					}
					if (((p_habich(7) > 0) && (v_weg == 0))) {
						p_nachricht(28, 2);
						v_weg = 1;
					}
					if ((v_weg == 0)) {
						v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft + 1)) + 2);
						if ((a_skills(126, g_akt_spieler).f_gewaehlt == 1)) {
							v_schaden = (v_schaden * 2);
						}
						p_spielerschaden(v_schaden, 1, 5);
					}
					break;
				case 2:
					p_sternchen(156, 156, 5);
					p_nachricht(29, 2);
					if ((a_spieler(g_akt_spieler).f_fluch == 0)) {
						a_spieler(g_akt_spieler).f_fluch = (p_random(25) + 1);
						if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
							p_sound(30);
						} else {
							p_sound(25);
						}
						a_spieler(g_akt_spieler).f_fluchdauer = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft * 2)) + 5);
						if ((a_skills(127, g_akt_spieler).f_gewaehlt == 1)) {
							a_spieler(g_akt_spieler).f_fluchdauer = (a_spieler(g_akt_spieler).f_fluchdauer * 2);
						}
					} else {
						a_spieler(g_akt_spieler).f_fluchdauer = ((a_spieler(g_akt_spieler).f_fluchdauer + p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft * 2))) + 5);
						if ((a_skills(127, g_akt_spieler).f_gewaehlt == 1)) {
							a_spieler(g_akt_spieler).f_fluchdauer = ((a_spieler(g_akt_spieler).f_fluchdauer + p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft * 2))) + 5);
						}
					}
					break;
				case 3:
					p_sound(25);
					p_sternchen(156, 156, 6);
					if (((a_skills(100, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) > 50))) {
						p_nachricht(880, 2);
					} else {
						v_geg = 0;
						for (v_i = 1; v_i <= 50; v_i += 1) {
							if (((a_inventory(v_i, g_akt_spieler).f_name != 0) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 0))) {
								v_geg = 1;
							}
						}
						if ((v_geg == 1)) {
							v_geklaut = 0;
							v_counter = 1;
							do {
								v_wasele = (p_random(49) + 1);
								if (((a_inventory(v_wasele, g_akt_spieler).f_name != 0) && (a_inventory(v_wasele, g_akt_spieler).f_benutzt == 0))) {
									v_geklaut = 1;
									p_nachricht7((((a_nachricht_text(30, (1 + g_sprache)) + " (") + a_gegenstand(a_inventory(v_wasele, g_akt_spieler).f_name).f_name[(1 + g_sprache)]) + ")"), 2);
									p_leeren(v_wasele);
								}
								v_counter = (v_counter + 1);
							} while (!((v_geklaut == 1) || (v_counter > 500)));
						} else {
							p_nachricht(37, 2);
						}
					}
					break;
				case 4:
					p_sound(25);
					p_sternchen(156, 156, 1);
					p_nachricht(31, 2);
					v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft + 1)) + 2);
					if ((a_skills(126, g_akt_spieler).f_gewaehlt == 1)) {
						v_schaden = (v_schaden * 2);
					}
					a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana - v_schaden);
					if ((a_spieler(g_akt_spieler).f_mana < 0)) {
						a_spieler(g_akt_spieler).f_mana = 0;
					}
					break;
				case 5:
					p_sound(25);
					for (v_j = 1; v_j <= 5; v_j += 1) {
						for (v_i = 1; v_i <= 4; v_i += 1) {
							p_laby_screen2();
							if ((v_i == 1)) {
								p_clipsprite(17, 80, 40, 39, 39);
							}
							if ((v_i == 2)) {
								p_clipsprite(17, 120, 40, 39, 39);
							}
							if ((v_i == 3)) {
								p_clipsprite(17, 1, 80, 39, 39);
							}
							if ((v_i == 4)) {
								p_clipsprite(17, 40, 80, 39, 39);
							}
							p_displaytransparentsprite(17, 156, 156);
							p_flipbuffers(1);
							p_delay(90);
						}
					}
					if ((p_habich(124) > 0)) {
						p_nachricht(431, 2);
					} else {
						p_nachricht(32, 2);
						v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft + 1)) + 2);
						if ((a_skills(126, g_akt_spieler).f_gewaehlt == 1)) {
							v_schaden = (v_schaden * 2);
						}
						p_spielerschaden(v_schaden, 1, 7);
						a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_lebenspunkte = (a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_lebenspunkte + v_schaden);
					}
					break;
				case 6:
					p_sound(13);
					p_nachricht(27, 2);
					p_fernangriff_monster(3);
					if ((p_habich(124) > 0)) {
						p_nachricht(431, 2);
					} else {
						v_schaden = (p_random((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauberkraft + 1)) + 2);
						if ((a_skills(126, g_akt_spieler).f_gewaehlt == 1)) {
							v_schaden = (v_schaden * 2);
						}
						p_spielerschaden(v_schaden, 1, 6);
					}
					break;
				case 7:
					p_sound(25);
					p_nachricht(521, 2);
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					a_spieler(g_akt_spieler).f_character_x = a_eingangx(a_spieler(g_akt_spieler).f_level);
					a_spieler(g_akt_spieler).f_character_y = a_eingangy(a_spieler(g_akt_spieler).f_level);
					p_laby_screen();
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					for (v_i = 1; v_i <= 8; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
						p_displaytransparentsprite(37, 160, 160);
						p_flipbuffers(1);
						p_delay(90);
					}
					break;
				case 8:
					p_sound(25);
					p_sternchen(156, 156, 3);
					p_nachricht(594, 2);
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if (((a_aktive(v_i, g_akt_spieler).f_dauer > 0) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							a_aktive(v_i, g_akt_spieler).f_dauer = 0;
						}
					}
					p_laby_screen();
					break;
				}
			}
		}
	}
}

static int32_t p_fernkampf() {
	int32_t v_i = 0;
	int16_t v_x = 0;
	int16_t v_xx = 0;
	int16_t v_y = 0;
	int16_t v_yy = 0;
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_spieler(g_akt_spieler).f_character_y - v_i) > 0)) {
			if ((p_istmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - v_i)) == 1)) {
				if ((p_hat_fernkampf(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - v_i)) == 1)) {
					if (((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - v_i)).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - v_i)).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
						g_spell_x = 0;
						g_spell_y = (v_i - (2 * v_i));
						p_los();
						v_x = (g_spell_x + 5);
						v_y = (g_spell_y + 5);
						v_xx = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
						v_yy = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
						p_restaurieren();
						p_fernattack(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - v_i), v_i);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
						p_restaurieren();
					}
				}
			}
		}
	}
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_spieler(g_akt_spieler).f_character_y + v_i) <= a_groesse(a_spieler(g_akt_spieler).f_level))) {
			if ((p_istmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + v_i)) == 1)) {
				if ((p_hat_fernkampf(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + v_i)) == 1)) {
					if (((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + v_i)).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + v_i)).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
						g_spell_x = 0;
						g_spell_y = v_i;
						p_los();
						v_x = (g_spell_x + 5);
						v_y = (g_spell_y + 5);
						v_xx = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
						v_yy = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
						p_restaurieren();
						p_fernattack(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + v_i), v_i);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
						p_restaurieren();
					}
				}
			}
		}
	}
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_spieler(g_akt_spieler).f_character_x - v_i) > 0)) {
			if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x - v_i), a_spieler(g_akt_spieler).f_character_y) == 1)) {
				if ((p_hat_fernkampf((a_spieler(g_akt_spieler).f_character_x - v_i), a_spieler(g_akt_spieler).f_character_y) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - v_i), a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x - v_i), a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
						g_spell_x = (v_i - (2 * v_i));
						g_spell_y = 0;
						p_los();
						v_x = (g_spell_x + 5);
						v_y = (g_spell_y + 5);
						v_xx = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
						v_yy = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
						p_restaurieren();
						p_fernattack((a_spieler(g_akt_spieler).f_character_x - v_i), a_spieler(g_akt_spieler).f_character_y, v_i);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
						p_restaurieren();
					}
				}
			}
		}
	}
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_spieler(g_akt_spieler).f_character_x + v_i) <= a_groesse(a_spieler(g_akt_spieler).f_level))) {
			if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + v_i), a_spieler(g_akt_spieler).f_character_y) == 1)) {
				if ((p_hat_fernkampf((a_spieler(g_akt_spieler).f_character_x + v_i), a_spieler(g_akt_spieler).f_character_y) == 1)) {
					if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + v_i), a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + v_i), a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
						g_spell_x = v_i;
						g_spell_y = 0;
						p_los();
						v_x = (g_spell_x + 5);
						v_y = (g_spell_y + 5);
						v_xx = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
						v_yy = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
						p_restaurieren();
						p_fernattack((a_spieler(g_akt_spieler).f_character_x + v_i), a_spieler(g_akt_spieler).f_character_y, v_i);
						if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
							p_draw_tile(53, v_x, v_y, 0, 0);
						} else {
							p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
						}
						p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
						p_restaurieren();
					}
				}
			}
		}
	}
}

static int32_t p_feuerschaden(int16_t v_schaden) {
	int16_t v_testfeld = 0;
	v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
	if ((((a_spieler(g_akt_spieler).f_character_x + g_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) > 0))) {
		if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
			if ((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 15) == 1) && (p_random(100) > 50)) && (p_habich(160) == 0))) {
				p_nachricht(312, 2);
			} else {
				if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 11) == 1)) {
					v_schaden = (v_schaden * 2);
				}
				if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 12) == 0) || (p_habich(160) > 0))) {
					p_monsterschaden(v_schaden);
				} else {
					p_nachricht(265, 3);
				}
			}
		}
		if ((v_testfeld == 80)) {
			if ((v_schaden > 3)) {
				p_sound(23);
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_delay(g_mydelay);
				p_laby_screen();
			}
		}
	}
}

static int32_t p_finden1() {
	int16_t v_egon = 0;
	int32_t v_hugo = 0;
	int16_t v_obje = 0;
	int16_t v_willi = 0;
	v_obje = 0;
	v_hugo = (p_random(12) + 1);
	if ((g_test == 1)) {
		v_hugo = 5;
	}
	switch (v_hugo) {
	case 1:
		if ((p_random(15) < 15)) {
			v_hugo = p_random(14);
			v_obje = (24 + v_hugo);
		} else {
			v_obje = 41;
		}
		break;
	case 2:
		v_hugo = p_random(20);
		v_obje = (1 + v_hugo);
		break;
	case 3:
		v_hugo = (p_random(2) + 1);
		if ((v_hugo == 1)) {
			v_obje = (56 + p_random(9));
		}
		if ((v_hugo == 2)) {
			v_obje = (42 + p_random(2));
		}
		if ((v_hugo == 3)) {
			v_willi = (p_random(3) + 1);
			switch (v_willi) {
			case 1:
				v_obje = 53;
				break;
			case 2:
				v_obje = 383;
				break;
			case 3:
				v_obje = 384;
				break;
			case 4:
				v_obje = 396;
				break;
			}
		}
		break;
	case 4:
		do {
			v_egon = (p_random(405) + 1);
			if ((a_gegenstand(v_egon).f_art == 16)) {
				v_obje = v_egon;
			}
		} while (!(v_obje > 0));
		break;
	case 5:
		v_obje = (p_random(37) + 75);
		break;
	case 6:
		v_hugo = p_random(100);
		if ((v_hugo < 51)) {
			v_obje = 270;
		} else {
			v_obje = 269;
		}
		break;
	case 7:
		v_hugo = (p_random(6) + 1);
		switch (v_hugo) {
		case 1:
			v_obje = 291;
			break;
		case 2:
			v_obje = 292;
			break;
		case 3:
			v_obje = 190;
			break;
		case 4:
			v_obje = 170;
			break;
		case 5:
			v_obje = 171;
			break;
		case 6:
			v_obje = 172;
			break;
		case 7:
			v_obje = 173;
			break;
		}
		break;
	case 8:
		v_hugo = p_random(100);
		if ((v_hugo < 51)) {
			v_obje = 231;
		} else {
			v_obje = 219;
		}
		break;
	case 9:
		v_obje = 38;
		break;
	case 10:
		v_hugo = p_random(100);
		if ((v_hugo < 61)) {
			v_obje = 46;
		}
		if (((v_hugo > 60) && (v_hugo < 85))) {
			v_obje = 39;
		}
		if ((v_hugo > 84)) {
			v_obje = 134;
		}
		break;
	case 11:
		if ((p_random(100) < 50)) {
			v_obje = 353;
		} else {
			v_obje = 249;
		}
		break;
	case 12:
		do {
			v_hugo = p_random(18);
			v_obje = (357 + v_hugo);
		} while (!(v_obje != 367));
		break;
	case 13:
		v_obje = (75 + p_random(37));
		break;
	}
	return v_obje;
}

static int32_t p_finden2() {
	int16_t v_egon = 0;
	int32_t v_hugo = 0;
	int16_t v_mag_geg = 0;
	int32_t v_willi = 0;
	v_mag_geg = 0;
	v_egon = 0;
	v_hugo = (p_random(5) + 1);
	if ((g_test == 1)) {
		v_hugo = 1;
	}
	switch (v_hugo) {
	case 1:
		do {
			v_egon = (p_random(405) + 1);
			if ((a_gegenstand(v_egon).f_art == 18)) {
				v_mag_geg = v_egon;
			}
		} while (!(v_mag_geg > 0));
		break;
	case 2:
		do {
			v_egon = (p_random(405) + 1);
			if ((a_gegenstand(v_egon).f_art == 22)) {
				v_mag_geg = v_egon;
			}
		} while (!(v_mag_geg > 0));
		break;
	case 3:
		do {
			v_egon = (p_random(405) + 1);
			if ((a_gegenstand(v_egon).f_art == 20)) {
				v_mag_geg = v_egon;
			}
		} while (!(v_mag_geg > 0));
		break;
	case 4:
		v_willi = (p_random(28) + 1);
		switch (v_willi) {
		case 1:
			v_mag_geg = 142;
			break;
		case 2:
			v_mag_geg = 143;
			break;
		case 3:
			v_mag_geg = 187;
			break;
		case 4:
			v_mag_geg = 237;
			break;
		case 5:
			v_mag_geg = 161;
			break;
		case 6:
			v_mag_geg = 155;
			break;
		case 7:
			v_mag_geg = 157;
			break;
		case 8:
			v_mag_geg = 280;
			break;
		case 9:
			v_mag_geg = 281;
			break;
		case 10:
			v_mag_geg = 286;
			break;
		case 11:
			v_mag_geg = 284;
			break;
		case 12:
			v_mag_geg = 280;
			break;
		case 13:
			v_mag_geg = 288;
			break;
		case 14:
			v_mag_geg = 161;
			break;
		case 15:
			v_mag_geg = 164;
			break;
		case 16:
			v_mag_geg = 162;
			break;
		case 17:
			v_mag_geg = 144;
			break;
		case 18:
			v_mag_geg = 376;
			break;
		case 19:
			v_mag_geg = 377;
			break;
		case 20:
			v_mag_geg = 378;
			break;
		case 21:
			v_mag_geg = 379;
			break;
		case 22:
			v_mag_geg = 380;
			break;
		case 23:
			v_mag_geg = 381;
			break;
		case 24:
			v_mag_geg = 382;
			break;
		case 25:
			v_mag_geg = 238;
			break;
		case 26:
			v_mag_geg = 235;
			break;
		case 27:
			v_mag_geg = 233;
			break;
		case 28:
			v_mag_geg = 236;
			break;
		case 29:
			v_mag_geg = 49;
			break;
		}
		break;
	case 5:
		v_willi = (p_random(17) + 1);
		switch (v_willi) {
		case 1:
			v_mag_geg = 239;
			break;
		case 2:
			v_mag_geg = 200;
			break;
		case 3:
			v_mag_geg = 51;
			break;
		case 4:
			v_mag_geg = 201;
			break;
		case 5:
			v_mag_geg = 222;
			break;
		case 6:
			v_mag_geg = 153;
			break;
		case 7:
			v_mag_geg = 154;
			break;
		case 8:
			v_mag_geg = 229;
			break;
		case 9:
			v_mag_geg = 230;
			break;
		case 10:
			v_mag_geg = 224;
			break;
		case 11:
			v_mag_geg = 225;
			break;
		case 12:
			v_mag_geg = 156;
			break;
		case 13:
			v_mag_geg = 347;
			break;
		case 14:
			v_mag_geg = 348;
			break;
		case 15:
			v_mag_geg = 349;
			break;
		case 16:
			v_mag_geg = 160;
			break;
		case 17:
			v_mag_geg = 54;
			break;
		case 18:
			v_mag_geg = 260;
			break;
		}
		break;
	case 6:
		v_willi = (p_random(12) + 1);
		switch (v_willi) {
		case 1:
			v_mag_geg = 212;
			break;
		case 2:
			v_mag_geg = 146;
			break;
		case 3:
			v_mag_geg = 148;
			break;
		case 4:
			v_mag_geg = 247;
			break;
		case 5:
			v_mag_geg = 244;
			break;
		case 6:
			v_mag_geg = 241;
			break;
		case 7:
			v_mag_geg = 158;
			break;
		case 8:
			v_mag_geg = 165;
			break;
		case 9:
			v_mag_geg = 289;
			break;
		case 10:
			v_mag_geg = 248;
			break;
		case 11:
			v_mag_geg = 159;
			break;
		case 12:
			v_mag_geg = 399;
			break;
		case 13:
			v_mag_geg = 400;
			break;
		}
		break;
	}
	return v_mag_geg;
}

static int32_t p_freie_magie() {
	int16_t v_akt_zauber = 0;
	int32_t v_aktuell = 0;
	int32_t v_besch = 0;
	int16_t v_i = 0;
	int16_t v_j = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_mauszauber = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	std::string v_mzauber;
	int32_t v_raushier = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	p_liste_leeren();
	g_anz_zauber = 1;
	for (v_i = 1; v_i <= 177; v_i += 1) {
		if (((a_zauber(v_i, g_akt_spieler).f_level <= a_spieler(g_akt_spieler).f_circle) && (a_zauber(v_i, g_akt_spieler).f_erlernt == 0))) {
			if ((p_zauber_nehmen(v_i) == 0)) {
				for (v_j = 1; v_j <= 3; v_j += 1) {
					a_zauberliste((g_anz_zauber + g_akt_zauber_offset2)).f_name[v_j] = a_zauber(v_i, g_akt_spieler).f_name[v_j];
				}
				g_anz_zauber = (g_anz_zauber + 1);
			}
		}
	}
	p_bubblesort();
	v_akt_zauber = 1;
	do {
		p_fenster(0);
		p_clearscreen(0);
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		p_examinekeyboard();
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mouse_links = p_mousebutton(1);
		v_mouse_rechts = p_mousebutton(2);
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			if ((v_akt_zauber < (g_anz_zauber - 1))) {
				v_akt_zauber = (v_akt_zauber + 1);
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			if ((v_akt_zauber > 0)) {
				v_akt_zauber = (v_akt_zauber - 1);
			}
		}
		p_frontcolor(p_rgb(150, 150, 150));
		p_box(200, (200 + g_yplus2), 260, g_yplus, -1);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(250, 25, a_nachricht_text(593, (1 + g_sprache)), -1, 0);
		v_x = 250;
		v_y = 52;
		v_besch = 0;
		v_mzauber = "";
		for (v_i = 1; v_i <= g_anzz; v_i += 1) {
			p_frontcolor(p_rgb(255, 255, 255));
			if ((v_i == v_mauszauber)) {
				p_frontcolor(p_rgb(1, 1, 255));
				v_mzauber = a_zauberliste((v_i + v_akt_zauber)).f_name[2];
			}
			p_drawtext(v_x, v_y, a_zauberliste((v_i + v_akt_zauber)).f_name[(1 + g_sprache)], -1, 0);
			v_y = (v_y + g_yplus);
		}
		if ((v_mzauber == "")) {
			for (v_i = 1; v_i <= 177; v_i += 1) {
				if ((a_zauber(v_i, g_akt_spieler).f_name[2] == a_zauberliste((v_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
					v_besch = v_i;
				}
			}
		} else {
			for (v_i = 1; v_i <= 177; v_i += 1) {
				if ((a_zauber(v_i, g_akt_spieler).f_name[2] == v_mzauber)) {
					v_besch = v_i;
				}
			}
		}
		if ((v_besch > 0)) {
			v_x = 350;
			v_y = 390;
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_x, v_y, p_nachricht4(61), -1, 0);
			p_drawtext((v_x + 100), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_level), -1, 0);
			v_y = (v_y + g_yplus);
			p_drawtext(v_x, v_y, p_nachricht4(101), -1, 0);
			p_drawtext((v_x + 100), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_kosten), -1, 0);
			v_y = (v_y + g_yplus);
			p_drawtext(v_x, v_y, p_nachricht4(91), -1, 0);
			p_drawtext((v_x + 100), v_y, p_str(p_power(v_besch)), -1, 0);
			v_y = (v_y + g_yplus);
			p_drawtext(v_x, v_y, p_nachricht4(102), -1, 0);
			p_drawtext((v_x + 100), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_dauer), -1, 0);
			v_y = (v_y + g_yplus);
			p_drawtext(v_x, v_y, p_nachricht4(103), -1, 0);
			p_drawtext((v_x + 100), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_chance), -1, 0);
			p_drawtext(25, 400, a_zauber(v_besch, g_akt_spieler).f_besch_1[(1 + g_sprache)], -1, 0);
			p_drawtext(25, 420, a_zauber(v_besch, g_akt_spieler).f_besch_2[(1 + g_sprache)], -1, 0);
		}
		p_stopdrawing();
		if (((((v_mmouse_x >= 590) && (v_mmouse_x <= 622)) && (v_mmouse_y >= 310)) && (v_mmouse_y <= 342))) {
			p_clipsprite(6, 192, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 310);
			if ((v_mouse_links == 1)) {
				if ((v_akt_zauber > 0)) {
					v_akt_zauber = (v_akt_zauber - 1);
					p_delay(50);
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 310);
		}
		if (((((v_mmouse_x > 590) && (v_mmouse_x < 622)) && (v_mmouse_y > 340)) && (v_mmouse_y < 372))) {
			p_clipsprite(6, 224, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 340);
			if ((v_mouse_links == 1)) {
				if ((v_akt_zauber < (g_anz_zauber - 1))) {
					if ((v_akt_zauber < (g_anz_zauber - 1))) {
						v_akt_zauber = (v_akt_zauber + 1);
					}
					p_delay(50);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 340);
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(50);
		v_mauszauber = 0;
		v_y = 52;
		v_aktuell = 1;
		if (((v_mmouse_x > 250) && (v_mmouse_x < 550))) {
			for (v_i = 1; v_i <= g_anzz; v_i += 1) {
				if (((v_mmouse_y >= v_y) && (v_mmouse_y <= (v_y + g_yplus)))) {
					v_mauszauber = v_aktuell;
				}
				v_y = (v_y + g_yplus);
				v_aktuell = (v_aktuell + 1);
			}
		}
		v_raushier = 0;
		if (((v_mouse_links == 1) && (v_mauszauber > 0))) {
			v_raushier = 1;
		}
	} while (!((((v_raushier == 1) || (v_mouse_rechts == 1)) || p_keyboardpushed(13)) || (v_jb1 != 0)));
	if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
		a_zauber(v_besch, g_akt_spieler).f_erlernt = 1;
	}
	if ((v_raushier == 1)) {
		a_zauber(v_besch, g_akt_spieler).f_erlernt = 1;
	}
	p_nachricht(483, 1);
}

static int32_t p_ftasten() {
	int32_t v_ftaste = 0;
	v_ftaste = 0;
	if (p_keyboardpushed(282)) {
		v_ftaste = 1;
	}
	if (p_keyboardpushed(283)) {
		v_ftaste = 2;
	}
	if (p_keyboardpushed(284)) {
		v_ftaste = 3;
	}
	if (p_keyboardpushed(285)) {
		v_ftaste = 4;
	}
	if (p_keyboardpushed(286)) {
		v_ftaste = 5;
	}
	if (p_keyboardpushed(287)) {
		v_ftaste = 6;
	}
	if (p_keyboardpushed(288)) {
		v_ftaste = 7;
	}
	if (p_keyboardpushed(289)) {
		v_ftaste = 8;
	}
	if (p_keyboardpushed(290)) {
		v_ftaste = 9;
	}
	if (p_keyboardpushed(291)) {
		v_ftaste = 10;
	}
	if (((v_ftaste > 0) && (a_inventory((v_ftaste + 40), g_akt_spieler).f_name != 0))) {
		g_aktion = 1;
		g_feld = (v_ftaste + 40);
		if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
			g_do_it = 1;
			p_itemtest();
			g_do_it = 0;
		} else {
			g_do_it2 = 1;
			p_itemtest();
			g_do_it2 = 0;
		}
		p_laby_screen();
		p_delay(100);
		throw Lv_nach_zauber;
	}
}

static int32_t p_fullscreen() {
	int32_t v_windowid = 0;
	if ((g_win_mode == 2)) {
		g_win_mode = 1;
		if ((p_openscreen(640, 480, 16, "Lost Labyrinth") == 0)) {
		}
	} else {
		g_win_mode = 2;
		if ((p_openwindowedscreen(v_windowid, 0, 0, 640, 480, 0, 0, 0) == 0)) {
		}
	}
}

static int32_t p_gamespeed() {
	int32_t v_gewaehlt_animationen = 0;
	int16_t v_gewaehlt_message = 0;
	int16_t v_gewaehlt_scrolling = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int16_t v_xx = 0;
	int16_t v_xxx = 0;
	int16_t v_xxxx = 0;
	int32_t v_y = 0;
	int16_t v_yy = 0;
	int16_t v_yyy = 0;
	int16_t v_yyyy = 0;
	v_gewaehlt_message = 0;
	v_gewaehlt_scrolling = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(195, 25, a_nachricht_text(664, (1 + g_sprache)), -1, 0);
		v_xxx = 195;
		v_yyy = 100;
		p_drawtext(v_xxx, v_yyy, a_nachricht_text(665, (1 + g_sprache)), -1, 0);
		v_xx = 195;
		v_yy = 200;
		p_drawtext(v_xx, v_yy, "Scrolling", -1, 0);
		v_xxxx = 195;
		v_yyyy = 300;
		p_drawtext(v_xxxx, v_yyyy, a_nachricht_text(702, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		v_yyy = (v_yyy + 25);
		for (v_y = 1; v_y <= 9; v_y += 1) {
			if (((((v_mmouse_x > (50 + (v_y * 50))) && (v_mmouse_x < (100 + (v_y * 50)))) && (v_mmouse_y > v_yyy)) && (v_mmouse_y < (v_yyy + 50)))) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(100, 100, 100));
				p_box((50 + (v_y * 50)), v_yyy, 50, 50, -1);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				if ((v_y == (g_mydelay / 200))) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yyy), p_str((10 - v_y)), -1, 0);
				p_stopdrawing();
				if ((v_mmouse_links == 1)) {
					v_gewaehlt_message = v_y;
				}
			} else {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawingmode(1);
				if ((v_y == (g_mydelay / 200))) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yyy), p_str((10 - v_y)), -1, 0);
				p_stopdrawing();
			}
		}
		v_yy = (v_yy + 25);
		for (v_y = 1; v_y <= 5; v_y += 1) {
			if (((((v_mmouse_x > (50 + (v_y * 50))) && (v_mmouse_x < (100 + (v_y * 50)))) && (v_mmouse_y > v_yy)) && (v_mmouse_y < (v_yy + 50)))) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(100, 100, 100));
				p_box((50 + (v_y * 50)), v_yy, 50, 50, -1);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				if ((v_y == ((g_mydelay2 / 10) + 1))) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yy), p_str((6 - v_y)), -1, 0);
				p_stopdrawing();
				if ((v_mmouse_links == 1)) {
					v_gewaehlt_scrolling = v_y;
				}
			} else {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawingmode(1);
				if ((v_y == ((g_mydelay2 / 10) + 1))) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yy), p_str((6 - v_y)), -1, 0);
				p_stopdrawing();
			}
		}
		v_yyyy = (v_yyyy + 25);
		for (v_y = 1; v_y <= 4; v_y += 1) {
			if (((((v_mmouse_x > (50 + (v_y * 50))) && (v_mmouse_x < (100 + (v_y * 50)))) && (v_mmouse_y > v_yyyy)) && (v_mmouse_y < (v_yyyy + 50)))) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(100, 100, 100));
				p_box((50 + (v_y * 50)), v_yyyy, 50, 50, -1);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				if (((4 - v_y) == g_mydelay4)) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yyyy), p_str((4 - (v_y - 1))), -1, 0);
				p_stopdrawing();
				if ((v_mmouse_links == 1)) {
					v_gewaehlt_animationen = v_y;
				}
			} else {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawingmode(1);
				if (((4 - v_y) == g_mydelay4)) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				p_drawtext((75 + (v_y * 50)), (17 + v_yyyy), p_str((4 - (v_y - 1))), -1, 0);
				p_stopdrawing();
			}
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(50);
	} while (!((((v_gewaehlt_message > 0) || (v_gewaehlt_scrolling > 0)) || (v_gewaehlt_animationen > 0)) || (v_mmouse_rechts == 1)));
	if ((v_gewaehlt_message > 0)) {
		g_mydelay = (v_gewaehlt_message * 200);
	}
	if ((v_gewaehlt_scrolling > 0)) {
		g_mydelay2 = ((v_gewaehlt_scrolling - 1) * 10);
	}
	if ((v_gewaehlt_animationen > 0)) {
		g_mydelay4 = (4 - v_gewaehlt_animationen);
	}
	p_delay(g_mydelay);
}

static int32_t p_gang_graben(int16_t v_x, int16_t v_y, int16_t v_wand, int16_t v_hauptgang, int16_t v_mit_was, int16_t v_level) {
	int32_t v_gangende = 0;
	int32_t v_hugo = 0;
	int32_t v_inhalt = 0;
	int16_t v_offen = 0;
	int32_t v_richtung = 0;
	int32_t v_stat = 0;
	int16_t v_was = 0;
	int32_t v_willi = 0;
	g_ganglaenge = 0;
	p_setlaby(v_x, v_y, v_level, a_inhalt(v_level), 0, 0, 0);
	v_stat = 1;
	while ((v_stat < 3)) {
		v_richtung = p_random(100);
		if (((v_y > 1) && (((v_stat == 1) && (v_richtung < 25)) || (v_stat == 2)))) {
			if ((a_labyrinth(v_x, (v_y - 2)).f_feld[v_level] == a_mit_was(v_level))) {
				p_setlaby(v_x, (v_y - 1), v_level, a_inhalt(v_level), 0, 0, 0);
				p_setlaby(v_x, (v_y - 2), v_level, a_inhalt(v_level), 0, 0, 0);
				g_ganglaenge = (g_ganglaenge + 2);
				v_y = (v_y - 2);
				v_stat = 0;
			}
		}
		if (((v_y < (a_groesse(v_level) - 1)) && ((((v_stat == 1) && (v_richtung >= 25)) && (v_richtung < 50)) || (v_stat == 2)))) {
			if ((a_labyrinth(v_x, (v_y + 2)).f_feld[v_level] == a_mit_was(v_level))) {
				p_setlaby(v_x, (v_y + 1), v_level, a_inhalt(v_level), 0, 0, 0);
				p_setlaby(v_x, (v_y + 2), v_level, a_inhalt(v_level), 0, 0, 0);
				g_ganglaenge = (g_ganglaenge + 2);
				v_y = (v_y + 2);
				v_stat = 0;
			}
		}
		if (((v_x > 1) && ((((v_stat == 1) && (v_richtung >= 50)) && (v_richtung < 75)) || (v_stat == 2)))) {
			if ((a_labyrinth((v_x - 2), v_y).f_feld[v_level] == a_mit_was(v_level))) {
				p_setlaby((v_x - 1), v_y, v_level, a_inhalt(v_level), 0, 0, 0);
				p_setlaby((v_x - 2), v_y, v_level, a_inhalt(v_level), 0, 0, 0);
				g_ganglaenge = (g_ganglaenge + 2);
				v_x = (v_x - 2);
				v_stat = 0;
			}
		}
		if (((v_x < (a_groesse(v_level) - 1)) && (((v_stat == 1) && (v_richtung >= 75)) || (v_stat == 2)))) {
			if ((a_labyrinth((v_x + 2), v_y).f_feld[v_level] == a_mit_was(v_level))) {
				p_setlaby((v_x + 1), v_y, v_level, a_inhalt(v_level), 0, 0, 0);
				p_setlaby((v_x + 2), v_y, v_level, a_inhalt(v_level), 0, 0, 0);
				g_ganglaenge = (g_ganglaenge + 2);
				v_x = (v_x + 2);
				v_stat = 0;
			}
		}
		v_stat = (v_stat + 1);
	}
	v_gangende = a_inhalt(v_level);
	v_willi = p_random(100);
	if ((v_willi < 25)) {
		if ((p_random(100) > 90)) {
			v_gangende = 73;
		} else {
			v_gangende = 9;
		}
	}
	if (((v_willi >= 25) && (v_willi < 50))) {
		v_gangende = 6;
		if ((p_random(100) > 90)) {
			if ((p_random(100) > 50)) {
				v_gangende = 62;
			} else {
				v_gangende = 63;
			}
		}
		if ((((p_random(100) < 50) && (p_random(99) < v_level)) && (v_level > 9))) {
			v_gangende = 97;
		}
	}
	if (((v_willi >= 50) && (v_willi < 75))) {
		v_gangende = a_inhalt(v_level);
	}
	if ((v_willi >= 75)) {
		if ((p_random(100) > 50)) {
			v_gangende = 75;
		} else {
			p_setitem(v_x, v_y, v_level, (65 + p_random(9)), 0, 0);
		}
	}
	if (((v_gangende == 6) && (p_random(99) < (v_level / 3)))) {
		v_gangende = 67;
	}
	v_was = 0;
	if ((v_gangende == 6)) {
		v_was = p_finden1();
	}
	if ((v_gangende == 67)) {
		v_was = p_finden2();
	}
	if (((v_gangende == 62) || (v_gangende == 63))) {
		if ((p_random(100) > 50)) {
			v_was = p_finden1();
		} else {
			v_was = p_finden2();
		}
	}
	if ((v_was > 0)) {
		p_setlaby(v_x, v_y, v_level, v_gangende, 0, 0, v_was);
	}
	if ((v_hauptgang == 0)) {
		if ((v_x > 1)) {
			if ((((a_labyrinth((v_x - 2), v_y).f_feld[v_level] == a_inhalt(v_level)) && (a_labyrinth((v_x - 1), v_y).f_feld[v_level] == v_wand)) && (v_x > 1))) {
				v_hugo = p_random(100);
				if ((v_hugo < 34)) {
					if ((a_sonderlevel(v_level) == 0)) {
						p_setlaby((v_x - 1), v_y, v_level, 20, 0, 0, 0);
					}
				}
				if (((v_hugo >= 34) && (v_hugo < 67))) {
					p_setlaby((v_x - 1), v_y, v_level, v_inhalt, 0, 0, 0);
				}
				if ((v_hugo >= 67)) {
					if ((a_sonderlevel(v_level) != 11)) {
						v_offen = 0;
						if ((p_random(100) > 85)) {
							v_offen = 2;
						}
						p_setlaby((v_x - 1), v_y, v_level, 70, 0, 0, v_offen);
					}
				}
			}
		}
		if ((((a_labyrinth((v_x + 2), v_y).f_feld[v_level] == a_inhalt(v_level)) && (a_labyrinth((v_x + 1), v_y).f_feld[v_level] == v_wand)) && (v_x < (a_groesse(v_level) - 2)))) {
			v_hugo = p_random(100);
			if ((v_hugo < 34)) {
				if ((a_sonderlevel(v_level) == 0)) {
					p_setlaby((v_x + 1), v_y, v_level, 20, 0, 0, 0);
				}
			}
			if (((v_hugo >= 34) && (v_hugo < 67))) {
				p_setlaby((v_x + 1), v_y, v_level, a_inhalt(v_level), 0, 0, 0);
			}
			if ((v_hugo >= 67)) {
				if ((a_sonderlevel(v_level) != 11)) {
					v_offen = 0;
					if ((p_random(100) > 85)) {
						v_offen = 2;
					}
					p_setlaby((v_x + 1), v_y, v_level, 70, 0, 0, v_offen);
				}
			}
		}
		if ((v_y > 1)) {
			if ((((a_labyrinth(v_x, (v_y - 2)).f_feld[v_level] == a_inhalt(v_level)) && (a_labyrinth(v_x, (v_y - 1)).f_feld[v_level] == v_wand)) && (v_y > 1))) {
				v_hugo = p_random(100);
				if ((v_hugo < 34)) {
					if ((a_sonderlevel(v_level) == 0)) {
						p_setlaby(v_x, (v_y - 1), v_level, 20, 0, 0, 0);
					}
				}
				if (((v_hugo >= 34) && (v_hugo < 67))) {
					p_setlaby(v_x, (v_y - 1), v_level, a_inhalt(v_level), 0, 0, 0);
				}
				if ((v_hugo >= 67)) {
					if ((a_sonderlevel(v_level) != 11)) {
						v_offen = 0;
						if ((p_random(100) > 85)) {
							v_offen = 2;
						}
						p_setlaby(v_x, (v_y - 1), v_level, 70, 0, 0, v_offen);
					}
				}
			}
		}
		if ((((a_labyrinth(v_x, (v_y + 2)).f_feld[v_level] == a_inhalt(v_level)) && (a_labyrinth(v_x, (v_y + 1)).f_feld[v_level] == v_wand)) && (v_y < (a_groesse(v_level) - 2)))) {
			v_hugo = p_random(100);
			if ((v_hugo < 34)) {
				p_setlaby(v_x, (v_y + 1), v_level, 20, 0, 0, 0);
			}
			if (((v_hugo >= 34) && (v_hugo < 67))) {
				p_setlaby(v_x, (v_y + 1), v_level, a_inhalt(v_level), 0, 0, 0);
			}
			if ((v_hugo >= 67)) {
				if ((a_sonderlevel(v_level) != 11)) {
					v_offen = 0;
					if ((p_random(100) > 85)) {
						v_offen = 2;
					}
					p_setlaby(v_x, (v_y + 1), v_level, 70, 0, 0, v_offen);
				}
			}
		}
	}
	g_pos = ((v_y * a_groesse(v_level)) + v_x);
}

static int32_t p_gefaehrte(int32_t v_welcher) {
	int16_t v_anstellen = 0;
	int16_t v_at = 0;
	int16_t v_attack = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_kosten = 0;
	int16_t v_lp = 0;
	int16_t v_mit_was = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int8_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_s_max = 0;
	int16_t v_s_min = 0;
	int16_t v_sel = 0;
	int16_t v_sp = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_sel = 1;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_raus = 0;
		v_lp = 0;
		v_at = 0;
		v_s_min = 0;
		v_s_max = 0;
		v_sp = 0;
		v_attack = 0;
		v_anstellen = 0;
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = 1;
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = 2;
		}
		v_yy = 65;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, v_yy, a_nachricht_text(273, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(190, v_yy, a_nachricht_text(274, (1 + g_sprache)), -1, 0);
		switch (v_welcher) {
		case 1:
			v_lp = 10;
			v_at = 45;
			v_sp = 5;
			v_s_min = 1;
			v_s_max = 6;
			v_kosten = 15;
			break;
		case 2:
			v_lp = 15;
			v_at = 45;
			v_sp = 5;
			v_s_min = 1;
			v_s_max = 7;
			v_kosten = 20;
			break;
		case 3:
			v_lp = 20;
			v_at = 50;
			v_sp = 6;
			v_s_min = 1;
			v_s_max = 8;
			v_kosten = 25;
			break;
		case 4:
			v_lp = 25;
			v_at = 50;
			v_sp = 6;
			v_s_min = 1;
			v_s_max = 9;
			v_kosten = 30;
			break;
		case 5:
			v_lp = 30;
			v_at = 55;
			v_sp = 7;
			v_s_min = 2;
			v_s_max = 10;
			v_kosten = 35;
			break;
		case 6:
			v_lp = 35;
			v_at = 55;
			v_sp = 7;
			v_s_min = 2;
			v_s_max = 12;
			v_kosten = 40;
			break;
		case 7:
			v_lp = 40;
			v_at = 60;
			v_sp = 8;
			v_s_min = 2;
			v_s_max = 14;
			v_kosten = 45;
			break;
		case 8:
			v_lp = 45;
			v_at = 65;
			v_sp = 8;
			v_s_min = 3;
			v_s_max = 15;
			v_kosten = 50;
			break;
		case 9:
			v_lp = 50;
			v_at = 70;
			v_sp = 9;
			v_s_min = 3;
			v_s_max = 18;
			v_kosten = 70;
			break;
		case 10:
			v_lp = 55;
			v_at = 80;
			v_sp = 9;
			v_s_min = 3;
			v_s_max = 20;
			v_kosten = 80;
			break;
		}
		if ((a_skills(114, g_akt_spieler).f_gewaehlt == 1)) {
			v_kosten = (int32_t)((v_kosten * 0.75));
		}
		v_yy = (v_yy + 25);
		p_drawtext(100, v_yy, a_nachricht_text(276, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(100, v_yy, ((a_nachricht_text(55, (1 + g_sprache)) + "  ") + p_str(v_lp)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(100, v_yy, ((a_nachricht_text(52, (1 + g_sprache)) + "  ") + p_str(v_at)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(100, v_yy, ((a_nachricht_text(56, (1 + g_sprache)) + "  ") + p_str(v_sp)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(100, v_yy, ((a_nachricht_text(101, (1 + g_sprache)) + "  ") + p_str(v_kosten)), -1, 0);
		v_yy = (v_yy + 35);
		if ((g_sprache == 0)) {
			p_drawtext(100, v_yy, ("Your Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 1)) {
			p_drawtext(100, v_yy, ("Dein Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 2)) {
			p_drawtext(100, v_yy, ("Tu oro: " + p_str(p_gold_anzahl())), -1, 0);
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		if (((((v_mmouse_x > 90) && (v_mmouse_x < 150)) && (v_mmouse_y > 260)) && (v_mmouse_y < 280))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(90, 260, 50, 20, -1);
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(90, 260, a_nachricht_text(277, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_anstellen = 1;
			}
		} else {
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_anstellen = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(90, 260, a_nachricht_text(277, (1 + g_sprache)), -1, 0);
		}
		if ((v_anstellen == 1)) {
			if ((p_gold_anzahl() >= v_kosten)) {
				p_gold_verlieren(v_kosten);
				v_raus = 1;
				a_spieler(g_akt_spieler).f_creature_typ = 20;
				a_spieler(g_akt_spieler).f_creature_x = (a_spieler(g_akt_spieler).f_character_x + 1);
				a_spieler(g_akt_spieler).f_creature_y = (a_spieler(g_akt_spieler).f_character_y + 1);
				a_spieler(g_akt_spieler).f_creature_attack = v_at;
				a_spieler(g_akt_spieler).f_creature_lifepoints = v_lp;
				a_spieler(g_akt_spieler).f_creature_schaden_min = v_s_min;
				a_spieler(g_akt_spieler).f_creature_schaden_max = v_s_max;
				a_spieler(g_akt_spieler).f_creature_maxspeed = v_sp;
				v_mit_was = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_mit_was, 0, 0, 0);
				p_nachricht(280, 1);
			} else {
				p_nachricht(215, 5);
				v_raus = 1;
			}
		}
		if (((((v_mmouse_x > 90) && (v_mmouse_x < 150)) && (v_mmouse_y > 280)) && (v_mmouse_y < 300))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(90, 280, 50, 20, -1);
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(90, 280, a_nachricht_text(278, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
			}
		} else {
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(90, 280, a_nachricht_text(278, (1 + g_sprache)), -1, 0);
		}
		p_stopdrawing();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	g_aktion = 1;
}

static int32_t p_gen_laby(int16_t v_akt_level) {
	int32_t v_anfang = 0;
	int32_t v_anz_bowlders = 0;
	int16_t v_anz_herbs = 0;
	int16_t v_anz_scrolls = 0;
	int32_t v_anzahl_fallen = 0;
	int16_t v_anzahl_runen = 0;
	int16_t v_ausg_x = 0;
	int16_t v_ausg_y = 0;
	int32_t v_ausgang_vorh = 0;
	int32_t v_breite = 0;
	int16_t v_counter = 0;
	int16_t v_counter2 = 0;
	int16_t v_erreichbar = 0;
	int32_t v_falle = 0;
	int16_t v_filler = 0;
	int32_t v_graben = 0;
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_level = 0;
	int32_t v_ok = 0;
	int16_t v_special = 0;
	float v_verg1 = 0.0;
	float v_verg2 = 0.0;
	int16_t v_was = 0;
	int16_t v_which = 0;
	int16_t v_willi = 0;
	int32_t v_x = 0;
	int32_t v_xx = 0;
	int32_t v_y = 0;
	int32_t v_yy = 0;
	int32_t v_zaehler = 0;
	int32_t v_ziel_x = 0;
	int32_t v_ziel_y = 0;
	a_groesse(v_akt_level) = (v_akt_level + 10);
	a_eingangx(v_akt_level) = 1;
	a_eingangy(v_akt_level) = 1;
	if ((g_test == 1)) {
		a_groesse(v_akt_level) = 100;
	}
	v_verg1 = (v_akt_level / 5.0);
	v_verg2 = (int32_t)((v_akt_level / 5.0));
	if ((v_verg1 == v_verg2)) {
		if ((p_random(5) > 4)) {
			g_mit_was_normal = 1;
		} else {
			g_mit_was_normal = (101 + p_random(3));
		}
		if ((p_random(6) > 5)) {
			g_inhalt_normal = 4;
		} else {
			g_inhalt_normal = (105 + p_random(4));
		}
	}
	a_mit_was(v_akt_level) = g_mit_was_normal;
	a_inhalt(v_akt_level) = g_inhalt_normal;
	a_visionen(v_akt_level) = 1;
	if ((a_levelmod(v_akt_level) == 8)) {
		a_inhalt(v_akt_level) = 81;
	}
	if ((a_sonderlevel(v_akt_level) == 1)) {
		a_mit_was(v_akt_level) = 165;
		a_inhalt(v_akt_level) = 204;
	}
	if ((a_sonderlevel(v_akt_level) == 2)) {
		a_mit_was(v_akt_level) = 41;
		a_inhalt(v_akt_level) = 110;
	}
	if ((a_sonderlevel(v_akt_level) == 3)) {
		a_mit_was(v_akt_level) = 55;
	}
	if ((a_sonderlevel(v_akt_level) == 4)) {
		a_mit_was(v_akt_level) = 1;
		a_inhalt(v_akt_level) = 89;
	}
	if ((a_sonderlevel(v_akt_level) == 5)) {
		a_mit_was(v_akt_level) = 1;
	}
	if ((a_sonderlevel(v_akt_level) == 6)) {
		a_mit_was(v_akt_level) = 136;
		a_inhalt(v_akt_level) = 94;
	}
	if ((a_sonderlevel(v_akt_level) == 7)) {
		a_mit_was(v_akt_level) = 45;
		a_inhalt(v_akt_level) = 44;
	}
	if ((a_sonderlevel(v_akt_level) == 8)) {
		a_mit_was(v_akt_level) = 88;
		a_inhalt(v_akt_level) = 89;
	}
	if ((a_sonderlevel(v_akt_level) == 9)) {
		a_mit_was(v_akt_level) = 178;
		a_inhalt(v_akt_level) = 177;
	}
	if ((a_sonderlevel(v_akt_level) == 10)) {
		a_mit_was(v_akt_level) = 53;
		a_inhalt(v_akt_level) = 53;
	}
	if ((a_sonderlevel(v_akt_level) == 11)) {
		a_mit_was(v_akt_level) = 199;
		a_inhalt(v_akt_level) = 198;
	}
	v_special = 0;
	if ((a_sonderlevel(v_akt_level) == 9)) {
		v_special = 1;
		for (v_i = 1; v_i <= 200; v_i += 1) {
			for (v_j = 1; v_j <= 200; v_j += 1) {
				p_setlaby(v_i, v_j, v_akt_level, a_mit_was(v_akt_level), 0, 0, 0);
			}
		}
		for (v_i = 1; v_i <= (a_groesse(v_akt_level) / 3); v_i += 1) {
			v_zaehler = 1;
			do {
				v_x = p_random(a_groesse(v_akt_level));
				v_y = p_random(a_groesse(v_akt_level));
				v_zaehler = (v_zaehler + 1);
			} while (!(((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_mit_was(v_akt_level)) && (a_labyrinth((v_x + 1), (v_y + 1)).f_feld[v_akt_level] == a_mit_was(v_akt_level))) && (a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_mit_was(v_akt_level))) && (a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_mit_was(v_akt_level))) || (v_zaehler > 500)));
			if ((v_zaehler <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 182, 0, 0, 0);
				p_setlaby((v_x + 1), v_y, v_akt_level, 183, 0, 0, 0);
				p_setlaby(v_x, (v_y + 1), v_akt_level, 184, 0, 0, 0);
				p_setlaby((v_x + 1), (v_y + 1), v_akt_level, 185, 0, 0, 0);
			}
		}
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
					switch (p_random(13)) {
					case 0:
						p_setlaby(v_i, v_j, v_akt_level, 177, 0, 0, 0);
						break;
					case 1:
						p_setlaby(v_i, v_j, v_akt_level, 177, 0, 0, 0);
						break;
					case 2:
						p_setlaby(v_i, v_j, v_akt_level, 177, 0, 0, 0);
						break;
					case 3:
						p_setlaby(v_i, v_j, v_akt_level, 179, 0, 0, 0);
						break;
					case 4:
						p_setlaby(v_i, v_j, v_akt_level, 179, 0, 0, 0);
						break;
					case 5:
						p_setlaby(v_i, v_j, v_akt_level, 179, 0, 0, 0);
						break;
					case 6:
						p_setlaby(v_i, v_j, v_akt_level, 180, 0, 0, 0);
						break;
					case 7:
						p_setlaby(v_i, v_j, v_akt_level, 180, 0, 0, 0);
						break;
					case 8:
						p_setlaby(v_i, v_j, v_akt_level, 180, 0, 0, 0);
						break;
					case 9:
						p_setlaby(v_i, v_j, v_akt_level, 181, 0, 0, 0);
						break;
					case 10:
						p_setlaby(v_i, v_j, v_akt_level, 181, 0, 0, 0);
						break;
					case 11:
						p_setlaby(v_i, v_j, v_akt_level, 181, 0, 0, 0);
						break;
					case 12:
						p_setlaby(v_i, v_j, v_akt_level, 186, 0, 0, 0);
						break;
					case 13:
						p_setlaby(v_i, v_j, v_akt_level, 187, 0, 0, 0);
						break;
					}
				}
			}
		}
		p_setlaby(1, 1, v_akt_level, 3, 0, 0, 0);
		switch (p_random(2)) {
		case 0:
			v_ziel_x = a_groesse(v_akt_level);
			v_ziel_y = a_groesse(v_akt_level);
			break;
		case 1:
			v_ziel_x = a_groesse(v_akt_level);
			v_ziel_y = 1;
			break;
		case 2:
			v_ziel_x = 1;
			v_ziel_y = a_groesse(v_akt_level);
			break;
		}
		if ((g_test == 0)) {
			p_setlaby(v_ziel_x, v_ziel_y, v_akt_level, 2, 0, 0, 0);
		}
		a_ausgangx(v_akt_level) = v_ziel_x;
		a_ausgangy(v_akt_level) = v_ziel_y;
	}
	if ((a_sonderlevel(v_akt_level) == 10)) {
		v_special = 1;
		for (v_i = a_groesse(v_akt_level); v_i <= 200; v_i += 1) {
			for (v_j = a_groesse(v_akt_level); v_j <= 200; v_j += 1) {
				p_setlaby(v_i, v_j, v_akt_level, a_mit_was(v_akt_level), 0, 0, 1);
			}
		}
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				p_setlaby(v_i, v_j, v_akt_level, a_mit_was(v_akt_level), 0, 0, 0);
			}
		}
		v_x = 1;
		do {
			v_y = 1;
			do {
				v_willi = p_random(2);
				if (((v_x == 1) && (v_y == 1))) {
					v_willi = 1;
				}
				switch (v_willi) {
				case 0:
					p_setlaby(v_x, v_y, v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), v_y, v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), v_y, v_akt_level, 49, 0, 0, 0);
					p_setlaby((v_x + 3), v_y, v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 4), v_y, v_akt_level, 50, 0, 0, 0);
					p_setlaby(v_x, (v_y + 1), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 1), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					if ((p_random(100) > 70)) {
						switch (p_random(2)) {
						case 0:
							p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 191, 0, 0, 0);
							break;
						case 1:
							p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 192, 0, 0, p_finden1());
							break;
						case 2:
							if ((p_random(100) < 80)) {
								p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 193, 0, 0, p_finden2());
							} else {
								p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 194, 0, 0, p_finden2());
							}
							break;
						}
					} else {
						p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					}
					p_setlaby((v_x + 4), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					p_setlaby(v_x, (v_y + 2), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 2), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 51, 0, 0, 0);
					p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 4), (v_y + 2), v_akt_level, 52, 0, 0, 0);
					p_setlaby(v_x, (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 3), (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 4), (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby(v_x, (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 3), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 4), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					break;
				case 1:
					p_setlaby(v_x, v_y, v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), v_y, v_akt_level, 49, 0, 0, 0);
					p_setlaby((v_x + 2), v_y, v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 3), v_y, v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 4), v_y, v_akt_level, 50, 0, 0, 0);
					p_setlaby(v_x, (v_y + 1), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					if ((p_random(100) > 70)) {
						switch (p_random(2)) {
						case 0:
							p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 191, 0, 0, 0);
							break;
						case 1:
							p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 192, 0, 0, p_finden1());
							break;
						case 2:
							if ((p_random(100) < 80)) {
								p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 193, 0, 0, p_finden2());
							} else {
								p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 194, 0, 0, p_finden2());
							}
							break;
						}
					} else {
						p_setlaby((v_x + 2), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					}
					if ((p_random(100) > 70)) {
						switch (p_random(2)) {
						case 0:
							p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 191, 0, 0, 0);
							break;
						case 1:
							p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 192, 0, 0, p_finden1());
							break;
						case 2:
							if ((p_random(100) < 80)) {
								p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 193, 0, 0, p_finden2());
							} else {
								p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 194, 0, 0, p_finden2());
							}
							break;
						}
					} else {
						p_setlaby((v_x + 3), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					}
					p_setlaby((v_x + 4), (v_y + 1), v_akt_level, 94, 0, 0, 0);
					p_setlaby(v_x, (v_y + 2), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 2), v_akt_level, 94, 0, 0, 0);
					if ((p_random(100) > 70)) {
						switch (p_random(2)) {
						case 0:
							p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 191, 0, 0, 0);
							break;
						case 1:
							p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 192, 0, 0, p_finden1());
							break;
						case 2:
							if ((p_random(100) < 80)) {
								p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 193, 0, 0, p_finden2());
							} else {
								p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 194, 0, 0, p_finden2());
							}
							break;
						}
					} else {
						p_setlaby((v_x + 2), (v_y + 2), v_akt_level, 94, 0, 0, 0);
					}
					if ((p_random(100) > 70)) {
						switch (p_random(2)) {
						case 0:
							p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 191, 0, 0, 0);
							break;
						case 1:
							p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 192, 0, 0, p_finden1());
							break;
						case 2:
							if ((p_random(100) < 80)) {
								p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 193, 0, 0, p_finden2());
							} else {
								p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 194, 0, 0, p_finden2());
							}
							break;
						}
					} else {
						p_setlaby((v_x + 3), (v_y + 2), v_akt_level, 94, 0, 0, 0);
					}
					p_setlaby((v_x + 4), (v_y + 2), v_akt_level, 94, 0, 0, 0);
					p_setlaby(v_x, (v_y + 3), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 3), v_akt_level, 51, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 3), v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 3), (v_y + 3), v_akt_level, 94, 0, 0, 0);
					p_setlaby((v_x + 4), (v_y + 3), v_akt_level, 52, 0, 0, 0);
					p_setlaby(v_x, (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 1), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 2), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 3), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					p_setlaby((v_x + 4), (v_y + 4), v_akt_level, 53, 0, 0, 0);
					break;
				case 2:
					for (v_xx = 0; v_xx <= 4; v_xx += 1) {
						for (v_yy = 0; v_yy <= 4; v_yy += 1) {
							p_setlaby((v_x + v_xx), (v_y + v_yy), v_akt_level, 53, 0, 0, 0);
						}
					}
					break;
				}
				v_y = (v_y + 5);
			} while (!(v_y > a_groesse(v_akt_level)));
			v_x = (v_x + 5);
		} while (!(v_x > a_groesse(v_akt_level)));
		for (v_i = 1; v_i <= v_akt_level; v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				switch (p_random(2)) {
				case 0:
					if ((p_random(100) < 80)) {
						p_setlaby(v_x, v_y, v_akt_level, 161, 0, 0, p_finden1());
					} else {
						p_setlaby(v_x, v_y, v_akt_level, 162, 0, 0, p_finden2());
					}
					break;
				case 1:
					p_setlaby(v_x, v_y, v_akt_level, 163, 0, 0, 0);
					break;
				case 2:
					p_setlaby(v_x, v_y, v_akt_level, 160, 0, 0, 0);
					break;
				}
			}
		}
		p_setlaby(1, 1, v_akt_level, 3, 0, 0, 0);
		switch (p_random(2)) {
		case 0:
			v_ziel_x = a_groesse(v_akt_level);
			v_ziel_y = a_groesse(v_akt_level);
			break;
		case 1:
			v_ziel_x = a_groesse(v_akt_level);
			v_ziel_y = 1;
			break;
		case 2:
			v_ziel_x = 1;
			v_ziel_y = a_groesse(v_akt_level);
			break;
		}
		p_setlaby(v_ziel_x, v_ziel_y, v_akt_level, 2, 0, 0, 0);
		a_ausgangx(v_akt_level) = v_ziel_x;
		a_ausgangy(v_akt_level) = v_ziel_y;
	}
	if ((v_special == 0)) {
		do {
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					p_setlaby(v_i, v_j, v_akt_level, a_mit_was(v_akt_level), 0, 0, 0);
				}
			}
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					p_setmonster(v_i, v_j, v_akt_level, 0, 0, 0, 0, 0);
				}
			}
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					p_setitem(v_i, v_j, v_akt_level, 0, 0, 0);
				}
			}
			p_gang_graben(1, 1, 1, 1, a_mit_was(v_akt_level), v_akt_level);
			v_ok = 1;
			if ((g_ganglaenge <= (a_groesse(v_akt_level) * 2))) {
				v_ok = 0;
			}
			v_ziel_y = (g_pos / a_groesse(v_akt_level));
			v_ziel_x = (g_pos - (v_ziel_y * a_groesse(v_akt_level)));
			if (((v_ziel_x < (a_groesse(v_akt_level) / 2)) && (v_ziel_y < (a_groesse(v_akt_level) / 2)))) {
				v_ok = 0;
			}
		} while (!(v_ok == 1));
		for (v_x = 1; v_x <= (a_groesse(v_akt_level) - 2); v_x += 2) {
			for (v_y = 1; v_y <= (a_groesse(v_akt_level) - 2); v_y += 2) {
				if ((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
					v_graben = 0;
					if (((v_graben == 0) && (v_y > 1))) {
						if ((a_labyrinth(v_x, (v_y - 2)).f_feld[v_akt_level] == a_inhalt(v_akt_level))) {
							p_setlaby(v_x, (v_y - 1), v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
							v_graben = 1;
						}
					}
					if (((v_graben == 0) && (v_x < (a_groesse(v_akt_level) - 2)))) {
						if ((a_labyrinth((v_x + 2), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level))) {
							p_setlaby((v_x + 1), v_y, v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
							v_graben = 1;
						}
					}
					if (((v_graben == 0) && (v_y < (a_groesse(v_akt_level) - 2)))) {
						if ((a_labyrinth(v_x, (v_y + 2)).f_feld[v_akt_level] == a_inhalt(v_akt_level))) {
							p_setlaby(v_x, (v_y + 1), v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
							v_graben = 1;
						}
					}
					if (((v_graben == 0) && (v_x > 1))) {
						if ((a_labyrinth((v_x - 2), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level))) {
							p_setlaby((v_x - 1), v_y, v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
							v_graben = 1;
						}
					}
					if ((v_graben == 1)) {
						p_gang_graben(v_x, v_y, a_mit_was(v_akt_level), 0, a_mit_was(v_akt_level), v_akt_level);
					}
				}
			}
		}
		p_setlaby(1, 1, v_akt_level, 3, 0, 0, 0);
		p_setlaby(v_ziel_x, v_ziel_y, v_akt_level, 2, 0, 0, 0);
		a_ausgangx(v_akt_level) = v_ziel_x;
		a_ausgangy(v_akt_level) = v_ziel_y;
	}
	for (v_i = 1; v_i <= 200; v_i += 1) {
		for (v_j = 1; v_j <= 200; v_j += 1) {
			if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 0)) {
				p_setlaby(v_i, v_j, v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 0)) {
		if ((a_raeume(v_akt_level) > 0)) {
			p_setzen(8, 8, v_akt_level);
		}
	}
	if (((v_akt_level > 2) && (a_sonderlevel(v_akt_level) == 0))) {
		v_anzahl_fallen = ((a_groesse(v_akt_level) / 8) * (a_groesse(v_akt_level) / 8));
		if ((a_levelmod(v_akt_level) == 2)) {
			v_anzahl_fallen = (v_anzahl_fallen * 3);
		}
		for (v_i = 1; v_i <= v_anzahl_fallen; v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_akt_level < 10)) {
				v_falle = (p_random(2) + 22);
			}
			if ((v_akt_level > 9)) {
				v_falle = (p_random(8) + 22);
			}
			p_setlaby(v_x, v_y, v_akt_level, v_falle, 0, 0, 0);
		}
	}
	if (((v_akt_level > 2) && (a_sonderlevel(v_akt_level) == 0))) {
		v_anzahl_runen = p_random((v_akt_level / 2));
		if ((g_test == 1)) {
			v_anzahl_runen = 5;
		}
		for (v_i = 1; v_i <= v_anzahl_runen; v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			switch (p_random(2)) {
			case 0:
				p_setlaby(v_x, v_y, v_akt_level, 149, 0, 0, 0);
				break;
			case 1:
				p_setlaby(v_x, v_y, v_akt_level, 158, 0, 0, 0);
				break;
			case 2:
				p_setlaby(v_x, v_y, v_akt_level, 159, 0, 0, 0);
				break;
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) != 10)) {
		for (v_i = 1; v_i <= (v_akt_level + 1); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			v_willi = (p_random(8) + 1);
			if ((p_random(100) > 75)) {
				v_filler = 1;
			} else {
				v_filler = 0;
			}
			switch (v_willi) {
			case 1:
				p_setlaby(v_x, v_y, v_akt_level, 5, v_filler, 0, 0);
				break;
			case 2:
				p_setlaby(v_x, v_y, v_akt_level, 150, v_filler, 0, 0);
				break;
			case 3:
				p_setlaby(v_x, v_y, v_akt_level, 151, v_filler, 0, 0);
				break;
			case 4:
				p_setlaby(v_x, v_y, v_akt_level, 152, v_filler, 0, 0);
				break;
			case 5:
				p_setlaby(v_x, v_y, v_akt_level, 153, v_filler, 0, 0);
				break;
			case 6:
				p_setlaby(v_x, v_y, v_akt_level, 154, v_filler, 0, 0);
				break;
			case 7:
				p_setlaby(v_x, v_y, v_akt_level, 155, v_filler, 0, 0);
				break;
			case 8:
				p_setlaby(v_x, v_y, v_akt_level, 156, v_filler, 0, 0);
				break;
			case 9:
				p_setlaby(v_x, v_y, v_akt_level, 157, v_filler, 0, 0);
				break;
			}
		}
	}
	if ((a_fluss(v_akt_level) == 1)) {
		v_breite = (a_groesse(v_akt_level) / 3);
		if ((p_random(1) == 0)) {
			if ((v_ziel_x > (v_breite + 2))) {
				v_anfang = (p_random((v_ziel_x - v_breite)) + 1);
				for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
					for (v_i = 1; v_i <= v_breite; v_i += 1) {
						if ((p_random(100) < 75)) {
							p_setlaby((v_i + v_anfang), v_j, v_akt_level, 53, 0, 0, 0);
						} else {
							p_setlaby((v_i + v_anfang), v_j, v_akt_level, 72, 0, 0, 0);
						}
					}
				}
			}
		} else {
			if ((v_ziel_y > (v_breite + 2))) {
				v_anfang = (p_random((v_ziel_y - v_breite)) + 1);
				for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
					for (v_j = 1; v_j <= v_breite; v_j += 1) {
						if ((p_random(100) < 90)) {
							p_setlaby(v_i, (v_j + v_anfang), v_akt_level, 53, 0, 0, 0);
						} else {
							p_setlaby(v_i, (v_j + v_anfang), v_akt_level, 72, 0, 0, 0);
						}
					}
				}
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 4)) {
		v_hugo = 122;
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && (v_x > (a_groesse(v_akt_level) / 2))) && (v_y > (a_groesse(v_akt_level) / 2))) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_setmonster(v_x, v_y, v_akt_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, v_hugo, 0);
			a_goblinkoenig(v_akt_level) = 1;
		}
	}
	if ((a_sonderlevel(v_akt_level) == 8)) {
		v_hugo = 121;
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && (v_x > (a_groesse(v_akt_level) / 2))) && (v_y > (a_groesse(v_akt_level) / 2))) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_setmonster(v_x, v_y, v_akt_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, v_hugo, 0);
			a_spinnenkoenigin(v_akt_level) = 1;
		}
	}
	if ((a_sonderlevel(v_akt_level) == 3)) {
		v_hugo = 123;
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && (v_x > (a_groesse(v_akt_level) / 2))) && (v_y > (a_groesse(v_akt_level) / 2))) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_setmonster(v_x, v_y, v_akt_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, v_hugo, 0);
			a_untotenherr(v_akt_level) = 1;
		}
	}
	if ((a_levelmod(v_akt_level) != 5)) {
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_setlaby(v_x, v_y, v_akt_level, 8, (g_anz_spieler * 3), 0, 0);
		}
	}
	if ((a_levelmod(v_akt_level) != 6)) {
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_setlaby(v_x, v_y, v_akt_level, 7, (g_anz_spieler * 3), 1, 0);
		}
	}
	if (((a_sonderlevel(v_akt_level) != 10) && (a_sonderlevel(v_akt_level) != 11))) {
		v_anz_bowlders = p_random(((v_akt_level / 4) + 1));
		if (((v_anz_bowlders > 0) && (a_sonderlevel(v_akt_level) == 0))) {
			for (v_i = 1; v_i <= v_anz_bowlders; v_i += 1) {
				v_counter = 1;
				do {
					v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
					v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
					v_counter = (v_counter + 1);
				} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == 1) || (v_counter > 500)));
				if ((v_counter <= 500)) {
					p_setlaby(v_x, v_y, v_akt_level, 112, 0, 0, 0);
				}
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 0)) {
		v_anz_scrolls = (p_random((v_akt_level / 4)) + 1);
		for (v_i = 1; v_i <= v_anz_scrolls; v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				do {
					v_which = (p_random(176) + 1);
				} while (!(a_zauber(v_which, 1).f_dauer != 9999));
				p_setitem(v_x, v_y, v_akt_level, 38, v_which, 0);
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 11)) {
		for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 200, 0, 0, 0);
			}
		}
		for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 201, 0, 0, 0);
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 0)) {
		v_anz_herbs = (p_random((v_akt_level / 2)) + 1);
		for (v_i = 1; v_i <= v_anz_herbs; v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				if ((p_random(100) > 80)) {
					p_setitem(v_x, v_y, v_akt_level, 354, 0, 0);
				} else {
					p_setitem(v_x, v_y, v_akt_level, 353, 0, 0);
				}
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 8)) {
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 135, 0, 0, 0);
			}
		}
	}
	if ((((p_random(100) > 80) && (a_sonderlevel(v_akt_level) != 10)) && (a_sonderlevel(v_akt_level) != 11))) {
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			v_was = p_finden2();
			p_setlaby(v_x, v_y, v_akt_level, 93, 0, 0, v_was);
		}
	}
	if (((((a_sonderlevel(v_akt_level) != 10) && (a_sonderlevel(v_akt_level) != 11)) && (a_sonderlevel(v_akt_level) != 9)) && ((v_akt_level > 5) || (g_test == 1)))) {
		for (v_i = 1; v_i <= (a_groesse(v_akt_level) / 10); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 209, 0, 0, 0);
			}
		}
	}
	if (((((a_sonderlevel(v_akt_level) != 10) && (a_sonderlevel(v_akt_level) != 11)) && (a_sonderlevel(v_akt_level) != 9)) && (v_akt_level > 7))) {
		for (v_i = 1; v_i <= (p_random((a_groesse(v_akt_level) * 2)) + 1); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 208, 0, 0, 0);
			}
		}
	}
	if ((v_level >= 8)) {
		if ((p_random(100) > 95)) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 202, 0, 0, 0);
			}
		}
	}
	if (((((((p_random(100) > (68 + v_akt_level)) && (a_raeume(v_akt_level) != 1)) && (a_raeume(v_akt_level) != 15)) && (a_raeume(v_akt_level) != 27)) && (a_raeume(v_akt_level) != 28)) && (a_raeume(v_akt_level) != 30))) {
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
		if ((v_counter <= 500)) {
			p_kleinhaendler_init(v_akt_level);
			if ((p_random(100) > 50)) {
				p_setlaby(v_x, v_y, v_akt_level, 120, 0, 0, 0);
			} else {
				p_setlaby(v_x, v_y, v_akt_level, 121, 0, 0, 0);
			}
		}
	}
	if ((a_levelmod(v_akt_level) == 12)) {
		for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 20, 0, 0, 0);
			}
		}
	}
	if ((((((p_random(100) > 40) && (v_akt_level > 3)) || (a_sonderlevel(v_akt_level) == 7)) && (a_sonderlevel(v_akt_level) != 10)) || (g_test == 1))) {
		v_i = 1;
		if (((v_akt_level > 10) && (p_random(100) > 50))) {
			v_i = (v_i + 1);
		}
		if (((v_akt_level > 20) && (p_random(100) > 50))) {
			v_i = (v_i + 1);
		}
		if ((a_sonderlevel(v_akt_level) == 7)) {
			v_i = ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12);
		}
		for (v_j = 1; v_j <= v_i; v_j += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			v_counter2 = 1;
			do {
				v_xx = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_yy = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter2 = (v_counter2 + 1);
			} while (!((a_labyrinth(v_xx, v_yy).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter2 > 500)));
			if (((v_counter <= 500) && (v_counter2 <= 500))) {
				p_setlaby(v_x, v_y, v_akt_level, 74, v_xx, v_yy, 0);
				p_setlaby(v_xx, v_yy, v_akt_level, 74, v_x, v_y, 0);
			}
		}
	}
	if (((((a_sonderlevel(v_akt_level) != 10) && (a_sonderlevel(v_akt_level) != 9)) && (a_sonderlevel(v_akt_level) != 2)) && (a_sonderlevel(v_akt_level) != 7))) {
		for (v_i = 1; v_i <= (a_groesse(v_akt_level) / 10); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 206, 0, 0, 0);
			}
		}
	}
	for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
		if ((a_sonderlevel(v_akt_level) == 10)) {
			p_wassermonster_setzen(v_akt_level, p_monster_random(v_akt_level, a_sonderlevel(v_akt_level)));
		} else {
			p_monster_setzen(v_akt_level, p_monster_random(v_akt_level, a_sonderlevel(v_akt_level)));
		}
	}
	if ((a_levelmod(v_akt_level) == 3)) {
		for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
			if ((a_sonderlevel(v_akt_level) == 10)) {
				p_wassermonster_setzen(v_akt_level, p_monster_random(v_akt_level, a_sonderlevel(v_akt_level)));
			} else {
				p_monster_setzen(v_akt_level, p_monster_random(v_akt_level, a_sonderlevel(v_akt_level)));
			}
		}
	}
	if ((a_sonderlevel(v_akt_level) == 1)) {
		for (v_i = 1; v_i <= ((a_groesse(v_akt_level) * a_groesse(v_akt_level)) / 12); v_i += 1) {
			v_counter = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_counter = (v_counter + 1);
			} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 500)));
			if ((v_counter <= 500)) {
				p_setlaby(v_x, v_y, v_akt_level, 80, 0, 0, 0);
			}
		}
	}
	v_ausgang_vorh = 0;
	if ((g_test == 0)) {
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 2)) {
					v_ausgang_vorh = 1;
				}
			}
		}
	}
	if ((v_ausgang_vorh == 0)) {
		v_zaehler = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_zaehler = (v_zaehler + 1);
		} while (!(((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && ((((a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (a_labyrinth((v_x - 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y - 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level)))) && (v_x > (a_groesse(v_akt_level) - 6))) && (v_y > (a_groesse(v_akt_level) - 6))) || (v_zaehler > 500)));
		a_ausgangx(v_akt_level) = v_x;
		a_ausgangy(v_akt_level) = v_y;
		if ((v_zaehler > 500)) {
			v_zaehler = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_zaehler = (v_zaehler + 1);
			} while (!(((((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && ((((a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (a_labyrinth((v_x - 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y - 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level)))) && (v_x < 6)) && (v_y > (a_groesse(v_akt_level) - 6))) || (v_zaehler > 500)));
			a_ausgangx(v_akt_level) = v_x;
			a_ausgangy(v_akt_level) = v_y;
		}
		if ((v_zaehler > 500)) {
			v_zaehler = 1;
			do {
				v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
				v_zaehler = (v_zaehler + 1);
			} while (!(((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) && ((((a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (a_labyrinth((v_x - 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level))) || (a_labyrinth(v_x, (v_y - 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level)))) || (v_zaehler > 2000)));
		}
		if ((v_zaehler <= 2000)) {
			p_setlaby(v_x, v_y, v_akt_level, 2, 0, 0, 0);
			a_ausgangx(v_akt_level) = v_x;
			a_ausgangy(v_akt_level) = v_y;
		} else {
			v_x = (a_groesse(v_akt_level) - 1);
			v_y = (a_groesse(v_akt_level) - 1);
			p_setlaby(v_x, v_y, v_akt_level, 2, 0, 0, 0);
			a_ausgangx(v_akt_level) = v_x;
			a_ausgangy(v_akt_level) = v_y;
		}
	}
	v_erreichbar = 0;
	v_x = a_ausgangx(v_akt_level);
	v_y = a_ausgangy(v_akt_level);
	if ((((v_x - 1) >= 1) && ((a_labyrinth((v_x - 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (p_istmonster((v_x - 1), v_y) == 1)))) {
		v_erreichbar = 1;
	}
	if ((((v_x + 1) <= a_groesse(v_akt_level)) && ((a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (p_istmonster((v_x + 1), v_y) == 1)))) {
		v_erreichbar = 1;
	}
	if ((((v_y - 1) >= 1) && ((a_labyrinth(v_x, (v_y - 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (p_istmonster(v_x, (v_y - 1)) == 1)))) {
		v_erreichbar = 1;
	}
	if ((((v_y + 1) <= a_groesse(v_akt_level)) && ((a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (p_istmonster(v_x, (v_y + 1)) == 1)))) {
		v_erreichbar = 1;
	}
	if ((v_erreichbar == 0)) {
		if (((v_x - 1) >= 1)) {
			if ((a_labyrinth((v_x - 1), v_y).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
				p_setlaby((v_x - 1), v_y, v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
			}
		}
		if (((v_x + 1) <= a_groesse(v_akt_level))) {
			if ((a_labyrinth((v_x + 1), v_y).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
				p_setlaby((v_x + 1), v_y, v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
			}
		}
		if (((v_y - 1) >= 1)) {
			if ((a_labyrinth(v_x, (v_y - 1)).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
				p_setlaby(v_x, (v_y - 1), v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
			}
		}
		if (((v_y + 1) <= a_groesse(v_akt_level))) {
			if ((a_labyrinth(v_x, (v_y + 1)).f_feld[v_akt_level] == a_mit_was(v_akt_level))) {
				p_setlaby(v_x, (v_y + 1), v_akt_level, a_inhalt(v_akt_level), 0, 0, 0);
			}
		}
	}
	if ((a_levelmod(v_akt_level) == 4)) {
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 2)) {
					v_ausg_x = v_i;
					v_ausg_y = v_j;
				}
			}
		}
		if ((a_labyrinth((v_ausg_x - 1), v_ausg_y).f_feld[v_akt_level] != 1)) {
			p_setlaby((v_ausg_x - 1), v_ausg_y, v_akt_level, 70, 0, 0, 1);
		}
		if ((a_labyrinth((v_ausg_x + 1), v_ausg_y).f_feld[v_akt_level] != 1)) {
			p_setlaby((v_ausg_x + 1), v_ausg_y, v_akt_level, 70, 0, 0, 1);
		}
		if ((a_labyrinth(v_ausg_x, (v_ausg_y - 1)).f_feld[v_akt_level] != 1)) {
			p_setlaby(v_ausg_x, (v_ausg_y - 1), v_akt_level, 70, 0, 0, 1);
		}
		if ((a_labyrinth(v_ausg_x, (v_ausg_y + 1)).f_feld[v_akt_level] != 1)) {
			p_setlaby(v_ausg_x, (v_ausg_y + 1), v_akt_level, 70, 0, 0, 1);
		}
		v_counter = 1;
		do {
			v_x = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_y = (p_random((a_groesse(v_akt_level) - 3)) + 2);
			v_counter = (v_counter + 1);
		} while (!((a_labyrinth(v_x, v_y).f_feld[v_akt_level] == a_inhalt(v_akt_level)) || (v_counter > 2000)));
		if ((v_counter <= 2000)) {
			p_setlaby(v_x, v_y, v_akt_level, 19, 0, 0, 0);
		}
	}
	if ((a_levelmod(v_akt_level) == 9)) {
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 4)) {
					p_setlaby(v_i, v_j, v_akt_level, 41, 0, 0, 0);
				}
			}
		}
	}
	if ((a_levelmod(v_akt_level) == 10)) {
		for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
				if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 4)) {
					p_setlaby(v_i, v_j, v_akt_level, 80, 0, 0, 0);
				}
			}
		}
	}
	if (((a_sonderlevel(v_akt_level) != 10) && (a_sonderlevel(v_akt_level) != 9))) {
		v_hugo = (p_random(7) + 1);
		switch (v_hugo) {
		case 1:
			break;
		case 2:
			p_diagonal(v_akt_level);
			break;
		case 3:
			p_vertikal(v_akt_level);
			break;
		case 4:
			p_diagonal(v_akt_level);
			p_vertikal(v_akt_level);
			break;
		case 5:
			p_horizontal(v_akt_level);
			break;
		case 6:
			p_diagonal(v_akt_level);
			p_horizontal(v_akt_level);
			break;
		case 7:
			p_vertikal(v_akt_level);
			p_horizontal(v_akt_level);
			break;
		case 8:
			p_diagonal(v_akt_level);
			p_vertikal(v_akt_level);
			p_horizontal(v_akt_level);
			break;
		}
	}
}

static int32_t p_get_creature(int16_t v_typ) {
	a_spieler(g_akt_spieler).f_creature_typ = v_typ;
	a_spieler(g_akt_spieler).f_creature_lifepoints = a_creature(v_typ).f_creature_lifepoints;
	a_spieler(g_akt_spieler).f_creature_attack = a_creature(v_typ).f_creature_attack;
	a_spieler(g_akt_spieler).f_creature_schaden_min = a_creature(v_typ).f_creature_schaden_min;
	a_spieler(g_akt_spieler).f_creature_schaden_max = a_creature(v_typ).f_creature_schaden_max;
	a_spieler(g_akt_spieler).f_creature_speed = p_creature_speed();
	a_spieler(g_akt_spieler).f_creature_maxspeed = a_creature(v_typ).f_creature_maxspeed;
	a_spieler(g_akt_spieler).f_creature_x = (a_spieler(g_akt_spieler).f_character_x + g_spell_x);
	a_spieler(g_akt_spieler).f_creature_y = (a_spieler(g_akt_spieler).f_character_y + g_spell_y);
	a_spieler(g_akt_spieler).f_creature_heading = 2;
}

static int32_t p_gewicht() {
	int16_t v_gewicht = 0;
	int32_t v_i = 0;
	v_gewicht = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((((a_inventory(v_i, g_akt_spieler).f_name != 0) && (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_gewicht > 0)) && (a_inventory(v_i, g_akt_spieler).f_anzahl >= 0)) && (a_inventory(v_i, g_akt_spieler).f_name <= 406))) {
			v_gewicht = (v_gewicht + (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_gewicht * (a_inventory(v_i, g_akt_spieler).f_anzahl + 1)));
		}
	}
	return v_gewicht;
}

static int32_t p_gold(int16_t v_x, int16_t v_y) {
	int32_t v_hugo = 0;
	v_hugo = (p_random(((a_spieler(g_akt_spieler).f_level * 5) + p_luck())) + 1);
	p_gold_finden(v_hugo);
	if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 9)) {
		p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
	}
	if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 160)) {
		p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 53, 0, 0, 0);
	}
}

static int32_t p_gold_anzahl() {
	int16_t v_beutel = 0;
	int32_t v_i = 0;
	v_beutel = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if ((a_inventory(v_i, g_akt_spieler).f_name == 150)) {
			v_beutel = v_i;
		}
	}
	if ((v_beutel > 0)) {
		return a_inventory(v_beutel, g_akt_spieler).f_attri1;
	} else {
		return 0;
	}
}

static int32_t p_gold_finden(int16_t v_anzahl) {
	int16_t v_beutel = 0;
	int32_t v_i = 0;
	if ((a_spieler(g_akt_spieler).f_fluch != 16)) {
		p_sound(9);
		p_nachricht3(6, v_anzahl, 8);
		if (((a_skills(108, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < (600 / p_maxlife())))) {
			a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
			p_nachricht(326, 6);
		}
		v_beutel = 0;
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if ((a_inventory(v_i, g_akt_spieler).f_name == 150)) {
				v_beutel = v_i;
			}
		}
		if ((v_beutel == 0)) {
			v_i = 0;
			do {
				v_i = (v_i + 1);
			} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
			if ((v_i <= 50)) {
				a_inventory(v_i, g_akt_spieler).f_name = 150;
				a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(150).f_art;
				a_inventory(v_i, g_akt_spieler).f_attri1 = v_anzahl;
				a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(150).f_attri2;
				a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(150).f_attri3;
				a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(150).f_attri4;
			} else {
				p_nachricht(428, 6);
			}
		} else {
			if (((a_inventory(v_beutel, g_akt_spieler).f_attri1 + v_anzahl) < 32565)) {
				a_inventory(v_beutel, g_akt_spieler).f_attri1 = (a_inventory(v_beutel, g_akt_spieler).f_attri1 + v_anzahl);
			} else {
				a_inventory(v_beutel, g_akt_spieler).f_attri1 = 32565;
			}
		}
	} else {
		p_nachricht(7, 6);
	}
}

static int32_t p_gold_finden2(int16_t v_anzahl) {
	int16_t v_beutel = 0;
	int32_t v_i = 0;
	if ((a_spieler(g_akt_spieler).f_fluch != 16)) {
		p_sound(9);
		v_beutel = 0;
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if ((a_inventory(v_i, g_akt_spieler).f_name == 150)) {
				v_beutel = v_i;
			}
		}
		if ((v_beutel == 0)) {
			v_i = 0;
			do {
				v_i = (v_i + 1);
			} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
			if ((v_i <= 50)) {
				a_inventory(v_i, g_akt_spieler).f_name = 150;
				a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(150).f_art;
				a_inventory(v_i, g_akt_spieler).f_attri1 = v_anzahl;
				a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(150).f_attri2;
				a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(150).f_attri3;
				a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(150).f_attri4;
			} else {
				p_nachricht(428, 6);
			}
		} else {
			a_inventory(v_beutel, g_akt_spieler).f_attri1 = (a_inventory(v_beutel, g_akt_spieler).f_attri1 + v_anzahl);
		}
	} else {
		p_nachricht(7, 6);
	}
}

static int32_t p_gold_verlieren(int16_t v_anzahl) {
	int16_t v_beutel = 0;
	int32_t v_i = 0;
	v_beutel = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if ((a_inventory(v_i, g_akt_spieler).f_name == 150)) {
			v_beutel = v_i;
		}
	}
	if ((v_beutel > 0)) {
		a_inventory(v_beutel, g_akt_spieler).f_attri1 = (a_inventory(v_beutel, g_akt_spieler).f_attri1 - v_anzahl);
		if ((a_inventory(v_beutel, g_akt_spieler).f_attri1 < 1)) {
			a_inventory(v_beutel, g_akt_spieler).f_attri1 = 0;
		}
	}
}

static int32_t p_gott_check() {
	if ((a_skills(103, g_akt_spieler).f_gewaehlt == 1)) {
		if ((p_random(100) < (200 / a_spieler(g_akt_spieler).f_maxlifepoints))) {
			a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
			p_nachricht(321, 5);
		}
	}
	if ((a_skills(104, g_akt_spieler).f_gewaehlt == 1)) {
		if ((p_random(100) < (200 / a_spieler(g_akt_spieler).f_maxmana))) {
			a_spieler(g_akt_spieler).f_maxmana = (a_spieler(g_akt_spieler).f_maxmana + 1);
			p_nachricht(322, 5);
		}
	}
}

static int32_t p_habich(int16_t v_nr) {
	int32_t v_gef = 0;
	int32_t v_habich = 0;
	int32_t v_i = 0;
	v_habich = 0;
	v_gef = 0;
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if ((a_aktive(v_i, g_akt_spieler).f_nr == v_nr)) {
			v_habich = a_aktive(v_i, g_akt_spieler).f_staerke;
			v_gef = 1;
		}
	}
	if (((v_habich == 0) && (v_gef == 1))) {
		v_habich = 1;
	}
	return v_habich;
}

static int32_t p_haendler() {
	int16_t v_a = 0;
	int16_t v_b = 0;
	int16_t v_c = 0;
	int16_t v_d = 0;
	std::string v_gegname;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_kauf = 0;
	int16_t v_kaufobjekt1 = 0;
	int16_t v_kaufobjekt2 = 0;
	int16_t v_kaufpreis1 = 0;
	int16_t v_kaufpreis2 = 0;
	int16_t v_leer = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_oldmouse_x = 0;
	int16_t v_oldmouse_y = 0;
	int16_t v_pos = 0;
	int16_t v_pos2 = 0;
	int32_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_save_i = 0;
	int16_t v_save_j = 0;
	int16_t v_savepos1 = 0;
	int16_t v_savepos2 = 0;
	int16_t v_sel_x = 0;
	int16_t v_sel_y = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int16_t v_sr = 0;
	std::string v_text1;
	std::string v_text2;
	std::string v_text3;
	int16_t v_verkauf = 0;
	int32_t v_verkaufobjekt = 0;
	int16_t v_verkaufobjekt1 = 0;
	int16_t v_verkaufobjekt2 = 0;
	int16_t v_verkaufpreis1 = 0;
	int16_t v_verkaufpreis2 = 0;
	int32_t v_verkaufspreis1 = 0;
	int32_t v_verkaufspreis2 = 0;
	int16_t v_weg = 0;
	int16_t v_willi = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_kauf = 0;
	v_verkauf = 0;
	v_sel_x = 1;
	v_sel_y = 1;
	if ((((((a_raeume(a_spieler(g_akt_spieler).f_level) == 1) || (a_raeume(a_spieler(g_akt_spieler).f_level) == 15)) || (a_raeume(a_spieler(g_akt_spieler).f_level) == 27)) || (a_raeume(a_spieler(g_akt_spieler).f_level) == 28)) || (a_raeume(a_spieler(g_akt_spieler).f_level) == 30))) {
		v_leer = 1;
		for (v_i = 1; v_i <= 40; v_i += 1) {
			if ((a_haendler_objekte(v_i, a_spieler(g_akt_spieler).f_level) != 0)) {
				v_leer = 0;
			}
		}
		if ((v_leer == 1)) {
			v_willi = (p_random(4) + 1);
			switch (v_willi) {
			case 1:
				p_haendler_init1(a_spieler(g_akt_spieler).f_level);
				break;
			case 2:
				p_haendler_init2(a_spieler(g_akt_spieler).f_level);
				break;
			case 3:
				p_haendler_init3(a_spieler(g_akt_spieler).f_level);
				break;
			case 4:
				p_haendler_init4(a_spieler(g_akt_spieler).f_level);
				break;
			case 5:
				p_haendler_init5(a_spieler(g_akt_spieler).f_level);
				break;
			}
		}
	}
	v_result = p_examinemouse();
	v_oldmouse_x = p_mousex();
	v_oldmouse_y = p_mousey();
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, 25, ((((a_nachricht_text(66, (1 + g_sprache)) + " (") + a_nachricht_text(113, (1 + g_sprache))) + p_str(g_akt_spieler)) + ")"), -1, 0);
		p_stopdrawing();
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			v_sel_x = (v_sel_x + 1);
			if ((v_sel_x > 16)) {
				v_sel_x = 16;
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			v_sel_x = (v_sel_x - 1);
			if ((v_sel_x < 1)) {
				v_sel_x = 1;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel_y = (v_sel_y + 1);
			if ((v_sel_y > 5)) {
				v_sel_y = 5;
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel_y = (v_sel_y - 1);
			if ((v_sel_y < 1)) {
				v_sel_y = 1;
			}
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		v_kauf = 0;
		v_verkauf = 0;
		v_kaufpreis1 = 0;
		v_kaufpreis2 = 0;
		v_verkaufpreis1 = 0;
		v_verkaufpreis2 = 0;
		v_kaufobjekt1 = 0;
		v_kaufobjekt2 = 0;
		v_verkaufobjekt1 = 0;
		v_verkaufobjekt2 = 0;
		v_x = 25;
		v_y = 60;
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 5; v_j += 1) {
				v_a = (v_x + ((v_i * 32) - 32));
				v_b = (v_x + (v_i * 32));
				v_c = (v_y + ((v_j * 32) - 32));
				v_d = (v_y + (v_j * 32));
				if ((((((v_mmouse_x > v_a) && (v_mmouse_x < v_b)) && (v_mmouse_y > v_c)) && (v_mmouse_y < v_d)) || ((v_sel_x == v_i) && (v_sel_y == v_j)))) {
					if (((v_sel_x == v_i) && (v_sel_y == v_j))) {
						p_clipsprite(1, 0, 32, 32, 32);
						p_displaytransparentsprite(1, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					} else {
						p_clipsprite(8, 224, 320, 32, 32);
						p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					}
					if ((v_mmouse_links == 1)) {
						v_kauf = 98;
						v_verkauf = 0;
					}
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						v_kauf = 99;
						v_verkauf = 0;
					}
					if (((((v_mmouse_x > v_a) && (v_mmouse_x < v_b)) && (v_mmouse_y > v_c)) && (v_mmouse_y < v_d))) {
						v_kaufobjekt1 = a_haendler_objekte((v_i + ((8 * v_j) - 8)), a_spieler(g_akt_spieler).f_level);
						v_save_i = v_i;
						v_save_j = v_j;
						v_pos = (v_i + ((8 * v_j) - 8));
					}
					if (((v_sel_x == v_i) && (v_sel_y == v_j))) {
						v_kaufobjekt2 = a_haendler_objekte((v_sel_x + ((8 * v_sel_y) - 8)), a_spieler(g_akt_spieler).f_level);
						v_pos2 = (v_sel_x + ((8 * v_sel_y) - 8));
					}
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					p_frontcolor(p_rgb(255, 255, 1));
					if ((v_kaufobjekt1 > 0)) {
						v_kaufpreis1 = a_gegenstand(v_kaufobjekt1).f_einkauf;
						if ((a_gegenstand(v_kaufobjekt1).f_qualitaet > 0)) {
							v_kaufpreis1 = (v_kaufpreis1 * a_haendler_staerke(v_pos, a_spieler(g_akt_spieler).f_level));
						}
						if ((v_kaufobjekt1 == 38)) {
							v_kaufpreis1 = 35;
						}
						if ((a_skills(114, g_akt_spieler).f_gewaehlt == 1)) {
							v_kaufpreis1 = ((v_kaufpreis1 / 4) * 3);
							if ((v_kaufpreis1 < 1)) {
								v_kaufpreis1 = 1;
							}
						}
						v_weg = 0;
						p_drawtext(25, 285, a_gegenstand(v_kaufobjekt1).f_name[(1 + g_sprache)], -1, 0);
						v_weg = p_details(v_kaufobjekt1);
						if ((v_kaufobjekt1 == 38)) {
							v_weg = 1;
							p_drawtext(25, 300, a_zauber(a_haendler_schriftrolle(v_pos, a_spieler(g_akt_spieler).f_level), g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
						}
						if ((v_weg == 0)) {
							if ((a_gegenstand(v_kaufobjekt1).f_qualitaet > 0)) {
								p_drawtext(25, 300, (("+" + p_str(a_haendler_staerke(v_pos, a_spieler(g_akt_spieler).f_level))) + a_gegenstand(v_kaufobjekt1).f_info[(1 + g_sprache)]), -1, 0);
							} else {
								p_drawtext(25, 300, a_gegenstand(v_kaufobjekt1).f_info[(1 + g_sprache)], -1, 0);
							}
						}
						p_drawtext(25, 315, ("Price: " + p_str(v_kaufpreis1)), -1, 0);
					}
					if ((v_kaufobjekt2 > 0)) {
						v_kaufpreis2 = a_gegenstand(v_kaufobjekt2).f_einkauf;
						if ((v_kaufobjekt2 == 38)) {
							v_kaufpreis2 = 35;
						}
						if ((a_skills(114, g_akt_spieler).f_gewaehlt == 1)) {
							v_kaufpreis2 = ((v_kaufpreis2 / 4) * 3);
							if ((v_kaufpreis2 < 1)) {
								v_kaufpreis2 = 1;
							}
						}
						v_weg = 0;
						p_drawtext(25, 340, a_gegenstand(v_kaufobjekt2).f_name[(1 + g_sprache)], -1, 0);
						v_weg = p_details(v_kaufobjekt2);
						if ((v_kaufobjekt2 == 38)) {
							v_weg = 1;
							p_drawtext(25, 355, a_zauber(a_haendler_schriftrolle(v_pos2, a_spieler(g_akt_spieler).f_level), g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
						}
						if ((v_weg == 0)) {
							if ((a_gegenstand(v_kaufobjekt2).f_qualitaet > 0)) {
								p_drawtext(25, 355, (("+" + p_str(a_haendler_staerke(v_pos2, a_spieler(g_akt_spieler).f_level))) + a_gegenstand(v_kaufobjekt2).f_info[(1 + g_sprache)]), -1, 0);
							} else {
								p_drawtext(25, 355, a_gegenstand(v_kaufobjekt2).f_info[(1 + g_sprache)], -1, 0);
							}
						}
						p_drawtext(25, 370, ("Price: " + p_str(v_kaufpreis2)), -1, 0);
					}
					p_stopdrawing();
				} else {
					p_clipsprite(8, 480, 64, 32, 32);
					p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				}
				v_pos = (v_i + ((8 * v_j) - 8));
				v_sprite_x = a_haendler_objekte(v_pos, a_spieler(g_akt_spieler).f_level);
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
			}
		}
		v_x = 365;
		v_y = 60;
		v_verkaufobjekt = 0;
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 5; v_j += 1) {
				v_a = (v_x + ((v_i * 32) - 32));
				v_b = (v_x + (v_i * 32));
				v_c = (v_y + ((v_j * 32) - 32));
				v_d = (v_y + (v_j * 32));
				if ((((((v_mmouse_x > v_a) && (v_mmouse_x < v_b)) && (v_mmouse_y > v_c)) && (v_mmouse_y < v_d)) || ((v_i == (v_sel_x - 8)) && (v_sel_y == v_j)))) {
					if ((((v_sel_x - 8) == v_i) && (v_sel_y == v_j))) {
						p_clipsprite(1, 0, 32, 32, 32);
						p_displaytransparentsprite(1, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					} else {
						p_clipsprite(8, 224, 320, 32, 32);
						p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					}
					if ((v_mmouse_links == 1)) {
						v_verkauf = 98;
						v_kauf = 0;
					}
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						v_verkauf = 99;
						v_kauf = 0;
					}
					if (((((v_mmouse_x > v_a) && (v_mmouse_x < v_b)) && (v_mmouse_y > v_c)) && (v_mmouse_y < v_d))) {
						v_verkaufobjekt1 = a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_name;
						v_save_i = v_i;
						v_save_j = v_j;
						v_savepos1 = (v_i + ((8 * v_j) - 8));
					}
					if (((v_i == (v_sel_x - 8)) && (v_sel_y == v_j))) {
						v_verkaufobjekt2 = a_inventory(((v_sel_x - 8) + ((8 * v_sel_y) - 8)), g_akt_spieler).f_name;
						v_savepos2 = ((v_sel_x - 8) + ((8 * v_sel_y) - 8));
					}
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					p_frontcolor(p_rgb(255, 255, 1));
					if (((v_verkaufobjekt1 > 0) && (v_verkaufobjekt1 <= 406))) {
						v_gegname = "";
						v_sr = 0;
						if ((v_verkaufobjekt1 == 38)) {
							v_sr = 1;
							v_verkaufpreis1 = 15;
							if ((((a_skills(64, g_akt_spieler).f_gewaehlt == 0) && (a_skills(47, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_savepos1, g_akt_spieler).f_status == 0))) {
								v_gegname = a_nachricht_text(584, (1 + g_sprache));
							} else {
								v_gegname = a_zauber(a_inventory(v_savepos1, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
							}
						}
						if ((v_sr == 0)) {
							v_verkaufpreis1 = a_gegenstand(v_verkaufobjekt1).f_verkauf;
							if ((a_gegenstand(v_verkaufobjekt1).f_qualitaet > 0)) {
								v_verkaufpreis1 = (a_gegenstand(v_verkaufobjekt1).f_verkauf * a_inventory(v_savepos1, g_akt_spieler).f_status);
							}
							if ((a_gegenstand(v_verkaufobjekt1).f_name[2] == "Udjat Auge")) {
								if ((a_inventory(v_savepos1, g_akt_spieler).f_attri1 == 0)) {
									v_verkaufpreis1 = 50;
								}
								if ((a_inventory(v_savepos1, g_akt_spieler).f_attri1 == 1)) {
									v_verkaufpreis1 = 150;
								}
								if ((a_inventory(v_savepos1, g_akt_spieler).f_attri1 == 2)) {
									v_verkaufpreis1 = 300;
								}
							}
							if ((((a_gegenstand(v_verkaufobjekt1).f_art == 1) || (a_gegenstand(v_verkaufobjekt1).f_art == 9)) || (a_gegenstand(v_verkaufobjekt1).f_art == 11))) {
								if ((a_inventory(v_savepos1, g_akt_spieler).f_status == 1)) {
									v_verkaufpreis1 = (v_verkaufpreis1 / 2);
								}
								if ((a_inventory(v_savepos1, g_akt_spieler).f_status == 2)) {
									v_verkaufpreis1 = 0;
								}
							}
							if ((a_gegenstand(v_verkaufobjekt1).f_art == 22)) {
								if ((a_inventory(v_savepos1, g_akt_spieler).f_status == 1)) {
									v_verkaufpreis1 = (int32_t)((v_verkaufpreis1 * 1.2));
								}
								if ((a_inventory(v_savepos1, g_akt_spieler).f_status == 2)) {
									v_verkaufpreis1 = (int32_t)((v_verkaufpreis1 * 1.5));
								}
							}
							if (((v_verkaufobjekt1 >= 75) && (v_verkaufobjekt1 <= 112))) {
								if ((((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_savepos1, g_akt_spieler).f_status == 0))) {
									v_gegname = a_nachricht_text(586, (1 + g_sprache));
									v_verkaufspreis1 = 15;
								}
							}
							if ((v_verkaufobjekt1 == 38)) {
								v_verkaufspreis1 = 15;
							}
							if (((v_verkaufobjekt1 >= 65) && (v_verkaufobjekt1 <= 74))) {
								if ((a_skills(113, g_akt_spieler).f_gewaehlt == 0)) {
									v_gegname = a_nachricht_text(585, (1 + g_sprache));
								}
							}
							if (((v_gegname == "") && (v_verkaufobjekt1 > 0))) {
								v_gegname = a_gegenstand(v_verkaufobjekt1).f_name[(1 + g_sprache)];
							}
						}
						p_drawtext(375, 300, v_gegname, -1, 0);
						v_weg = p_details(v_verkaufobjekt1);
						if ((v_weg == 0)) {
							if ((a_gegenstand(v_verkaufobjekt1).f_qualitaet > 0)) {
								p_drawtext(375, 315, (("+" + p_str(a_inventory(v_savepos1, g_akt_spieler).f_status)) + a_gegenstand(v_verkaufobjekt1).f_info[(1 + g_sprache)]), -1, 0);
							} else {
								p_drawtext(375, 315, a_gegenstand(v_verkaufobjekt1).f_info[(1 + g_sprache)], -1, 0);
							}
						}
						p_drawtext(375, 330, ((a_nachricht_text(587, (1 + g_sprache)) + p_str(v_verkaufpreis1)) + a_nachricht_text(8, (1 + g_sprache))), -1, 0);
					}
					if (((v_verkaufobjekt2 > 0) && (v_verkaufobjekt2 <= 406))) {
						v_gegname = "";
						v_sr = 0;
						if ((v_verkaufobjekt2 == 38)) {
							v_sr = 1;
							v_verkaufpreis2 = 15;
							if ((((a_skills(64, g_akt_spieler).f_gewaehlt == 0) && (a_skills(47, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_savepos2, g_akt_spieler).f_status == 0))) {
								v_gegname = a_nachricht_text(584, (1 + g_sprache));
							} else {
								v_gegname = a_zauber(a_inventory(v_savepos2, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
							}
						}
						if ((v_sr == 0)) {
							v_verkaufpreis2 = a_gegenstand(v_verkaufobjekt2).f_verkauf;
							if ((a_gegenstand(v_verkaufobjekt2).f_qualitaet > 0)) {
								v_verkaufpreis2 = (a_gegenstand(v_verkaufobjekt2).f_verkauf * a_inventory(v_savepos2, g_akt_spieler).f_status);
							}
							if ((a_gegenstand(v_verkaufobjekt2).f_name[2] == "Udjat Auge")) {
								if ((a_inventory(v_savepos2, g_akt_spieler).f_attri1 == 0)) {
									v_verkaufpreis2 = 50;
								}
								if ((a_inventory(v_savepos2, g_akt_spieler).f_attri1 == 1)) {
									v_verkaufpreis2 = 150;
								}
								if ((a_inventory(v_savepos2, g_akt_spieler).f_attri1 == 2)) {
									v_verkaufpreis2 = 300;
								}
							}
							if ((((a_gegenstand(v_verkaufobjekt2).f_art == 1) || (a_gegenstand(v_verkaufobjekt2).f_art == 9)) || (a_gegenstand(v_verkaufobjekt2).f_art == 11))) {
								if ((a_inventory(v_savepos2, g_akt_spieler).f_status == 1)) {
									v_verkaufpreis2 = (v_verkaufpreis2 / 2);
								}
								if ((a_inventory(v_savepos2, g_akt_spieler).f_status == 2)) {
									v_verkaufpreis2 = 0;
								}
							}
							if ((a_gegenstand(v_verkaufobjekt2).f_art == 22)) {
								if ((a_inventory(v_savepos2, g_akt_spieler).f_status == 1)) {
									v_verkaufpreis2 = (int32_t)((v_verkaufpreis2 * 1.2));
								}
								if ((a_inventory(v_savepos2, g_akt_spieler).f_status == 2)) {
									v_verkaufpreis2 = (int32_t)((v_verkaufpreis2 * 1.5));
								}
							}
							if (((v_verkaufobjekt2 >= 75) && (v_verkaufobjekt2 <= 112))) {
								if ((((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_savepos2, g_akt_spieler).f_status == 0))) {
									v_gegname = a_nachricht_text(586, (1 + g_sprache));
									v_verkaufspreis2 = 15;
								}
							}
							if ((v_verkaufobjekt2 == 38)) {
								v_verkaufspreis2 = 15;
							}
							if (((v_verkaufobjekt2 >= 65) && (v_verkaufobjekt2 <= 74))) {
								if ((a_skills(113, g_akt_spieler).f_gewaehlt == 0)) {
									v_gegname = a_nachricht_text(585, (1 + g_sprache));
								}
							}
							if ((((v_gegname == "") && (v_verkaufobjekt2 > 0)) && (v_verkaufobjekt2 <= 406))) {
								v_gegname = a_gegenstand(v_verkaufobjekt2).f_name[(1 + g_sprache)];
							}
						}
						p_drawtext(375, 355, v_gegname, -1, 0);
						v_weg = p_details(v_verkaufobjekt2);
						if ((v_weg == 0)) {
							if ((a_gegenstand(v_verkaufobjekt2).f_qualitaet > 0)) {
								p_drawtext(375, 370, (("+" + p_str(a_inventory(v_savepos2, g_akt_spieler).f_status)) + a_gegenstand(v_verkaufobjekt2).f_info[(1 + g_sprache)]), -1, 0);
							} else {
								p_drawtext(375, 370, a_gegenstand(v_verkaufobjekt2).f_info[(1 + g_sprache)], -1, 0);
							}
						}
						p_drawtext(375, 385, ((a_nachricht_text(587, (1 + g_sprache)) + p_str(v_verkaufpreis2)) + a_nachricht_text(8, (1 + g_sprache))), -1, 0);
					}
					p_stopdrawing();
				} else {
					p_clipsprite(8, 480, 64, 32, 32);
					p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				}
				v_pos = (v_i + ((8 * v_j) - 8));
				if ((a_inventory(v_pos, g_akt_spieler).f_benutzt == 1)) {
					p_frontcolor(p_rgb(120, 120, 120));
					p_box((v_x + ((v_i * 32) - 31)), (v_y + ((v_j * 32) - 31)), 30, 29, -1);
				}
				v_sprite_x = a_inventory(v_pos, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				if ((a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_anzahl > 0)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawingmode(1);
					p_drawtext(((v_x + ((v_i * 32) - 32)) + 22), ((v_y + ((v_j * 32) - 32)) + 18), p_str((a_inventory(v_pos, g_akt_spieler).f_anzahl + 1)), -1, 0);
					p_stopdrawing();
				}
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		if ((g_sprache == 0)) {
			p_drawtext(25, 400, ("Your Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 1)) {
			p_drawtext(25, 400, ("Dein Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 2)) {
			p_drawtext(25, 400, ("Tu oro: " + p_str(p_gold_anzahl())), -1, 0);
		}
		p_stopdrawing();
		g_warten = (g_warten + 1);
		if ((g_warten > 50)) {
			if (((v_kauf > 0) && (v_verkauf == 0))) {
				if ((v_kauf == 98)) {
					v_kauf = (v_save_i + ((8 * v_save_j) - 8));
					if ((p_gold_anzahl() >= v_kaufpreis1)) {
						p_gold_verlieren(v_kaufpreis1);
						p_nachricht7((a_nachricht_text(437, (1 + g_sprache)) + a_gegenstand(v_kaufobjekt1).f_name[(1 + g_sprache)]), 5);
						v_kaufpreis1 = 0;
						a_haendler_objekte(v_kauf, a_spieler(g_akt_spieler).f_level) = 0;
						v_i = 0;
						do {
							v_i = (v_i + 1);
						} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
						if ((v_i <= 50)) {
							if ((v_kaufobjekt1 == 38)) {
								a_inventory(v_i, g_akt_spieler).f_name = 38;
								a_inventory(v_i, g_akt_spieler).f_art = 5;
								a_inventory(v_i, g_akt_spieler).f_status = 1;
								a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
								a_inventory(v_i, g_akt_spieler).f_attri1 = a_haendler_schriftrolle(v_kauf, a_spieler(g_akt_spieler).f_level);
								a_inventory(v_i, g_akt_spieler).f_attri2 = a_haendler_staerke(v_kauf, a_spieler(g_akt_spieler).f_level);
							} else {
								a_inventory(v_i, g_akt_spieler).f_name = v_kaufobjekt1;
								a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_kaufobjekt1).f_art;
								a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
								a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(v_kaufobjekt1).f_attri1;
								a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_kaufobjekt1).f_attri2;
								a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_kaufobjekt1).f_attri3;
								a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_kaufobjekt1).f_attri4;
								if ((a_gegenstand(v_kaufobjekt1).f_qualitaet > 0)) {
									a_inventory(v_i, g_akt_spieler).f_status = a_haendler_staerke(v_kauf, a_spieler(g_akt_spieler).f_level);
								}
								if ((a_inventory(v_i, g_akt_spieler).f_art == 4)) {
									a_inventory(v_i, g_akt_spieler).f_status = 1;
								}
							}
						}
					}
					v_kauf = 0;
					v_kaufobjekt1 = 0;
				}
				if ((v_kauf == 99)) {
					v_kauf = (v_sel_x + ((8 * v_sel_y) - 8));
					if ((a_haendler_objekte(v_kauf, a_spieler(g_akt_spieler).f_level) == 0)) {
						v_raus = 1;
					} else {
						if ((p_gold_anzahl() >= v_kaufpreis2)) {
							p_gold_verlieren(v_kaufpreis2);
							p_nachricht7((a_nachricht_text(437, (1 + g_sprache)) + a_gegenstand(v_kaufobjekt2).f_name[(1 + g_sprache)]), 5);
							v_kaufpreis2 = 0;
							a_haendler_objekte(v_kauf, a_spieler(g_akt_spieler).f_level) = 0;
							v_i = 0;
							do {
								v_i = (v_i + 1);
							} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
							if ((v_i <= 50)) {
								if ((v_kaufobjekt2 == 38)) {
									a_inventory(v_i, g_akt_spieler).f_name = 38;
									a_inventory(v_i, g_akt_spieler).f_art = 5;
									a_inventory(v_i, g_akt_spieler).f_status = 1;
									a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
									a_inventory(v_i, g_akt_spieler).f_attri1 = a_haendler_schriftrolle(v_kauf, a_spieler(g_akt_spieler).f_level);
									a_inventory(v_i, g_akt_spieler).f_attri2 = a_haendler_staerke(v_kauf, a_spieler(g_akt_spieler).f_level);
								} else {
									a_inventory(v_i, g_akt_spieler).f_name = v_kaufobjekt2;
									a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_kaufobjekt2).f_art;
									a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
									a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(v_kaufobjekt2).f_attri1;
									a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_kaufobjekt2).f_attri2;
									a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_kaufobjekt2).f_attri3;
									a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_kaufobjekt2).f_attri4;
									if ((a_gegenstand(v_kaufobjekt2).f_qualitaet > 0)) {
										a_inventory(v_i, g_akt_spieler).f_status = a_haendler_staerke(v_kauf, a_spieler(g_akt_spieler).f_level);
									}
									if ((a_inventory(v_i, g_akt_spieler).f_art == 4)) {
										a_inventory(v_i, g_akt_spieler).f_status = 1;
									}
								}
							}
						}
						v_kauf = 0;
						v_kaufobjekt2 = 0;
					}
				}
			}
			if (((v_verkauf > 0) && (v_kauf == 0))) {
				if ((v_verkauf == 98)) {
					v_verkauf = (v_save_i + ((8 * v_save_j) - 8));
					if ((((a_inventory(v_verkauf, g_akt_spieler).f_benutzt == 0) && (a_inventory(v_verkauf, g_akt_spieler).f_name != 0)) && (a_inventory(v_verkauf, g_akt_spieler).f_name != 150))) {
						p_gold_finden2(v_verkaufpreis1);
						p_nachricht7((a_nachricht_text(438, (1 + g_sprache)) + v_gegname), 5);
						v_verkaufpreis1 = 0;
						v_i = 0;
						do {
							v_i = (v_i + 1);
						} while (!((v_i > 40) || (a_haendler_objekte(v_i, a_spieler(g_akt_spieler).f_level) == 0)));
						if ((v_i <= 40)) {
							a_haendler_objekte(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_name;
							if ((a_inventory(v_verkauf, g_akt_spieler).f_name == 38)) {
								a_haendler_schriftrolle(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_attri1;
								a_haendler_staerke(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_attri2;
							} else {
								if ((a_gegenstand(a_inventory(v_verkauf, g_akt_spieler).f_name).f_qualitaet > 0)) {
									a_haendler_staerke(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_status;
								}
							}
						}
						p_leeren(v_verkauf);
						v_verkauf = 0;
					}
				}
				if ((v_verkauf == 99)) {
					v_verkauf = ((v_sel_x - 8) + ((8 * v_sel_y) - 8));
					if ((a_inventory(v_verkauf, g_akt_spieler).f_name == 0)) {
						v_raus = 1;
					} else {
						if ((((a_inventory(v_verkauf, g_akt_spieler).f_benutzt == 0) && (a_inventory(v_verkauf, g_akt_spieler).f_name != 0)) && (a_inventory(v_verkauf, g_akt_spieler).f_name != 150))) {
							p_gold_finden2(v_verkaufpreis2);
							p_nachricht7((a_nachricht_text(438, (1 + g_sprache)) + v_gegname), 5);
							v_verkaufpreis2 = 0;
							v_i = 0;
							do {
								v_i = (v_i + 1);
							} while (!((v_i > 40) || (a_haendler_objekte(v_i, a_spieler(g_akt_spieler).f_level) == 0)));
							if ((v_i <= 40)) {
								a_haendler_objekte(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_name;
								if ((a_inventory(v_verkauf, g_akt_spieler).f_name == 38)) {
									a_haendler_schriftrolle(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_attri1;
									a_haendler_staerke(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_attri2;
								} else {
									if ((a_gegenstand(a_inventory(v_verkauf, g_akt_spieler).f_name).f_qualitaet > 0)) {
										a_haendler_staerke(v_i, a_spieler(g_akt_spieler).f_level) = a_inventory(v_verkauf, g_akt_spieler).f_status;
									}
								}
							}
							p_leeren(v_verkauf);
							v_verkauf = 0;
						}
					}
				}
			}
		} else {
			p_delay(1);
			if ((g_warten < 1000)) {
				g_warten = (g_warten + 1);
			}
		}
		p_examinekeyboard();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!(((v_mmouse_rechts == 1) || p_keyboardpushed(27)) || (v_raus == 1)));
	p_delay(g_mydelay);
}

static int32_t p_haendler_init1(int16_t v_level) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	a_haendler_objekte(1, v_level) = 56;
	a_haendler_objekte(2, v_level) = 44;
	a_haendler_objekte(3, v_level) = 46;
	a_haendler_objekte(4, v_level) = 39;
	a_haendler_objekte(5, v_level) = 134;
	a_haendler_objekte(6, v_level) = 193;
	a_haendler_objekte(7, v_level) = 20;
	v_j = 0;
	for (v_i = 8; v_i <= 29; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (1 + v_j);
		v_j = (v_j + 1);
	}
	v_j = 0;
	for (v_i = 30; v_i <= 40; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (23 + v_j);
		v_j = (v_j + 1);
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_haendler_init2(int16_t v_level) {
	int32_t v_i = 0;
	a_haendler_objekte(1, v_level) = 60;
	a_haendler_objekte(2, v_level) = 44;
	a_haendler_objekte(3, v_level) = 46;
	a_haendler_objekte(4, v_level) = 39;
	a_haendler_objekte(5, v_level) = 134;
	a_haendler_objekte(6, v_level) = 193;
	a_haendler_objekte(7, v_level) = 20;
	a_haendler_objekte(8, v_level) = 147;
	a_haendler_objekte(9, v_level) = 270;
	a_haendler_objekte(10, v_level) = 186;
	a_haendler_objekte(11, v_level) = 240;
	a_haendler_objekte(12, v_level) = 229;
	a_haendler_objekte(13, v_level) = 239;
	a_haendler_objekte(14, v_level) = 248;
	a_haendler_objekte(15, v_level) = 200;
	a_haendler_objekte(16, v_level) = 142;
	a_haendler_objekte(17, v_level) = 143;
	a_haendler_objekte(18, v_level) = 177;
	a_haendler_objekte(19, v_level) = 178;
	a_haendler_objekte(20, v_level) = 179;
	a_haendler_objekte(21, v_level) = 180;
	a_haendler_objekte(22, v_level) = 181;
	a_haendler_objekte(23, v_level) = 182;
	a_haendler_objekte(24, v_level) = 183;
	a_haendler_objekte(25, v_level) = 184;
	a_haendler_objekte(26, v_level) = 267;
	a_haendler_objekte(27, v_level) = 220;
	a_haendler_objekte(28, v_level) = 221;
	a_haendler_objekte(29, v_level) = 146;
	a_haendler_objekte(30, v_level) = 260;
	a_haendler_objekte(31, v_level) = 190;
	for (v_i = 31; v_i <= 40; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (75 + p_random(37));
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_haendler_init3(int16_t v_level) {
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	a_haendler_objekte(1, v_level) = 61;
	a_haendler_objekte(2, v_level) = 44;
	a_haendler_objekte(3, v_level) = 46;
	a_haendler_objekte(4, v_level) = 39;
	a_haendler_objekte(5, v_level) = 134;
	a_haendler_objekte(6, v_level) = 193;
	a_haendler_objekte(7, v_level) = 20;
	a_haendler_objekte(8, v_level) = 269;
	a_haendler_objekte(9, v_level) = 399;
	v_hugo = 0;
	for (v_i = 10; v_i <= 15; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (261 + v_hugo);
		v_hugo = (v_hugo + 1);
	}
	v_hugo = 0;
	for (v_i = 16; v_i <= 21; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (135 + v_hugo);
		v_hugo = (v_hugo + 1);
	}
	a_haendler_objekte(22, v_level) = 51;
	a_haendler_objekte(23, v_level) = 145;
	v_hugo = 15;
	for (v_i = 24; v_i <= 40; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = (75 + v_hugo);
		v_hugo = (v_hugo + 1);
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_haendler_init4(int16_t v_level) {
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	a_haendler_objekte(1, v_level) = 63;
	a_haendler_objekte(2, v_level) = 43;
	a_haendler_objekte(3, v_level) = 46;
	a_haendler_objekte(4, v_level) = 39;
	a_haendler_objekte(5, v_level) = 134;
	a_haendler_objekte(6, v_level) = 193;
	a_haendler_objekte(7, v_level) = 20;
	a_haendler_objekte(8, v_level) = 162;
	a_haendler_objekte(9, v_level) = 232;
	a_haendler_objekte(10, v_level) = 247;
	a_haendler_objekte(11, v_level) = 244;
	a_haendler_objekte(12, v_level) = 241;
	a_haendler_objekte(13, v_level) = 292;
	a_haendler_objekte(14, v_level) = 291;
	a_haendler_objekte(15, v_level) = 302;
	a_haendler_objekte(16, v_level) = 303;
	a_haendler_objekte(17, v_level) = 304;
	a_haendler_objekte(18, v_level) = 305;
	a_haendler_objekte(19, v_level) = 306;
	a_haendler_objekte(20, v_level) = 307;
	a_haendler_objekte(21, v_level) = 155;
	a_haendler_objekte(22, v_level) = 156;
	a_haendler_objekte(23, v_level) = 157;
	a_haendler_objekte(24, v_level) = 158;
	a_haendler_objekte(25, v_level) = 160;
	a_haendler_objekte(26, v_level) = 41;
	a_haendler_objekte(27, v_level) = 161;
	a_haendler_objekte(28, v_level) = 53;
	a_haendler_objekte(29, v_level) = 52;
	a_haendler_objekte(30, v_level) = 164;
	a_haendler_objekte(31, v_level) = 400;
	for (v_hugo = 32; v_hugo <= 40; v_hugo += 1) {
		a_haendler_objekte(v_hugo, v_level) = 38;
		do {
			a_haendler_schriftrolle(v_hugo, v_level) = (p_random(176) + 1);
		} while (!(a_zauber(a_haendler_schriftrolle(v_hugo, v_level), g_akt_spieler).f_dauer != 9999));
		a_haendler_staerke(v_hugo, v_level) = (p_random(6) + 2);
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_haendler_init5(int16_t v_level) {
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	a_haendler_objekte(1, v_level) = 64;
	a_haendler_objekte(2, v_level) = 42;
	a_haendler_objekte(3, v_level) = 46;
	a_haendler_objekte(4, v_level) = 39;
	a_haendler_objekte(5, v_level) = 134;
	a_haendler_objekte(6, v_level) = 193;
	a_haendler_objekte(7, v_level) = 20;
	a_haendler_objekte(8, v_level) = 326;
	a_haendler_objekte(9, v_level) = 327;
	a_haendler_objekte(10, v_level) = 355;
	a_haendler_objekte(11, v_level) = 165;
	a_haendler_objekte(12, v_level) = 289;
	a_haendler_objekte(13, v_level) = 280;
	a_haendler_objekte(14, v_level) = 281;
	a_haendler_objekte(15, v_level) = 286;
	a_haendler_objekte(16, v_level) = 284;
	a_haendler_objekte(17, v_level) = 287;
	a_haendler_objekte(18, v_level) = 288;
	a_haendler_objekte(19, v_level) = 357;
	a_haendler_objekte(20, v_level) = 358;
	a_haendler_objekte(21, v_level) = 359;
	a_haendler_objekte(22, v_level) = 360;
	a_haendler_objekte(23, v_level) = 361;
	a_haendler_objekte(24, v_level) = 362;
	a_haendler_objekte(25, v_level) = 363;
	a_haendler_objekte(26, v_level) = 364;
	a_haendler_objekte(27, v_level) = 365;
	a_haendler_objekte(28, v_level) = 366;
	a_haendler_objekte(29, v_level) = 368;
	a_haendler_objekte(30, v_level) = 369;
	a_haendler_objekte(31, v_level) = 370;
	a_haendler_objekte(32, v_level) = 371;
	a_haendler_objekte(33, v_level) = 372;
	a_haendler_objekte(34, v_level) = 373;
	a_haendler_objekte(35, v_level) = 374;
	a_haendler_objekte(36, v_level) = 375;
	for (v_hugo = 37; v_hugo <= 40; v_hugo += 1) {
		a_haendler_objekte(v_hugo, v_level) = 38;
		do {
			a_haendler_schriftrolle(v_hugo, v_level) = (p_random(176) + 1);
		} while (!(a_zauber(a_haendler_schriftrolle(v_hugo, v_level), g_akt_spieler).f_dauer != 9999));
		a_haendler_staerke(v_hugo, v_level) = (p_random(6) + 2);
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_hat_eigenschaft(int16_t v_labyx, int16_t v_labyy, int16_t v_eigensch) {
	int16_t v_trait = 0;
	v_trait = 0;
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft1 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft2 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft3 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft4 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft5 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft6 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft7 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft8 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft9 == v_eigensch)) {
		v_trait = 1;
	}
	if ((a_monster(a_laby_monster(v_labyx, v_labyy).f_name[a_spieler(g_akt_spieler).f_level]).f_eigenschaft10 == v_eigensch)) {
		v_trait = 1;
	}
	return v_trait;
}

static int32_t p_hat_eigenschaft2(int16_t v_welches, int16_t v_eigensch) {
	int32_t v_gef = 0;
	v_gef = 0;
	if ((a_monster(v_welches).f_eigenschaft1 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft2 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft3 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft4 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft5 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft6 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft7 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft8 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft9 == v_eigensch)) {
		v_gef = 1;
	}
	if ((a_monster(v_welches).f_eigenschaft10 == v_eigensch)) {
		v_gef = 1;
	}
	return v_gef;
}

static int32_t p_hat_fernkampf(int16_t v_x, int16_t v_y) {
	if ((((((((((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_zauber > 0) || (p_hat_eigenschaft(v_x, v_y, 5) == 1)) || (p_hat_eigenschaft(v_x, v_y, 20) == 1)) || (p_hat_eigenschaft(v_x, v_y, 21) == 1)) || (p_hat_eigenschaft(v_x, v_y, 23) == 1)) || (p_hat_eigenschaft(v_x, v_y, 14) == 1)) || (p_hat_eigenschaft(v_x, v_y, 22) == 1)) || (p_hat_eigenschaft(v_x, v_y, 24) == 1)) || (p_hat_eigenschaft(v_x, v_y, 41) == 1))) {
		return 1;
	} else {
		return 0;
	}
}

static int32_t p_hater(int16_t v_nr, int32_t v_xx) {
	int32_t v_hater = 0;
	int32_t v_i = 0;
	v_hater = 0;
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if ((a_aktive(v_i, v_xx).f_nr == v_nr)) {
			v_hater = 1;
		}
	}
	return v_hater;
}

static int32_t p_helpful_wizard() {
	int16_t v_heal = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_kill = 0;
	int16_t v_mit_was = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_open = 0;
	int8_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_sel = 0;
	int16_t v_traps = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_sel = 1;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_raus = 0;
		v_kill = 0;
		v_traps = 0;
		v_open = 0;
		v_heal = 0;
		v_yy = 65;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, v_yy, a_nachricht_text(338, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(190, v_yy, a_nachricht_text(339, (1 + g_sprache)), -1, 0);
		p_clipsprite(1, 288, 384, 32, 32);
		p_displaysprite(1, 50, 70);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = (v_sel - 1);
			if ((v_sel < 1)) {
				v_sel = 1;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = (v_sel + 1);
			if ((v_sel > 4)) {
				v_sel = 4;
			}
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 120)) && (v_mmouse_y < 140))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 120, 550, 20, -1);
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 120, a_nachricht_text(340, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_kill = 1;
			}
		} else {
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_kill = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 120, a_nachricht_text(340, (1 + g_sprache)), -1, 0);
		}
		if ((v_kill == 1)) {
			v_mit_was = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_mit_was, 0, 0, 0);
			p_nachricht(344, 1);
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					if ((p_istmonster(v_i, v_j) == 1)) {
						p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					}
				}
			}
		}
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 140)) && (v_mmouse_y < 160))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 140, 550, 20, -1);
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 140, a_nachricht_text(341, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_traps = 1;
			}
		} else {
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_traps = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 140, a_nachricht_text(341, (1 + g_sprache)), -1, 0);
		}
		if ((v_traps == 1)) {
			v_mit_was = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_mit_was, 0, 0, 0);
			p_nachricht(344, 1);
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					if (((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] >= 22) && (a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] <= 39))) {
						p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					}
				}
			}
		}
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 160)) && (v_mmouse_y < 180))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 160, 550, 20, -1);
			if ((v_sel == 3)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 160, a_nachricht_text(342, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_open = 1;
			}
		} else {
			if ((v_sel == 3)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_open = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 160, a_nachricht_text(342, (1 + g_sprache)), -1, 0);
		}
		if ((v_open == 1)) {
			v_mit_was = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_mit_was, 0, 0, 0);
			p_nachricht(344, 1);
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					if ((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 67)) {
						p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, 68, 0, 0, 0);
					}
					if ((a_labyrinth(v_i, v_j).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
						p_setlaby(v_i, v_j, a_spieler(g_akt_spieler).f_level, 21, 0, 0, 0);
					}
				}
			}
		}
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 180)) && (v_mmouse_y < 200))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 180, 550, 20, -1);
			if ((v_sel == 4)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 180, a_nachricht_text(343, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_heal = 1;
			}
		} else {
			if ((v_sel == 4)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_heal = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 180, a_nachricht_text(343, (1 + g_sprache)), -1, 0);
		}
		if ((v_heal == 1)) {
			v_mit_was = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_mit_was, 0, 0, 0);
			p_nachricht(344, 1);
			a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
			a_spieler(g_akt_spieler).f_mana = p_maxmana();
			a_spieler(g_akt_spieler).f_fluch = 0;
			a_spieler(g_akt_spieler).f_fluchdauer = 0;
			a_spieler(g_akt_spieler).f_gift = 0;
			a_spieler(g_akt_spieler).f_giftdauer = 0;
		}
		p_stopdrawing();
		p_delay(g_mydelay3);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	g_aktion = 1;
}

static int32_t p_highscore_upload() {
	int16_t v_akt_skill = 0;
	std::string v_charactereigenschaften;
	int32_t v_con = 0;
	int32_t v_ebene = 0;
	std::string v_endezeit;
	int16_t v_gef_stabteile = 0;
	int32_t v_gold = 0;
	int16_t v_i = 0;
	int16_t v_icon = 0;
	int32_t v_mks = 0;
	std::string v_name;
	std::string v_p;
	int16_t v_runden = 0;
	int32_t v_score = 0;
	std::string v_server;
	std::string v_todesart;
	std::string v_verifikation;
	std::string v_version;
	v_server = "www.lostlabyrinth.com";
	if ((g_test == 1)) {
		v_server = "localhost";
	}
	v_p = "";
	v_name = g_myname;
	v_verifikation = a_spieler(g_akt_spieler).f_verifikation;
	v_gold = p_gold_anzahl();
	v_ebene = a_spieler(g_akt_spieler).f_level;
	v_version = "2.9";
	v_runden = a_spieler(g_akt_spieler).f_moves;
	v_charactereigenschaften = "";
	v_todesart = a_spieler(g_akt_spieler).f_sterbegrund[1];
	for (v_i = 1; v_i <= 141; v_i += 1) {
		v_akt_skill = 0;
		if ((a_skills(v_i, g_akt_spieler).f_gewaehlt == 1)) {
			if ((v_charactereigenschaften != "")) {
				v_charactereigenschaften = (v_charactereigenschaften + ":");
			}
			switch (a_skills(v_i, g_akt_spieler).f_nummer) {
			case 35:
				v_akt_skill = 1;
				break;
			case 36:
				v_akt_skill = 2;
				break;
			case 37:
				v_akt_skill = 3;
				break;
			case 38:
				v_akt_skill = 4;
				break;
			case 42:
				v_akt_skill = 5;
				break;
			case 43:
				v_akt_skill = 6;
				break;
			case 44:
				v_akt_skill = 7;
				break;
			case 102:
				v_akt_skill = 8;
				break;
			case 45:
				v_akt_skill = 9;
				break;
			case 48:
				v_akt_skill = 10;
				break;
			case 49:
				v_akt_skill = 11;
				break;
			case 50:
				v_akt_skill = 12;
				break;
			case 51:
				v_akt_skill = 13;
				break;
			case 52:
				v_akt_skill = 14;
				break;
			case 53:
				v_akt_skill = 15;
				break;
			case 54:
				v_akt_skill = 16;
				break;
			case 55:
				v_akt_skill = 17;
				break;
			case 56:
				v_akt_skill = 18;
				break;
			case 57:
				v_akt_skill = 19;
				break;
			case 58:
				v_akt_skill = 20;
				break;
			case 59:
				v_akt_skill = 21;
				break;
			case 1:
				v_akt_skill = 22;
				break;
			case 2:
				v_akt_skill = 23;
				break;
			case 3:
				v_akt_skill = 24;
				break;
			case 5:
				v_akt_skill = 25;
				break;
			case 6:
				v_akt_skill = 26;
				break;
			case 7:
				v_akt_skill = 27;
				break;
			case 69:
				v_akt_skill = 28;
				break;
			case 70:
				v_akt_skill = 29;
				break;
			case 71:
				v_akt_skill = 30;
				break;
			case 72:
				v_akt_skill = 31;
				break;
			case 73:
				v_akt_skill = 32;
				break;
			case 74:
				v_akt_skill = 33;
				break;
			case 75:
				v_akt_skill = 34;
				break;
			case 83:
				v_akt_skill = 35;
				break;
			case 84:
				v_akt_skill = 36;
				break;
			case 111:
				v_akt_skill = 37;
				break;
			case 112:
				v_akt_skill = 38;
				break;
			case 85:
				v_akt_skill = 39;
				break;
			case 8:
				v_akt_skill = 40;
				break;
			case 39:
				v_akt_skill = 41;
				break;
			case 47:
				v_akt_skill = 42;
				break;
			case 86:
				v_akt_skill = 43;
				break;
			case 87:
				v_akt_skill = 44;
				break;
			case 9:
				v_akt_skill = 45;
				break;
			case 40:
				v_akt_skill = 46;
				break;
			case 88:
				v_akt_skill = 47;
				break;
			case 76:
				v_akt_skill = 48;
				break;
			case 41:
				v_akt_skill = 49;
				break;
			case 30:
				v_akt_skill = 50;
				break;
			case 113:
				v_akt_skill = 51;
				break;
			case 4:
				v_akt_skill = 52;
				break;
			case 114:
				v_akt_skill = 53;
				break;
			case 10:
				v_akt_skill = 54;
				break;
			case 97:
				v_akt_skill = 55;
				break;
			case 11:
				v_akt_skill = 56;
				break;
			case 46:
				v_akt_skill = 57;
				break;
			case 115:
				v_akt_skill = 58;
				break;
			case 89:
				v_akt_skill = 59;
				break;
			case 60:
				v_akt_skill = 60;
				break;
			case 121:
				v_akt_skill = 61;
				break;
			case 122:
				v_akt_skill = 62;
				break;
			case 123:
				v_akt_skill = 63;
				break;
			case 124:
				v_akt_skill = 64;
				break;
			case 125:
				v_akt_skill = 65;
				break;
			case 126:
				v_akt_skill = 66;
				break;
			case 127:
				v_akt_skill = 67;
				break;
			case 128:
				v_akt_skill = 68;
				break;
			case 129:
				v_akt_skill = 69;
				break;
			case 130:
				v_akt_skill = 70;
				break;
			case 90:
				v_akt_skill = 71;
				break;
			case 133:
				v_akt_skill = 72;
				break;
			case 132:
				v_akt_skill = 73;
				break;
			case 131:
				v_akt_skill = 74;
				break;
			case 61:
				v_akt_skill = 75;
				break;
			case 14:
				v_akt_skill = 76;
				break;
			case 15:
				v_akt_skill = 77;
				break;
			case 13:
				v_akt_skill = 78;
				break;
			case 103:
				v_akt_skill = 79;
				break;
			case 104:
				v_akt_skill = 80;
				break;
			case 105:
				v_akt_skill = 81;
				break;
			case 106:
				v_akt_skill = 82;
				break;
			case 108:
				v_akt_skill = 83;
				break;
			case 107:
				v_akt_skill = 84;
				break;
			case 134:
				v_akt_skill = 85;
				break;
			case 12:
				v_akt_skill = 86;
				break;
			case 91:
				v_akt_skill = 87;
				break;
			case 92:
				v_akt_skill = 88;
				break;
			case 77:
				v_akt_skill = 89;
				break;
			case 116:
				v_akt_skill = 90;
				break;
			case 17:
				v_akt_skill = 91;
				break;
			case 21:
				v_akt_skill = 92;
				break;
			case 22:
				v_akt_skill = 93;
				break;
			case 23:
				v_akt_skill = 94;
				break;
			case 24:
				v_akt_skill = 95;
				break;
			case 25:
				v_akt_skill = 96;
				break;
			case 62:
				v_akt_skill = 97;
				break;
			case 110:
				v_akt_skill = 98;
				break;
			case 79:
				v_akt_skill = 99;
				break;
			case 80:
				v_akt_skill = 100;
				break;
			case 18:
				v_akt_skill = 101;
				break;
			case 19:
				v_akt_skill = 102;
				break;
			case 20:
				v_akt_skill = 103;
				break;
			case 31:
				v_akt_skill = 104;
				break;
			case 26:
				v_akt_skill = 105;
				break;
			case 63:
				v_akt_skill = 106;
				break;
			case 64:
				v_akt_skill = 107;
				break;
			case 78:
				v_akt_skill = 108;
				break;
			case 93:
				v_akt_skill = 109;
				break;
			case 94:
				v_akt_skill = 110;
				break;
			case 95:
				v_akt_skill = 111;
				break;
			case 135:
				v_akt_skill = 112;
				break;
			case 96:
				v_akt_skill = 113;
				break;
			case 65:
				v_akt_skill = 114;
				break;
			case 117:
				v_akt_skill = 115;
				break;
			case 27:
				v_akt_skill = 116;
				break;
			case 32:
				v_akt_skill = 117;
				break;
			case 33:
				v_akt_skill = 118;
				break;
			case 81:
				v_akt_skill = 119;
				break;
			case 16:
				v_akt_skill = 120;
				break;
			case 118:
				v_akt_skill = 121;
				break;
			case 67:
				v_akt_skill = 122;
				break;
			case 98:
				v_akt_skill = 123;
				break;
			case 99:
				v_akt_skill = 124;
				break;
			case 138:
				v_akt_skill = 125;
				break;
			case 139:
				v_akt_skill = 126;
				break;
			case 140:
				v_akt_skill = 127;
				break;
			case 119:
				v_akt_skill = 128;
				break;
			case 100:
				v_akt_skill = 128;
				break;
			default:
				v_akt_skill = 0;

				break;
			}
			if ((v_akt_skill > 0)) {
				v_charactereigenschaften = (v_charactereigenschaften + p_right(p_str(v_akt_skill), 3));
			}
		}
	}
	v_gef_stabteile = a_spieler(g_akt_spieler).f_stabteile;
	v_icon = a_spieler(g_akt_spieler).f_maennchen;
	v_endezeit = p_formatdate("%yyyy%mm%dd%hh%ii%ss", p_date());
	v_mks = a_spieler(g_akt_spieler).f_mks;
	v_score = p_punkte();
	if ((p_initnetwork() == 0)) {
	}
	v_con = p_opennetworkconnection(v_server, 80);
	if ((v_con == 0)) {
	}
	v_p = ("name=" + p_replacestring(v_name, " ", "%20"));
	v_p = ((v_p + "&verifikation=") + v_verifikation);
	v_p = ((v_p + "&anfangszeit=") + g_anfangszeit);
	v_p = ((v_p + "&endezeit=") + v_endezeit);
	v_p = ((v_p + "&ebene=") + p_str(v_ebene));
	v_p = ((v_p + "&mks=") + p_str(v_mks));
	v_p = ((v_p + "&punkte=") + p_str(v_score));
	v_p = ((v_p + "&version=") + v_version);
	v_p = ((v_p + "&gold=") + p_str(v_gold));
	v_todesart = p_replacestring(v_todesart, " ", "%20");
	v_p = ((v_p + "&tod=") + v_todesart);
	v_p = ((v_p + "&icon=") + p_str(v_icon));
	v_p = ((v_p + "&st=") + p_str(v_gef_stabteile));
	v_p = ((v_p + "&runden=") + p_str(v_runden));
	v_p = ((v_p + "&ce=") + v_charactereigenschaften);
	v_p = ((v_p + "&saves=") + p_str(g_nr_of_saves));
	p_sendnetworkstring(v_con, ((("GET /newhighscore.php?" + v_p) + " HTTP/1.1") + p_chr(10)));
	p_sendnetworkstring(v_con, (("Host: " + v_server) + p_chr(10)));
	p_sendnetworkstring(v_con, ("User-agent: PureBasicAgent" + p_chr(10)));
	p_sendnetworkstring(v_con, ("Accept: */*" + p_chr(10)));
	p_sendnetworkstring(v_con, p_chr(10));
	p_closenetworkconnection(v_con);
	p_nachricht(330, 5);
}

static int32_t p_hilfe() {
	int16_t v_mmouse_links = 0;
	int16_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_pos_x = 0;
	int32_t v_pos_y = 0;
	std::string v_text;
	int32_t v_x = 0;
	int32_t v_y = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		if ((g_gb_callfromtitlescreen == 1)) {
			p_clipsprite(18, 0, 0, 640, 480);
			p_displaysprite(18, 0, 0);
			p_clipsprite(54, 0, 0, 640, 17);
			p_displaysprite(54, 0, 0);
			p_clipsprite(56, 0, 0, 17, 480);
			p_displaysprite(56, 0, 0);
			p_clipsprite(57, 0, 0, 640, 17);
			p_displaysprite(57, 0, 464);
			p_clipsprite(59, 0, 0, 17, 480);
			p_displaysprite(59, 624, 0);
			v_x = 220;
			v_y = 90;
			v_pos_x = 220;
			v_pos_y = 400;
		} else {
			p_laby_rahmen();
			p_show_logo();
			p_show_varys();
			p_show_buttons();
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_x = 100;
			v_y = 70;
			v_pos_x = 60;
			v_pos_y = 385;
		}
		p_startdrawing(p_screenoutput());
		p_drawingmode(1);
		p_frontcolor(16776960);
		p_drawtext(v_x, v_y, a_nachricht_text(67, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(74, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(69, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(70, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(72, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(518, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(657, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(68, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(71, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(72, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(73, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(73, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(807, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(720, (g_sprache + 1)), -1, 0);
		v_y += g_yplus;
		p_drawtext(v_x, v_y, a_nachricht_text(415, (g_sprache + 1)), -1, 0);
		p_stopdrawing();
		p_examinekeyboard();
		if (p_examinemouse()) {
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		p_drawbuttonnotpressed(69, v_pos_x, v_pos_y, 6, 24, a_nachricht_text(819, (1 + g_sprache)));
		if (((((v_mmouse_x > (v_pos_x - 6)) && (v_mmouse_x < (v_pos_x + 60))) && (v_mmouse_y > (v_pos_y - 6))) && (v_mmouse_y < (v_pos_y + 20)))) {
			v_text = "";
			if ((g_sprache == 0)) {
				v_text = "readme.txt";
			}
			if ((g_sprache == 1)) {
				v_text = "liesmich.txt";
			}
			if ((g_sprache == 2)) {
				v_text = "leeme.txt";
			}
			p_drawbuttonpressed(69, v_pos_x, v_pos_y, 6, 24, a_nachricht_text(819, (1 + g_sprache)));
			if ((v_mmouse_links == 1)) {
				p_display(v_text);
			}
		}
		p_drawbuttonnotpressed(69, (v_pos_x + 100), v_pos_y, 6, 24, a_nachricht_text(820, (1 + g_sprache)));
		if (((((v_mmouse_x > (v_pos_x + 94)) && (v_mmouse_x < (v_pos_x + 200))) && (v_mmouse_y > (v_pos_y - 6))) && (v_mmouse_y < (v_pos_y + 20)))) {
			v_text = "";
			if ((g_sprache == 0)) {
				v_text = "readme_spells.txt";
			}
			if ((g_sprache == 1)) {
				v_text = "liesmich_zauber.txt";
			}
			if ((g_sprache == 2)) {
				v_text = "leeme_hechizos.txt";
			}
			p_drawbuttonpressed(69, (v_pos_x + 100), v_pos_y, 6, 24, a_nachricht_text(820, (1 + g_sprache)));
			if ((v_mmouse_links == 1)) {
				p_display(v_text);
			}
		}
		p_drawbuttonnotpressed(69, (v_pos_x + 230), v_pos_y, 6, 24, "FAQ");
		if (((((v_mmouse_x > (v_pos_x + 224)) && (v_mmouse_x < (v_pos_x + 250))) && (v_mmouse_y > (v_pos_y - 6))) && (v_mmouse_y < (v_pos_y + 20)))) {
			v_text = "";
			if ((g_sprache == 0)) {
				v_text = "FAQ_eng.txt";
			}
			if ((g_sprache == 1)) {
				v_text = "FAQ_deu.txt";
			}
			if ((g_sprache == 2)) {
				v_text = "FAQ_esp.txt";
			}
			p_drawbuttonpressed(69, (v_pos_x + 230), v_pos_y, 6, 24, "FAQ");
			if ((v_mmouse_links == 1)) {
				p_display(v_text);
			}
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(p_keyboardpushed(13) || (v_mmouse_rechts == 1)));
}

static int32_t p_hinterhalt(int16_t v_welches) {
	p_nachricht(4, 3);
	if (((((p_blockiert((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0)) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] != 53)) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] != 72))) {
		g_xmod = 1;
		g_ymod = 0;
		p_aufstehen(a_monster(v_welches).f_nr);
		p_setmonster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, 0, 0);
	}
	if ((((((p_blockiert((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level) == 0) && ((a_spieler(g_akt_spieler).f_character_x - 1) > 0)) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0)) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] != 53)) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] != 72))) {
		g_xmod = -1;
		g_ymod = 0;
		p_aufstehen(a_monster(v_welches).f_nr);
		p_setmonster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, 0, 0);
	}
	if (((((p_blockiert(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0)) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] != 53)) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] != 72))) {
		g_xmod = 0;
		g_ymod = 1;
		p_aufstehen(a_monster(v_welches).f_nr);
		p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, 0, 0);
	}
	if ((((((p_blockiert(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level) == 0) && ((a_spieler(g_akt_spieler).f_character_y - 1) > 0)) && (a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0)) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] != 53)) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] != 72))) {
		g_xmod = 0;
		g_ymod = -1;
		p_aufstehen(a_monster(v_welches).f_nr);
		p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, 0, 0);
	}
	p_laby_screen();
}

static int32_t p_hinterlassen(int16_t v_x, int16_t v_y) {
	int16_t v_hugo = 0;
	int32_t v_obje = 0;
	int16_t v_schongesetzt = 0;
	int16_t v_welcher_schatz = 0;
	if ((a_skills(27, g_akt_spieler).f_gewaehlt == 1)) {
		p_gold_finden2(p_min(5, a_spieler(g_akt_spieler).f_level));
	}
	v_schongesetzt = 0;
	if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] > 0)) {
		v_schongesetzt = 1;
	}
	if (((a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] == 121) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 30)) {
			v_hugo = (p_random(3) + 1);
			switch (v_hugo) {
			case 1:
				v_obje = 144;
				break;
			case 2:
				v_obje = 219;
				break;
			case 3:
				v_obje = 171;
				break;
			case 4:
				v_obje = 304;
				break;
			}
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, v_obje, 0, 0);
			v_schongesetzt = 1;
		}
	}
	if (((a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] == 122) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 30)) {
			v_hugo = (p_random(4) + 1);
			switch (v_hugo) {
			case 1:
				v_obje = 257;
				break;
			case 2:
				v_obje = 148;
				break;
			case 3:
				v_obje = 261;
				break;
			case 4:
				v_obje = 137;
				break;
			case 5:
				v_obje = 220;
				break;
			}
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, v_obje, 0, 0);
			v_schongesetzt = 1;
		}
	}
	if (((a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] == 123) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 30)) {
			v_hugo = (p_random(1) + 1);
			switch (v_hugo) {
			case 1:
				v_obje = 135;
				break;
			case 2:
				v_obje = 136;
				break;
			}
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, v_obje, 0, 0);
			v_schongesetzt = 1;
		}
	}
	if (((a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] == 102) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 90)) {
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 351, 0, 0);
			v_schongesetzt = 1;
		}
	}
	if ((((p_hat_eigenschaft(v_x, v_y, 27) == 1) && (p_random(100) > 50)) && (v_schongesetzt == 0))) {
		v_welcher_schatz = p_random(100);
		if ((v_welcher_schatz < 60)) {
			p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		}
		if (((v_welcher_schatz >= 60) && (v_welcher_schatz < 80))) {
			p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 6, 0, 0, p_finden1());
		}
		if (((v_welcher_schatz >= 80) && (v_welcher_schatz < 90))) {
			if ((p_random(100) < 50)) {
				if ((p_random(100) < 50)) {
					p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 62, 0, 0, p_finden1());
				} else {
					p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 62, 0, 0, p_finden2());
				}
			} else {
				if ((p_random(100) < 50)) {
					p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 63, 0, 0, p_finden1());
				} else {
					p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 63, 0, 0, p_finden2());
				}
			}
		}
		if ((v_welcher_schatz >= 90)) {
			p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 68, 0, 0, p_finden2());
		}
		v_schongesetzt = 1;
	}
	if ((((p_hat_eigenschaft(v_x, v_y, 26) == 1) && (p_random(100) > 50)) && (v_schongesetzt == 0))) {
		if ((p_random(100) < 60)) {
			p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		} else {
			if ((p_random(100) < 80)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 6, 0, 0, p_finden1());
			} else {
				if ((p_random(100) < 50)) {
					if ((p_random(100) < 50)) {
						p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 62, 0, 0, p_finden1());
					} else {
						p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 62, 0, 0, p_finden2());
					}
				} else {
					if ((p_random(100) < 50)) {
						p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 63, 0, 0, p_finden1());
					} else {
						p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 63, 0, 0, p_finden2());
					}
				}
			}
		}
		v_schongesetzt = 1;
	}
	if (((((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 3) && (a_skills(14, g_akt_spieler).f_gewaehlt == 1)) && (p_random(100) > 50)) && (v_schongesetzt == 0))) {
		p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		v_schongesetzt = 1;
	}
	if (((((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 2) && (a_skills(15, g_akt_spieler).f_gewaehlt == 1)) && (p_random(100) > 50)) && (v_schongesetzt == 0))) {
		p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		v_schongesetzt = 1;
	}
	if (((((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1) && (a_skills(13, g_akt_spieler).f_gewaehlt == 1)) && (p_random(100) > 50)) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 50)) {
			if ((p_random(100) > 50)) {
				p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 42, a_gegenstand(42).f_attri1, 0);
			} else {
				p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 43, a_gegenstand(43).f_attri1, 0);
			}
		} else {
			p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		}
		v_schongesetzt = 1;
	}
	if (((((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1) && (a_skills(93, g_akt_spieler).f_gewaehlt == 1)) && (p_random(100) > 90)) && (v_schongesetzt == 0))) {
		if ((p_random(100) > 50)) {
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 42, a_gegenstand(42).f_attri1, 0);
		} else {
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 43, a_gegenstand(43).f_attri1, 0);
		}
		v_schongesetzt = 1;
	}
	p_setmonster(v_x, v_y, a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
}

static int32_t p_horizontal(int16_t v_akt_level) {
	int16_t v_gef = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_save_anzahl = 0;
	int16_t v_save_duration = 0;
	int16_t v_save_feld = 0;
	int16_t v_save_graphic = 0;
	int16_t v_save_lebenspunkte = 0;
	int16_t v_save_lifepoints = 0;
	int16_t v_save_name = 0;
	int16_t v_save_name2 = 0;
	int16_t v_save_objekt = 0;
	int16_t v_save_status = 0;
	int16_t v_save_status2 = 0;
	int32_t v_xxx = 0;
	int16_t v_yyy = 0;
	for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
		for (v_j = 1; v_j <= (a_groesse(v_akt_level) / 2); v_j += 1) {
			v_save_feld = a_labyrinth(v_i, v_j).f_feld[v_akt_level];
			v_save_lebenspunkte = a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level];
			v_save_objekt = a_labyrinth(v_i, v_j).f_objekt[v_akt_level];
			v_save_status = a_labyrinth(v_i, v_j).f_status[v_akt_level];
			v_save_name = a_laby_monster(v_i, v_j).f_name[v_akt_level];
			v_save_graphic = a_laby_monster(v_i, v_j).f_graphic[v_akt_level];
			v_save_lifepoints = a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level];
			v_save_status = a_laby_monster(v_i, v_j).f_status[v_akt_level];
			v_save_duration = a_laby_monster(v_i, v_j).f_duration[v_akt_level];
			v_save_name2 = a_laby_item(v_i, v_j).f_name[v_akt_level];
			v_save_anzahl = a_laby_item(v_i, v_j).f_anzahl[v_akt_level];
			v_save_status2 = a_laby_item(v_i, v_j).f_status[v_akt_level];
			a_labyrinth(v_i, v_j).f_feld[v_akt_level] = a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_feld[v_akt_level];
			a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level] = a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_lebenspunkte[v_akt_level];
			a_labyrinth(v_i, v_j).f_objekt[v_akt_level] = a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_objekt[v_akt_level];
			a_labyrinth(v_i, v_j).f_status[v_akt_level] = a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_name[v_akt_level] = a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_name[v_akt_level];
			a_laby_monster(v_i, v_j).f_graphic[v_akt_level] = a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_graphic[v_akt_level];
			a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level] = a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_lifepoints[v_akt_level];
			a_laby_monster(v_i, v_j).f_status[v_akt_level] = a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_duration[v_akt_level] = a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_duration[v_akt_level];
			a_laby_item(v_i, v_j).f_name[v_akt_level] = a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_name[v_akt_level];
			a_laby_item(v_i, v_j).f_anzahl[v_akt_level] = a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_anzahl[v_akt_level];
			a_laby_item(v_i, v_j).f_status[v_akt_level] = a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level];
			a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_feld[v_akt_level] = v_save_feld;
			a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_lebenspunkte[v_akt_level] = v_save_lebenspunkte;
			a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_objekt[v_akt_level] = v_save_objekt;
			a_labyrinth(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level] = v_save_status;
			a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_name[v_akt_level] = v_save_name;
			a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_graphic[v_akt_level] = v_save_graphic;
			a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_lifepoints[v_akt_level] = v_save_lifepoints;
			a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level] = v_save_status;
			a_laby_monster(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_duration[v_akt_level] = v_save_duration;
			a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_name[v_akt_level] = v_save_name2;
			a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_anzahl[v_akt_level] = v_save_anzahl;
			a_laby_item(v_i, ((a_groesse(v_akt_level) + 1) - v_j)).f_status[v_akt_level] = v_save_status2;
		}
	}
	for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
		for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
			if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 74)) {
				a_labyrinth(v_i, v_j).f_objekt[v_akt_level] = ((a_groesse(v_akt_level) + 1) - a_labyrinth(v_i, v_j).f_objekt[v_akt_level]);
			}
		}
	}
	v_yyy = 1;
	v_gef = 0;
	do {
		v_yyy = 0;
		do {
			if ((a_labyrinth(v_xxx, v_yyy).f_feld[v_akt_level] == 47)) {
				v_gef = 1;
			}
			v_yyy = (v_yyy + 1);
		} while (!((v_gef == 1) || (v_yyy > a_groesse(v_akt_level))));
		v_xxx = (v_xxx + 1);
	} while (!((v_gef == 1) || (v_xxx > a_groesse(v_akt_level))));
	a_raumy(v_akt_level) = (v_yyy - 2);
	a_eingangy(v_akt_level) = a_groesse(v_akt_level);
	a_ausgangy(v_akt_level) = ((a_groesse(v_akt_level) + 1) - a_ausgangy(v_akt_level));
}

static int32_t p_hydra_zauber(int16_t v_schaden) {
	int32_t v_neue_koepfe = 0;
	if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] >= 137) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] <= 148))) {
		if ((v_schaden > p_min(p_max(((a_spieler(g_akt_spieler).f_level / 2) + 1), 6), 15))) {
			a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
			p_nachricht(287, 3);
			p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
			if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
			}
		} else {
			v_neue_koepfe = (p_random(1) + 1);
			a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] + v_neue_koepfe);
			if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] > 9)) {
				a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 9;
			}
			p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
		}
	}
}

static int32_t p_ich_trage(int16_t v_was) {
	int32_t v_i = 0;
	int32_t v_jupp = 0;
	int32_t v_waffe = 0;
	v_jupp = 0;
	v_waffe = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_klasse == v_was) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_jupp = 1;
		}
		if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_waffe = 1;
		}
	}
	if (((v_was == 10) && (v_waffe == 1))) {
		v_jupp = 1;
	}
	return v_jupp;
}

static int32_t p_ich_trage2(int16_t v_geg) {
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	v_hugo = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_name == v_geg) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_hugo = 1;
		}
	}
	return v_hugo;
}

static int32_t p_ich_trage3(int16_t v_was) {
	int32_t v_i = 0;
	int32_t v_jupp = 0;
	v_jupp = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_name == v_was) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_jupp = 1;
		}
	}
	return v_jupp;
}

static int32_t p_ich_trage4() {
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	v_hugo = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_magisch == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_hugo = 1;
		}
	}
	return v_hugo;
}

static int32_t p_immune(int16_t v_gegen) {
	int16_t v_res = 0;
	if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), v_gegen) == 0) || (p_habich(160) > 0))) {
		v_res = 0;
	} else {
		v_res = 1;
	}
	return v_res;
}

static int32_t p_in_rucksack(int16_t v_geg, int16_t v_anzahl) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	v_i = 0;
	do {
		v_i = (v_i + 1);
	} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
	if ((v_i <= 50)) {
		if ((v_geg == 38)) {
			a_new_item(1).f_name = 38;
			a_new_item(1).f_anzahl = 0;
			a_new_item(1).f_art = 5;
			a_new_item(1).f_benutzt = 0;
			a_new_item(1).f_status = 0;
			do {
				a_new_item(1).f_attri1 = (p_random(176) + 1);
			} while (!(a_zauber(a_new_item(1).f_attri1, g_akt_spieler).f_dauer != 9999));
			a_new_item(1).f_attri2 = (p_random(6) + 2);
			a_new_item(1).f_attri3 = 0;
			a_new_item(1).f_attri4 = 0;
			a_inventory(v_i, g_akt_spieler).f_name = a_new_item(1).f_name;
			a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
			a_inventory(v_i, g_akt_spieler).f_anzahl = a_new_item(1).f_anzahl;
			a_inventory(v_i, g_akt_spieler).f_art = a_new_item(1).f_art;
			a_inventory(v_i, g_akt_spieler).f_status = a_new_item(1).f_status;
			a_inventory(v_i, g_akt_spieler).f_attri1 = a_new_item(1).f_attri1;
			a_inventory(v_i, g_akt_spieler).f_attri2 = a_new_item(1).f_attri2;
			a_inventory(v_i, g_akt_spieler).f_attri3 = a_new_item(1).f_attri3;
			a_inventory(v_i, g_akt_spieler).f_attri4 = a_new_item(1).f_attri4;
		} else {
			a_new_item(1).f_name = v_geg;
			a_new_item(1).f_anzahl = (v_anzahl - 1);
			a_new_item(1).f_art = a_gegenstand(v_geg).f_art;
			a_new_item(1).f_status = 0;
			a_new_item(1).f_attri1 = a_gegenstand(v_geg).f_attri1;
			a_new_item(1).f_attri2 = a_gegenstand(v_geg).f_attri2;
			a_new_item(1).f_attri3 = a_gegenstand(v_geg).f_attri3;
			a_new_item(1).f_attri4 = a_gegenstand(v_geg).f_attri4;
			if ((a_gegenstand(v_geg).f_qualitaet > 0)) {
				a_new_item(1).f_status = (p_random(2) + 1);
			} else {
				a_new_item(1).f_status = 0;
			}
			if ((v_geg == 249)) {
				a_new_item(1).f_attri1 = (p_random(6) + 1);
			}
			v_j = 0;
			do {
				v_j = (v_j + 1);
			} while (!((((((((a_inventory(v_j, g_akt_spieler).f_name == a_new_item(1).f_name) && (a_inventory(v_j, g_akt_spieler).f_art == a_new_item(1).f_art)) && (a_inventory(v_j, g_akt_spieler).f_status == a_new_item(1).f_status)) && (a_inventory(v_j, g_akt_spieler).f_attri1 == a_new_item(1).f_attri1)) && (a_inventory(v_j, g_akt_spieler).f_attri2 == a_new_item(1).f_attri2)) && (a_inventory(v_j, g_akt_spieler).f_attri3 == a_new_item(1).f_attri3)) && (a_inventory(v_j, g_akt_spieler).f_attri4 == a_new_item(1).f_attri4)) || (v_j > 50)));
			if ((v_j > 50)) {
				a_inventory(v_i, g_akt_spieler).f_name = a_new_item(1).f_name;
				a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
				a_inventory(v_i, g_akt_spieler).f_anzahl = a_new_item(1).f_anzahl;
				a_inventory(v_i, g_akt_spieler).f_art = a_new_item(1).f_art;
				a_inventory(v_i, g_akt_spieler).f_status = a_new_item(1).f_status;
				a_inventory(v_i, g_akt_spieler).f_attri1 = a_new_item(1).f_attri1;
				a_inventory(v_i, g_akt_spieler).f_attri2 = a_new_item(1).f_attri2;
				a_inventory(v_i, g_akt_spieler).f_attri3 = a_new_item(1).f_attri3;
				a_inventory(v_i, g_akt_spieler).f_attri4 = a_new_item(1).f_attri4;
			} else {
				a_inventory(v_j, g_akt_spieler).f_anzahl = (a_inventory(v_j, g_akt_spieler).f_anzahl + 1);
			}
		}
	} else {
		p_nachricht(428, 1);
	}
	return v_i;
}

static int32_t p_init_creatures() {
	a_creature(1).f_creature_lifepoints = 5;
	a_creature(1).f_creature_attack = 20;
	a_creature(1).f_creature_schaden_min = 1;
	a_creature(1).f_creature_schaden_max = 2;
	a_creature(1).f_creature_maxspeed = 10;
	a_creature(2).f_creature_lifepoints = 10;
	a_creature(2).f_creature_attack = 40;
	a_creature(2).f_creature_schaden_min = 1;
	a_creature(2).f_creature_schaden_max = 4;
	a_creature(2).f_creature_maxspeed = 4;
	a_creature(3).f_creature_lifepoints = 20;
	a_creature(3).f_creature_attack = 70;
	a_creature(3).f_creature_schaden_min = 1;
	a_creature(3).f_creature_schaden_max = 10;
	a_creature(3).f_creature_maxspeed = 5;
	a_creature(4).f_creature_lifepoints = 10;
	a_creature(4).f_creature_attack = 40;
	a_creature(4).f_creature_schaden_min = 1;
	a_creature(4).f_creature_schaden_max = 2;
	a_creature(4).f_creature_maxspeed = 15;
	a_creature(5).f_creature_lifepoints = 25;
	a_creature(5).f_creature_attack = 70;
	a_creature(5).f_creature_schaden_min = 2;
	a_creature(5).f_creature_schaden_max = 10;
	a_creature(5).f_creature_maxspeed = 7;
	a_creature(6).f_creature_lifepoints = 50;
	a_creature(6).f_creature_attack = 60;
	a_creature(6).f_creature_schaden_min = 2;
	a_creature(6).f_creature_schaden_max = 15;
	a_creature(6).f_creature_maxspeed = 4;
	a_creature(7).f_creature_lifepoints = 70;
	a_creature(7).f_creature_attack = 80;
	a_creature(7).f_creature_schaden_min = 3;
	a_creature(7).f_creature_schaden_max = 20;
	a_creature(7).f_creature_maxspeed = 8;
	a_creature(8).f_creature_lifepoints = 70;
	a_creature(8).f_creature_attack = 80;
	a_creature(8).f_creature_schaden_min = 3;
	a_creature(8).f_creature_schaden_max = 20;
	a_creature(8).f_creature_maxspeed = 8;
	a_creature(9).f_creature_lifepoints = 100;
	a_creature(9).f_creature_attack = 80;
	a_creature(9).f_creature_schaden_min = 4;
	a_creature(9).f_creature_schaden_max = 25;
	a_creature(9).f_creature_maxspeed = 5;
	a_creature(10).f_creature_lifepoints = 0;
	a_creature(10).f_creature_attack = 60;
	a_creature(10).f_creature_schaden_min = 2;
	a_creature(10).f_creature_schaden_max = 10;
	a_creature(10).f_creature_maxspeed = 0;
	a_creature(11).f_creature_lifepoints = 5;
	a_creature(11).f_creature_attack = 20;
	a_creature(11).f_creature_schaden_min = 1;
	a_creature(11).f_creature_schaden_max = 2;
	a_creature(11).f_creature_maxspeed = 12;
	a_creature(12).f_creature_lifepoints = 100;
	a_creature(12).f_creature_attack = 60;
	a_creature(12).f_creature_schaden_min = 2;
	a_creature(12).f_creature_schaden_max = 10;
	a_creature(12).f_creature_maxspeed = 4;
	a_creature(13).f_creature_lifepoints = 20;
	a_creature(13).f_creature_attack = 60;
	a_creature(13).f_creature_schaden_min = 2;
	a_creature(13).f_creature_schaden_max = 8;
	a_creature(13).f_creature_maxspeed = 6;
	a_creature(14).f_creature_lifepoints = 24;
	a_creature(14).f_creature_attack = 60;
	a_creature(14).f_creature_schaden_min = 2;
	a_creature(14).f_creature_schaden_max = 14;
	a_creature(14).f_creature_maxspeed = 5;
	a_creature(15).f_creature_lifepoints = 24;
	a_creature(15).f_creature_attack = 60;
	a_creature(15).f_creature_schaden_min = 2;
	a_creature(15).f_creature_schaden_max = 14;
	a_creature(15).f_creature_maxspeed = 5;
}

static int32_t p_init_highscores() {
	int32_t v_i = 0;
	int32_t v_j = 0;
	for (v_i = 1; v_i <= 30; v_i += 1) {
		a_hscores(v_i).f_version = " ";
		a_hscores(v_i).f_name = " ";
		a_hscores(v_i).f_level = 0;
		a_hscores(v_i).f_gold = 0;
		a_hscores(v_i).f_mks = 0;
		a_hscores(v_i).f_punkte = 0;
		a_hscores(v_i).f_maennchen = 0;
		a_hscores(v_i).f_anfangszeit = " ";
		a_hscores(v_i).f_endezeit = " ";
		a_hscores(v_i).f_maxlifepoints = 0;
		a_hscores(v_i).f_maxmana = 0;
		a_hscores(v_i).f_attack = 0;
		a_hscores(v_i).f_dexterity = 0;
		a_hscores(v_i).f_strength = 0;
		a_hscores(v_i).f_maxspeed = 0;
		a_hscores(v_i).f_perception = 0;
		a_hscores(v_i).f_luck_score = 0;
		a_hscores(v_i).f_power_score = 0;
		a_hscores(v_i).f_circle = 0;
		a_hscores(v_i).f_stabteile = 0;
		a_hscores(v_i).f_moves = 0;
		for (v_j = 1; v_j <= 3; v_j += 1) {
			a_hscores(v_i).f_sterbegrund[v_j] = " ";
		}
		for (v_j = 1; v_j <= 30; v_j += 1) {
			a_hscores(v_i).f_skills[v_j] = 0;
		}
	}
}

static int32_t p_init_pilze() {
	int32_t v_i = 0;
	int32_t v_k = 0;
	int32_t v_nach = 0;
	int32_t v_von = 0;
	struct st_gs v_zw_geg;
	for (v_i = 1; v_i <= 100; v_i += 1) {
		v_von = (65 + p_random(9));
		v_nach = (65 + p_random(9));
		for (v_k = 1; v_k <= 3; v_k += 1) {
			v_zw_geg.f_name[v_k] = a_gegenstand(v_von).f_name[v_k];
		}
		v_zw_geg.f_art = a_gegenstand(v_von).f_art;
		v_zw_geg.f_einkauf = a_gegenstand(v_von).f_einkauf;
		v_zw_geg.f_verkauf = a_gegenstand(v_von).f_verkauf;
		for (v_k = 1; v_k <= 3; v_k += 1) {
			a_gegenstand(v_von).f_name[v_k] = a_gegenstand(v_nach).f_name[v_k];
		}
		a_gegenstand(v_von).f_art = a_gegenstand(v_nach).f_art;
		a_gegenstand(v_von).f_einkauf = a_gegenstand(v_nach).f_einkauf;
		a_gegenstand(v_von).f_verkauf = a_gegenstand(v_nach).f_verkauf;
		for (v_k = 1; v_k <= 3; v_k += 1) {
			a_gegenstand(v_nach).f_name[v_k] = v_zw_geg.f_name[v_k];
		}
		a_gegenstand(v_nach).f_art = v_zw_geg.f_art;
		a_gegenstand(v_nach).f_einkauf = v_zw_geg.f_einkauf;
		a_gegenstand(v_nach).f_verkauf = v_zw_geg.f_verkauf;
	}
}

static int32_t p_init_skills() {
	int32_t v_i = 0;
	if ((g_combi == 0)) {
		for (v_i = 1; v_i <= 141; v_i += 1) {
			a_skills(v_i, g_akt_spieler).f_gewaehlt = 0;
			a_skills(v_i, g_akt_spieler).f_gelocked = 0;
		}
	}
	a_skills(0, g_akt_spieler).f_name[2] = "Weg des Schwertes";
	a_skills(0, g_akt_spieler).f_name[1] = "Way of the Sword";
	a_skills(0, g_akt_spieler).f_name[3] = "Camino de la espada";
	a_skills(0, g_akt_spieler).f_nummer = 0;
	a_skills(0, g_akt_spieler).f_kosten = 0;
	a_skills(0, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(0, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(0, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(0, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(0, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(0, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(1, g_akt_spieler).f_name[2] = "Kampftraining";
	a_skills(1, g_akt_spieler).f_name[1] = "Combat Training";
	a_skills(1, g_akt_spieler).f_name[3] = "Entrenamiento de combate";
	a_skills(1, g_akt_spieler).f_nummer = 1;
	a_skills(1, g_akt_spieler).f_gruppe = 1;
	a_skills(1, g_akt_spieler).f_kosten = 2;
	a_skills(1, g_akt_spieler).f_beschreibung_1[2] = "Angriff: 4";
	a_skills(1, g_akt_spieler).f_beschreibung_1[1] = "Attack: 4";
	a_skills(1, g_akt_spieler).f_beschreibung_1[3] = "Ataque: 4";
	a_skills(1, g_akt_spieler).f_beschreibung_2[2] = "(Angriff = Chance im Kampf zu treffen)";
	a_skills(1, g_akt_spieler).f_beschreibung_2[1] = "(Attack = Chance to hit in combat)";
	a_skills(1, g_akt_spieler).f_beschreibung_2[3] = "(Ataque = Chance de alcanzar en combate)";
	a_skills(2, g_akt_spieler).f_name[2] = "Konstitution";
	a_skills(2, g_akt_spieler).f_name[1] = "Constitution";
	a_skills(2, g_akt_spieler).f_name[3] = "Complexion";
	a_skills(2, g_akt_spieler).f_nummer = 2;
	a_skills(2, g_akt_spieler).f_gruppe = 1;
	a_skills(2, g_akt_spieler).f_kosten = 2;
	a_skills(2, g_akt_spieler).f_beschreibung_1[2] = "15 Lebenspunkten; +4 Lebenspunkte bei Erfahrungsgewinn";
	a_skills(2, g_akt_spieler).f_beschreibung_1[1] = "15 Lifepoints; +4 Lifepoints per experience gain";
	a_skills(2, g_akt_spieler).f_beschreibung_1[3] = "15 Puntos de vida; +4 Puntos de vida al ganar experiencia";
	a_skills(2, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(2, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(2, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(3, g_akt_spieler).f_name[2] = "St\344rke";
	a_skills(3, g_akt_spieler).f_name[1] = "Strength";
	a_skills(3, g_akt_spieler).f_name[3] = "Fuerza";
	a_skills(3, g_akt_spieler).f_nummer = 3;
	a_skills(3, g_akt_spieler).f_gruppe = 1;
	a_skills(3, g_akt_spieler).f_kosten = 2;
	a_skills(3, g_akt_spieler).f_beschreibung_1[2] = "St\344rke: 4";
	a_skills(3, g_akt_spieler).f_beschreibung_1[1] = "Strength: 4";
	a_skills(3, g_akt_spieler).f_beschreibung_1[3] = "Fuerza: 4";
	a_skills(3, g_akt_spieler).f_beschreibung_2[2] = "(Richtet Schaden im Nahkampf an)";
	a_skills(3, g_akt_spieler).f_beschreibung_2[1] = "(Deals damage in closed combat)";
	a_skills(3, g_akt_spieler).f_beschreibung_2[3] = "(Hace dano en combate cerca)";
	a_skills(4, g_akt_spieler).f_name[2] = "Berserker";
	a_skills(4, g_akt_spieler).f_name[1] = "Berserk";
	a_skills(4, g_akt_spieler).f_name[3] = "Berserk";
	a_skills(4, g_akt_spieler).f_nummer = 4;
	a_skills(4, g_akt_spieler).f_gruppe = 1;
	a_skills(4, g_akt_spieler).f_kosten = 2;
	a_skills(4, g_akt_spieler).f_beschreibung_1[2] = "St\344rke z\344hlt im Nahkampf doppelt";
	a_skills(4, g_akt_spieler).f_beschreibung_1[1] = "Strength counts twice in melee combat";
	a_skills(4, g_akt_spieler).f_beschreibung_1[3] = "La fuerza se duplica en cuerpo a cuerpo";
	a_skills(4, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(4, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(4, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(5, g_akt_spieler).f_name[2] = "Gewandtheit";
	a_skills(5, g_akt_spieler).f_name[1] = "Dexterity";
	a_skills(5, g_akt_spieler).f_name[3] = "Destreza";
	a_skills(5, g_akt_spieler).f_nummer = 5;
	a_skills(5, g_akt_spieler).f_gruppe = 1;
	a_skills(5, g_akt_spieler).f_kosten = 2;
	a_skills(5, g_akt_spieler).f_beschreibung_1[2] = "Reflexe: 4";
	a_skills(5, g_akt_spieler).f_beschreibung_1[1] = "Dexterity: 4";
	a_skills(5, g_akt_spieler).f_beschreibung_1[3] = "Destreza: 4";
	a_skills(5, g_akt_spieler).f_beschreibung_2[2] = "(Verhindert Monster Treffer und weicht Fallen aus)";
	a_skills(5, g_akt_spieler).f_beschreibung_2[1] = "(Prevents to get hit from monsters and traps)";
	a_skills(5, g_akt_spieler).f_beschreibung_2[3] = "(Preventa que monstuos y trampas alcanzan)";
	a_skills(6, g_akt_spieler).f_name[2] = "Ausweichen";
	a_skills(6, g_akt_spieler).f_name[1] = "Dodging";
	a_skills(6, g_akt_spieler).f_name[3] = "Evasion";
	a_skills(6, g_akt_spieler).f_nummer = 6;
	a_skills(6, g_akt_spieler).f_gruppe = 1;
	a_skills(6, g_akt_spieler).f_kosten = 2;
	a_skills(6, g_akt_spieler).f_beschreibung_1[2] = "50% aller Monsterattacken verfehlen den Charakter";
	a_skills(6, g_akt_spieler).f_beschreibung_1[1] = "50% of all monster attacks miss the character";
	a_skills(6, g_akt_spieler).f_beschreibung_1[3] = "El 50% de ataques de monstruos fallan";
	a_skills(6, g_akt_spieler).f_beschreibung_2[2] = "(Im Nah- und Fernkampf)";
	a_skills(6, g_akt_spieler).f_beschreibung_2[1] = "(In closed and ranged combat)";
	a_skills(6, g_akt_spieler).f_beschreibung_2[3] = "(An combate cerca y lejos)";
	a_skills(7, g_akt_spieler).f_name[2] = "Kampf in R\374stung";
	a_skills(7, g_akt_spieler).f_name[1] = "Fighting in Armor";
	a_skills(7, g_akt_spieler).f_name[3] = "Lucha en armadura";
	a_skills(7, g_akt_spieler).f_nummer = 7;
	a_skills(7, g_akt_spieler).f_gruppe = 1;
	a_skills(7, g_akt_spieler).f_kosten = 2;
	a_skills(7, g_akt_spieler).f_beschreibung_1[2] = "Keine Behinderung durch R\374stung";
	a_skills(7, g_akt_spieler).f_beschreibung_1[1] = "No Encumbrance through armor";
	a_skills(7, g_akt_spieler).f_beschreibung_1[3] = "No Estorbos con armor";
	a_skills(7, g_akt_spieler).f_beschreibung_2[2] = "(Behinderung wird normalerweise von Angriff abgezogen)";
	a_skills(7, g_akt_spieler).f_beschreibung_2[1] = "(Encumbrance is normally subtracted from Attack)";
	a_skills(7, g_akt_spieler).f_beschreibung_2[3] = "(Encumbrance normalmente desmenuye su ataque)";
	a_skills(8, g_akt_spieler).f_name[2] = "H\344rte";
	a_skills(8, g_akt_spieler).f_name[1] = "Toughness";
	a_skills(8, g_akt_spieler).f_name[3] = "Dureza";
	a_skills(8, g_akt_spieler).f_nummer = 8;
	a_skills(8, g_akt_spieler).f_gruppe = 1;
	a_skills(8, g_akt_spieler).f_kosten = 2;
	a_skills(8, g_akt_spieler).f_beschreibung_1[2] = "Jeglicher Schaden wird um 1 Punkt reduziert";
	a_skills(8, g_akt_spieler).f_beschreibung_1[1] = "All damage is reduced by 1 point";
	a_skills(8, g_akt_spieler).f_beschreibung_1[3] = "Todos los danos se reducen en 1 punto";
	a_skills(8, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(8, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(8, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(9, g_akt_spieler).f_name[2] = "Veteran";
	a_skills(9, g_akt_spieler).f_name[1] = "Veteran";
	a_skills(9, g_akt_spieler).f_name[3] = "Veterano";
	a_skills(9, g_akt_spieler).f_nummer = 9;
	a_skills(9, g_akt_spieler).f_gruppe = 1;
	a_skills(9, g_akt_spieler).f_kosten = 2;
	a_skills(9, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit Schwert, Schild, R\374stung,";
	a_skills(9, g_akt_spieler).f_beschreibung_1[1] = "Starts with sword, shield, armour,";
	a_skills(9, g_akt_spieler).f_beschreibung_1[3] = "Empieza con espada, escudo, armadura,";
	a_skills(9, g_akt_spieler).f_beschreibung_2[2] = "Lederhelm und Lederschuhen";
	a_skills(9, g_akt_spieler).f_beschreibung_2[1] = "Leatherhelmet and Leathershoes";
	a_skills(9, g_akt_spieler).f_beschreibung_2[3] = "casco y zapatos de cuero";
	a_skills(10, g_akt_spieler).f_name[2] = "Duelist";
	a_skills(10, g_akt_spieler).f_name[1] = "Duelist";
	a_skills(10, g_akt_spieler).f_name[3] = "Duelista";
	a_skills(10, g_akt_spieler).f_nummer = 10;
	a_skills(10, g_akt_spieler).f_gruppe = 1;
	a_skills(10, g_akt_spieler).f_kosten = 2;
	a_skills(10, g_akt_spieler).f_beschreibung_1[2] = "Angriffs-Bonus: Reflexe/2 ";
	a_skills(10, g_akt_spieler).f_beschreibung_1[1] = "Attack bonus: Dexterity/2";
	a_skills(10, g_akt_spieler).f_beschreibung_1[3] = "Bonus en ataque: Destreza/2";
	a_skills(10, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(10, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(10, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(11, g_akt_spieler).f_name[2] = "Kampfeswut";
	a_skills(11, g_akt_spieler).f_name[1] = "Battlelust";
	a_skills(11, g_akt_spieler).f_name[3] = "Sed de batalla";
	a_skills(11, g_akt_spieler).f_nummer = 11;
	a_skills(11, g_akt_spieler).f_gruppe = 1;
	a_skills(11, g_akt_spieler).f_kosten = 2;
	a_skills(11, g_akt_spieler).f_beschreibung_1[2] = "Angriffs-Bonus: St\344rke/2";
	a_skills(11, g_akt_spieler).f_beschreibung_1[1] = "Attack bonus: Strength/2";
	a_skills(11, g_akt_spieler).f_beschreibung_1[3] = "Bonus en ataque: Fuerza/2";
	a_skills(11, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(11, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(11, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(12, g_akt_spieler).f_name[2] = "Zweih\344ndiger Kampf";
	a_skills(12, g_akt_spieler).f_name[1] = "Twohanded Fighting";
	a_skills(12, g_akt_spieler).f_name[3] = "Combate con dos armas";
	a_skills(12, g_akt_spieler).f_nummer = 12;
	a_skills(12, g_akt_spieler).f_gruppe = 1;
	a_skills(12, g_akt_spieler).f_kosten = 2;
	a_skills(12, g_akt_spieler).f_beschreibung_1[2] = "Zwei Waffen tragen und Vorteile beider Nutzen";
	a_skills(12, g_akt_spieler).f_beschreibung_1[1] = "Wear two weapons and use both advantages";
	a_skills(12, g_akt_spieler).f_beschreibung_1[3] = "Lleva dos armas y utiliza ambas aventajas";
	a_skills(12, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(12, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(12, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(13, g_akt_spieler).f_name[2] = "J\344ger";
	a_skills(13, g_akt_spieler).f_name[1] = "Hunter";
	a_skills(13, g_akt_spieler).f_name[3] = "Cazador";
	a_skills(13, g_akt_spieler).f_nummer = 13;
	a_skills(13, g_akt_spieler).f_gruppe = 1;
	a_skills(13, g_akt_spieler).f_kosten = 2;
	a_skills(13, g_akt_spieler).f_beschreibung_1[2] = "+3 Angriff und Schaden gegen Tiere. ";
	a_skills(13, g_akt_spieler).f_beschreibung_1[1] = "+3 Attack and Damage against animals.";
	a_skills(13, g_akt_spieler).f_beschreibung_1[3] = "+3 ataque y dano contra animales.";
	a_skills(13, g_akt_spieler).f_beschreibung_2[2] = "Diese lassen mit 50% Nahrung oder Gold zur\374ck";
	a_skills(13, g_akt_spieler).f_beschreibung_2[1] = "With 50% they leave food or gold behind";
	a_skills(13, g_akt_spieler).f_beschreibung_2[3] = "Ellos dejan carne o oro con 50%";
	a_skills(14, g_akt_spieler).f_name[2] = "Paladin";
	a_skills(14, g_akt_spieler).f_name[1] = "Paladin";
	a_skills(14, g_akt_spieler).f_name[3] = "Paladin";
	a_skills(14, g_akt_spieler).f_nummer = 14;
	a_skills(14, g_akt_spieler).f_gruppe = 1;
	a_skills(14, g_akt_spieler).f_kosten = 2;
	a_skills(14, g_akt_spieler).f_beschreibung_1[2] = "+3 Angriff und Schaden gegen Untote.";
	a_skills(14, g_akt_spieler).f_beschreibung_1[1] = "+3 Attack and Damage against undead.";
	a_skills(14, g_akt_spieler).f_beschreibung_1[3] = "+3 ataque y dano contra nomuertos.";
	a_skills(14, g_akt_spieler).f_beschreibung_2[2] = "Diese lassen mit 50% Gold zur\374ck";
	a_skills(14, g_akt_spieler).f_beschreibung_2[1] = "With 50% they leave gold behind";
	a_skills(14, g_akt_spieler).f_beschreibung_2[3] = "Ellos dejan oro con 50%";
	a_skills(15, g_akt_spieler).f_name[2] = "Kopfgeldj\344ger";
	a_skills(15, g_akt_spieler).f_name[1] = "Headhunter";
	a_skills(15, g_akt_spieler).f_name[3] = "Cazador de Cabezas";
	a_skills(15, g_akt_spieler).f_nummer = 15;
	a_skills(15, g_akt_spieler).f_gruppe = 1;
	a_skills(15, g_akt_spieler).f_kosten = 2;
	a_skills(15, g_akt_spieler).f_beschreibung_1[2] = "+3 Angriff und Schaden gegen Humanoide.";
	a_skills(15, g_akt_spieler).f_beschreibung_1[1] = "+3 Attack and Damage against Humanoids.";
	a_skills(15, g_akt_spieler).f_beschreibung_1[3] = "+3 ataque y dano contra humanoides.";
	a_skills(15, g_akt_spieler).f_beschreibung_2[2] = "Diese lassen mit 50% Gold zur\374ck";
	a_skills(15, g_akt_spieler).f_beschreibung_2[1] = "With 50% they leave gold behind";
	a_skills(15, g_akt_spieler).f_beschreibung_2[3] = "Ellos dejan oro con 50%";
	a_skills(16, g_akt_spieler).f_name[2] = "Geisterj\344ger";
	a_skills(16, g_akt_spieler).f_name[1] = "Ghosthunter";
	a_skills(16, g_akt_spieler).f_name[3] = "Cazador de Fantasmas";
	a_skills(16, g_akt_spieler).f_nummer = 16;
	a_skills(16, g_akt_spieler).f_gruppe = 1;
	a_skills(16, g_akt_spieler).f_kosten = 2;
	a_skills(16, g_akt_spieler).f_beschreibung_1[2] = "+5 Angriff und Schaden gegen Geister.";
	a_skills(16, g_akt_spieler).f_beschreibung_1[1] = "+5 Attack and Damage against Ghosts.";
	a_skills(16, g_akt_spieler).f_beschreibung_1[3] = "+5 ataque y dano contra fantasmas.";
	a_skills(16, g_akt_spieler).f_beschreibung_2[2] = "(Und diese sind mit normalen Waffen angreifbar)";
	a_skills(16, g_akt_spieler).f_beschreibung_2[1] = "(And attack them with normal weapons)";
	a_skills(16, g_akt_spieler).f_beschreibung_2[3] = "(Y atacarlos con armas normales)";
	a_skills(17, g_akt_spieler).f_name[2] = "Blutrausch";
	a_skills(17, g_akt_spieler).f_name[1] = "Bloodlust";
	a_skills(17, g_akt_spieler).f_name[3] = "Sed de Sangre";
	a_skills(17, g_akt_spieler).f_nummer = 17;
	a_skills(17, g_akt_spieler).f_gruppe = 1;
	a_skills(17, g_akt_spieler).f_kosten = 2;
	a_skills(17, g_akt_spieler).f_beschreibung_1[2] = "Grad deiner Verwundung erh\366ht deinen Schaden.";
	a_skills(17, g_akt_spieler).f_beschreibung_1[1] = "The more you are hurt the more damage you do.";
	a_skills(17, g_akt_spieler).f_beschreibung_1[3] = "Nivel de tu herida aumenta su dano.";
	a_skills(17, g_akt_spieler).f_beschreibung_2[2] = "(LP/2 -> Schaden*2, LP/3 -> Schaden*3, LP/5 -> Schaden*5)";
	a_skills(17, g_akt_spieler).f_beschreibung_2[1] = "(LP/2 -> Damage*2, LP/3 -> Damage*3, LP/5 -> Damage*5)";
	a_skills(17, g_akt_spieler).f_beschreibung_2[3] = "(PdV/2 -> Dano*2, PdV/3 -> Dano*3, PdV/5 -> Dano*5)";
	a_skills(18, g_akt_spieler).f_name[2] = "Rundschlag";
	a_skills(18, g_akt_spieler).f_name[1] = "Roundattack";
	a_skills(18, g_akt_spieler).f_name[3] = "Ataque alrededor";
	a_skills(18, g_akt_spieler).f_nummer = 18;
	a_skills(18, g_akt_spieler).f_gruppe = 1;
	a_skills(18, g_akt_spieler).f_kosten = 2;
	a_skills(18, g_akt_spieler).f_beschreibung_1[2] = "Du greifst alle Monster um dich an";
	a_skills(18, g_akt_spieler).f_beschreibung_1[1] = "You attack all monsters that surround you";
	a_skills(18, g_akt_spieler).f_beschreibung_1[3] = "Ataquas todos los monstros a su alrededor";
	a_skills(18, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(18, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(18, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(19, g_akt_spieler).f_name[2] = "Sturmangriff";
	a_skills(19, g_akt_spieler).f_name[1] = "Charge Attack";
	a_skills(19, g_akt_spieler).f_name[3] = "Ataque Continuo";
	a_skills(19, g_akt_spieler).f_nummer = 19;
	a_skills(19, g_akt_spieler).f_gruppe = 1;
	a_skills(19, g_akt_spieler).f_kosten = 2;
	a_skills(19, g_akt_spieler).f_beschreibung_1[2] = "Angriffe auf Monster kosten nur einen Bewegungspunkt";
	a_skills(19, g_akt_spieler).f_beschreibung_1[1] = "Attacking a monster costs a movement point";
	a_skills(19, g_akt_spieler).f_beschreibung_1[3] = "Atacar a un monstro cuesta un punto movimiento";
	a_skills(19, g_akt_spieler).f_beschreibung_2[2] = "statt den Zug";
	a_skills(19, g_akt_spieler).f_beschreibung_2[1] = "instead of ending the turn";
	a_skills(19, g_akt_spieler).f_beschreibung_2[3] = "y no termina su turno";
	a_skills(20, g_akt_spieler).f_name[2] = "Flinke Attacke";
	a_skills(20, g_akt_spieler).f_name[1] = "Fast Attack";
	a_skills(20, g_akt_spieler).f_name[3] = "Ataque Rapido";
	a_skills(20, g_akt_spieler).f_nummer = 20;
	a_skills(20, g_akt_spieler).f_gruppe = 1;
	a_skills(20, g_akt_spieler).f_kosten = 2;
	a_skills(20, g_akt_spieler).f_beschreibung_1[2] = "Zwei Angriffe pro Runde";
	a_skills(20, g_akt_spieler).f_beschreibung_1[1] = "Two attacks per turn";
	a_skills(20, g_akt_spieler).f_beschreibung_1[3] = "Dos ataques por turno";
	a_skills(20, g_akt_spieler).f_beschreibung_2[2] = "(Kombiniert sich mit 2h Kampf + Sturmangriff)";
	a_skills(20, g_akt_spieler).f_beschreibung_2[1] = "(Works together with 2h Fighting and Charge attack)";
	a_skills(20, g_akt_spieler).f_beschreibung_2[3] = "(Funciona con 2 Armas y Ataque continuo)";
	a_skills(21, g_akt_spieler).f_name[2] = "Schwertkampf";
	a_skills(21, g_akt_spieler).f_name[1] = "Swordfighting";
	a_skills(21, g_akt_spieler).f_name[3] = "Luchar con Espadas";
	a_skills(21, g_akt_spieler).f_nummer = 21;
	a_skills(21, g_akt_spieler).f_gruppe = 1;
	a_skills(21, g_akt_spieler).f_kosten = 2;
	a_skills(21, g_akt_spieler).f_beschreibung_1[2] = "+2 Angriff und Schaden mit Schwertern. Beginnt mit Schwert";
	a_skills(21, g_akt_spieler).f_beschreibung_1[1] = "+2 Attack and Damage with Swords. Begins with Sword";
	a_skills(21, g_akt_spieler).f_beschreibung_1[3] = "+2 Ataque y Dano con Espadas. Empieza con Espada";
	a_skills(21, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(21, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(21, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(22, g_akt_spieler).f_name[2] = "Axtkampf";
	a_skills(22, g_akt_spieler).f_name[1] = "Axefighting";
	a_skills(22, g_akt_spieler).f_name[3] = "Luchar con Hachas";
	a_skills(22, g_akt_spieler).f_nummer = 22;
	a_skills(22, g_akt_spieler).f_gruppe = 1;
	a_skills(22, g_akt_spieler).f_kosten = 2;
	a_skills(22, g_akt_spieler).f_beschreibung_1[2] = "+2 Angriff und Schaden mit \304xten. Beginnt mit Axt";
	a_skills(22, g_akt_spieler).f_beschreibung_1[1] = "+2 Attack and Damage with Axes. Begins with Axe";
	a_skills(22, g_akt_spieler).f_beschreibung_1[3] = "+2 Ataque y Dano con Hachas. Empieza con Hacha";
	a_skills(22, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(22, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(22, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(23, g_akt_spieler).f_name[2] = "Speerkampf";
	a_skills(23, g_akt_spieler).f_name[1] = "Spearfighting";
	a_skills(23, g_akt_spieler).f_name[3] = "Luchar con Lanzas";
	a_skills(23, g_akt_spieler).f_nummer = 23;
	a_skills(23, g_akt_spieler).f_gruppe = 1;
	a_skills(23, g_akt_spieler).f_kosten = 2;
	a_skills(23, g_akt_spieler).f_beschreibung_1[2] = "+2 Angriff und Schaden mit Speeren. Beginnt mit Speer";
	a_skills(23, g_akt_spieler).f_beschreibung_1[1] = "+2 Attack and Damage with Spears. Begins with Spear";
	a_skills(23, g_akt_spieler).f_beschreibung_1[3] = "+2 Ataque y Dano con Lanzas. Empieza con Lanza";
	a_skills(23, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(23, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(23, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(24, g_akt_spieler).f_name[2] = "Hammerkampf";
	a_skills(24, g_akt_spieler).f_name[1] = "Hammerfighting";
	a_skills(24, g_akt_spieler).f_name[3] = "Luchar con Martillos";
	a_skills(24, g_akt_spieler).f_nummer = 24;
	a_skills(24, g_akt_spieler).f_gruppe = 1;
	a_skills(24, g_akt_spieler).f_kosten = 2;
	a_skills(24, g_akt_spieler).f_beschreibung_1[2] = "+2 Angriff und Schaden mit H\344mmern. Beginnt mit Hammer";
	a_skills(24, g_akt_spieler).f_beschreibung_1[1] = "+2 Attack and Damage with Hammers. Begins with Hammer";
	a_skills(24, g_akt_spieler).f_beschreibung_1[3] = "+2 Ataque y Dano con Martillos. Empieza con Martillo";
	a_skills(24, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(24, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(24, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(25, g_akt_spieler).f_name[2] = "Waffenloser Kampf";
	a_skills(25, g_akt_spieler).f_name[1] = "Unarmed Combat";
	a_skills(25, g_akt_spieler).f_name[3] = "Luchar sin Armas";
	a_skills(25, g_akt_spieler).f_nummer = 25;
	a_skills(25, g_akt_spieler).f_gruppe = 1;
	a_skills(25, g_akt_spieler).f_kosten = 2;
	a_skills(25, g_akt_spieler).f_beschreibung_1[2] = "+3 Angriff und Schaden ohne Waffe";
	a_skills(25, g_akt_spieler).f_beschreibung_1[1] = "+3 Attack and Damage without Weapon";
	a_skills(25, g_akt_spieler).f_beschreibung_1[3] = "+3 Ataque y Dano sin Arma";
	a_skills(25, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(25, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(25, g_akt_spieler).f_beschreibung_2[3] = "+";
	a_skills(26, g_akt_spieler).f_name[2] = "Anf\374hrer";
	a_skills(26, g_akt_spieler).f_name[1] = "Leader";
	a_skills(26, g_akt_spieler).f_name[3] = "Comandante";
	a_skills(26, g_akt_spieler).f_nummer = 26;
	a_skills(26, g_akt_spieler).f_gruppe = 1;
	a_skills(26, g_akt_spieler).f_kosten = 2;
	a_skills(26, g_akt_spieler).f_beschreibung_1[2] = "Alle Spieler erhalten +2 Angriff";
	a_skills(26, g_akt_spieler).f_beschreibung_1[1] = "All Players get +2 Attack";
	a_skills(26, g_akt_spieler).f_beschreibung_1[3] = "Todos Jugadores reciben Ataque +2";
	a_skills(26, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(26, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(26, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(27, g_akt_spieler).f_name[2] = "S\366ldner";
	a_skills(27, g_akt_spieler).f_name[1] = "Mercenary";
	a_skills(27, g_akt_spieler).f_name[3] = "Mercenario";
	a_skills(27, g_akt_spieler).f_nummer = 27;
	a_skills(27, g_akt_spieler).f_gruppe = 1;
	a_skills(27, g_akt_spieler).f_kosten = 2;
	a_skills(27, g_akt_spieler).f_beschreibung_1[2] = "Jeder Level gibt dir Ebene*5 Gold";
	a_skills(27, g_akt_spieler).f_beschreibung_1[1] = "Every Level gives you Level*5 Gold";
	a_skills(27, g_akt_spieler).f_beschreibung_1[3] = "Cada Nivel te da Nival*5 Oro";
	a_skills(27, g_akt_spieler).f_beschreibung_2[2] = "Jedes erchlagene Monster Level Gold (max. 5)";
	a_skills(27, g_akt_spieler).f_beschreibung_2[1] = "Every killed monster Level Gold (max. 5)";
	a_skills(27, g_akt_spieler).f_beschreibung_2[3] = "Cada monstruo que matas Nivel Oro (max. 5)";
	a_skills(28, g_akt_spieler).f_name[2] = "Kampftechniken";
	a_skills(28, g_akt_spieler).f_name[1] = "Fighting Styles";
	a_skills(28, g_akt_spieler).f_name[3] = "Estilos de combate";
	a_skills(28, g_akt_spieler).f_nummer = 28;
	a_skills(28, g_akt_spieler).f_gruppe = 1;
	a_skills(28, g_akt_spieler).f_kosten = 2;
	a_skills(28, g_akt_spieler).f_beschreibung_1[2] = "Du beherrscht verschiedene Kampftechniken";
	a_skills(28, g_akt_spieler).f_beschreibung_1[1] = "You mastered several different fightingstyles";
	a_skills(28, g_akt_spieler).f_beschreibung_1[3] = "Sabes algunos estilos del combate";
	a_skills(28, g_akt_spieler).f_beschreibung_2[2] = "(Siehe FAQ f\374r Beschreibung)";
	a_skills(28, g_akt_spieler).f_beschreibung_2[1] = "(See FAQ for Details)";
	a_skills(28, g_akt_spieler).f_beschreibung_2[3] = "(El FAQ contiene Detalles)";
	a_skills(29, g_akt_spieler).f_name[1] = "Way of the Bow";
	a_skills(29, g_akt_spieler).f_name[2] = "Weg des Bogens";
	a_skills(29, g_akt_spieler).f_name[3] = "Camino del Arco";
	a_skills(29, g_akt_spieler).f_nummer = 0;
	a_skills(29, g_akt_spieler).f_kosten = 0;
	a_skills(29, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(29, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(29, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(29, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(29, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(29, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(30, g_akt_spieler).f_name[2] = "Bogenschiessen";
	a_skills(30, g_akt_spieler).f_name[1] = "Archery";
	a_skills(30, g_akt_spieler).f_name[3] = "Arqueria";
	a_skills(30, g_akt_spieler).f_nummer = 30;
	a_skills(30, g_akt_spieler).f_gruppe = 2;
	a_skills(30, g_akt_spieler).f_kosten = 2;
	a_skills(30, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit Bogen und Pfeilen; +50% Trefferchance";
	a_skills(30, g_akt_spieler).f_beschreibung_1[1] = "Starts with bow and arrows; +50% success chance";
	a_skills(30, g_akt_spieler).f_beschreibung_1[3] = "Empieza con arco y flechas; +50% de acierto";
	a_skills(30, g_akt_spieler).f_beschreibung_2[2] = "(Du bekommst 10 neue Pfeile jeden Level)";
	a_skills(30, g_akt_spieler).f_beschreibung_2[1] = "(You get 10 new Arrows every level)";
	a_skills(30, g_akt_spieler).f_beschreibung_2[3] = "(Recibes 10 nuevas flechas cada nivel)";
	a_skills(31, g_akt_spieler).f_name[2] = "Zen Bogenschiessen";
	a_skills(31, g_akt_spieler).f_name[1] = "Zen Bowmastery";
	a_skills(31, g_akt_spieler).f_name[3] = "Zen Arcomaestro";
	a_skills(31, g_akt_spieler).f_nummer = 31;
	a_skills(31, g_akt_spieler).f_gruppe = 2;
	a_skills(31, g_akt_spieler).f_kosten = 2;
	a_skills(31, g_akt_spieler).f_beschreibung_1[2] = "Wenn ein Monster deinen ersten Pfeil \374berlebt schiesst du";
	a_skills(31, g_akt_spieler).f_beschreibung_1[1] = "If a monster still lives after your first shot you shoot";
	a_skills(31, g_akt_spieler).f_beschreibung_1[3] = "Si un montruo sobrevive su primera fleche ataquas otra vez.";
	a_skills(31, g_akt_spieler).f_beschreibung_2[2] = "gleich nochmal. Das zweitemal kostet keinen Pfeil";
	a_skills(31, g_akt_spieler).f_beschreibung_2[1] = "another arrow. The second one does not cost an arrow";
	a_skills(31, g_akt_spieler).f_beschreibung_2[3] = "La segunda vez no cuesta flecha";
	a_skills(32, g_akt_spieler).f_name[2] = "Pfeilmacher";
	a_skills(32, g_akt_spieler).f_name[1] = "Flechery";
	a_skills(32, g_akt_spieler).f_name[3] = "Flecheria";
	a_skills(32, g_akt_spieler).f_nummer = 32;
	a_skills(32, g_akt_spieler).f_gruppe = 2;
	a_skills(32, g_akt_spieler).f_kosten = 2;
	a_skills(32, g_akt_spieler).f_beschreibung_1[2] = "Jede Ebene bekommst du einen Pack Spezialpfeile";
	a_skills(32, g_akt_spieler).f_beschreibung_1[1] = "Every level you get one pack of special arrows";
	a_skills(32, g_akt_spieler).f_beschreibung_1[3] = "Cada nivel te da un paar de flechas magicas";
	a_skills(32, g_akt_spieler).f_beschreibung_2[2] = "Beginnt mit Naga, Oger und Explodierenden Pfeilen";
	a_skills(32, g_akt_spieler).f_beschreibung_2[1] = "Starts the game with Naga, Oger and exploding arrows";
	a_skills(32, g_akt_spieler).f_beschreibung_2[3] = "Empiece el juego con naga, ogre y alcazan flechas";
	a_skills(33, g_akt_spieler).f_name[2] = "Scharfschutze";
	a_skills(33, g_akt_spieler).f_name[1] = "Sharpshooter";
	a_skills(33, g_akt_spieler).f_name[3] = "Franco Tirador";
	a_skills(33, g_akt_spieler).f_nummer = 33;
	a_skills(33, g_akt_spieler).f_gruppe = 2;
	a_skills(33, g_akt_spieler).f_kosten = 2;
	a_skills(33, g_akt_spieler).f_beschreibung_1[2] = "Doppelte Chance f\374r kritischen Treffer im Fernkampf. Max 45%";
	a_skills(33, g_akt_spieler).f_beschreibung_1[1] = "Percentage for critical hits in ranged combat doubled. Max 45%";
	a_skills(33, g_akt_spieler).f_beschreibung_1[3] = "Porcentage de golpe critico duplicado con armas de distancia. Max 45%";
	a_skills(33, g_akt_spieler).f_beschreibung_2[2] = "(Chance=(Geschicklichkeit+Gl\374ck)*2% + Waffe)";
	a_skills(33, g_akt_spieler).f_beschreibung_2[1] = "(Chance=(Dexterity+Luck)*2% + Weapon)";
	a_skills(33, g_akt_spieler).f_beschreibung_2[3] = "(Chance=(Destreza+Suerte)*2% + Arma)";
	a_skills(34, g_akt_spieler).f_name[1] = "Way of Magic";
	a_skills(34, g_akt_spieler).f_name[2] = "Weg der Magie";
	a_skills(34, g_akt_spieler).f_name[3] = "Camino de la Magia";
	a_skills(34, g_akt_spieler).f_nummer = 0;
	a_skills(34, g_akt_spieler).f_kosten = 0;
	a_skills(34, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(34, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(34, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(34, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(34, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(34, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(35, g_akt_spieler).f_name[2] = "Arkane Gabe";
	a_skills(35, g_akt_spieler).f_name[1] = "Arcane Power";
	a_skills(35, g_akt_spieler).f_name[3] = "Poder Secreto";
	a_skills(35, g_akt_spieler).f_nummer = 35;
	a_skills(35, g_akt_spieler).f_gruppe = 3;
	a_skills(35, g_akt_spieler).f_kosten = 3;
	a_skills(35, g_akt_spieler).f_beschreibung_1[2] = "Der Level des Zaubers z\344hlt als Bonus auf die Zaubermacht";
	a_skills(35, g_akt_spieler).f_beschreibung_1[1] = "The level of a spell counts as bonus to the spell power";
	a_skills(35, g_akt_spieler).f_beschreibung_1[3] = "El nivel de un hechizo bonifica el poder de hechizo";
	a_skills(35, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(35, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(35, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(36, g_akt_spieler).f_name[2] = "Ley Kontakt";
	a_skills(36, g_akt_spieler).f_name[1] = "Leylines Contact";
	a_skills(36, g_akt_spieler).f_name[3] = "Contacto sobrenatural";
	a_skills(36, g_akt_spieler).f_nummer = 36;
	a_skills(36, g_akt_spieler).f_gruppe = 3;
	a_skills(36, g_akt_spieler).f_kosten = 2;
	a_skills(36, g_akt_spieler).f_beschreibung_1[2] = "Beim Betreten einer neuen Ebene wird dein Mana regeneriert";
	a_skills(36, g_akt_spieler).f_beschreibung_1[1] = "Upon entering a new level all mana is restored";
	a_skills(36, g_akt_spieler).f_beschreibung_1[3] = "Cuando se empieza un nivel el mana se restaura";
	a_skills(36, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(36, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(36, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(37, g_akt_spieler).f_name[2] = "Magielehre";
	a_skills(37, g_akt_spieler).f_name[1] = "Magic Training";
	a_skills(37, g_akt_spieler).f_name[3] = "Entrenamiento magico";
	a_skills(37, g_akt_spieler).f_nummer = 37;
	a_skills(37, g_akt_spieler).f_gruppe = 3;
	a_skills(37, g_akt_spieler).f_kosten = 2;
	a_skills(37, g_akt_spieler).f_beschreibung_1[2] = "Zirkel: 3";
	a_skills(37, g_akt_spieler).f_beschreibung_1[1] = "Spell Circle: 3";
	a_skills(37, g_akt_spieler).f_beschreibung_1[3] = "Circulo magico: 3";
	a_skills(37, g_akt_spieler).f_beschreibung_2[2] = "(Du bist ein ausgebildeter Magier)";
	a_skills(37, g_akt_spieler).f_beschreibung_2[1] = "(You are a trained magician)";
	a_skills(37, g_akt_spieler).f_beschreibung_2[3] = "(Eres un mago entrenado)";
	a_skills(38, g_akt_spieler).f_name[2] = "Zaubermacht";
	a_skills(38, g_akt_spieler).f_name[1] = "Spell Power";
	a_skills(38, g_akt_spieler).f_name[3] = "Poder de hechizos";
	a_skills(38, g_akt_spieler).f_nummer = 38;
	a_skills(38, g_akt_spieler).f_gruppe = 3;
	a_skills(38, g_akt_spieler).f_kosten = 2;
	a_skills(38, g_akt_spieler).f_beschreibung_1[2] = "Zaubermacht: 4";
	a_skills(38, g_akt_spieler).f_beschreibung_1[1] = "Spell Power: 4";
	a_skills(38, g_akt_spieler).f_beschreibung_1[3] = "Poder de hechizo: 4";
	a_skills(38, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(38, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(38, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(39, g_akt_spieler).f_name[2] = "Mana";
	a_skills(39, g_akt_spieler).f_name[1] = "Mana";
	a_skills(39, g_akt_spieler).f_name[3] = "Mana";
	a_skills(39, g_akt_spieler).f_nummer = 39;
	a_skills(39, g_akt_spieler).f_gruppe = 3;
	a_skills(39, g_akt_spieler).f_kosten = 2;
	a_skills(39, g_akt_spieler).f_beschreibung_1[2] = "Mana: 12; +4 Mana bei Erfahrungsgewinn";
	a_skills(39, g_akt_spieler).f_beschreibung_1[1] = "Mana: 12; +4 Mana per experience gain";
	a_skills(39, g_akt_spieler).f_beschreibung_1[3] = "Mana: 12; +4 Mana por gano de experiencia";
	a_skills(39, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(39, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(39, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(40, g_akt_spieler).f_name[2] = "Zauberkunst";
	a_skills(40, g_akt_spieler).f_name[1] = "Sorcery";
	a_skills(40, g_akt_spieler).f_name[3] = "Hechizeria";
	a_skills(40, g_akt_spieler).f_nummer = 40;
	a_skills(40, g_akt_spieler).f_gruppe = 3;
	a_skills(40, g_akt_spieler).f_kosten = 2;
	a_skills(40, g_akt_spieler).f_beschreibung_1[2] = "Die Erfolgschance bei allen Zaubern aus Zauberschulen betr\344gt 99%";
	a_skills(40, g_akt_spieler).f_beschreibung_1[1] = "The casting success for all spells from spellschools is raised to 99%";
	a_skills(40, g_akt_spieler).f_beschreibung_1[3] = "La probabilidad de acierto para hechizos de las escuelas es del 99%";
	a_skills(40, g_akt_spieler).f_beschreibung_2[2] = "(Normalerweise betr\344gt sie 50% und erh\366ht sich um 5% bei erfolgreicher Anwendung)";
	a_skills(40, g_akt_spieler).f_beschreibung_2[1] = "(Normally is 50% and increases by 5% per sucessfull casting)";
	a_skills(40, g_akt_spieler).f_beschreibung_2[3] = "(Normalmente es 50% y aumenta de 5% per hechizar exitoso)";
	a_skills(41, g_akt_spieler).f_name[2] = "Alte Magie";
	a_skills(41, g_akt_spieler).f_name[1] = "Elder Magic";
	a_skills(41, g_akt_spieler).f_name[3] = "Magia antigua";
	a_skills(41, g_akt_spieler).f_nummer = 41;
	a_skills(41, g_akt_spieler).f_gruppe = 3;
	a_skills(41, g_akt_spieler).f_kosten = 4;
	a_skills(41, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber kosten einen Manapunkt weniger (min.1)";
	a_skills(41, g_akt_spieler).f_beschreibung_1[1] = "All spells cost 1 point mana less (min.1)";
	a_skills(41, g_akt_spieler).f_beschreibung_1[3] = "Los hechizos cuestan 1 punto menos de manq (min.1)";
	a_skills(41, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(41, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(41, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(42, g_akt_spieler).f_name[2] = "Magieresistenz";
	a_skills(42, g_akt_spieler).f_name[1] = "Magic Resistance";
	a_skills(42, g_akt_spieler).f_name[3] = "Resistencia a la magia";
	a_skills(42, g_akt_spieler).f_nummer = 42;
	a_skills(42, g_akt_spieler).f_gruppe = 3;
	a_skills(42, g_akt_spieler).f_kosten = 2;
	a_skills(42, g_akt_spieler).f_beschreibung_1[2] = "Mit 70% Resistenz gegen feindliche Magie";
	a_skills(42, g_akt_spieler).f_beschreibung_1[1] = "With 70% Resistance against hostile magic";
	a_skills(42, g_akt_spieler).f_beschreibung_1[3] = "Con 70% Resistencia ante magia hostil";
	a_skills(42, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(42, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(42, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(43, g_akt_spieler).f_name[2] = "Alchemie";
	a_skills(43, g_akt_spieler).f_name[1] = "Alchemy";
	a_skills(43, g_akt_spieler).f_name[3] = "Alquimia";
	a_skills(43, g_akt_spieler).f_nummer = 43;
	a_skills(43, g_akt_spieler).f_gruppe = 3;
	a_skills(43, g_akt_spieler).f_kosten = 2;
	a_skills(43, g_akt_spieler).f_beschreibung_1[2] = "Zaubertr\344nke aus Pilzen brauen und Tr\344nke mischen";
	a_skills(43, g_akt_spieler).f_beschreibung_1[1] = "Create Potions from Mushrooms and mix potions";
	a_skills(43, g_akt_spieler).f_beschreibung_1[3] = "Crear Pociones de Hongos y mezclar pociones";
	a_skills(43, g_akt_spieler).f_beschreibung_2[2] = "(Startet mit 5 Pilzen)";
	a_skills(43, g_akt_spieler).f_beschreibung_2[1] = "(Starts with 5 Mushrooms)";
	a_skills(43, g_akt_spieler).f_beschreibung_2[3] = "(Empiece con 5 Hongos)";
	a_skills(44, g_akt_spieler).f_name[2] = "Thaumaturgie";
	a_skills(44, g_akt_spieler).f_name[1] = "Thaumaturgy";
	a_skills(44, g_akt_spieler).f_name[3] = "Taumaturgia";
	a_skills(44, g_akt_spieler).f_nummer = 44;
	a_skills(44, g_akt_spieler).f_gruppe = 3;
	a_skills(44, g_akt_spieler).f_kosten = 2;
	a_skills(44, g_akt_spieler).f_beschreibung_1[2] = "Erlaubt die Herstellung von Zauberst\344ben aus Edelsteinen";
	a_skills(44, g_akt_spieler).f_beschreibung_1[1] = "Allows the creation of spell wands from gems";
	a_skills(44, g_akt_spieler).f_beschreibung_1[3] = "Permite crear varitas magicas con gemas";
	a_skills(44, g_akt_spieler).f_beschreibung_2[2] = "(Startet mit 5 Edelsteinen)";
	a_skills(44, g_akt_spieler).f_beschreibung_2[1] = "(Starts with 5 Diamonds)";
	a_skills(44, g_akt_spieler).f_beschreibung_2[3] = "(Empiece con 5 piedras preciosas)";
	a_skills(45, g_akt_spieler).f_name[2] = "Zaubern in R\374stung";
	a_skills(45, g_akt_spieler).f_name[1] = "Casting in Armor";
	a_skills(45, g_akt_spieler).f_name[3] = "Hechizar en armadura";
	a_skills(45, g_akt_spieler).f_nummer = 45;
	a_skills(45, g_akt_spieler).f_gruppe = 3;
	a_skills(45, g_akt_spieler).f_kosten = 2;
	a_skills(45, g_akt_spieler).f_beschreibung_1[2] = "Kein Abzug beim Zaubern durch R\374stungen";
	a_skills(45, g_akt_spieler).f_beschreibung_1[1] = "No reduction to spellcasting ability when wearing armor";
	a_skills(45, g_akt_spieler).f_beschreibung_1[3] = "No se reduce la habilidad de hechizo al llevar armadura";
	a_skills(45, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(45, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(45, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(97, g_akt_spieler).f_name[2] = "Elfenblut";
	a_skills(97, g_akt_spieler).f_name[1] = "Elf Blood";
	a_skills(97, g_akt_spieler).f_name[3] = "Sangre elfica";
	a_skills(97, g_akt_spieler).f_nummer = 97;
	a_skills(97, g_akt_spieler).f_gruppe = 3;
	a_skills(97, g_akt_spieler).f_kosten = 2;
	a_skills(97, g_akt_spieler).f_beschreibung_1[2] = "Alle deine Attribute sind um eins besser";
	a_skills(97, g_akt_spieler).f_beschreibung_1[1] = "All your attributes are one point better";
	a_skills(97, g_akt_spieler).f_beschreibung_1[3] = "Todos sus attributos aumentan de un punto";
	a_skills(97, g_akt_spieler).f_beschreibung_2[2] = "ang, st\344, ges, wah, gl\374ck, zmacht";
	a_skills(97, g_akt_spieler).f_beschreibung_2[1] = "att, str, dex, per, luck, spower";
	a_skills(97, g_akt_spieler).f_beschreibung_2[3] = "ata, fue, des, per, sue, pod";
	a_skills(46, g_akt_spieler).f_name[2] = "Blutmagie";
	a_skills(46, g_akt_spieler).f_name[1] = "Blood Magic";
	a_skills(46, g_akt_spieler).f_name[3] = "Magia sangrienta";
	a_skills(46, g_akt_spieler).f_nummer = 46;
	a_skills(46, g_akt_spieler).f_gruppe = 3;
	a_skills(46, g_akt_spieler).f_kosten = 2;
	a_skills(46, g_akt_spieler).f_beschreibung_1[2] = "Grad deiner Verwundung erh\366ht deine Zauberkraft";
	a_skills(46, g_akt_spieler).f_beschreibung_1[1] = "The more you are hurt the more spellpower you have.";
	a_skills(46, g_akt_spieler).f_beschreibung_1[3] = "Nivel de tu herida aumenta su poder de hechizos.";
	a_skills(46, g_akt_spieler).f_beschreibung_2[2] = "(LP/2 -> Zauberkraft*2, LP/3 -> Zauberkraft*3, LP/5 -> Zauberkraft*5)";
	a_skills(46, g_akt_spieler).f_beschreibung_2[1] = "(LP/2 -> Spellpower*2, LP/3 -> Spellpower*3, LP/5 -> Spellpower*5)";
	a_skills(46, g_akt_spieler).f_beschreibung_2[3] = "(PdV/2 -> Poder*2, PdV/3 -> Poder*3, PdV/5 -> Poder*5)";
	a_skills(47, g_akt_spieler).f_name[2] = "Zauberschrift";
	a_skills(47, g_akt_spieler).f_name[1] = "Arcane Writings";
	a_skills(47, g_akt_spieler).f_name[3] = "Escritos secretas";
	a_skills(47, g_akt_spieler).f_nummer = 47;
	a_skills(47, g_akt_spieler).f_gruppe = 3;
	a_skills(47, g_akt_spieler).f_kosten = 2;
	a_skills(47, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit dem Libram der tausend Zauber und 5 Schriftrollen";
	a_skills(47, g_akt_spieler).f_beschreibung_1[1] = "Starts the game with the Libram of Thousand Spells and 5 magic scrolls";
	a_skills(47, g_akt_spieler).f_beschreibung_1[3] = "Empieza el juego con el Codice de los Mil Hechizos y 5 pergaminos magicos";
	a_skills(47, g_akt_spieler).f_beschreibung_2[2] = "(Dieser kann eine Schriftrolle pro Level erzeugen)";
	a_skills(47, g_akt_spieler).f_beschreibung_2[1] = "(It can produce one scroll per level)";
	a_skills(47, g_akt_spieler).f_beschreibung_2[3] = "(Lo puede crear un scroll por nivel)";
	a_skills(48, g_akt_spieler).f_name[2] = "Sternenmagie";
	a_skills(48, g_akt_spieler).f_name[1] = "Star Magic";
	a_skills(48, g_akt_spieler).f_name[3] = "Magia estelar";
	a_skills(48, g_akt_spieler).f_nummer = 48;
	a_skills(48, g_akt_spieler).f_gruppe = 3;
	a_skills(48, g_akt_spieler).f_kosten = 2;
	a_skills(48, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Sterne und der Himmelsk\366rper";
	a_skills(48, g_akt_spieler).f_beschreibung_1[1] = "All spells of the stars and the heavenly bodies";
	a_skills(48, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de las estrellas y los cuerpos celestes";
	a_skills(48, g_akt_spieler).f_beschreibung_2[2] = "(Die besten Lichtzauber, Sternenfeuer, Sternenfee beschw\366ren)";
	a_skills(48, g_akt_spieler).f_beschreibung_2[1] = "(The best Lightspells, Starfire, Summon Starfaerie)";
	a_skills(48, g_akt_spieler).f_beschreibung_2[3] = "(Los mejores hechizos de luz, Fuego de las estrellas, Hada de las estrellas)";
	a_skills(49, g_akt_spieler).f_name[2] = "Illusionsmagie";
	a_skills(49, g_akt_spieler).f_name[1] = "Illusion Magic";
	a_skills(49, g_akt_spieler).f_name[3] = "Ilusionismo";
	a_skills(49, g_akt_spieler).f_nummer = 49;
	a_skills(49, g_akt_spieler).f_gruppe = 3;
	a_skills(49, g_akt_spieler).f_kosten = 2;
	a_skills(49, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Illusion und der T\344uschung";
	a_skills(49, g_akt_spieler).f_beschreibung_1[1] = "All spells of illusion and deception";
	a_skills(49, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de ilusion y confusion";
	a_skills(49, g_akt_spieler).f_beschreibung_2[2] = "(Verschwinden, Doppelg\344nger, Unsichtbarkeit)";
	a_skills(49, g_akt_spieler).f_beschreibung_2[1] = "(Vanish, Doppelganger, Invisibility)";
	a_skills(49, g_akt_spieler).f_beschreibung_2[3] = "(Desvanecerse, Gemelo, Invisibilidad)";
	a_skills(50, g_akt_spieler).f_name[2] = "Warlock";
	a_skills(50, g_akt_spieler).f_name[1] = "Warlock";
	a_skills(50, g_akt_spieler).f_name[3] = "Arsenal";
	a_skills(50, g_akt_spieler).f_nummer = 50;
	a_skills(50, g_akt_spieler).f_gruppe = 3;
	a_skills(50, g_akt_spieler).f_kosten = 2;
	a_skills(50, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber des Krieges und der Kampfmagie";
	a_skills(50, g_akt_spieler).f_beschreibung_1[1] = "All spells of warfare and combat magic";
	a_skills(50, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de guerra y magia combativa";
	a_skills(50, g_akt_spieler).f_beschreibung_2[2] = "(Magische R\374stungen+Waffen, Mentalschlag, Unverwundbarkeit)";
	a_skills(50, g_akt_spieler).f_beschreibung_2[1] = "(Magical Weapons+Armor, Mentalbolt, Invulnerability)";
	a_skills(50, g_akt_spieler).f_beschreibung_2[3] = "(Armaduras+Armas magicas, rayo mental, Invulnerabilidad)";
	a_skills(51, g_akt_spieler).f_name[2] = "Weisse Magie";
	a_skills(51, g_akt_spieler).f_name[1] = "White Magic";
	a_skills(51, g_akt_spieler).f_name[3] = "Magia blanca";
	a_skills(51, g_akt_spieler).f_nummer = 51;
	a_skills(51, g_akt_spieler).f_gruppe = 3;
	a_skills(51, g_akt_spieler).f_kosten = 2;
	a_skills(51, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Heilung und des Schutzes";
	a_skills(51, g_akt_spieler).f_beschreibung_1[1] = "All spells of healing and protection";
	a_skills(51, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de curacion y proteccion";
	a_skills(51, g_akt_spieler).f_beschreibung_2[2] = "(Untote bannen, Andere heilen, Engel)";
	a_skills(51, g_akt_spieler).f_beschreibung_2[1] = "(Banish undead, Heal others, Angel)";
	a_skills(51, g_akt_spieler).f_beschreibung_2[3] = "(Ahuyentar no-muertos, Curar otros, Angelito)";
	a_skills(52, g_akt_spieler).f_name[2] = "Schwarze Magie";
	a_skills(52, g_akt_spieler).f_name[1] = "Black Magic";
	a_skills(52, g_akt_spieler).f_name[3] = "Magia negra";
	a_skills(52, g_akt_spieler).f_nummer = 52;
	a_skills(52, g_akt_spieler).f_gruppe = 3;
	a_skills(52, g_akt_spieler).f_kosten = 2;
	a_skills(52, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber des Todes und der Zerst\366rung";
	a_skills(52, g_akt_spieler).f_beschreibung_1[1] = "All spells of death and destruction";
	a_skills(52, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de muerte y destruccion";
	a_skills(52, g_akt_spieler).f_beschreibung_2[2] = "(Dunkles Mana, D\344mon, Wort des Todes)";
	a_skills(52, g_akt_spieler).f_beschreibung_2[1] = "(Dark Mana, Demon, Word of Death)";
	a_skills(52, g_akt_spieler).f_beschreibung_2[3] = "(Mana oscuro, Demonio, Palabra de Muerte)";
	a_skills(53, g_akt_spieler).f_name[2] = "Feuermagie";
	a_skills(53, g_akt_spieler).f_name[1] = "Fire Magic";
	a_skills(53, g_akt_spieler).f_name[3] = "Magia de fuego";
	a_skills(53, g_akt_spieler).f_nummer = 53;
	a_skills(53, g_akt_spieler).f_gruppe = 3;
	a_skills(53, g_akt_spieler).f_kosten = 2;
	a_skills(53, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Hitze und des Feuers";
	a_skills(53, g_akt_spieler).f_beschreibung_1[1] = "All spells of the realm of fire";
	a_skills(53, g_akt_spieler).f_beschreibung_1[3] = "Hechizos del reino del fuego";
	a_skills(53, g_akt_spieler).f_beschreibung_2[2] = "(Funke, Feuerball, Flammenmeer)";
	a_skills(53, g_akt_spieler).f_beschreibung_2[1] = "(Spark, Fireball, Sea of Flames)";
	a_skills(53, g_akt_spieler).f_beschreibung_2[3] = "(Chispa, Bola de Fuego, Mar de Fuego)";
	a_skills(54, g_akt_spieler).f_name[2] = "Wassermagie";
	a_skills(54, g_akt_spieler).f_name[1] = "Water Magic";
	a_skills(54, g_akt_spieler).f_name[3] = "Magia de agua";
	a_skills(54, g_akt_spieler).f_nummer = 54;
	a_skills(54, g_akt_spieler).f_gruppe = 3;
	a_skills(54, g_akt_spieler).f_kosten = 2;
	a_skills(54, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Fl\374sse und des Wassers";
	a_skills(54, g_akt_spieler).f_beschreibung_1[1] = "All spells of the realm of water";
	a_skills(54, g_akt_spieler).f_beschreibung_1[3] = "Hechizos del reino del agua";
	a_skills(54, g_akt_spieler).f_beschreibung_2[2] = "(Erfrischung, Dehydration, Flutwelle)";
	a_skills(54, g_akt_spieler).f_beschreibung_2[1] = "(Refresh, Dehydration, Tidal Wave)";
	a_skills(54, g_akt_spieler).f_beschreibung_2[3] = "(Refrescar, Dehidracion, Ola de la marea)";
	a_skills(55, g_akt_spieler).f_name[2] = "Erdmagie";
	a_skills(55, g_akt_spieler).f_name[1] = "Earth Magic";
	a_skills(55, g_akt_spieler).f_name[3] = "Magia de tierra";
	a_skills(55, g_akt_spieler).f_nummer = 55;
	a_skills(55, g_akt_spieler).f_gruppe = 3;
	a_skills(55, g_akt_spieler).f_kosten = 2;
	a_skills(55, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber des Gesteins und der Erde";
	a_skills(55, g_akt_spieler).f_beschreibung_1[1] = "All spells of the realm of the earth";
	a_skills(55, g_akt_spieler).f_beschreibung_1[3] = "Hechizos del reino de la tierra";
	a_skills(55, g_akt_spieler).f_beschreibung_2[2] = "(Portal, Fallensinn, Versteinern)";
	a_skills(55, g_akt_spieler).f_beschreibung_2[1] = "(Portal, Trap Sense, Turn to Stone)";
	a_skills(55, g_akt_spieler).f_beschreibung_2[3] = "(Portal, Sentir Trampas, Convertir a piedra)";
	a_skills(56, g_akt_spieler).f_name[2] = "Luftmagie";
	a_skills(56, g_akt_spieler).f_name[1] = "Air Magic";
	a_skills(56, g_akt_spieler).f_name[3] = "Magia de aire";
	a_skills(56, g_akt_spieler).f_nummer = 56;
	a_skills(56, g_akt_spieler).f_gruppe = 3;
	a_skills(56, g_akt_spieler).f_kosten = 2;
	a_skills(56, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Winde und der St\374rme";
	a_skills(56, g_akt_spieler).f_beschreibung_1[1] = "All spells of the realm of the air";
	a_skills(56, g_akt_spieler).f_beschreibung_1[3] = "Hechizos del reino del aire";
	a_skills(56, g_akt_spieler).f_beschreibung_2[2] = "(Federfall, R\374ckenwind, Fliegen)";
	a_skills(56, g_akt_spieler).f_beschreibung_2[1] = "(Featherfall, Helpful Winds, Flying)";
	a_skills(56, g_akt_spieler).f_beschreibung_2[3] = "(Peso pluma, Vientos amigos, Volar)";
	a_skills(57, g_akt_spieler).f_name[2] = "Druidenmagie";
	a_skills(57, g_akt_spieler).f_name[1] = "Druid Magic";
	a_skills(57, g_akt_spieler).f_name[3] = "Magia de druida";
	a_skills(57, g_akt_spieler).f_nummer = 57;
	a_skills(57, g_akt_spieler).f_gruppe = 3;
	a_skills(57, g_akt_spieler).f_kosten = 2;
	a_skills(57, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der W\344lder und der Natur";
	a_skills(57, g_akt_spieler).f_beschreibung_1[1] = "All spells of the realm of nature";
	a_skills(57, g_akt_spieler).f_beschreibung_1[3] = "Hechizos del reino de la naturaleza";
	a_skills(57, g_akt_spieler).f_beschreibung_2[2] = "(Magic Apple, Tiere bannen, Wolfsform)";
	a_skills(57, g_akt_spieler).f_beschreibung_2[1] = "(Magic Apple, Banish Animals, Form of the Wolf)";
	a_skills(57, g_akt_spieler).f_beschreibung_2[3] = "(Manazana magica, Ahuyentar animales, Forma de lobo)";
	a_skills(58, g_akt_spieler).f_name[2] = "Hexerei";
	a_skills(58, g_akt_spieler).f_name[1] = "Witchcraft";
	a_skills(58, g_akt_spieler).f_name[3] = "Brujeria";
	a_skills(58, g_akt_spieler).f_nummer = 58;
	a_skills(58, g_akt_spieler).f_gruppe = 3;
	a_skills(58, g_akt_spieler).f_kosten = 2;
	a_skills(58, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber der Kontrolle und Verfluchung";
	a_skills(58, g_akt_spieler).f_beschreibung_1[1] = "All spells of control and cursing";
	a_skills(58, g_akt_spieler).f_beschreibung_1[3] = "Hechizos de control y maldicion";
	a_skills(58, g_akt_spieler).f_beschreibung_2[2] = "(Blitze werfen, Vergiften, Tiger beschw\366ren)";
	a_skills(58, g_akt_spieler).f_beschreibung_2[1] = "(Throw Lightning, Poison, Summon Tigre)";
	a_skills(58, g_akt_spieler).f_beschreibung_2[3] = "(Relampago, Envenenar, Conjurar Tigre)";
	a_skills(59, g_akt_spieler).f_name[2] = "Hohe Magie";
	a_skills(59, g_akt_spieler).f_name[1] = "High Magic";
	a_skills(59, g_akt_spieler).f_name[3] = "Alta magia";
	a_skills(59, g_akt_spieler).f_nummer = 59;
	a_skills(59, g_akt_spieler).f_gruppe = 3;
	a_skills(59, g_akt_spieler).f_kosten = 2;
	a_skills(59, g_akt_spieler).f_beschreibung_1[2] = "Alle Zauber, die die Magie selbst beeinflussen";
	a_skills(59, g_akt_spieler).f_beschreibung_1[1] = "All spells which influence magic itself";
	a_skills(59, g_akt_spieler).f_beschreibung_1[3] = "Hechizos que influyen en la magia";
	a_skills(59, g_akt_spieler).f_beschreibung_2[2] = "(Nexus finden, Nexus, Metamagie)";
	a_skills(59, g_akt_spieler).f_beschreibung_2[1] = "(Find Nexus, Nexus, Metamagic)";
	a_skills(59, g_akt_spieler).f_beschreibung_2[3] = "(Encontrar Nexus, Nexus, Meta magia)";
	a_skills(60, g_akt_spieler).f_name[2] = "Zauberlieder";
	a_skills(60, g_akt_spieler).f_name[1] = "Spellsongs";
	a_skills(60, g_akt_spieler).f_name[3] = "Canciones magicas";
	a_skills(60, g_akt_spieler).f_nummer = 60;
	a_skills(60, g_akt_spieler).f_gruppe = 3;
	a_skills(60, g_akt_spieler).f_kosten = 2;
	a_skills(60, g_akt_spieler).f_beschreibung_1[2] = "Magische Lieder der Barden";
	a_skills(60, g_akt_spieler).f_beschreibung_1[1] = "Magic songs of the Bards";
	a_skills(60, g_akt_spieler).f_beschreibung_1[3] = "Canciones magicas de los bardos";
	a_skills(60, g_akt_spieler).f_beschreibung_2[2] = "(Reise - +1 Bewegung, Einsamkeit - Keine Hinterhalte, Magie - Keine Runenfallen";
	a_skills(60, g_akt_spieler).f_beschreibung_2[1] = "(Travel - +1 Movement, Loneliness - No Ambushes, Magic - No Runetraps)";
	a_skills(60, g_akt_spieler).f_beschreibung_2[3] = "(Viaje - +1 Velocidad, Soledad - No Emboscadas, Magia - No Trampas Runas)";
	a_skills(61, g_akt_spieler).f_name[2] = "Best\344ndige Magie";
	a_skills(61, g_akt_spieler).f_name[1] = "Stable Magic";
	a_skills(61, g_akt_spieler).f_name[3] = "Magia persistente";
	a_skills(61, g_akt_spieler).f_nummer = 61;
	a_skills(61, g_akt_spieler).f_gruppe = 3;
	a_skills(61, g_akt_spieler).f_kosten = 2;
	a_skills(61, g_akt_spieler).f_beschreibung_1[2] = "Spruchdauer doppelt so lange";
	a_skills(61, g_akt_spieler).f_beschreibung_1[1] = "Doubles the Duration of Spells";
	a_skills(61, g_akt_spieler).f_beschreibung_1[3] = "Doble duracion de Hechizos";
	a_skills(61, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(61, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(61, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(62, g_akt_spieler).f_name[2] = "Elementarmagie";
	a_skills(62, g_akt_spieler).f_name[1] = "Elementary Magic";
	a_skills(62, g_akt_spieler).f_name[3] = "Magia de los Elementos";
	a_skills(62, g_akt_spieler).f_nummer = 62;
	a_skills(62, g_akt_spieler).f_gruppe = 3;
	a_skills(62, g_akt_spieler).f_kosten = 6;
	a_skills(62, g_akt_spieler).f_beschreibung_1[2] = "Erd, Feuer, Luft und Wassermagie";
	a_skills(62, g_akt_spieler).f_beschreibung_1[1] = "Air, Earth, Fire and Watermagic";
	a_skills(62, g_akt_spieler).f_beschreibung_1[3] = "Magia de Aire, Tierra, Fuego y Aqua";
	a_skills(62, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(62, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(62, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(64, g_akt_spieler).f_name[2] = "Scrollwissen";
	a_skills(64, g_akt_spieler).f_name[1] = "Scrollore";
	a_skills(64, g_akt_spieler).f_name[3] = "Sabiduria de Scrolls";
	a_skills(64, g_akt_spieler).f_nummer = 64;
	a_skills(64, g_akt_spieler).f_gruppe = 3;
	a_skills(64, g_akt_spieler).f_kosten = 2;
	a_skills(64, g_akt_spieler).f_beschreibung_1[2] = "Erm\366glicht erlernen von Zaubern von Schriftrollen.";
	a_skills(64, g_akt_spieler).f_beschreibung_1[1] = "Learn Spells from Scrolls";
	a_skills(64, g_akt_spieler).f_beschreibung_1[3] = "Aprender Hechizos de Scrolls";
	a_skills(64, g_akt_spieler).f_beschreibung_2[2] = "(Max Level eigener Zirkel -2)";
	a_skills(64, g_akt_spieler).f_beschreibung_2[1] = "(Max level your circle -2)";
	a_skills(64, g_akt_spieler).f_beschreibung_2[3] = "(Max level su circulo -2)";
	a_skills(65, g_akt_spieler).f_name[2] = "Freie Magie";
	a_skills(65, g_akt_spieler).f_name[1] = "Free Magic";
	a_skills(65, g_akt_spieler).f_name[3] = "Magia libre";
	a_skills(65, g_akt_spieler).f_nummer = 65;
	a_skills(65, g_akt_spieler).f_gruppe = 3;
	a_skills(65, g_akt_spieler).f_kosten = 4;
	a_skills(65, g_akt_spieler).f_beschreibung_1[2] = "Erm\366glicht das lernen beliebiger Zauber aller Schulen";
	a_skills(65, g_akt_spieler).f_beschreibung_1[1] = "Allows you to learn spells from all spellschools";
	a_skills(65, g_akt_spieler).f_beschreibung_1[3] = "Permite aprender hechizos de todas las escuelas";
	a_skills(65, g_akt_spieler).f_beschreibung_2[2] = "Allerdings nur einen pro Zirkel";
	a_skills(65, g_akt_spieler).f_beschreibung_2[1] = "But only one per circle";
	a_skills(65, g_akt_spieler).f_beschreibung_2[3] = "Pero solo uno por circulo";
	a_skills(66, g_akt_spieler).f_name[2] = "Zauberweben";
	a_skills(66, g_akt_spieler).f_name[1] = "Spellweaving";
	a_skills(66, g_akt_spieler).f_name[3] = "Fortificar hechizos";
	a_skills(66, g_akt_spieler).f_nummer = 66;
	a_skills(66, g_akt_spieler).f_gruppe = 3;
	a_skills(66, g_akt_spieler).f_kosten = 2;
	a_skills(66, g_akt_spieler).f_beschreibung_1[2] = "Je mehr Mana der Magier einsetzt desto";
	a_skills(66, g_akt_spieler).f_beschreibung_1[1] = "The more mana the mage invests the";
	a_skills(66, g_akt_spieler).f_beschreibung_1[3] = "Mientras mas mana invierta el mago,";
	a_skills(66, g_akt_spieler).f_beschreibung_2[2] = "st\344rker sind seine Spr\374che";
	a_skills(66, g_akt_spieler).f_beschreibung_2[1] = "stronger are his spells";
	a_skills(66, g_akt_spieler).f_beschreibung_2[3] = "mas fuertes seran sus hechizos";
	a_skills(67, g_akt_spieler).f_name[2] = "Beschw\366rer";
	a_skills(67, g_akt_spieler).f_name[1] = "Summoner";
	a_skills(67, g_akt_spieler).f_name[3] = "Conjurador";
	a_skills(67, g_akt_spieler).f_nummer = 67;
	a_skills(67, g_akt_spieler).f_gruppe = 3;
	a_skills(67, g_akt_spieler).f_kosten = 2;
	a_skills(67, g_akt_spieler).f_beschreibung_1[2] = "Alle Beschw\366rungszauber";
	a_skills(67, g_akt_spieler).f_beschreibung_1[1] = "All summon creature Spells";
	a_skills(67, g_akt_spieler).f_beschreibung_1[3] = "Todos los hechizos de conjuration";
	a_skills(67, g_akt_spieler).f_beschreibung_2[2] = "(Kreatur heilen)";
	a_skills(67, g_akt_spieler).f_beschreibung_2[1] = "(Heal creature)";
	a_skills(67, g_akt_spieler).f_beschreibung_2[3] = "(curar kriatura)";
	a_skills(68, g_akt_spieler).f_name[1] = "Way of Shadows";
	a_skills(68, g_akt_spieler).f_name[2] = "Weg der Schatten";
	a_skills(68, g_akt_spieler).f_name[3] = "Camino de las sombras";
	a_skills(68, g_akt_spieler).f_nummer = 0;
	a_skills(68, g_akt_spieler).f_kosten = 0;
	a_skills(68, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(68, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(68, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(68, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(68, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(68, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(69, g_akt_spieler).f_name[2] = "Fallenkunde";
	a_skills(69, g_akt_spieler).f_name[1] = "Trap Lore";
	a_skills(69, g_akt_spieler).f_name[3] = "Conocimiento de trampas";
	a_skills(69, g_akt_spieler).f_nummer = 69;
	a_skills(69, g_akt_spieler).f_gruppe = 4;
	a_skills(69, g_akt_spieler).f_kosten = 2;
	a_skills(69, g_akt_spieler).f_beschreibung_1[2] = "Automatisches Entsch\344rfen von entdeckten Fallen";
	a_skills(69, g_akt_spieler).f_beschreibung_1[1] = "Detected traps are automatically disarmed";
	a_skills(69, g_akt_spieler).f_beschreibung_1[3] = "Las trampas detectadas se desactivan automaticamente";
	a_skills(69, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(69, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(69, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(70, g_akt_spieler).f_name[2] = "Wahrnehmung";
	a_skills(70, g_akt_spieler).f_name[1] = "Perception";
	a_skills(70, g_akt_spieler).f_name[3] = "Percepcion";
	a_skills(70, g_akt_spieler).f_nummer = 70;
	a_skills(70, g_akt_spieler).f_gruppe = 4;
	a_skills(70, g_akt_spieler).f_kosten = 2;
	a_skills(70, g_akt_spieler).f_beschreibung_1[2] = "Wahrnehmung: 4";
	a_skills(70, g_akt_spieler).f_beschreibung_1[1] = "Perception: 4";
	a_skills(70, g_akt_spieler).f_beschreibung_1[3] = "Percepcion: 4";
	a_skills(70, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(70, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(70, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(71, g_akt_spieler).f_name[2] = "Nachtsicht";
	a_skills(71, g_akt_spieler).f_name[1] = "Night Vision";
	a_skills(71, g_akt_spieler).f_name[3] = "Vision nocturna";
	a_skills(71, g_akt_spieler).f_nummer = 71;
	a_skills(71, g_akt_spieler).f_gruppe = 4;
	a_skills(71, g_akt_spieler).f_kosten = 2;
	a_skills(71, g_akt_spieler).f_beschreibung_1[2] = "Sichtradius +2 Feld";
	a_skills(71, g_akt_spieler).f_beschreibung_1[1] = "Sight radius +2 Fields";
	a_skills(71, g_akt_spieler).f_beschreibung_1[3] = "Radio de vision incrementado en +2";
	a_skills(71, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(71, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(71, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(72, g_akt_spieler).f_name[2] = "Schnelligkeit";
	a_skills(72, g_akt_spieler).f_name[1] = "Speed";
	a_skills(72, g_akt_spieler).f_name[3] = "Velocidad";
	a_skills(72, g_akt_spieler).f_nummer = 72;
	a_skills(72, g_akt_spieler).f_gruppe = 4;
	a_skills(72, g_akt_spieler).f_kosten = 2;
	a_skills(72, g_akt_spieler).f_beschreibung_1[2] = "Schnelligkeit: 11";
	a_skills(72, g_akt_spieler).f_beschreibung_1[1] = "Speed: 11";
	a_skills(72, g_akt_spieler).f_beschreibung_1[3] = "Velocidad: 11";
	a_skills(72, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(72, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(72, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(73, g_akt_spieler).f_name[2] = "Schleichen";
	a_skills(73, g_akt_spieler).f_name[1] = "Stealth";
	a_skills(73, g_akt_spieler).f_name[3] = "Furtivo";
	a_skills(73, g_akt_spieler).f_nummer = 73;
	a_skills(73, g_akt_spieler).f_gruppe = 4;
	a_skills(73, g_akt_spieler).f_kosten = 2;
	a_skills(73, g_akt_spieler).f_beschreibung_1[2] = "An Monstern vorbeischleichen";
	a_skills(73, g_akt_spieler).f_beschreibung_1[1] = "Sneak by Monsters";
	a_skills(73, g_akt_spieler).f_beschreibung_1[3] = "Escabullirse de los monstruos";
	a_skills(73, g_akt_spieler).f_beschreibung_2[2] = "(Chance=Gl\374ck*5%+Geschicklichkeit*10%+25%-Monsterlevel)";
	a_skills(73, g_akt_spieler).f_beschreibung_2[1] = "(Chance=Luck*5%+Dexterity*10%+25%-Monsterlevel)";
	a_skills(73, g_akt_spieler).f_beschreibung_2[3] = "(Chance=Suerte*5%+Destreza*10%+25%-Nivel del Monstruo)";
	a_skills(74, g_akt_spieler).f_name[2] = "Schl\366sser \366ffnen";
	a_skills(74, g_akt_spieler).f_name[1] = "Pick Locks";
	a_skills(74, g_akt_spieler).f_name[3] = "Cerrajero";
	a_skills(74, g_akt_spieler).f_nummer = 74;
	a_skills(74, g_akt_spieler).f_gruppe = 4;
	a_skills(74, g_akt_spieler).f_kosten = 2;
	a_skills(74, g_akt_spieler).f_beschreibung_1[2] = "\326ffnet jede T\374r automatisch";
	a_skills(74, g_akt_spieler).f_beschreibung_1[1] = "You open every door with ease";
	a_skills(74, g_akt_spieler).f_beschreibung_1[3] = "Puedes abrir las puertas";
	a_skills(74, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(74, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(74, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(75, g_akt_spieler).f_name[2] = "Diebstahl";
	a_skills(75, g_akt_spieler).f_name[1] = "Thievery";
	a_skills(75, g_akt_spieler).f_name[3] = "Ladron";
	a_skills(75, g_akt_spieler).f_nummer = 75;
	a_skills(75, g_akt_spieler).f_gruppe = 4;
	a_skills(75, g_akt_spieler).f_kosten = 2;
	a_skills(75, g_akt_spieler).f_beschreibung_1[2] = "2 mal pro Ebene bestimmte Monster bestehlen";
	a_skills(75, g_akt_spieler).f_beschreibung_1[1] = "2 times per level you can steal from certain monsters";
	a_skills(75, g_akt_spieler).f_beschreibung_1[3] = "2 veces por nivel puedes robar a algunos monstruos";
	a_skills(75, g_akt_spieler).f_beschreibung_2[2] = "(Chance=Geschicklichkeit*8%+Gl\374ck*6%)";
	a_skills(75, g_akt_spieler).f_beschreibung_2[1] = "(Chance=Dexterity*8%+Luck*6%)";
	a_skills(75, g_akt_spieler).f_beschreibung_2[3] = "(Chance=Suerte*8%+Destreza*6%)";
	a_skills(76, g_akt_spieler).f_name[2] = "Assassine";
	a_skills(76, g_akt_spieler).f_name[1] = "Assassination";
	a_skills(76, g_akt_spieler).f_name[3] = "Asesino";
	a_skills(76, g_akt_spieler).f_nummer = 76;
	a_skills(76, g_akt_spieler).f_gruppe = 4;
	a_skills(76, g_akt_spieler).f_kosten = 2;
	a_skills(76, g_akt_spieler).f_beschreibung_1[2] = "Doppelte Chance f\374r kritischen Treffer im Nahkampf. Max 45%";
	a_skills(76, g_akt_spieler).f_beschreibung_1[1] = "Percentage for critical hits in close combat doubled. Max 45%";
	a_skills(76, g_akt_spieler).f_beschreibung_1[3] = "Porcentage de golpe critico duplicado con armas de filo. Max 45%";
	a_skills(76, g_akt_spieler).f_beschreibung_2[2] = "(Chance=(Geschicklichkeit+Gl\374ck)*2% + Waffe)";
	a_skills(76, g_akt_spieler).f_beschreibung_2[1] = "(Chance=(Dexterity+Luck)*2% + Weapon)";
	a_skills(76, g_akt_spieler).f_beschreibung_2[3] = "(Chance=(Destreza+Suerte)*2% + Arma)";
	a_skills(77, g_akt_spieler).f_name[2] = "Gefahren sp\374hren";
	a_skills(77, g_akt_spieler).f_name[1] = "Danger Sense";
	a_skills(77, g_akt_spieler).f_name[3] = "Percepcion de Peligros";
	a_skills(77, g_akt_spieler).f_nummer = 77;
	a_skills(77, g_akt_spieler).f_gruppe = 4;
	a_skills(77, g_akt_spieler).f_kosten = 2;
	a_skills(77, g_akt_spieler).f_beschreibung_1[2] = "+70% Fallen finden. 50% weniger Hinterhalte";
	a_skills(77, g_akt_spieler).f_beschreibung_1[1] = "+70% Find traps. 50% less ambushes";
	a_skills(77, g_akt_spieler).f_beschreibung_1[3] = "+70% Encontrar Trampas. 50% menos emboscadas";
	a_skills(77, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(77, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(77, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(78, g_akt_spieler).f_name[2] = "Spion";
	a_skills(78, g_akt_spieler).f_name[1] = "Spy";
	a_skills(78, g_akt_spieler).f_name[3] = "Espia";
	a_skills(78, g_akt_spieler).f_nummer = 78;
	a_skills(78, g_akt_spieler).f_gruppe = 4;
	a_skills(78, g_akt_spieler).f_kosten = 2;
	a_skills(78, g_akt_spieler).f_beschreibung_1[2] = "Alle Spieler erhalten +2 Zugweite";
	a_skills(78, g_akt_spieler).f_beschreibung_1[1] = "All Players get +2 Movement";
	a_skills(78, g_akt_spieler).f_beschreibung_1[3] = "Todos Jugadores reciben Velocidad +2";
	a_skills(78, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(78, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(78, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(79, g_akt_spieler).f_name[2] = "Schatzj\344ger";
	a_skills(79, g_akt_spieler).f_name[1] = "Treasure Hunter";
	a_skills(79, g_akt_spieler).f_name[3] = "Cazador de Tesoros";
	a_skills(79, g_akt_spieler).f_nummer = 79;
	a_skills(79, g_akt_spieler).f_gruppe = 4;
	a_skills(79, g_akt_spieler).f_kosten = 2;
	a_skills(79, g_akt_spieler).f_beschreibung_1[2] = "Sieht Sch\344tze ausserhalb Sichtweite und findet alle verborgenen Sch\344tze";
	a_skills(79, g_akt_spieler).f_beschreibung_1[1] = "Sees treasures outside lightradius and finds all hidden treasures";
	a_skills(79, g_akt_spieler).f_beschreibung_1[3] = "Ve tesoros afuera de su vista y enuentra todos tesoros esondidos";
	a_skills(79, g_akt_spieler).f_beschreibung_2[2] = "(Startet mit 2 Schaufeln, Schl\374ssel und Peitsche)";
	a_skills(79, g_akt_spieler).f_beschreibung_2[1] = "(Starts with 2 Shovels, Key and Whip)";
	a_skills(79, g_akt_spieler).f_beschreibung_2[3] = "(Empiece con 2 palas, Llave y Latigo)";
	a_skills(80, g_akt_spieler).f_name[2] = "Erde sp\374hren";
	a_skills(80, g_akt_spieler).f_name[1] = "Sense Earth";
	a_skills(80, g_akt_spieler).f_name[3] = "Sentir la tierra";
	a_skills(80, g_akt_spieler).f_nummer = 80;
	a_skills(80, g_akt_spieler).f_gruppe = 4;
	a_skills(80, g_akt_spieler).f_kosten = 2;
	a_skills(80, g_akt_spieler).f_beschreibung_1[2] = "Sieht auch Mauern ausserhalb des Sichtradiuses";
	a_skills(80, g_akt_spieler).f_beschreibung_1[1] = "Sees walls outside sight radius";
	a_skills(80, g_akt_spieler).f_beschreibung_1[3] = "Ve pareds afuera de su vista";
	a_skills(80, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(80, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(80, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(81, g_akt_spieler).f_name[2] = "Monster sp\374hren";
	a_skills(81, g_akt_spieler).f_name[1] = "Monstersense";
	a_skills(81, g_akt_spieler).f_name[3] = "Sentir monstruos";
	a_skills(81, g_akt_spieler).f_nummer = 81;
	a_skills(81, g_akt_spieler).f_gruppe = 4;
	a_skills(81, g_akt_spieler).f_kosten = 2;
	a_skills(81, g_akt_spieler).f_beschreibung_1[2] = "Sieht auch Monster ausserhalb des Sichtradiuses";
	a_skills(81, g_akt_spieler).f_beschreibung_1[1] = "Sees monsters outside sight radius";
	a_skills(81, g_akt_spieler).f_beschreibung_1[3] = "Ve monstruos afuera de su vista";
	a_skills(81, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(81, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(81, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(82, g_akt_spieler).f_name[2] = "Weg der Abenteuer";
	a_skills(82, g_akt_spieler).f_name[1] = "Way of Adventure";
	a_skills(82, g_akt_spieler).f_name[3] = "Camino de la aventura";
	a_skills(82, g_akt_spieler).f_nummer = 0;
	a_skills(82, g_akt_spieler).f_kosten = 0;
	a_skills(82, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(82, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(82, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(82, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(82, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(82, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(83, g_akt_spieler).f_name[2] = "Gl\374ck";
	a_skills(83, g_akt_spieler).f_name[1] = "Luck";
	a_skills(83, g_akt_spieler).f_name[3] = "Suerte";
	a_skills(83, g_akt_spieler).f_nummer = 83;
	a_skills(83, g_akt_spieler).f_gruppe = 5;
	a_skills(83, g_akt_spieler).f_kosten = 2;
	a_skills(83, g_akt_spieler).f_beschreibung_1[2] = "Gl\374ck: 4";
	a_skills(83, g_akt_spieler).f_beschreibung_1[1] = "Luck: 4";
	a_skills(83, g_akt_spieler).f_beschreibung_1[3] = "Suerte: 4";
	a_skills(83, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(83, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(83, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(84, g_akt_spieler).f_name[2] = "Giftresistenz";
	a_skills(84, g_akt_spieler).f_name[1] = "Poison resistance";
	a_skills(84, g_akt_spieler).f_name[3] = "Resistencia al veneno";
	a_skills(84, g_akt_spieler).f_nummer = 84;
	a_skills(84, g_akt_spieler).f_gruppe = 5;
	a_skills(84, g_akt_spieler).f_kosten = 2;
	a_skills(84, g_akt_spieler).f_beschreibung_1[2] = "Du erholst dich doppelt so schnell von Gift";
	a_skills(84, g_akt_spieler).f_beschreibung_1[1] = "You recover twice as fast from poison";
	a_skills(84, g_akt_spieler).f_beschreibung_1[3] = "Te mejoras con doble velocidad de venenos";
	a_skills(84, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(84, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(84, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(85, g_akt_spieler).f_name[2] = "Heilkunde";
	a_skills(85, g_akt_spieler).f_name[1] = "First Aid";
	a_skills(85, g_akt_spieler).f_name[3] = "Primeros auxilios";
	a_skills(85, g_akt_spieler).f_nummer = 85;
	a_skills(85, g_akt_spieler).f_gruppe = 5;
	a_skills(85, g_akt_spieler).f_kosten = 2;
	a_skills(85, g_akt_spieler).f_beschreibung_1[2] = "Heilt alle Wunden beim Betreten einer neuen Ebene";
	a_skills(85, g_akt_spieler).f_beschreibung_1[1] = "Heals all wounds when entering a new level";
	a_skills(85, g_akt_spieler).f_beschreibung_1[3] = "Cura todas las heridas al empezar un nivel";
	a_skills(85, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(85, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(85, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(86, g_akt_spieler).f_name[2] = "Kartographie";
	a_skills(86, g_akt_spieler).f_name[1] = "Cartography";
	a_skills(86, g_akt_spieler).f_name[3] = "Cartografia";
	a_skills(86, g_akt_spieler).f_nummer = 86;
	a_skills(86, g_akt_spieler).f_gruppe = 5;
	a_skills(86, g_akt_spieler).f_kosten = 2;
	a_skills(86, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit einer Karte";
	a_skills(86, g_akt_spieler).f_beschreibung_1[1] = "Starts the game with a map";
	a_skills(86, g_akt_spieler).f_beschreibung_1[3] = "Empieza el juego con un mapa";
	a_skills(86, g_akt_spieler).f_beschreibung_2[2] = "(Diese zeigt immer den aktuellen Level)";
	a_skills(86, g_akt_spieler).f_beschreibung_2[1] = "(Always shows the actual level)";
	a_skills(86, g_akt_spieler).f_beschreibung_2[3] = "(Siempre muestra el nivel actual)";
	a_skills(87, g_akt_spieler).f_name[2] = "Spelunker";
	a_skills(87, g_akt_spieler).f_name[1] = "Spelunker";
	a_skills(87, g_akt_spieler).f_name[3] = "Viajero";
	a_skills(87, g_akt_spieler).f_nummer = 87;
	a_skills(87, g_akt_spieler).f_gruppe = 5;
	a_skills(87, g_akt_spieler).f_kosten = 2;
	a_skills(87, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit Lampe, \326l, Seil";
	a_skills(87, g_akt_spieler).f_beschreibung_1[1] = "Starts with lamp, oil, rope";
	a_skills(87, g_akt_spieler).f_beschreibung_1[3] = "Empieza con lampara, aceite, cuerda";
	a_skills(87, g_akt_spieler).f_beschreibung_2[2] = "Schaufel und Spitzhacke";
	a_skills(87, g_akt_spieler).f_beschreibung_2[1] = "Shovel and Pickaxe";
	a_skills(87, g_akt_spieler).f_beschreibung_2[3] = "Pala y Picketa";
	a_skills(88, g_akt_spieler).f_name[2] = "Erbschaft";
	a_skills(88, g_akt_spieler).f_name[1] = "Heirloom";
	a_skills(88, g_akt_spieler).f_name[3] = "Herencia";
	a_skills(88, g_akt_spieler).f_nummer = 88;
	a_skills(88, g_akt_spieler).f_gruppe = 5;
	a_skills(88, g_akt_spieler).f_kosten = 2;
	a_skills(88, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit 1000 Gold";
	a_skills(88, g_akt_spieler).f_beschreibung_1[1] = "Starts with 1000 gold pieces";
	a_skills(88, g_akt_spieler).f_beschreibung_1[3] = "Empieza con 1000 monedas de oro";
	a_skills(88, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(88, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(88, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(89, g_akt_spieler).f_name[2] = "Udjat-Auge";
	a_skills(89, g_akt_spieler).f_name[1] = "Udjat Eye";
	a_skills(89, g_akt_spieler).f_name[3] = "Ojo de Udjat";
	a_skills(89, g_akt_spieler).f_nummer = 89;
	a_skills(89, g_akt_spieler).f_gruppe = 5;
	a_skills(89, g_akt_spieler).f_kosten = 2;
	a_skills(89, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit einem Udjat-Auge mit 3 Ladungen.";
	a_skills(89, g_akt_spieler).f_beschreibung_1[1] = "Starts with an Udjat Eye and 3 charges.";
	a_skills(89, g_akt_spieler).f_beschreibung_1[3] = "Empieza con un Ojo de Udjat y 3 cargas.";
	a_skills(89, g_akt_spieler).f_beschreibung_2[2] = "(Jede gibt einen zus\344tzlichen Erfahrungsgewinn)";
	a_skills(89, g_akt_spieler).f_beschreibung_2[1] = "(Additional Experience Gain each)";
	a_skills(89, g_akt_spieler).f_beschreibung_2[3] = "(Una avance mas de experiencia cada uno)";
	a_skills(90, g_akt_spieler).f_name[2] = "Weisheit";
	a_skills(90, g_akt_spieler).f_name[1] = "Wisdom";
	a_skills(90, g_akt_spieler).f_name[3] = "Sabiduria";
	a_skills(90, g_akt_spieler).f_nummer = 90;
	a_skills(90, g_akt_spieler).f_gruppe = 5;
	a_skills(90, g_akt_spieler).f_kosten = 2;
	a_skills(90, g_akt_spieler).f_beschreibung_1[2] = "Ein zus\344tzlicher Erfahrungsgewinn alle 4 Levels";
	a_skills(90, g_akt_spieler).f_beschreibung_1[1] = "Provides an additional experience gain every 4 dungeon levels";
	a_skills(90, g_akt_spieler).f_beschreibung_1[3] = "Produce un gano de experiencia adicional cada 4 niveles";
	a_skills(90, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(90, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(90, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(91, g_akt_spieler).f_name[2] = "Ringmeisterung";
	a_skills(91, g_akt_spieler).f_name[1] = "Ringmastery";
	a_skills(91, g_akt_spieler).f_name[3] = "Maestro de Anillos";
	a_skills(91, g_akt_spieler).f_nummer = 91;
	a_skills(91, g_akt_spieler).f_gruppe = 5;
	a_skills(91, g_akt_spieler).f_kosten = 2;
	a_skills(91, g_akt_spieler).f_beschreibung_1[2] = "Beliebig viele Ringe gleichzeitig tragen.";
	a_skills(91, g_akt_spieler).f_beschreibung_1[1] = "You can wear all rings at the same time.";
	a_skills(91, g_akt_spieler).f_beschreibung_1[3] = "Puedes ponerte todos anillos al mismo tiempo.";
	a_skills(91, g_akt_spieler).f_beschreibung_2[2] = "F\344ngt mit einem Ring an";
	a_skills(91, g_akt_spieler).f_beschreibung_2[1] = "Starts with a Ring";
	a_skills(91, g_akt_spieler).f_beschreibung_2[3] = "Empiece con un Anillo";
	a_skills(92, g_akt_spieler).f_name[2] = "Mystische Attacke";
	a_skills(92, g_akt_spieler).f_name[1] = "Mystic Attack";
	a_skills(92, g_akt_spieler).f_name[3] = "Ataque Mistico";
	a_skills(92, g_akt_spieler).f_nummer = 92;
	a_skills(92, g_akt_spieler).f_gruppe = 5;
	a_skills(92, g_akt_spieler).f_kosten = 2;
	a_skills(92, g_akt_spieler).f_beschreibung_1[2] = "Mentaler Schlag die dir und einem Monster Schaden zuf\374gt";
	a_skills(92, g_akt_spieler).f_beschreibung_1[1] = "Mental Attack that damages you and a monster";
	a_skills(92, g_akt_spieler).f_beschreibung_1[3] = "Ataque Mental que dana tu y un monstruo";
	a_skills(92, g_akt_spieler).f_beschreibung_2[2] = "(Kostet einen LP und macht 4-14+level Schaden)";
	a_skills(92, g_akt_spieler).f_beschreibung_2[1] = "(Costs a LP and does 4-14+level damage)";
	a_skills(92, g_akt_spieler).f_beschreibung_2[3] = "(Cuesta un PdV y hace 4-14+nivel dano)";
	a_skills(93, g_akt_spieler).f_name[2] = "\334berlebensk\374nstler";
	a_skills(93, g_akt_spieler).f_name[1] = "Survival Expert";
	a_skills(93, g_akt_spieler).f_name[3] = "Experto de Sobrevivir";
	a_skills(93, g_akt_spieler).f_nummer = 93;
	a_skills(93, g_akt_spieler).f_gruppe = 5;
	a_skills(93, g_akt_spieler).f_kosten = 2;
	a_skills(93, g_akt_spieler).f_beschreibung_1[2] = "N\344hrwert aller Lebensmittel verdoppelt. Findet mit 10% Nahrung";
	a_skills(93, g_akt_spieler).f_beschreibung_1[1] = "Value of all food is doubled. Finds food with 10% each slain animal.";
	a_skills(93, g_akt_spieler).f_beschreibung_1[3] = "Valor de todos los alimentos cuenta doble. Encuentra Comida cada";
	a_skills(93, g_akt_spieler).f_beschreibung_2[2] = " bei erschlagenen Tieren. Beginnt mit Angel und Fallenwerkzeug";
	a_skills(93, g_akt_spieler).f_beschreibung_2[1] = "Starts with a Fishing Rod and Traptools";
	a_skills(93, g_akt_spieler).f_beschreibung_2[3] = " animal con 10%. Empiece con una Cana de Pescar y herramientos para desarmar trampas";
	a_skills(94, g_akt_spieler).f_name[2] = "H\344ndler";
	a_skills(94, g_akt_spieler).f_name[1] = "Merchant";
	a_skills(94, g_akt_spieler).f_name[3] = "Comerciante";
	a_skills(94, g_akt_spieler).f_nummer = 94;
	a_skills(94, g_akt_spieler).f_gruppe = 5;
	a_skills(94, g_akt_spieler).f_kosten = 2;
	a_skills(94, g_akt_spieler).f_beschreibung_1[2] = "Beim erreichen einer neuen Ebene 20% einen H\344ndler ";
	a_skills(94, g_akt_spieler).f_beschreibung_1[1] = "When you reach a new level you got 20% to meet";
	a_skills(94, g_akt_spieler).f_beschreibung_1[3] = "Cuando entras a nuevo nivel tienes 20% para encontrarse";
	a_skills(94, g_akt_spieler).f_beschreibung_2[2] = "zu treffen";
	a_skills(94, g_akt_spieler).f_beschreibung_2[1] = "a merchant";
	a_skills(94, g_akt_spieler).f_beschreibung_2[3] = "a un comerciante";
	a_skills(63, g_akt_spieler).f_name[2] = "Zauberf\374rst";
	a_skills(63, g_akt_spieler).f_name[1] = "Magelord";
	a_skills(63, g_akt_spieler).f_name[3] = "Rey Mago";
	a_skills(63, g_akt_spieler).f_nummer = 63;
	a_skills(63, g_akt_spieler).f_gruppe = 5;
	a_skills(63, g_akt_spieler).f_kosten = 2;
	a_skills(63, g_akt_spieler).f_beschreibung_1[2] = "Alle Spieler erhalten +2 Zauberkraft";
	a_skills(63, g_akt_spieler).f_beschreibung_1[1] = "All Players get +2 Spellpower";
	a_skills(63, g_akt_spieler).f_beschreibung_1[3] = "Todos Jugadores reciben Poder de Hechizos +2";
	a_skills(63, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(63, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(63, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(95, g_akt_spieler).f_name[2] = "Visionen";
	a_skills(95, g_akt_spieler).f_name[1] = "Visions";
	a_skills(95, g_akt_spieler).f_name[3] = "Visiones";
	a_skills(95, g_akt_spieler).f_nummer = 95;
	a_skills(95, g_akt_spieler).f_gruppe = 5;
	a_skills(95, g_akt_spieler).f_kosten = 2;
	a_skills(95, g_akt_spieler).f_beschreibung_1[2] = "Erkennt R\344ume bevor er sie betritt";
	a_skills(95, g_akt_spieler).f_beschreibung_1[1] = "Identifies Rooms before entering them";
	a_skills(95, g_akt_spieler).f_beschreibung_1[3] = "Identifica Habitaciones antes de entrarlas";
	a_skills(95, g_akt_spieler).f_beschreibung_2[2] = "(+30% Fallen entdecken + Verborgene Sch\344tze finden)";
	a_skills(95, g_akt_spieler).f_beschreibung_2[1] = "(+30% Spot Traps + find hidden treasure)";
	a_skills(95, g_akt_spieler).f_beschreibung_2[3] = "(+30% encontrar trampas + tesoros escondidos)";
	a_skills(96, g_akt_spieler).f_name[2] = "Schmiedekunst";
	a_skills(96, g_akt_spieler).f_name[1] = "Weaponcraft";
	a_skills(96, g_akt_spieler).f_name[3] = "Forjar";
	a_skills(96, g_akt_spieler).f_nummer = 96;
	a_skills(96, g_akt_spieler).f_gruppe = 5;
	a_skills(96, g_akt_spieler).f_kosten = 2;
	a_skills(96, g_akt_spieler).f_beschreibung_1[2] = "F\344higkeit besch\344digte/zerst\366rte Waffen zu reparieren";
	a_skills(96, g_akt_spieler).f_beschreibung_1[1] = "Ability to repair damaged/broken Weapons/Armor";
	a_skills(96, g_akt_spieler).f_beschreibung_1[3] = "Abilidad de arreglar Armas/Armaduras danados/rompios";
	a_skills(96, g_akt_spieler).f_beschreibung_2[2] = "(Mit Diamanten k\366nnen wir magische Waffen/Pfeile erschaffen)";
	a_skills(96, g_akt_spieler).f_beschreibung_2[1] = "(With Diamonds we can create magical Weapons/Arrows)";
	a_skills(96, g_akt_spieler).f_beschreibung_2[3] = "(Con piedras preciosas podemos crear armas/flechas magicas)";
	a_skills(98, g_akt_spieler).f_name[2] = "St\344mmig";
	a_skills(98, g_akt_spieler).f_name[1] = "Corpulent";
	a_skills(98, g_akt_spieler).f_name[3] = "Duro";
	a_skills(98, g_akt_spieler).f_nummer = 98;
	a_skills(98, g_akt_spieler).f_gruppe = 5;
	a_skills(98, g_akt_spieler).f_kosten = 2;
	a_skills(98, g_akt_spieler).f_beschreibung_1[2] = "Jeder Punkt St\344rke gibt zus\344tzlich +2 Lebenspunkte";
	a_skills(98, g_akt_spieler).f_beschreibung_1[1] = "Each Point of Strength gives +2 Lifepoints additionally";
	a_skills(98, g_akt_spieler).f_beschreibung_1[3] = "Cada punto de fuerza te da +2 puntos de vida tambien";
	a_skills(98, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(98, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(98, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(99, g_akt_spieler).f_name[2] = "Fingerfertigkeit";
	a_skills(99, g_akt_spieler).f_name[1] = "Swift Fingers";
	a_skills(99, g_akt_spieler).f_name[3] = "Agil";
	a_skills(99, g_akt_spieler).f_nummer = 99;
	a_skills(99, g_akt_spieler).f_gruppe = 5;
	a_skills(99, g_akt_spieler).f_kosten = 2;
	a_skills(99, g_akt_spieler).f_beschreibung_1[2] = "Gegenst\344nde aufnehmen kostet nicht den Zug";
	a_skills(99, g_akt_spieler).f_beschreibung_1[1] = "Picking up items does not cost the turn";
	a_skills(99, g_akt_spieler).f_beschreibung_1[3] = "Recoger cosas no termine el turno";
	a_skills(99, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(99, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(99, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(100, g_akt_spieler).f_name[2] = "Aufmerksamkeit";
	a_skills(100, g_akt_spieler).f_name[1] = "Awareness";
	a_skills(100, g_akt_spieler).f_name[3] = "Atento";
	a_skills(100, g_akt_spieler).f_nummer = 100;
	a_skills(100, g_akt_spieler).f_gruppe = 5;
	a_skills(100, g_akt_spieler).f_kosten = 2;
	a_skills(100, g_akt_spieler).f_beschreibung_1[2] = "Halbiert alle Chancen beklaut zu werden";
	a_skills(100, g_akt_spieler).f_beschreibung_1[1] = "Halves all chances to get robbed";
	a_skills(100, g_akt_spieler).f_beschreibung_1[3] = "La probabilidad para ser robado es";
	a_skills(100, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(100, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(100, g_akt_spieler).f_beschreibung_2[3] = "la mitad";
	a_skills(101, g_akt_spieler).f_name[2] = "Weg der G\366tter";
	a_skills(101, g_akt_spieler).f_name[1] = "Way of the Gods";
	a_skills(101, g_akt_spieler).f_name[3] = "Camino de los Dioses";
	a_skills(101, g_akt_spieler).f_nummer = 0;
	a_skills(101, g_akt_spieler).f_kosten = 0;
	a_skills(101, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(101, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(101, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(101, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(101, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(101, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(102, g_akt_spieler).f_name[2] = "Akolyth";
	a_skills(102, g_akt_spieler).f_name[1] = "Akolyth";
	a_skills(102, g_akt_spieler).f_name[3] = "Acolito";
	a_skills(102, g_akt_spieler).f_nummer = 102;
	a_skills(102, g_akt_spieler).f_gruppe = 6;
	a_skills(102, g_akt_spieler).f_kosten = 2;
	a_skills(102, g_akt_spieler).f_beschreibung_1[2] = "Sanktum regeneriert verlorenes Mana und heilt Gifte, Krankheiten";
	a_skills(102, g_akt_spieler).f_beschreibung_1[1] = "The sanctum regenerates lost mana and heals Poison, Diseases";
	a_skills(102, g_akt_spieler).f_beschreibung_1[3] = "El sanctum regenera el mana y cura veneno, enfermedades";
	a_skills(102, g_akt_spieler).f_beschreibung_2[2] = "und Fl\374che";
	a_skills(102, g_akt_spieler).f_beschreibung_2[1] = "and Curses";
	a_skills(102, g_akt_spieler).f_beschreibung_2[3] = "y maldiciones";
	a_skills(103, g_akt_spieler).f_name[2] = "Gott des Krieges";
	a_skills(103, g_akt_spieler).f_name[1] = "God of War";
	a_skills(103, g_akt_spieler).f_name[3] = "Dios de la guerra";
	a_skills(103, g_akt_spieler).f_nummer = 103;
	a_skills(103, g_akt_spieler).f_gruppe = 6;
	a_skills(103, g_akt_spieler).f_kosten = 2;
	a_skills(103, g_akt_spieler).f_beschreibung_1[2] = "Bei jedem get\366teten Monster chance auf +1 LP";
	a_skills(103, g_akt_spieler).f_beschreibung_1[1] = "For each killed monster chance to get +1 LP";
	a_skills(103, g_akt_spieler).f_beschreibung_1[3] = "Cada monstruo que matas te da una chance para +1 PdV";
	a_skills(103, g_akt_spieler).f_beschreibung_2[2] = "(Chance=200/Maximale Lebenspunkte in %)";
	a_skills(103, g_akt_spieler).f_beschreibung_2[1] = "(Chance=200/Maximum Lifepoints in %)";
	a_skills(103, g_akt_spieler).f_beschreibung_2[3] = "(Chance=200/Maximos Puntos de Vida en %)";
	a_skills(104, g_akt_spieler).f_name[2] = "Gott des Todes";
	a_skills(104, g_akt_spieler).f_name[1] = "God of Death";
	a_skills(104, g_akt_spieler).f_name[3] = "Dios del muerto";
	a_skills(104, g_akt_spieler).f_nummer = 104;
	a_skills(104, g_akt_spieler).f_gruppe = 6;
	a_skills(104, g_akt_spieler).f_kosten = 2;
	a_skills(104, g_akt_spieler).f_beschreibung_1[2] = "Bei jedem get\366tetem Monster chance auf +1 Mana";
	a_skills(104, g_akt_spieler).f_beschreibung_1[1] = "For each killed monster chance to get +1 Mana";
	a_skills(104, g_akt_spieler).f_beschreibung_1[3] = "Cada monstruo que matas te da una chance para +1 Mana";
	a_skills(104, g_akt_spieler).f_beschreibung_2[2] = "(Chance=200/Maximale Manapunkte in %)";
	a_skills(104, g_akt_spieler).f_beschreibung_2[1] = "(Chance=200/Maximum Manapoints in %)";
	a_skills(104, g_akt_spieler).f_beschreibung_2[3] = "(Chance=200/Maximos Puntos de Mana en %)";
	a_skills(105, g_akt_spieler).f_name[2] = "G\366ttin der Weisheit";
	a_skills(105, g_akt_spieler).f_name[1] = "Goddess of Wisdom";
	a_skills(105, g_akt_spieler).f_name[3] = "Diosa de la Sabiduria";
	a_skills(105, g_akt_spieler).f_nummer = 105;
	a_skills(105, g_akt_spieler).f_gruppe = 6;
	a_skills(105, g_akt_spieler).f_kosten = 2;
	a_skills(105, g_akt_spieler).f_beschreibung_1[2] = "+1 Mana pro Sanktum";
	a_skills(105, g_akt_spieler).f_beschreibung_1[1] = "+1 Mana per Sanktum";
	a_skills(105, g_akt_spieler).f_beschreibung_1[3] = "+1 Mana cada Sanktum";
	a_skills(105, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(105, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(105, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(106, g_akt_spieler).f_name[2] = "G\366ttin der Heilung";
	a_skills(106, g_akt_spieler).f_name[1] = "Goddess of Healing";
	a_skills(106, g_akt_spieler).f_name[3] = "Diosa de la Curacion";
	a_skills(106, g_akt_spieler).f_nummer = 106;
	a_skills(106, g_akt_spieler).f_gruppe = 6;
	a_skills(106, g_akt_spieler).f_kosten = 2;
	a_skills(106, g_akt_spieler).f_beschreibung_1[2] = "+1 LP pro Sanktum";
	a_skills(106, g_akt_spieler).f_beschreibung_1[1] = "+1 LP per Sanktum";
	a_skills(106, g_akt_spieler).f_beschreibung_1[3] = "+1 PdV cada Sanktum";
	a_skills(106, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(106, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(106, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(107, g_akt_spieler).f_name[2] = "Gott der Geheimnisse";
	a_skills(107, g_akt_spieler).f_name[1] = "God of Secrets";
	a_skills(107, g_akt_spieler).f_name[3] = "Dios de los secretos";
	a_skills(107, g_akt_spieler).f_nummer = 107;
	a_skills(107, g_akt_spieler).f_gruppe = 6;
	a_skills(107, g_akt_spieler).f_kosten = 2;
	a_skills(107, g_akt_spieler).f_beschreibung_1[2] = "+1 LP pro Geheimt\374r";
	a_skills(107, g_akt_spieler).f_beschreibung_1[1] = "+1 LP per Secret Door";
	a_skills(107, g_akt_spieler).f_beschreibung_1[3] = "+1 PdV cada puerta secreta";
	a_skills(107, g_akt_spieler).f_beschreibung_2[2] = "(Chance=100%-Ebene*2)";
	a_skills(107, g_akt_spieler).f_beschreibung_2[1] = "(Chance=100%-Level*2)";
	a_skills(107, g_akt_spieler).f_beschreibung_2[3] = "(Chance=100%-Nivel*2)";
	a_skills(108, g_akt_spieler).f_name[2] = "Gott des Reichtums";
	a_skills(108, g_akt_spieler).f_name[1] = "God of Wealth";
	a_skills(108, g_akt_spieler).f_name[3] = "Dios de la riqueza";
	a_skills(108, g_akt_spieler).f_nummer = 108;
	a_skills(108, g_akt_spieler).f_gruppe = 6;
	a_skills(108, g_akt_spieler).f_kosten = 2;
	a_skills(108, g_akt_spieler).f_beschreibung_1[2] = "Chance auf +1 LP pro Goldsack";
	a_skills(108, g_akt_spieler).f_beschreibung_1[1] = "Chance of +1 LP per Goldbag";
	a_skills(108, g_akt_spieler).f_beschreibung_1[3] = "Posibilidad +1 PdV cada bolsa de oro";
	a_skills(108, g_akt_spieler).f_beschreibung_2[2] = "(Chance=500/Maximale Lebenspunkte in %)";
	a_skills(108, g_akt_spieler).f_beschreibung_2[1] = "(Chance=500/Maximum Lifepoints in %)";
	a_skills(108, g_akt_spieler).f_beschreibung_2[3] = "(Chance=500/Maximos Puntos de Vida en %)";
	a_skills(109, g_akt_spieler).f_name[2] = "Sekund\344re Fertigkeiten";
	a_skills(109, g_akt_spieler).f_name[1] = "Secondary skills";
	a_skills(109, g_akt_spieler).f_name[3] = "Abilidades segundarias";
	a_skills(109, g_akt_spieler).f_nummer = 0;
	a_skills(109, g_akt_spieler).f_kosten = 0;
	a_skills(109, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(109, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(109, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(109, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(109, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(109, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(110, g_akt_spieler).f_name[2] = "Wurfwaffen";
	a_skills(110, g_akt_spieler).f_name[1] = "Throwing Weapons";
	a_skills(110, g_akt_spieler).f_name[3] = "Armas para lanzar";
	a_skills(110, g_akt_spieler).f_nummer = 110;
	a_skills(110, g_akt_spieler).f_gruppe = 7;
	a_skills(110, g_akt_spieler).f_kosten = 1;
	a_skills(110, g_akt_spieler).f_beschreibung_1[2] = "+50% Angriff und +2 Schaden mit Wurfwaffen. 5 extra Dolche";
	a_skills(110, g_akt_spieler).f_beschreibung_1[1] = "+50% Attack and +2 Damage with throwing weapons. 5 extra Daggers";
	a_skills(110, g_akt_spieler).f_beschreibung_1[3] = "+50% Ataque y +2 Dano con armas para lanzar. 5 Dagas mas";
	a_skills(110, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(110, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(110, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(111, g_akt_spieler).f_name[2] = "Klettern";
	a_skills(111, g_akt_spieler).f_name[1] = "Climbing";
	a_skills(111, g_akt_spieler).f_name[3] = "Escalador";
	a_skills(111, g_akt_spieler).f_nummer = 111;
	a_skills(111, g_akt_spieler).f_gruppe = 7;
	a_skills(111, g_akt_spieler).f_kosten = 1;
	a_skills(111, g_akt_spieler).f_beschreibung_1[2] = "Erlaubt das Klettern ohne Seil";
	a_skills(111, g_akt_spieler).f_beschreibung_1[1] = "Allows climbing without rope";
	a_skills(111, g_akt_spieler).f_beschreibung_1[3] = "Permite escalar sin cuerda";
	a_skills(111, g_akt_spieler).f_beschreibung_2[2] = "(Du kannst durch Sch\344chte in den n\344chsten Level klettern)";
	a_skills(111, g_akt_spieler).f_beschreibung_2[1] = "(You can climb through Holes to the next level)";
	a_skills(111, g_akt_spieler).f_beschreibung_2[3] = "(Puedes escalar a traves de agujeros al proximo nivel)";
	a_skills(112, g_akt_spieler).f_name[2] = "Schwimmen";
	a_skills(112, g_akt_spieler).f_name[1] = "Swimming";
	a_skills(112, g_akt_spieler).f_name[3] = "Natacion";
	a_skills(112, g_akt_spieler).f_nummer = 112;
	a_skills(112, g_akt_spieler).f_gruppe = 7;
	a_skills(112, g_akt_spieler).f_kosten = 1;
	a_skills(112, g_akt_spieler).f_beschreibung_1[2] = "Erlaubt das \374berqueren von Fl\374ssen und Seen ohne Schaden";
	a_skills(112, g_akt_spieler).f_beschreibung_1[1] = "Allows the crossing of rivers and lakes without problems";
	a_skills(112, g_akt_spieler).f_beschreibung_1[3] = "Permite cruzar rios y lagos sin problemas";
	a_skills(112, g_akt_spieler).f_beschreibung_2[2] = "(Und Wasserfelder kosten nicht den Zug)";
	a_skills(112, g_akt_spieler).f_beschreibung_2[1] = "(And Watertiles do not cost the turn)";
	a_skills(112, g_akt_spieler).f_beschreibung_2[3] = "(Y campos con aqua no te cuestan el turno)";
	a_skills(113, g_akt_spieler).f_name[2] = "Kr\344uterkunde";
	a_skills(113, g_akt_spieler).f_name[1] = "Herb Lore";
	a_skills(113, g_akt_spieler).f_name[3] = "Conocimiento de hierbas";
	a_skills(113, g_akt_spieler).f_nummer = 113;
	a_skills(113, g_akt_spieler).f_gruppe = 7;
	a_skills(113, g_akt_spieler).f_kosten = 1;
	a_skills(113, g_akt_spieler).f_beschreibung_1[2] = "Kennt Wirkung aller Tr\344nke, Kr\344uter und Pilze im Labyrinth.";
	a_skills(113, g_akt_spieler).f_beschreibung_1[1] = "Knows effects of all potions, herbs and mushrooms in the Labyrinth";
	a_skills(113, g_akt_spieler).f_beschreibung_1[3] = "Conoce los efectos de todas las pociones, hierbas i hongos en el labirinto";
	a_skills(113, g_akt_spieler).f_beschreibung_2[2] = "Beginnt mit 5 Pilzen und 5 Heilk\344utern";
	a_skills(113, g_akt_spieler).f_beschreibung_2[1] = "Starts with 5 Mushrooms and 5 Healing Herbs";
	a_skills(113, g_akt_spieler).f_beschreibung_2[3] = "Empiece con 5 Hongos y 5 Hierbas de Curacion";
	a_skills(114, g_akt_spieler).f_name[2] = "Feilschen";
	a_skills(114, g_akt_spieler).f_name[1] = "Haggle";
	a_skills(114, g_akt_spieler).f_name[3] = "Regateo";
	a_skills(114, g_akt_spieler).f_nummer = 114;
	a_skills(114, g_akt_spieler).f_gruppe = 7;
	a_skills(114, g_akt_spieler).f_kosten = 1;
	a_skills(114, g_akt_spieler).f_beschreibung_1[2] = "Reduziert die Kosten von Gegenst\344nden beim Einkauf und Lehrer um 25%";
	a_skills(114, g_akt_spieler).f_beschreibung_1[1] = "Reduces the cost of goods and training by 25%";
	a_skills(114, g_akt_spieler).f_beschreibung_1[3] = "Reduce el coste de los objetos y entrenamiento en un 25%";
	a_skills(114, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(114, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(114, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(115, g_akt_spieler).f_name[2] = "Monsterkunde";
	a_skills(115, g_akt_spieler).f_name[1] = "Monster Lore";
	a_skills(115, g_akt_spieler).f_name[3] = "Conocimiento de monstruos";
	a_skills(115, g_akt_spieler).f_nummer = 115;
	a_skills(115, g_akt_spieler).f_gruppe = 7;
	a_skills(115, g_akt_spieler).f_kosten = 1;
	a_skills(115, g_akt_spieler).f_beschreibung_1[2] = "Gibt alle Werte eines Monsters preis";
	a_skills(115, g_akt_spieler).f_beschreibung_1[1] = "Shows all attributes of a monster";
	a_skills(115, g_akt_spieler).f_beschreibung_1[3] = "Muestra todos los atributos de un monstruo";
	a_skills(115, g_akt_spieler).f_beschreibung_2[2] = "(Funktioniert auch durch W\344nde)";
	a_skills(115, g_akt_spieler).f_beschreibung_2[1] = "(Works even through walls)";
	a_skills(115, g_akt_spieler).f_beschreibung_2[3] = "(Funciona a traves de pareds)";
	a_skills(116, g_akt_spieler).f_name[2] = "Giftkenntnis";
	a_skills(116, g_akt_spieler).f_name[1] = "Poisonlore";
	a_skills(116, g_akt_spieler).f_name[3] = "Conocimiento de Venenos";
	a_skills(116, g_akt_spieler).f_nummer = 116;
	a_skills(116, g_akt_spieler).f_gruppe = 7;
	a_skills(116, g_akt_spieler).f_kosten = 1;
	a_skills(116, g_akt_spieler).f_beschreibung_1[2] = "Erkennt Gifte. Beginnt mit 5 starken Giften. Giftkunde + 2";
	a_skills(116, g_akt_spieler).f_beschreibung_1[1] = "Identifies Poisons. Starts with 5 strong poisons. Poisonlore + 2";
	a_skills(116, g_akt_spieler).f_beschreibung_1[3] = "Identifica Venenos. Empiece con 5 venenos fuertes. Conocimiento de venenos + 2";
	a_skills(116, g_akt_spieler).f_beschreibung_2[2] = "(Damit k\366nnen Waffen und Munition vergiftet werden)";
	a_skills(116, g_akt_spieler).f_beschreibung_2[1] = "(You can poison weapons and amunition)";
	a_skills(116, g_akt_spieler).f_beschreibung_2[3] = "(Puedes envenenar armas y amunicion)";
	a_skills(117, g_akt_spieler).f_name[2] = "Tr\344ger";
	a_skills(117, g_akt_spieler).f_name[1] = "Heavy Carrier";
	a_skills(117, g_akt_spieler).f_name[3] = "Porteador";
	a_skills(117, g_akt_spieler).f_nummer = 117;
	a_skills(117, g_akt_spieler).f_gruppe = 7;
	a_skills(117, g_akt_spieler).f_kosten = 1;
	a_skills(117, g_akt_spieler).f_beschreibung_1[2] = "Unbegrenzte Tragekraft";
	a_skills(117, g_akt_spieler).f_beschreibung_1[1] = "Carried weight does not matter";
	a_skills(117, g_akt_spieler).f_beschreibung_1[3] = "Peso de las cosas portadas no importa";
	a_skills(117, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(117, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(117, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(118, g_akt_spieler).f_name[2] = "Native Magie";
	a_skills(118, g_akt_spieler).f_name[1] = "Native Sorcery";
	a_skills(118, g_akt_spieler).f_name[3] = "Magia nativo";
	a_skills(118, g_akt_spieler).f_nummer = 118;
	a_skills(118, g_akt_spieler).f_gruppe = 7;
	a_skills(118, g_akt_spieler).f_kosten = 1;
	a_skills(118, g_akt_spieler).f_beschreibung_1[2] = "Zirkel: 1";
	a_skills(118, g_akt_spieler).f_beschreibung_1[1] = "Spell Circle: 1";
	a_skills(118, g_akt_spieler).f_beschreibung_1[3] = "Circulo magico: 1";
	a_skills(118, g_akt_spieler).f_beschreibung_2[2] = "(Du bist schwach Magiebegabt)";
	a_skills(118, g_akt_spieler).f_beschreibung_2[1] = "(You know how to use a little magic)";
	a_skills(118, g_akt_spieler).f_beschreibung_2[3] = "(Sabes un poco magia)";
	a_skills(119, g_akt_spieler).f_name[2] = "Starke H\344nde";
	a_skills(119, g_akt_spieler).f_name[1] = "Monkey Grip";
	a_skills(119, g_akt_spieler).f_name[3] = "Manos fuertes";
	a_skills(119, g_akt_spieler).f_nummer = 119;
	a_skills(119, g_akt_spieler).f_gruppe = 7;
	a_skills(119, g_akt_spieler).f_kosten = 1;
	a_skills(119, g_akt_spieler).f_beschreibung_1[2] = "Zweihandwaffen mit einer Hand f\374hren";
	a_skills(119, g_akt_spieler).f_beschreibung_1[1] = "Use two-handed weapons with one hand";
	a_skills(119, g_akt_spieler).f_beschreibung_1[3] = "Usa armas por 2 manos con un mano";
	a_skills(119, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(119, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(119, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(120, g_akt_spieler).f_name[2] = "Nachteile";
	a_skills(120, g_akt_spieler).f_name[1] = "Flaws";
	a_skills(120, g_akt_spieler).f_name[3] = "Defectos";
	a_skills(120, g_akt_spieler).f_nummer = 0;
	a_skills(120, g_akt_spieler).f_kosten = 0;
	a_skills(120, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(120, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(120, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(120, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(120, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(120, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(121, g_akt_spieler).f_name[2] = "Schw\344chlich";
	a_skills(121, g_akt_spieler).f_name[1] = "Weak";
	a_skills(121, g_akt_spieler).f_name[3] = "Debil";
	a_skills(121, g_akt_spieler).f_nummer = 121;
	a_skills(121, g_akt_spieler).f_gruppe = 8;
	a_skills(121, g_akt_spieler).f_kosten = -2;
	a_skills(121, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit 10 Lebenspunkten. +2 pro Erfahrungsgewinn";
	a_skills(121, g_akt_spieler).f_beschreibung_1[1] = "Starts with 10 lifepoints. +2 per Experiance gain";
	a_skills(121, g_akt_spieler).f_beschreibung_1[3] = "Empieza con 10 puntos de vida. +2 per Experiencia";
	a_skills(121, g_akt_spieler).f_beschreibung_2[2] = "(Maximal 50 Lebenspunkte)";
	a_skills(121, g_akt_spieler).f_beschreibung_2[1] = "(Maximum 50 Lifepoints)";
	a_skills(121, g_akt_spieler).f_beschreibung_2[3] = "(Maximum 50 Puntos de Vida)";
	a_skills(122, g_akt_spieler).f_name[2] = "Armut";
	a_skills(122, g_akt_spieler).f_name[1] = "Poverty";
	a_skills(122, g_akt_spieler).f_name[3] = "Pobre";
	a_skills(122, g_akt_spieler).f_nummer = 122;
	a_skills(122, g_akt_spieler).f_gruppe = 8;
	a_skills(122, g_akt_spieler).f_kosten = -2;
	a_skills(122, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel ohne Gold und Ausr\374stung";
	a_skills(122, g_akt_spieler).f_beschreibung_1[1] = "Starts without any gold or equipment";
	a_skills(122, g_akt_spieler).f_beschreibung_1[3] = "Empieza sin oro ni equipamiento";
	a_skills(122, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(122, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(122, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(123, g_akt_spieler).f_name[2] = "Unaufmerksam";
	a_skills(123, g_akt_spieler).f_name[1] = "Unobservant";
	a_skills(123, g_akt_spieler).f_name[3] = "Despistado";
	a_skills(123, g_akt_spieler).f_nummer = 123;
	a_skills(123, g_akt_spieler).f_gruppe = 8;
	a_skills(123, g_akt_spieler).f_kosten = -2;
	a_skills(123, g_akt_spieler).f_beschreibung_1[2] = "Charakter findet keine Fallen, Geheimt\374ren,";
	a_skills(123, g_akt_spieler).f_beschreibung_1[1] = "The character can't find traps, secret doors,";
	a_skills(123, g_akt_spieler).f_beschreibung_1[3] = "El personaje no encuentra trampas, puertas secretas,";
	a_skills(123, g_akt_spieler).f_beschreibung_2[2] = "Pilze und verborgene Sch\344tze";
	a_skills(123, g_akt_spieler).f_beschreibung_2[1] = "mushrooms and hidden treasure";
	a_skills(123, g_akt_spieler).f_beschreibung_2[3] = "hongos y tesoros escondidos";
	a_skills(124, g_akt_spieler).f_name[2] = "Geringes Mana";
	a_skills(124, g_akt_spieler).f_name[1] = "Low Mana";
	a_skills(124, g_akt_spieler).f_name[3] = "Bajo Mana";
	a_skills(124, g_akt_spieler).f_nummer = 124;
	a_skills(124, g_akt_spieler).f_gruppe = 8;
	a_skills(124, g_akt_spieler).f_kosten = -2;
	a_skills(124, g_akt_spieler).f_beschreibung_1[2] = "Beginnt das Spiel mit einem Manapunkt. +2 pro Erfahrungsgewinn";
	a_skills(124, g_akt_spieler).f_beschreibung_1[1] = "Starts with one mana point. +2 per Experiance Gain";
	a_skills(124, g_akt_spieler).f_beschreibung_1[3] = "Empieza con un punto de man. +2 con experiencia";
	a_skills(124, g_akt_spieler).f_beschreibung_2[2] = "(Maximal 50 Manapunkte)";
	a_skills(124, g_akt_spieler).f_beschreibung_2[1] = "(Maximum 50 Manapoints)";
	a_skills(124, g_akt_spieler).f_beschreibung_2[3] = "(Maximum 50 Puntos de Mana)";
	a_skills(125, g_akt_spieler).f_name[2] = "Schw\344che: Gift";
	a_skills(125, g_akt_spieler).f_name[1] = "Poison Weakness";
	a_skills(125, g_akt_spieler).f_name[3] = "Debilidad al veneno";
	a_skills(125, g_akt_spieler).f_nummer = 125;
	a_skills(125, g_akt_spieler).f_gruppe = 8;
	a_skills(125, g_akt_spieler).f_kosten = -2;
	a_skills(125, g_akt_spieler).f_beschreibung_1[2] = "Doppelter Schaden durch Gift";
	a_skills(125, g_akt_spieler).f_beschreibung_1[1] = "Poison does double damage";
	a_skills(125, g_akt_spieler).f_beschreibung_1[3] = "El veneno hace el doble de dano";
	a_skills(125, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(125, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(125, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(126, g_akt_spieler).f_name[2] = "Schw\344che: Magie";
	a_skills(126, g_akt_spieler).f_name[1] = "Magic Weakness";
	a_skills(126, g_akt_spieler).f_name[3] = "Debilidad a la magia";
	a_skills(126, g_akt_spieler).f_nummer = 126;
	a_skills(126, g_akt_spieler).f_gruppe = 8;
	a_skills(126, g_akt_spieler).f_kosten = -2;
	a_skills(126, g_akt_spieler).f_beschreibung_1[2] = "Doppelter Schaden durch feindliche Magie";
	a_skills(126, g_akt_spieler).f_beschreibung_1[1] = "Hostile magic does double damage";
	a_skills(126, g_akt_spieler).f_beschreibung_1[3] = "La magia hostil hace el doble de dano";
	a_skills(126, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(126, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(126, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(127, g_akt_spieler).f_name[2] = "Verflucht";
	a_skills(127, g_akt_spieler).f_name[1] = "Cursed";
	a_skills(127, g_akt_spieler).f_name[3] = "Maldito";
	a_skills(127, g_akt_spieler).f_nummer = 127;
	a_skills(127, g_akt_spieler).f_gruppe = 8;
	a_skills(127, g_akt_spieler).f_kosten = -2;
	a_skills(127, g_akt_spieler).f_beschreibung_1[2] = "Fl\374che haben doppelte Dauer.";
	a_skills(127, g_akt_spieler).f_beschreibung_1[1] = "Double duration for all curses.";
	a_skills(127, g_akt_spieler).f_beschreibung_1[3] = "Doble duracion para las maldiciones.";
	a_skills(127, g_akt_spieler).f_beschreibung_2[2] = "Mit 20%+Level neuen Fluch in neuer Ebene";
	a_skills(127, g_akt_spieler).f_beschreibung_2[1] = "With 20%+Level new curse every new level";
	a_skills(127, g_akt_spieler).f_beschreibung_2[3] = "Con 20%+Nivel nuevo malicion en nuevo nivel";
	a_skills(128, g_akt_spieler).f_name[2] = "Gottlos";
	a_skills(128, g_akt_spieler).f_name[1] = "Forsaken";
	a_skills(128, g_akt_spieler).f_name[3] = "Desamparado";
	a_skills(128, g_akt_spieler).f_nummer = 128;
	a_skills(128, g_akt_spieler).f_gruppe = 8;
	a_skills(128, g_akt_spieler).f_kosten = -2;
	a_skills(128, g_akt_spieler).f_beschreibung_1[2] = "Keine Heilung im Sanktum";
	a_skills(128, g_akt_spieler).f_beschreibung_1[1] = "No healing in Sanctum";
	a_skills(128, g_akt_spieler).f_beschreibung_1[3] = "El Sanctum no cura";
	a_skills(128, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(128, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(128, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(129, g_akt_spieler).f_name[2] = "Kurzsichtig";
	a_skills(129, g_akt_spieler).f_name[1] = "Short Sighted";
	a_skills(129, g_akt_spieler).f_name[3] = "Corto de vista";
	a_skills(129, g_akt_spieler).f_nummer = 129;
	a_skills(129, g_akt_spieler).f_gruppe = 8;
	a_skills(129, g_akt_spieler).f_kosten = -2;
	a_skills(129, g_akt_spieler).f_beschreibung_1[2] = "Sichtradius ist immer halbiert";
	a_skills(129, g_akt_spieler).f_beschreibung_1[1] = "Sight radius is always halved";
	a_skills(129, g_akt_spieler).f_beschreibung_1[3] = "El radio de vision se reduce de la mitad";
	a_skills(129, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(129, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(129, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(130, g_akt_spieler).f_name[2] = "Dumm";
	a_skills(130, g_akt_spieler).f_name[1] = "Stupid";
	a_skills(130, g_akt_spieler).f_name[3] = "Estupido";
	a_skills(130, g_akt_spieler).f_nummer = 130;
	a_skills(130, g_akt_spieler).f_gruppe = 8;
	a_skills(130, g_akt_spieler).f_kosten = -2;
	a_skills(130, g_akt_spieler).f_beschreibung_1[2] = "Gewinnt 3 mal keine Erfahrung";
	a_skills(130, g_akt_spieler).f_beschreibung_1[1] = "No experience for 3 times";
	a_skills(130, g_akt_spieler).f_beschreibung_1[3] = "No se gana experiencia durante 3 veces";
	a_skills(130, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(130, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(130, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(131, g_akt_spieler).f_name[2] = "Ausgestossen";
	a_skills(131, g_akt_spieler).f_name[1] = "Outcast";
	a_skills(131, g_akt_spieler).f_name[3] = "Abandonado";
	a_skills(131, g_akt_spieler).f_nummer = 131;
	a_skills(131, g_akt_spieler).f_gruppe = 8;
	a_skills(131, g_akt_spieler).f_kosten = -2;
	a_skills(131, g_akt_spieler).f_beschreibung_1[2] = "Alle H\344ndler und Lehrer fl\374chten vor dir";
	a_skills(131, g_akt_spieler).f_beschreibung_1[1] = "All merchants and trainers flee from you";
	a_skills(131, g_akt_spieler).f_beschreibung_1[3] = "Todos los comerciantes y profesores se escapan de ti";
	a_skills(131, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(131, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(131, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(132, g_akt_spieler).f_name[2] = "Disjunct";
	a_skills(132, g_akt_spieler).f_name[1] = "Disjunct";
	a_skills(132, g_akt_spieler).f_name[3] = "Antirecarga";
	a_skills(132, g_akt_spieler).f_nummer = 132;
	a_skills(132, g_akt_spieler).f_gruppe = 8;
	a_skills(132, g_akt_spieler).f_kosten = -2;
	a_skills(132, g_akt_spieler).f_beschreibung_1[2] = "Dein Mana wird nicht am Nexus regeneriert";
	a_skills(132, g_akt_spieler).f_beschreibung_1[1] = "Your mana no replenishes at the nexus";
	a_skills(132, g_akt_spieler).f_beschreibung_1[3] = "Tu mana no se recarga en el nexus";
	a_skills(132, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(132, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(132, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(133, g_akt_spieler).f_name[2] = "Keine Basismagie";
	a_skills(133, g_akt_spieler).f_name[1] = "No Basic Magic";
	a_skills(133, g_akt_spieler).f_name[3] = "No Magia Basica";
	a_skills(133, g_akt_spieler).f_nummer = 133;
	a_skills(133, g_akt_spieler).f_gruppe = 8;
	a_skills(133, g_akt_spieler).f_kosten = -2;
	a_skills(133, g_akt_spieler).f_beschreibung_1[2] = "Du kannst keine Basismagie lernen";
	a_skills(133, g_akt_spieler).f_beschreibung_1[1] = "You can't learn Basic Magic";
	a_skills(133, g_akt_spieler).f_beschreibung_1[3] = "No puedes aprender Magia Basica";
	a_skills(133, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(133, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(133, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(134, g_akt_spieler).f_name[2] = "Kurze Magie";
	a_skills(134, g_akt_spieler).f_name[1] = "Short Magic";
	a_skills(134, g_akt_spieler).f_name[3] = "Magia Corta";
	a_skills(134, g_akt_spieler).f_nummer = 134;
	a_skills(134, g_akt_spieler).f_gruppe = 8;
	a_skills(134, g_akt_spieler).f_kosten = -2;
	a_skills(134, g_akt_spieler).f_beschreibung_1[2] = "Die Dauer deiner Spr\374che ist halbiert";
	a_skills(134, g_akt_spieler).f_beschreibung_1[1] = "The duration of your Spells is halved";
	a_skills(134, g_akt_spieler).f_beschreibung_1[3] = "La duracion de sus hechizos es la mitad";
	a_skills(134, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(134, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(134, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(135, g_akt_spieler).f_name[2] = "Lahm";
	a_skills(135, g_akt_spieler).f_name[1] = "Lame";
	a_skills(135, g_akt_spieler).f_name[3] = "Postrado";
	a_skills(135, g_akt_spieler).f_nummer = 135;
	a_skills(135, g_akt_spieler).f_gruppe = 8;
	a_skills(135, g_akt_spieler).f_kosten = -2;
	a_skills(135, g_akt_spieler).f_beschreibung_1[2] = "Zugweite halbiert";
	a_skills(135, g_akt_spieler).f_beschreibung_1[1] = "Speed halved";
	a_skills(135, g_akt_spieler).f_beschreibung_1[3] = "La velocidad se reduce de la mitad";
	a_skills(135, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(135, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(135, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(136, g_akt_spieler).f_name[2] = "Kein Angriff";
	a_skills(136, g_akt_spieler).f_name[1] = "No attacking";
	a_skills(136, g_akt_spieler).f_name[3] = "No ataque";
	a_skills(136, g_akt_spieler).f_nummer = 136;
	a_skills(136, g_akt_spieler).f_gruppe = 8;
	a_skills(136, g_akt_spieler).f_kosten = -2;
	a_skills(136, g_akt_spieler).f_beschreibung_1[2] = "Du kannst nie einen Gegner";
	a_skills(136, g_akt_spieler).f_beschreibung_1[1] = "You can never attack in";
	a_skills(136, g_akt_spieler).f_beschreibung_1[3] = "Nunca puedes atacar en";
	a_skills(136, g_akt_spieler).f_beschreibung_2[2] = "im Nahkampf angreifen";
	a_skills(136, g_akt_spieler).f_beschreibung_2[1] = "closed range combat";
	a_skills(136, g_akt_spieler).f_beschreibung_2[3] = "combate cerca";
	a_skills(137, g_akt_spieler).f_name[2] = "Sekund\344re Nachteile";
	a_skills(137, g_akt_spieler).f_name[1] = "Secondary Flaws";
	a_skills(137, g_akt_spieler).f_name[3] = "Defectos Segundarios";
	a_skills(137, g_akt_spieler).f_nummer = 0;
	a_skills(137, g_akt_spieler).f_kosten = 0;
	a_skills(137, g_akt_spieler).f_beschreibung_1[2] = "";
	a_skills(137, g_akt_spieler).f_beschreibung_1[1] = "";
	a_skills(137, g_akt_spieler).f_beschreibung_1[3] = "";
	a_skills(137, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(137, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(137, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(138, g_akt_spieler).f_name[2] = "Schwache Arme";
	a_skills(138, g_akt_spieler).f_name[1] = "Weak arms";
	a_skills(138, g_akt_spieler).f_name[3] = "Brazos debiles";
	a_skills(138, g_akt_spieler).f_nummer = 138;
	a_skills(138, g_akt_spieler).f_gruppe = 9;
	a_skills(138, g_akt_spieler).f_kosten = -1;
	a_skills(138, g_akt_spieler).f_beschreibung_1[2] = "Du kannst keine Waffen f\374hren";
	a_skills(138, g_akt_spieler).f_beschreibung_1[1] = "You can't use weapons";
	a_skills(138, g_akt_spieler).f_beschreibung_1[3] = "No se puede usar armas";
	a_skills(138, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(138, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(138, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(139, g_akt_spieler).f_name[2] = "Schwache finger";
	a_skills(139, g_akt_spieler).f_name[1] = "Weak fingers";
	a_skills(139, g_akt_spieler).f_name[3] = "Dedos debiles";
	a_skills(139, g_akt_spieler).f_nummer = 139;
	a_skills(139, g_akt_spieler).f_gruppe = 9;
	a_skills(139, g_akt_spieler).f_kosten = -1;
	a_skills(139, g_akt_spieler).f_beschreibung_1[2] = "Du kannst keine Bogen f\374hren";
	a_skills(139, g_akt_spieler).f_beschreibung_1[1] = "You can't use bows";
	a_skills(139, g_akt_spieler).f_beschreibung_1[3] = "No se puede usar arcos";
	a_skills(139, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(139, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(139, g_akt_spieler).f_beschreibung_2[3] = "";
	a_skills(140, g_akt_spieler).f_name[2] = "Verunstaltet";
	a_skills(140, g_akt_spieler).f_name[1] = "Disfigured";
	a_skills(140, g_akt_spieler).f_name[3] = "Disfigurado";
	a_skills(140, g_akt_spieler).f_nummer = 140;
	a_skills(140, g_akt_spieler).f_gruppe = 9;
	a_skills(140, g_akt_spieler).f_kosten = -1;
	a_skills(140, g_akt_spieler).f_beschreibung_1[2] = "Du kannst keine R\374stung anziehen";
	a_skills(140, g_akt_spieler).f_beschreibung_1[1] = "You can't use armor";
	a_skills(140, g_akt_spieler).f_beschreibung_1[3] = "No se puede usar armadura";
	a_skills(140, g_akt_spieler).f_beschreibung_2[2] = "";
	a_skills(140, g_akt_spieler).f_beschreibung_2[1] = "";
	a_skills(140, g_akt_spieler).f_beschreibung_2[3] = "";
	a_unmoeglich(1).f_name = 128;
	a_unmoeglich(1).f_locked = 51;
	a_unmoeglich(2).f_name = 51;
	a_unmoeglich(2).f_locked = 127;
	a_unmoeglich(3).f_name = 128;
	a_unmoeglich(3).f_locked = 102;
	a_unmoeglich(4).f_name = 127;
	a_unmoeglich(4).f_locked = 51;
	a_unmoeglich(5).f_name = 127;
	a_unmoeglich(5).f_locked = 102;
	a_unmoeglich(6).f_name = 126;
	a_unmoeglich(6).f_locked = 42;
	a_unmoeglich(7).f_name = 42;
	a_unmoeglich(7).f_locked = 126;
	a_unmoeglich(8).f_name = 126;
	a_unmoeglich(8).f_locked = 59;
	a_unmoeglich(9).f_name = 59;
	a_unmoeglich(9).f_locked = 126;
	a_unmoeglich(10).f_name = 125;
	a_unmoeglich(10).f_locked = 84;
	a_unmoeglich(11).f_name = 84;
	a_unmoeglich(11).f_locked = 125;
	a_unmoeglich(12).f_name = 125;
	a_unmoeglich(12).f_locked = 51;
	a_unmoeglich(13).f_name = 124;
	a_unmoeglich(13).f_locked = 39;
	a_unmoeglich(14).f_name = 39;
	a_unmoeglich(14).f_locked = 124;
	a_unmoeglich(15).f_name = 123;
	a_unmoeglich(15).f_locked = 70;
	a_unmoeglich(16).f_name = 70;
	a_unmoeglich(16).f_locked = 123;
	a_unmoeglich(17).f_name = 123;
	a_unmoeglich(17).f_locked = 69;
	a_unmoeglich(18).f_name = 69;
	a_unmoeglich(18).f_locked = 123;
	a_unmoeglich(19).f_name = 122;
	a_unmoeglich(19).f_locked = 88;
	a_unmoeglich(20).f_name = 88;
	a_unmoeglich(20).f_locked = 122;
	a_unmoeglich(21).f_name = 122;
	a_unmoeglich(21).f_locked = 87;
	a_unmoeglich(22).f_name = 87;
	a_unmoeglich(22).f_locked = 122;
	a_unmoeglich(23).f_name = 122;
	a_unmoeglich(23).f_locked = 9;
	a_unmoeglich(24).f_name = 9;
	a_unmoeglich(24).f_locked = 122;
	a_unmoeglich(25).f_name = 121;
	a_unmoeglich(25).f_locked = 3;
	a_unmoeglich(26).f_name = 3;
	a_unmoeglich(26).f_locked = 121;
	a_unmoeglich(27).f_name = 121;
	a_unmoeglich(27).f_locked = 2;
	a_unmoeglich(28).f_name = 2;
	a_unmoeglich(28).f_locked = 121;
	a_unmoeglich(29).f_name = 121;
	a_unmoeglich(29).f_locked = 8;
	a_unmoeglich(30).f_name = 8;
	a_unmoeglich(30).f_locked = 121;
	a_unmoeglich(31).f_name = 121;
	a_unmoeglich(31).f_locked = 4;
	a_unmoeglich(32).f_name = 4;
	a_unmoeglich(32).f_locked = 121;
	a_unmoeglich(33).f_name = 129;
	a_unmoeglich(33).f_locked = 70;
	a_unmoeglich(34).f_name = 70;
	a_unmoeglich(34).f_locked = 129;
	a_unmoeglich(35).f_name = 129;
	a_unmoeglich(35).f_locked = 71;
	a_unmoeglich(36).f_name = 71;
	a_unmoeglich(36).f_locked = 129;
	a_unmoeglich(37).f_name = 129;
	a_unmoeglich(37).f_locked = 48;
	a_unmoeglich(38).f_name = 48;
	a_unmoeglich(38).f_locked = 129;
	a_unmoeglich(39).f_name = 130;
	a_unmoeglich(39).f_locked = 90;
	a_unmoeglich(40).f_name = 90;
	a_unmoeglich(40).f_locked = 130;
	a_unmoeglich(41).f_name = 52;
	a_unmoeglich(41).f_locked = 51;
	a_unmoeglich(42).f_name = 51;
	a_unmoeglich(42).f_locked = 52;
	a_unmoeglich(43).f_name = 51;
	a_unmoeglich(43).f_locked = 128;
	a_unmoeglich(44).f_name = 51;
	a_unmoeglich(44).f_locked = 125;
	a_unmoeglich(45).f_name = 128;
	a_unmoeglich(45).f_locked = 51;
	a_unmoeglich(46).f_name = 131;
	a_unmoeglich(46).f_locked = 114;
	a_unmoeglich(47).f_name = 114;
	a_unmoeglich(47).f_locked = 131;
	a_unmoeglich(48).f_name = 132;
	a_unmoeglich(48).f_locked = 36;
	a_unmoeglich(49).f_name = 36;
	a_unmoeglich(49).f_locked = 132;
	a_unmoeglich(50).f_name = 123;
	a_unmoeglich(50).f_locked = 77;
	a_unmoeglich(51).f_name = 77;
	a_unmoeglich(51).f_locked = 123;
	a_unmoeglich(52).f_name = 128;
	a_unmoeglich(52).f_locked = 103;
	a_unmoeglich(53).f_name = 128;
	a_unmoeglich(53).f_locked = 104;
	a_unmoeglich(54).f_name = 128;
	a_unmoeglich(54).f_locked = 105;
	a_unmoeglich(55).f_name = 128;
	a_unmoeglich(55).f_locked = 106;
	a_unmoeglich(56).f_name = 128;
	a_unmoeglich(56).f_locked = 107;
	a_unmoeglich(57).f_name = 128;
	a_unmoeglich(57).f_locked = 108;
	a_unmoeglich(58).f_name = 103;
	a_unmoeglich(58).f_locked = 128;
	a_unmoeglich(59).f_name = 104;
	a_unmoeglich(59).f_locked = 128;
	a_unmoeglich(60).f_name = 105;
	a_unmoeglich(60).f_locked = 128;
	a_unmoeglich(61).f_name = 106;
	a_unmoeglich(61).f_locked = 128;
	a_unmoeglich(62).f_name = 107;
	a_unmoeglich(62).f_locked = 128;
	a_unmoeglich(63).f_name = 108;
	a_unmoeglich(63).f_locked = 128;
	a_unmoeglich(64).f_name = 134;
	a_unmoeglich(64).f_locked = 61;
	a_unmoeglich(65).f_name = 61;
	a_unmoeglich(65).f_locked = 134;
	a_unmoeglich(66).f_name = 103;
	a_unmoeglich(66).f_locked = 104;
	a_unmoeglich(67).f_name = 103;
	a_unmoeglich(67).f_locked = 105;
	a_unmoeglich(68).f_name = 103;
	a_unmoeglich(68).f_locked = 106;
	a_unmoeglich(69).f_name = 103;
	a_unmoeglich(69).f_locked = 107;
	a_unmoeglich(70).f_name = 103;
	a_unmoeglich(70).f_locked = 108;
	a_unmoeglich(71).f_name = 104;
	a_unmoeglich(71).f_locked = 103;
	a_unmoeglich(72).f_name = 104;
	a_unmoeglich(72).f_locked = 105;
	a_unmoeglich(73).f_name = 104;
	a_unmoeglich(73).f_locked = 106;
	a_unmoeglich(74).f_name = 104;
	a_unmoeglich(74).f_locked = 107;
	a_unmoeglich(75).f_name = 104;
	a_unmoeglich(75).f_locked = 108;
	a_unmoeglich(76).f_name = 105;
	a_unmoeglich(76).f_locked = 103;
	a_unmoeglich(77).f_name = 105;
	a_unmoeglich(77).f_locked = 104;
	a_unmoeglich(78).f_name = 105;
	a_unmoeglich(78).f_locked = 106;
	a_unmoeglich(79).f_name = 105;
	a_unmoeglich(79).f_locked = 107;
	a_unmoeglich(80).f_name = 105;
	a_unmoeglich(80).f_locked = 108;
	a_unmoeglich(81).f_name = 106;
	a_unmoeglich(81).f_locked = 103;
	a_unmoeglich(82).f_name = 106;
	a_unmoeglich(82).f_locked = 104;
	a_unmoeglich(83).f_name = 106;
	a_unmoeglich(83).f_locked = 105;
	a_unmoeglich(84).f_name = 106;
	a_unmoeglich(84).f_locked = 107;
	a_unmoeglich(85).f_name = 106;
	a_unmoeglich(85).f_locked = 108;
	a_unmoeglich(86).f_name = 107;
	a_unmoeglich(86).f_locked = 103;
	a_unmoeglich(87).f_name = 107;
	a_unmoeglich(87).f_locked = 104;
	a_unmoeglich(88).f_name = 107;
	a_unmoeglich(88).f_locked = 105;
	a_unmoeglich(89).f_name = 107;
	a_unmoeglich(89).f_locked = 106;
	a_unmoeglich(90).f_name = 107;
	a_unmoeglich(90).f_locked = 108;
	a_unmoeglich(91).f_name = 108;
	a_unmoeglich(91).f_locked = 103;
	a_unmoeglich(92).f_name = 108;
	a_unmoeglich(92).f_locked = 104;
	a_unmoeglich(93).f_name = 108;
	a_unmoeglich(93).f_locked = 105;
	a_unmoeglich(94).f_name = 108;
	a_unmoeglich(94).f_locked = 106;
	a_unmoeglich(95).f_name = 108;
	a_unmoeglich(95).f_locked = 107;
	a_unmoeglich(96).f_name = 62;
	a_unmoeglich(96).f_locked = 55;
	a_unmoeglich(97).f_name = 62;
	a_unmoeglich(97).f_locked = 53;
	a_unmoeglich(98).f_name = 62;
	a_unmoeglich(98).f_locked = 54;
	a_unmoeglich(99).f_name = 55;
	a_unmoeglich(99).f_locked = 62;
	a_unmoeglich(100).f_name = 53;
	a_unmoeglich(100).f_locked = 62;
	a_unmoeglich(101).f_name = 54;
	a_unmoeglich(101).f_locked = 62;
	a_unmoeglich(102).f_name = 94;
	a_unmoeglich(102).f_locked = 131;
	a_unmoeglich(103).f_name = 131;
	a_unmoeglich(103).f_locked = 94;
	a_unmoeglich(104).f_name = 42;
	a_unmoeglich(104).f_locked = 127;
	a_unmoeglich(105).f_name = 127;
	a_unmoeglich(105).f_locked = 42;
	a_unmoeglich(106).f_name = 13;
	a_unmoeglich(106).f_locked = 14;
	a_unmoeglich(107).f_name = 13;
	a_unmoeglich(107).f_locked = 15;
	a_unmoeglich(108).f_name = 14;
	a_unmoeglich(108).f_locked = 13;
	a_unmoeglich(109).f_name = 14;
	a_unmoeglich(109).f_locked = 15;
	a_unmoeglich(110).f_name = 15;
	a_unmoeglich(110).f_locked = 13;
	a_unmoeglich(111).f_name = 15;
	a_unmoeglich(111).f_locked = 14;
	a_unmoeglich(112).f_name = 26;
	a_unmoeglich(112).f_locked = 78;
	a_unmoeglich(113).f_name = 26;
	a_unmoeglich(113).f_locked = 63;
	a_unmoeglich(114).f_name = 78;
	a_unmoeglich(114).f_locked = 26;
	a_unmoeglich(115).f_name = 78;
	a_unmoeglich(115).f_locked = 63;
	a_unmoeglich(116).f_name = 63;
	a_unmoeglich(116).f_locked = 26;
	a_unmoeglich(117).f_name = 63;
	a_unmoeglich(117).f_locked = 78;
	a_unmoeglich(118).f_name = 63;
	a_unmoeglich(118).f_locked = 131;
	a_unmoeglich(119).f_name = 78;
	a_unmoeglich(119).f_locked = 131;
	a_unmoeglich(120).f_name = 26;
	a_unmoeglich(120).f_locked = 131;
	a_unmoeglich(121).f_name = 131;
	a_unmoeglich(121).f_locked = 63;
	a_unmoeglich(122).f_name = 131;
	a_unmoeglich(122).f_locked = 78;
	a_unmoeglich(123).f_name = 131;
	a_unmoeglich(123).f_locked = 26;
	a_unmoeglich(124).f_name = 78;
	a_unmoeglich(124).f_locked = 135;
	a_unmoeglich(125).f_name = 135;
	a_unmoeglich(125).f_locked = 78;
	a_unmoeglich(126).f_name = 56;
	a_unmoeglich(126).f_locked = 135;
	a_unmoeglich(127).f_name = 135;
	a_unmoeglich(127).f_locked = 56;
	a_unmoeglich(128).f_name = 95;
	a_unmoeglich(128).f_locked = 123;
	a_unmoeglich(129).f_name = 123;
	a_unmoeglich(129).f_locked = 95;
	a_unmoeglich(130).f_name = 95;
	a_unmoeglich(130).f_locked = 129;
	a_unmoeglich(131).f_name = 129;
	a_unmoeglich(131).f_locked = 95;
	a_unmoeglich(132).f_name = 72;
	a_unmoeglich(132).f_locked = 135;
	a_unmoeglich(133).f_name = 135;
	a_unmoeglich(133).f_locked = 72;
	a_unmoeglich(134).f_name = 56;
	a_unmoeglich(134).f_locked = 62;
	a_unmoeglich(135).f_name = 62;
	a_unmoeglich(135).f_locked = 56;
	a_unmoeglich(136).f_name = 17;
	a_unmoeglich(136).f_locked = 121;
	a_unmoeglich(137).f_name = 121;
	a_unmoeglich(137).f_locked = 17;
	a_unmoeglich(138).f_name = 133;
	a_unmoeglich(138).f_locked = 134;
	a_unmoeglich(139).f_name = 134;
	a_unmoeglich(139).f_locked = 133;
	a_unmoeglich(140).f_name = 117;
	a_unmoeglich(140).f_locked = 121;
	a_unmoeglich(141).f_name = 121;
	a_unmoeglich(141).f_locked = 117;
	a_unmoeglich(142).f_name = 134;
	a_unmoeglich(142).f_locked = 97;
	a_unmoeglich(143).f_name = 97;
	a_unmoeglich(143).f_locked = 134;
	a_unmoeglich(144).f_name = 134;
	a_unmoeglich(144).f_locked = 42;
	a_unmoeglich(145).f_name = 42;
	a_unmoeglich(145).f_locked = 134;
	a_unmoeglich(146).f_name = 65;
	a_unmoeglich(146).f_locked = 133;
	a_unmoeglich(147).f_name = 133;
	a_unmoeglich(147).f_locked = 65;
	a_unmoeglich(148).f_name = 72;
	a_unmoeglich(148).f_locked = 78;
	a_unmoeglich(149).f_name = 78;
	a_unmoeglich(149).f_locked = 72;
	a_unmoeglich(150).f_name = 1;
	a_unmoeglich(150).f_locked = 136;
	a_unmoeglich(151).f_name = 136;
	a_unmoeglich(151).f_locked = 1;
	a_unmoeglich(152).f_name = 4;
	a_unmoeglich(152).f_locked = 136;
	a_unmoeglich(153).f_name = 136;
	a_unmoeglich(153).f_locked = 4;
	a_unmoeglich(154).f_name = 7;
	a_unmoeglich(154).f_locked = 136;
	a_unmoeglich(155).f_name = 136;
	a_unmoeglich(155).f_locked = 7;
	a_unmoeglich(156).f_name = 10;
	a_unmoeglich(156).f_locked = 136;
	a_unmoeglich(157).f_name = 136;
	a_unmoeglich(157).f_locked = 10;
	a_unmoeglich(158).f_name = 11;
	a_unmoeglich(158).f_locked = 136;
	a_unmoeglich(159).f_name = 136;
	a_unmoeglich(159).f_locked = 11;
	a_unmoeglich(160).f_name = 12;
	a_unmoeglich(160).f_locked = 136;
	a_unmoeglich(161).f_name = 136;
	a_unmoeglich(161).f_locked = 12;
	a_unmoeglich(162).f_name = 17;
	a_unmoeglich(162).f_locked = 136;
	a_unmoeglich(163).f_name = 136;
	a_unmoeglich(163).f_locked = 17;
	a_unmoeglich(164).f_name = 18;
	a_unmoeglich(164).f_locked = 136;
	a_unmoeglich(165).f_name = 136;
	a_unmoeglich(165).f_locked = 18;
	a_unmoeglich(166).f_name = 19;
	a_unmoeglich(166).f_locked = 136;
	a_unmoeglich(167).f_name = 136;
	a_unmoeglich(167).f_locked = 19;
	a_unmoeglich(168).f_name = 20;
	a_unmoeglich(168).f_locked = 136;
	a_unmoeglich(169).f_name = 136;
	a_unmoeglich(169).f_locked = 20;
	a_unmoeglich(170).f_name = 21;
	a_unmoeglich(170).f_locked = 136;
	a_unmoeglich(171).f_name = 136;
	a_unmoeglich(171).f_locked = 21;
	a_unmoeglich(172).f_name = 22;
	a_unmoeglich(172).f_locked = 136;
	a_unmoeglich(173).f_name = 136;
	a_unmoeglich(173).f_locked = 22;
	a_unmoeglich(174).f_name = 23;
	a_unmoeglich(174).f_locked = 136;
	a_unmoeglich(175).f_name = 136;
	a_unmoeglich(175).f_locked = 23;
	a_unmoeglich(176).f_name = 24;
	a_unmoeglich(176).f_locked = 136;
	a_unmoeglich(177).f_name = 136;
	a_unmoeglich(177).f_locked = 24;
	a_unmoeglich(178).f_name = 25;
	a_unmoeglich(178).f_locked = 136;
	a_unmoeglich(179).f_name = 136;
	a_unmoeglich(179).f_locked = 25;
	a_unmoeglich(180).f_name = 13;
	a_unmoeglich(180).f_locked = 136;
	a_unmoeglich(181).f_name = 136;
	a_unmoeglich(181).f_locked = 13;
	a_unmoeglich(182).f_name = 14;
	a_unmoeglich(182).f_locked = 136;
	a_unmoeglich(183).f_name = 136;
	a_unmoeglich(183).f_locked = 14;
	a_unmoeglich(184).f_name = 15;
	a_unmoeglich(184).f_locked = 136;
	a_unmoeglich(185).f_name = 136;
	a_unmoeglich(185).f_locked = 15;
	a_unmoeglich(186).f_name = 26;
	a_unmoeglich(186).f_locked = 136;
	a_unmoeglich(187).f_name = 136;
	a_unmoeglich(187).f_locked = 26;
	a_unmoeglich(188).f_name = 89;
	a_unmoeglich(188).f_locked = 130;
	a_unmoeglich(189).f_name = 130;
	a_unmoeglich(189).f_locked = 89;
	a_unmoeglich(190).f_name = 13;
	a_unmoeglich(190).f_locked = 16;
	a_unmoeglich(191).f_name = 16;
	a_unmoeglich(191).f_locked = 13;
	a_unmoeglich(192).f_name = 14;
	a_unmoeglich(192).f_locked = 16;
	a_unmoeglich(193).f_name = 16;
	a_unmoeglich(193).f_locked = 14;
	a_unmoeglich(194).f_name = 15;
	a_unmoeglich(194).f_locked = 16;
	a_unmoeglich(195).f_name = 16;
	a_unmoeglich(195).f_locked = 15;
	a_unmoeglich(196).f_name = 135;
	a_unmoeglich(196).f_locked = 72;
	a_unmoeglich(197).f_name = 72;
	a_unmoeglich(197).f_locked = 135;
	a_unmoeglich(198).f_name = 135;
	a_unmoeglich(198).f_locked = 78;
	a_unmoeglich(199).f_name = 78;
	a_unmoeglich(199).f_locked = 135;
	a_unmoeglich(200).f_name = 79;
	a_unmoeglich(200).f_locked = 123;
	a_unmoeglich(201).f_name = 123;
	a_unmoeglich(201).f_locked = 79;
	a_unmoeglich(202).f_name = 37;
	a_unmoeglich(202).f_locked = 118;
	a_unmoeglich(203).f_name = 118;
	a_unmoeglich(203).f_locked = 37;
	a_unmoeglich(204).f_name = 136;
	a_unmoeglich(204).f_locked = 138;
	a_unmoeglich(205).f_name = 138;
	a_unmoeglich(205).f_locked = 136;
	a_unmoeglich(206).f_name = 51;
	a_unmoeglich(206).f_locked = 128;
	a_unmoeglich(207).f_name = 127;
	a_unmoeglich(207).f_locked = 51;
	a_unmoeglich(208).f_name = 102;
	a_unmoeglich(208).f_locked = 128;
	a_unmoeglich(209).f_name = 51;
	a_unmoeglich(209).f_locked = 127;
	a_unmoeglich(210).f_name = 102;
	a_unmoeglich(210).f_locked = 127;
	a_unmoeglich(211).f_name = 119;
	a_unmoeglich(211).f_locked = 121;
	a_unmoeglich(212).f_name = 121;
	a_unmoeglich(212).f_locked = 119;
	a_unmoeglich(213).f_name = 100;
	a_unmoeglich(213).f_locked = 123;
	a_unmoeglich(214).f_name = 123;
	a_unmoeglich(214).f_locked = 100;
	a_unmoeglich(215).f_name = 100;
	a_unmoeglich(215).f_locked = 129;
	a_unmoeglich(216).f_name = 129;
	a_unmoeglich(216).f_locked = 100;
}

static int32_t p_init_spells() {
	int16_t v_i = 0;
	int16_t v_j = 0;
	for (v_i = 1; v_i <= 177; v_i += 1) {
		for (v_j = 1; v_j <= 4; v_j += 1) {
			a_zauber(v_i, v_j).f_anhaltend = 0;
			a_zauber(v_i, v_j).f_erlernt = 0;
			a_zauber(v_i, v_j).f_chance = 50;
		}
	}
	for (v_i = 1; v_i <= 4; v_i += 1) {
		a_zauber(1, v_i).f_name[2] = "Mondlicht";
		a_zauber(1, v_i).f_name[1] = "Moonlight";
		a_zauber(1, v_i).f_name[3] = "Luz lunar";
		a_zauber(1, v_i).f_kosten = 1;
		a_zauber(1, v_i).f_level = 1;
		a_zauber(1, v_i).f_dauer = 5;
		a_zauber(1, v_i).f_art = "basis";
		a_zauber(1, v_i).f_besch_1[2] = "Ruft das Licht des Mondes herbei und ";
		a_zauber(1, v_i).f_besch_2[2] = "erhellt das Labyrinth (Aktiver Zauber)";
		a_zauber(1, v_i).f_besch_1[1] = "Summons the light of the moon to ";
		a_zauber(1, v_i).f_besch_2[1] = "follow the magician (active spell)";
		a_zauber(1, v_i).f_besch_1[3] = "Hace que la luz de la luna siga ";
		a_zauber(1, v_i).f_besch_2[3] = "al mago (hechizo activo)";
		a_zauber(2, v_i).f_name[2] = "Wirbelwind";
		a_zauber(2, v_i).f_name[1] = "Whirlwind";
		a_zauber(2, v_i).f_name[3] = "Torbellino";
		a_zauber(2, v_i).f_kosten = 1;
		a_zauber(2, v_i).f_level = 2;
		a_zauber(2, v_i).f_dauer = 0;
		a_zauber(2, v_i).f_art = "basis";
		a_zauber(2, v_i).f_besch_1[2] = "Ruft einen Wirbelwind herbei der ";
		a_zauber(2, v_i).f_besch_2[2] = "ein nahes Monster attackiert";
		a_zauber(2, v_i).f_besch_1[1] = "Summons a small whirlwind to";
		a_zauber(2, v_i).f_besch_2[1] = "attack a nearby monster";
		a_zauber(2, v_i).f_besch_1[3] = "Crea un pequeno torbellino para ";
		a_zauber(2, v_i).f_besch_2[3] = "atacar a un monstruo cercano";
		a_zauber(3, v_i).f_name[2] = "Heilung";
		a_zauber(3, v_i).f_name[1] = "Heal";
		a_zauber(3, v_i).f_name[3] = "Curacion";
		a_zauber(3, v_i).f_kosten = 2;
		a_zauber(3, v_i).f_level = 3;
		a_zauber(3, v_i).f_dauer = 0;
		a_zauber(3, v_i).f_art = "basis";
		a_zauber(3, v_i).f_besch_1[2] = "Bringt dem Magier verlorene Lebenspunkte";
		a_zauber(3, v_i).f_besch_2[2] = "zur\374ck. (3 mal pro Level)";
		a_zauber(3, v_i).f_besch_1[1] = "Restores lost life points of the";
		a_zauber(3, v_i).f_besch_2[1] = "magician (3 times per level)";
		a_zauber(3, v_i).f_besch_1[3] = "Recupera puntos de vida al ";
		a_zauber(3, v_i).f_besch_2[3] = "mago (3 veces por nivel)";
		a_zauber(4, v_i).f_name[2] = "Erde sp\374hren";
		a_zauber(4, v_i).f_name[1] = "Sense Earth";
		a_zauber(4, v_i).f_name[3] = "Sentir la tierra";
		a_zauber(4, v_i).f_kosten = 1;
		a_zauber(4, v_i).f_level = 1;
		a_zauber(4, v_i).f_dauer = 0;
		a_zauber(4, v_i).f_art = "erde";
		a_zauber(4, v_i).f_besch_1[2] = "Zeigt eine Karte mit allen ";
		a_zauber(4, v_i).f_besch_2[2] = "Mauern der n\344heren Umgebung";
		a_zauber(4, v_i).f_besch_1[1] = "Shows a map containing the ";
		a_zauber(4, v_i).f_besch_2[1] = "walls of the actual level";
		a_zauber(4, v_i).f_besch_1[3] = "Muestra un mapa con los ";
		a_zauber(4, v_i).f_besch_2[3] = "obstaculos del nivel";
		a_zauber(5, v_i).f_name[2] = "Funke";
		a_zauber(5, v_i).f_name[1] = "Spark";
		a_zauber(5, v_i).f_name[3] = "Chispa";
		a_zauber(5, v_i).f_kosten = 1;
		a_zauber(5, v_i).f_level = 1;
		a_zauber(5, v_i).f_dauer = 0;
		a_zauber(5, v_i).f_art = "feuer";
		a_zauber(5, v_i).f_besch_1[2] = "Beschw\366rt einen magischen Funken, ";
		a_zauber(5, v_i).f_besch_2[2] = "um ein Monster zu attackieren";
		a_zauber(5, v_i).f_besch_1[1] = "Summons a magic spark that ";
		a_zauber(5, v_i).f_besch_2[1] = "damages a nearby monster";
		a_zauber(5, v_i).f_besch_1[3] = "Crea una chispa magica que ";
		a_zauber(5, v_i).f_besch_2[3] = "dana un monstruo cercano";
		a_zauber(6, v_i).f_name[2] = "Erdst\344rke";
		a_zauber(6, v_i).f_name[1] = "Earthen Strength";
		a_zauber(6, v_i).f_name[3] = "Fuerza terrestre";
		a_zauber(6, v_i).f_kosten = 1;
		a_zauber(6, v_i).f_level = 2;
		a_zauber(6, v_i).f_dauer = 5;
		a_zauber(6, v_i).f_art = "erde";
		a_zauber(6, v_i).f_besch_1[2] = "Erh\366ht die St\344rke des ";
		a_zauber(6, v_i).f_besch_2[2] = "Magiers (Aktiver Zauber)";
		a_zauber(6, v_i).f_besch_1[1] = "Increases the strength ";
		a_zauber(6, v_i).f_besch_2[1] = "of the magician (active spell)";
		a_zauber(6, v_i).f_besch_1[3] = "Incrementa la fuerza del ";
		a_zauber(6, v_i).f_besch_2[3] = "mago (hechizo activo)";
		a_zauber(7, v_i).f_name[2] = "Feuerschild";
		a_zauber(7, v_i).f_name[1] = "Fireshield";
		a_zauber(7, v_i).f_name[3] = "Escudo de Fuego";
		a_zauber(7, v_i).f_kosten = 1;
		a_zauber(7, v_i).f_level = 2;
		a_zauber(7, v_i).f_dauer = 5;
		a_zauber(7, v_i).f_art = "feuer";
		a_zauber(7, v_i).f_besch_1[2] = "Sch\374tzt den Magier vor ";
		a_zauber(7, v_i).f_besch_2[2] = "Feuer und Hitze (aktiver Zauber)";
		a_zauber(7, v_i).f_besch_1[1] = "Wards against heat and ";
		a_zauber(7, v_i).f_besch_2[1] = "flame (active spell)";
		a_zauber(7, v_i).f_besch_1[3] = "Proteccion frente al calor y ";
		a_zauber(7, v_i).f_besch_2[3] = "las llamas (hechizo activo)";
		a_zauber(8, v_i).f_name[2] = "Totengold";
		a_zauber(8, v_i).f_name[1] = "Dead Man's Gold";
		a_zauber(8, v_i).f_name[3] = "Oro del muerto";
		a_zauber(8, v_i).f_kosten = 3;
		a_zauber(8, v_i).f_level = 3;
		a_zauber(8, v_i).f_dauer = 0;
		a_zauber(8, v_i).f_art = "schwarz";
		a_zauber(8, v_i).f_besch_1[2] = "Verwandelt ein Skelett ";
		a_zauber(8, v_i).f_besch_2[2] = "in einen Goldsack";
		a_zauber(8, v_i).f_besch_1[1] = "Turns a skeleton into ";
		a_zauber(8, v_i).f_besch_2[1] = "a bag of gold";
		a_zauber(8, v_i).f_besch_1[3] = "Convierte un esqueleto ";
		a_zauber(8, v_i).f_besch_2[3] = "en una bolsa de oro";
		a_zauber(9, v_i).f_name[2] = "Magische Flamme";
		a_zauber(9, v_i).f_name[1] = "Magic Flame";
		a_zauber(9, v_i).f_name[3] = "Llama magica";
		a_zauber(9, v_i).f_kosten = 2;
		a_zauber(9, v_i).f_level = 3;
		a_zauber(9, v_i).f_dauer = 4;
		a_zauber(9, v_i).f_art = "feuer";
		a_zauber(9, v_i).f_besch_1[2] = "Eine magische Flamme spendet ";
		a_zauber(9, v_i).f_besch_2[2] = "dem Zauberer Licht (Aktiver Zauber)";
		a_zauber(9, v_i).f_besch_1[1] = "A magical flame gives light ";
		a_zauber(9, v_i).f_besch_2[1] = "to the magician (active spell)";
		a_zauber(9, v_i).f_besch_1[3] = "Una llama magica alumbra ";
		a_zauber(9, v_i).f_besch_2[3] = "al mago (hechizo activo)";
		a_zauber(10, v_i).f_name[2] = "Magischer Apfel";
		a_zauber(10, v_i).f_name[1] = "Magic Apple";
		a_zauber(10, v_i).f_name[3] = "Manzana magica";
		a_zauber(10, v_i).f_kosten = 1;
		a_zauber(10, v_i).f_level = 1;
		a_zauber(10, v_i).f_dauer = 0;
		a_zauber(10, v_i).f_art = "druide";
		a_zauber(10, v_i).f_besch_1[2] = "Beschw\366rt einen magischen ";
		a_zauber(10, v_i).f_besch_2[2] = "Apfel zum Essen";
		a_zauber(10, v_i).f_besch_1[1] = "Conjures a magic apple for ";
		a_zauber(10, v_i).f_besch_2[1] = "the magician to eat";
		a_zauber(10, v_i).f_besch_1[3] = "Conjura una manzana ";
		a_zauber(10, v_i).f_besch_2[3] = "magica comestible";
		a_zauber(11, v_i).f_name[2] = "Erfrischung";
		a_zauber(11, v_i).f_name[1] = "Refresh";
		a_zauber(11, v_i).f_name[3] = "Refrescar";
		a_zauber(11, v_i).f_kosten = 1;
		a_zauber(11, v_i).f_level = 1;
		a_zauber(11, v_i).f_dauer = 0;
		a_zauber(11, v_i).f_art = "wasser";
		a_zauber(11, v_i).f_besch_1[2] = "L\366scht den Durst ";
		a_zauber(11, v_i).f_besch_2[2] = "des Magiers";
		a_zauber(11, v_i).f_besch_1[1] = "Quenches the thirst ";
		a_zauber(11, v_i).f_besch_2[1] = "of the magician";
		a_zauber(11, v_i).f_besch_1[3] = "Calma la sed ";
		a_zauber(11, v_i).f_besch_2[3] = "del mago";
		a_zauber(12, v_i).f_name[2] = "Sternenlicht";
		a_zauber(12, v_i).f_name[1] = "Starlight";
		a_zauber(12, v_i).f_name[3] = "Luz estelar";
		a_zauber(12, v_i).f_kosten = 1;
		a_zauber(12, v_i).f_level = 1;
		a_zauber(12, v_i).f_dauer = 4;
		a_zauber(12, v_i).f_art = "sterne";
		a_zauber(12, v_i).f_besch_1[2] = "Ruft das Licht der Sterne herbei und";
		a_zauber(12, v_i).f_besch_2[2] = "erhellt das Labyrinth (Aktiver Zauber)";
		a_zauber(12, v_i).f_besch_1[1] = "Summons the light of the stars to ";
		a_zauber(12, v_i).f_besch_2[1] = "follow the magician (active spell)";
		a_zauber(12, v_i).f_besch_1[3] = "Hace que la luz de las estrellas ";
		a_zauber(12, v_i).f_besch_2[3] = "siga al mago (hechizo activo)";
		a_zauber(13, v_i).f_name[2] = "Schmerzen lindern";
		a_zauber(13, v_i).f_name[1] = "Ease pain";
		a_zauber(13, v_i).f_name[3] = "Aliviar el dolor";
		a_zauber(13, v_i).f_kosten = 1;
		a_zauber(13, v_i).f_level = 1;
		a_zauber(13, v_i).f_dauer = 0;
		a_zauber(13, v_i).f_art = "weiss";
		a_zauber(13, v_i).f_besch_1[2] = "Heilt die Wunden des Magiers";
		a_zauber(13, v_i).f_besch_2[2] = "";
		a_zauber(13, v_i).f_besch_1[1] = "Heals the wounds of the magician";
		a_zauber(13, v_i).f_besch_2[1] = "";
		a_zauber(13, v_i).f_besch_1[3] = "Cura las heridas del mago";
		a_zauber(13, v_i).f_besch_2[3] = "";
		a_zauber(14, v_i).f_name[2] = "Lied der Reise";
		a_zauber(14, v_i).f_name[1] = "Song of Travels";
		a_zauber(14, v_i).f_name[3] = "Cancion de viaje";
		a_zauber(14, v_i).f_kosten = 1;
		a_zauber(14, v_i).f_level = 1;
		a_zauber(14, v_i).f_dauer = 9999;
		a_zauber(14, v_i).f_art = "barde";
		a_zauber(14, v_i).f_besch_1[2] = "Erh\366ht die Zugweite des Barden um +1";
		a_zauber(14, v_i).f_besch_2[2] = "";
		a_zauber(14, v_i).f_besch_1[1] = "Increases the movement of the ";
		a_zauber(14, v_i).f_besch_2[1] = "bard by +1";
		a_zauber(14, v_i).f_besch_1[3] = "Incrementa el movimiento ";
		a_zauber(14, v_i).f_besch_2[3] = "del bardo en +1";
		a_zauber(15, v_i).f_name[2] = "Federfall";
		a_zauber(15, v_i).f_name[1] = "Featherfall";
		a_zauber(15, v_i).f_name[3] = "Peso pluma";
		a_zauber(15, v_i).f_kosten = 2;
		a_zauber(15, v_i).f_level = 2;
		a_zauber(15, v_i).f_dauer = 0;
		a_zauber(15, v_i).f_art = "luft";
		a_zauber(15, v_i).f_besch_1[2] = "L\344sst den Magier einen Schacht ";
		a_zauber(15, v_i).f_besch_2[2] = "hinabschweben";
		a_zauber(15, v_i).f_besch_1[1] = "Lets the magician float down a ";
		a_zauber(15, v_i).f_besch_2[1] = "shaft or pit";
		a_zauber(15, v_i).f_besch_1[3] = "Permita al mago descender ";
		a_zauber(15, v_i).f_besch_2[3] = "una chimenea";
		a_zauber(16, v_i).f_name[2] = "Tiere bannen";
		a_zauber(16, v_i).f_name[1] = "Banish animals";
		a_zauber(16, v_i).f_name[3] = "Castigar animales";
		a_zauber(16, v_i).f_kosten = 1;
		a_zauber(16, v_i).f_level = 2;
		a_zauber(16, v_i).f_dauer = 0;
		a_zauber(16, v_i).f_art = "druide";
		a_zauber(16, v_i).f_besch_1[2] = "Vertreibt ein einzelnes";
		a_zauber(16, v_i).f_besch_2[2] = "Tier";
		a_zauber(16, v_i).f_besch_1[1] = "Banishes a single";
		a_zauber(16, v_i).f_besch_2[1] = "animal";
		a_zauber(16, v_i).f_besch_1[3] = "Castiga un solo animal";
		a_zauber(16, v_i).f_besch_2[3] = "";
		a_zauber(17, v_i).f_name[2] = "Untote bannen";
		a_zauber(17, v_i).f_name[1] = "Banish undead";
		a_zauber(17, v_i).f_name[3] = "Castigar no-muertos";
		a_zauber(17, v_i).f_kosten = 2;
		a_zauber(17, v_i).f_level = 2;
		a_zauber(17, v_i).f_dauer = 0;
		a_zauber(17, v_i).f_art = "weiss";
		a_zauber(17, v_i).f_besch_1[2] = "Vertreibt einen einzelnen";
		a_zauber(17, v_i).f_besch_2[2] = "Untoten";
		a_zauber(17, v_i).f_besch_1[1] = "Banishes a single";
		a_zauber(17, v_i).f_besch_2[1] = "undead creature";
		a_zauber(17, v_i).f_besch_1[3] = "Castigar un solo no-muerto";
		a_zauber(17, v_i).f_besch_2[3] = "";
		a_zauber(18, v_i).f_name[2] = "Schutzschild";
		a_zauber(18, v_i).f_name[1] = "Shield";
		a_zauber(18, v_i).f_name[3] = "Escudo";
		a_zauber(18, v_i).f_kosten = 2;
		a_zauber(18, v_i).f_level = 5;
		a_zauber(18, v_i).f_dauer = 5;
		a_zauber(18, v_i).f_art = "basis";
		a_zauber(18, v_i).f_besch_1[2] = "Sch\374tzt vor Nahkampf-";
		a_zauber(18, v_i).f_besch_2[2] = "Attacken (aktiver Zauber)";
		a_zauber(18, v_i).f_besch_1[1] = "Wards against melee";
		a_zauber(18, v_i).f_besch_2[1] = "attacks (active spell)";
		a_zauber(18, v_i).f_besch_1[3] = "Proteccion contra ataques cuerpo ";
		a_zauber(18, v_i).f_besch_2[3] = "a cuerpo (hechizo activo)";
		a_zauber(19, v_i).f_name[2] = "Arkaner Schlag";
		a_zauber(19, v_i).f_name[1] = "Arcane Bolt";
		a_zauber(19, v_i).f_name[3] = "Rayo secreto";
		a_zauber(19, v_i).f_kosten = 2;
		a_zauber(19, v_i).f_level = 5;
		a_zauber(19, v_i).f_dauer = 0;
		a_zauber(19, v_i).f_art = "basis";
		a_zauber(19, v_i).f_besch_1[2] = "Wirft eine Sph\344re aus Magie";
		a_zauber(19, v_i).f_besch_2[2] = "auf einen Gegner";
		a_zauber(19, v_i).f_besch_1[1] = "Throws a sphere of magic";
		a_zauber(19, v_i).f_besch_2[1] = "on a nearby enemy";
		a_zauber(19, v_i).f_besch_1[3] = "Lanza una esfera de magia ";
		a_zauber(19, v_i).f_besch_2[3] = "a un enemigo cercano";
		a_zauber(20, v_i).f_name[2] = "Fallen zeigen";
		a_zauber(20, v_i).f_name[1] = "Show Traps";
		a_zauber(20, v_i).f_name[3] = "Muestra trampas";
		a_zauber(20, v_i).f_kosten = 2;
		a_zauber(20, v_i).f_level = 6;
		a_zauber(20, v_i).f_dauer = 0;
		a_zauber(20, v_i).f_art = "basis";
		a_zauber(20, v_i).f_besch_1[2] = "Deckt Fallen in n\344chster";
		a_zauber(20, v_i).f_besch_2[2] = "N\344he auf (mit 80%)";
		a_zauber(20, v_i).f_besch_1[1] = "Reveals traps around the";
		a_zauber(20, v_i).f_besch_2[1] = "magician (with 80%)";
		a_zauber(20, v_i).f_besch_1[3] = "Se muestran todas las trampas ";
		a_zauber(20, v_i).f_besch_2[3] = "cercanas del mago (con 80%)";
		a_zauber(21, v_i).f_name[2] = "Portal";
		a_zauber(21, v_i).f_name[1] = "Portal";
		a_zauber(21, v_i).f_name[3] = "Portal";
		a_zauber(21, v_i).f_kosten = 5;
		a_zauber(21, v_i).f_level = 5;
		a_zauber(21, v_i).f_dauer = 0;
		a_zauber(21, v_i).f_art = "erde";
		a_zauber(21, v_i).f_besch_1[2] = "Erzeugt eine magische \326ffnung";
		a_zauber(21, v_i).f_besch_2[2] = "in einer Mauer. 1 mal pro Ebene";
		a_zauber(21, v_i).f_besch_1[1] = "Creates a magical passage";
		a_zauber(21, v_i).f_besch_2[1] = "through a wall. Once per level";
		a_zauber(21, v_i).f_besch_1[3] = "Crea un pasadizo magico a traves";
		a_zauber(21, v_i).f_besch_2[3] = "de una pared. 1 vez por nivel";
		a_zauber(65, v_i).f_name[2] = "Feuerschlag";
		a_zauber(65, v_i).f_name[1] = "Fire Bolt";
		a_zauber(65, v_i).f_name[3] = "Rayo de fuego";
		a_zauber(65, v_i).f_kosten = 2;
		a_zauber(65, v_i).f_level = 4;
		a_zauber(65, v_i).f_dauer = 0;
		a_zauber(65, v_i).f_art = "feuer";
		a_zauber(65, v_i).f_besch_1[2] = "Wirft einen Feuerball auf";
		a_zauber(65, v_i).f_besch_2[2] = "einen Gegner";
		a_zauber(65, v_i).f_besch_1[1] = "Throws a fireball on";
		a_zauber(65, v_i).f_besch_2[1] = "a nearby enemy";
		a_zauber(65, v_i).f_besch_1[3] = "Lanza una bola de fuego a ";
		a_zauber(65, v_i).f_besch_2[3] = "un enemigo cercano";
		a_zauber(23, v_i).f_name[2] = "Flammenmeer";
		a_zauber(23, v_i).f_name[1] = "Sea of Flames";
		a_zauber(23, v_i).f_name[3] = "Mar de fuego";
		a_zauber(23, v_i).f_kosten = 3;
		a_zauber(23, v_i).f_level = 6;
		a_zauber(23, v_i).f_dauer = 0;
		a_zauber(23, v_i).f_art = "feuer";
		a_zauber(23, v_i).f_besch_1[2] = "Verbrennt alle Monster in";
		a_zauber(23, v_i).f_besch_2[2] = "Sichtweite mit magischem Feuer";
		a_zauber(23, v_i).f_besch_1[1] = "Burns all monsters in";
		a_zauber(23, v_i).f_besch_2[1] = "sight with magical fire";
		a_zauber(23, v_i).f_besch_1[3] = "Quema a todos los monstruos ";
		a_zauber(23, v_i).f_besch_2[3] = "visibles con fuego magico";
		a_zauber(24, v_i).f_name[2] = "Furcht";
		a_zauber(24, v_i).f_name[1] = "Fear";
		a_zauber(24, v_i).f_name[3] = "Miedo";
		a_zauber(24, v_i).f_kosten = 1;
		a_zauber(24, v_i).f_level = 3;
		a_zauber(24, v_i).f_dauer = 0;
		a_zauber(24, v_i).f_art = "schwarz";
		a_zauber(24, v_i).f_besch_1[2] = "Bringt ein Monster dazu";
		a_zauber(24, v_i).f_besch_2[2] = "vor Furcht zu fliehen";
		a_zauber(24, v_i).f_besch_1[1] = "Causes a monster to flee";
		a_zauber(24, v_i).f_besch_2[1] = "from fear";
		a_zauber(24, v_i).f_besch_1[3] = "Hace que un monstruo ";
		a_zauber(24, v_i).f_besch_2[3] = "huya despavorido";
		a_zauber(25, v_i).f_name[2] = "Dunkler Sog";
		a_zauber(25, v_i).f_name[1] = "Drain Life";
		a_zauber(25, v_i).f_name[3] = "Drenar vida";
		a_zauber(25, v_i).f_kosten = 3;
		a_zauber(25, v_i).f_level = 5;
		a_zauber(25, v_i).f_dauer = 0;
		a_zauber(25, v_i).f_art = "schwarz";
		a_zauber(25, v_i).f_besch_1[2] = "Stielt einem Monster";
		a_zauber(25, v_i).f_besch_2[2] = "Lebenspunkte";
		a_zauber(25, v_i).f_besch_1[1] = "Drains lifepoints from a";
		a_zauber(25, v_i).f_besch_2[1] = "monster";
		a_zauber(25, v_i).f_besch_1[3] = "Drena puntos de vida ";
		a_zauber(25, v_i).f_besch_2[3] = "de un monstruo";
		a_zauber(26, v_i).f_name[2] = "Fallen sp\374hren";
		a_zauber(26, v_i).f_name[1] = "Sense Traps";
		a_zauber(26, v_i).f_name[3] = "Sentir trampas";
		a_zauber(26, v_i).f_kosten = 2;
		a_zauber(26, v_i).f_level = 3;
		a_zauber(26, v_i).f_dauer = 10;
		a_zauber(26, v_i).f_art = "druide";
		a_zauber(26, v_i).f_besch_1[2] = "Erh\366ht die Chance eine";
		a_zauber(26, v_i).f_besch_2[2] = "Falle zu entdecken";
		a_zauber(26, v_i).f_besch_1[1] = "Increases the chance";
		a_zauber(26, v_i).f_besch_2[1] = "to spot a trap";
		a_zauber(26, v_i).f_besch_1[3] = "Incrementa las posibilidades ";
		a_zauber(26, v_i).f_besch_2[3] = "de detectar una trampa";
		a_zauber(27, v_i).f_name[2] = "\326ffnen";
		a_zauber(27, v_i).f_name[1] = "Open";
		a_zauber(27, v_i).f_name[3] = "Abrir";
		a_zauber(27, v_i).f_kosten = 3;
		a_zauber(27, v_i).f_level = 5;
		a_zauber(27, v_i).f_dauer = 0;
		a_zauber(27, v_i).f_art = "druide";
		a_zauber(27, v_i).f_besch_1[2] = "\326ffnet eine verschlossene";
		a_zauber(27, v_i).f_besch_2[2] = "T\374r oder Truhe";
		a_zauber(27, v_i).f_besch_1[1] = "Opens a locked";
		a_zauber(27, v_i).f_besch_2[1] = "door or chest";
		a_zauber(27, v_i).f_besch_1[3] = "Abre una puerta o ";
		a_zauber(27, v_i).f_besch_2[3] = "cerradura";
		a_zauber(28, v_i).f_name[2] = "Frostschlag";
		a_zauber(28, v_i).f_name[1] = "Frost Bolt";
		a_zauber(28, v_i).f_name[3] = "Bola de hielo";
		a_zauber(28, v_i).f_kosten = 2;
		a_zauber(28, v_i).f_level = 4;
		a_zauber(28, v_i).f_dauer = 0;
		a_zauber(28, v_i).f_art = "wasser";
		a_zauber(28, v_i).f_besch_1[2] = "Wirft eine Kugel aus Eis";
		a_zauber(28, v_i).f_besch_2[2] = "auf einen Gegner";
		a_zauber(28, v_i).f_besch_1[1] = "Throws a ball of ice";
		a_zauber(28, v_i).f_besch_2[1] = "on a nearby enemy";
		a_zauber(28, v_i).f_besch_1[3] = "Lanza una bola de hielo ";
		a_zauber(28, v_i).f_besch_2[3] = "a un enemigo proximo";
		a_zauber(29, v_i).f_name[2] = "Dehydration";
		a_zauber(29, v_i).f_name[1] = "Dehydration";
		a_zauber(29, v_i).f_name[3] = "Deshidratacion";
		a_zauber(29, v_i).f_kosten = 2;
		a_zauber(29, v_i).f_level = 6;
		a_zauber(29, v_i).f_dauer = 0;
		a_zauber(29, v_i).f_art = "wasser";
		a_zauber(29, v_i).f_besch_1[2] = "Zerst\366rt das Wasser in einem Monster";
		a_zauber(29, v_i).f_besch_2[2] = "und fgt ihm damit Schaden zu";
		a_zauber(29, v_i).f_besch_1[1] = "Evaporates the water inside a";
		a_zauber(29, v_i).f_besch_2[1] = "monster and damages it";
		a_zauber(29, v_i).f_besch_1[3] = "Hace desaparecer el agua de un ";
		a_zauber(29, v_i).f_besch_2[3] = "monstruo y le dana";
		a_zauber(30, v_i).f_name[2] = "Nordlicht";
		a_zauber(30, v_i).f_name[1] = "Polar Light";
		a_zauber(30, v_i).f_name[3] = "Luz polar";
		a_zauber(30, v_i).f_kosten = 1;
		a_zauber(30, v_i).f_level = 3;
		a_zauber(30, v_i).f_dauer = 4;
		a_zauber(30, v_i).f_art = "sterne";
		a_zauber(30, v_i).f_besch_1[2] = "Das helle Licht";
		a_zauber(30, v_i).f_besch_2[2] = "des Nordens (aktiver Zauber)";
		a_zauber(30, v_i).f_besch_1[1] = "The bright light";
		a_zauber(30, v_i).f_besch_2[1] = "of the north (active Spell)";
		a_zauber(30, v_i).f_besch_1[3] = "La luz clara del norte ";
		a_zauber(30, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(31, v_i).f_name[2] = "Sonnenlicht";
		a_zauber(31, v_i).f_name[1] = "Sunlight";
		a_zauber(31, v_i).f_name[3] = "Luz solar";
		a_zauber(31, v_i).f_kosten = 2;
		a_zauber(31, v_i).f_level = 5;
		a_zauber(31, v_i).f_dauer = 4;
		a_zauber(31, v_i).f_art = "sterne";
		a_zauber(31, v_i).f_besch_1[2] = "Ein starker Licht-";
		a_zauber(31, v_i).f_besch_2[2] = "zauber (aktiver Zauber)";
		a_zauber(31, v_i).f_besch_1[1] = "A strong lightspell";
		a_zauber(31, v_i).f_besch_2[1] = "(active spell)";
		a_zauber(31, v_i).f_besch_1[3] = "Un fuerte hechizo luminoso ";
		a_zauber(31, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(32, v_i).f_name[2] = "Exorzismus";
		a_zauber(32, v_i).f_name[1] = "Exorcism";
		a_zauber(32, v_i).f_name[3] = "Exorcismo";
		a_zauber(32, v_i).f_kosten = 2;
		a_zauber(32, v_i).f_level = 14;
		a_zauber(32, v_i).f_dauer = 0;
		a_zauber(32, v_i).f_art = "weiss";
		a_zauber(32, v_i).f_besch_1[2] = "Zerst\366rt alle Wiederg\344nger";
		a_zauber(32, v_i).f_besch_2[2] = "in unmittelbarer N\344he";
		a_zauber(32, v_i).f_besch_1[1] = "Destroys all nearby";
		a_zauber(32, v_i).f_besch_2[1] = "revenants";
		a_zauber(32, v_i).f_besch_1[3] = "Destruye todos los ";
		a_zauber(32, v_i).f_besch_2[3] = "espectros proximos";
		a_zauber(33, v_i).f_name[2] = "Weisser Schutz";
		a_zauber(33, v_i).f_name[1] = "White Protection";
		a_zauber(33, v_i).f_name[3] = "Proteccion blanca";
		a_zauber(33, v_i).f_kosten = 2;
		a_zauber(33, v_i).f_level = 3;
		a_zauber(33, v_i).f_dauer = 5;
		a_zauber(33, v_i).f_art = "weiss";
		a_zauber(33, v_i).f_besch_1[2] = "Sch\374tzt vor Nahkampf-";
		a_zauber(33, v_i).f_besch_2[2] = "Attacken (aktiver Zauber)";
		a_zauber(33, v_i).f_besch_1[1] = "Wards against melee";
		a_zauber(33, v_i).f_besch_2[1] = "attacks (active spell)";
		a_zauber(33, v_i).f_besch_1[3] = "Proteccion contra ataques cuerpo ";
		a_zauber(33, v_i).f_besch_2[3] = "a cuerpo (hechizo activo)";
		a_zauber(34, v_i).f_name[2] = "Vergiftung heilen";
		a_zauber(34, v_i).f_name[1] = "Heal Poison";
		a_zauber(34, v_i).f_name[3] = "Curar veneno";
		a_zauber(34, v_i).f_kosten = 2;
		a_zauber(34, v_i).f_level = 4;
		a_zauber(34, v_i).f_dauer = 0;
		a_zauber(34, v_i).f_art = "weiss";
		a_zauber(34, v_i).f_besch_1[2] = "Reduziert die Dauer einer";
		a_zauber(34, v_i).f_besch_2[2] = "Vergiftung";
		a_zauber(34, v_i).f_besch_1[1] = "Reduces the duration of";
		a_zauber(34, v_i).f_besch_2[1] = "poison";
		a_zauber(34, v_i).f_besch_1[3] = "Reduce la duracion ";
		a_zauber(34, v_i).f_besch_2[3] = "del veneno";
		a_zauber(35, v_i).f_name[2] = "Lied des Kampfes";
		a_zauber(35, v_i).f_name[1] = "Song of Battle";
		a_zauber(35, v_i).f_name[3] = "Cancion de batalla";
		a_zauber(35, v_i).f_kosten = 2;
		a_zauber(35, v_i).f_level = 2;
		a_zauber(35, v_i).f_dauer = 9999;
		a_zauber(35, v_i).f_art = "barde";
		a_zauber(35, v_i).f_besch_1[2] = "+1 auf Angriff und";
		a_zauber(35, v_i).f_besch_2[2] = "+1 auf Schaden im Nahkampf";
		a_zauber(35, v_i).f_besch_1[1] = "+1 to attack and +1";
		a_zauber(35, v_i).f_besch_2[1] = "to damage in melee combat";
		a_zauber(35, v_i).f_besch_1[3] = "+1 al ataque y +1 al dano en ";
		a_zauber(35, v_i).f_besch_2[3] = "combate cuerpo a cuerpo";
		a_zauber(36, v_i).f_name[2] = "Lied der Hoffnung";
		a_zauber(36, v_i).f_name[1] = "Song of Hope";
		a_zauber(36, v_i).f_name[3] = "Cancion de esperanza";
		a_zauber(36, v_i).f_kosten = 3;
		a_zauber(36, v_i).f_level = 3;
		a_zauber(36, v_i).f_dauer = 9999;
		a_zauber(36, v_i).f_art = "barde";
		a_zauber(36, v_i).f_besch_1[2] = "+1 auf Lichtradius";
		a_zauber(36, v_i).f_besch_2[2] = "";
		a_zauber(36, v_i).f_besch_1[1] = "+1 to light radius";
		a_zauber(36, v_i).f_besch_2[1] = "";
		a_zauber(36, v_i).f_besch_1[3] = "+1 al radio de luz";
		a_zauber(36, v_i).f_besch_2[3] = "";
		a_zauber(37, v_i).f_name[2] = "Lied der Einsamkeit";
		a_zauber(37, v_i).f_name[1] = "Song of Loneliness";
		a_zauber(37, v_i).f_name[3] = "Cancion de soledad";
		a_zauber(37, v_i).f_kosten = 4;
		a_zauber(37, v_i).f_level = 4;
		a_zauber(37, v_i).f_dauer = 9999;
		a_zauber(37, v_i).f_art = "barde";
		a_zauber(37, v_i).f_besch_1[2] = "Sch\374tzt gegen Hinterhalte";
		a_zauber(37, v_i).f_besch_2[2] = "";
		a_zauber(37, v_i).f_besch_1[1] = "Wards against Ambushes";
		a_zauber(37, v_i).f_besch_2[1] = "";
		a_zauber(37, v_i).f_besch_1[3] = "Proteccion contra emboscadas";
		a_zauber(37, v_i).f_besch_2[3] = "";
		a_zauber(38, v_i).f_name[2] = "Lied des Todes";
		a_zauber(38, v_i).f_name[1] = "Song of Death";
		a_zauber(38, v_i).f_name[3] = "Cancion de muerte";
		a_zauber(38, v_i).f_kosten = 5;
		a_zauber(38, v_i).f_level = 5;
		a_zauber(38, v_i).f_dauer = 9999;
		a_zauber(38, v_i).f_art = "barde";
		a_zauber(38, v_i).f_besch_1[2] = "Hindert Skelette daran";
		a_zauber(38, v_i).f_besch_2[2] = "sich zu erheben";
		a_zauber(38, v_i).f_besch_1[1] = "Stops skeletons from";
		a_zauber(38, v_i).f_besch_2[1] = "changing into undead";
		a_zauber(38, v_i).f_besch_1[3] = "Priva a los esqueletos a convertirse ";
		a_zauber(38, v_i).f_besch_2[3] = "en no-muertos";
		a_zauber(39, v_i).f_name[2] = "Winde rufen";
		a_zauber(39, v_i).f_name[1] = "Call winds";
		a_zauber(39, v_i).f_name[3] = "Llamar a los vientos";
		a_zauber(39, v_i).f_kosten = 1;
		a_zauber(39, v_i).f_level = 1;
		a_zauber(39, v_i).f_dauer = 0;
		a_zauber(39, v_i).f_art = "luft";
		a_zauber(39, v_i).f_besch_1[2] = "Ruft starke Winde herbei";
		a_zauber(39, v_i).f_besch_2[2] = "die fliegende Wesen attackieren";
		a_zauber(39, v_i).f_besch_1[1] = "Summons strong winds";
		a_zauber(39, v_i).f_besch_2[1] = "that damage flying monsters";
		a_zauber(39, v_i).f_besch_1[3] = "Crea fuertes vientos que danan ";
		a_zauber(39, v_i).f_besch_2[3] = "los monstruos voladores";
		a_zauber(40, v_i).f_name[2] = "R\374ckenwind";
		a_zauber(40, v_i).f_name[1] = "Helpful Winds";
		a_zauber(40, v_i).f_name[3] = "Vientos amigos";
		a_zauber(40, v_i).f_kosten = 2;
		a_zauber(40, v_i).f_level = 3;
		a_zauber(40, v_i).f_dauer = 5;
		a_zauber(40, v_i).f_art = "luft";
		a_zauber(40, v_i).f_besch_1[2] = "+3 Zugweite";
		a_zauber(40, v_i).f_besch_2[2] = "(aktiver Zauber)";
		a_zauber(40, v_i).f_besch_1[1] = "+3 Movement";
		a_zauber(40, v_i).f_besch_2[1] = "(active spell)";
		a_zauber(40, v_i).f_besch_1[3] = "+3 movimiento";
		a_zauber(40, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(41, v_i).f_name[2] = "Irrlicht";
		a_zauber(41, v_i).f_name[1] = "Will-of-the-Whisp";
		a_zauber(41, v_i).f_name[3] = "Voluntad de la Luciarnaga";
		a_zauber(41, v_i).f_kosten = 1;
		a_zauber(41, v_i).f_level = 2;
		a_zauber(41, v_i).f_dauer = 4;
		a_zauber(41, v_i).f_art = "illusion";
		a_zauber(41, v_i).f_besch_1[2] = "Beschw\366rt ein Irrlicht das";
		a_zauber(41, v_i).f_besch_2[2] = "Licht spendet (Akiver Zauber)";
		a_zauber(41, v_i).f_besch_1[1] = "Summons a will-o-the-wisp";
		a_zauber(41, v_i).f_besch_2[1] = "that gives light (active spell)";
		a_zauber(41, v_i).f_besch_1[3] = "Crea una luciarnaga que ";
		a_zauber(41, v_i).f_besch_2[3] = "ilumina (hechizo activo)";
		a_zauber(42, v_i).f_name[2] = "Vergolden";
		a_zauber(42, v_i).f_name[1] = "Turn-to-gold";
		a_zauber(42, v_i).f_name[3] = "Convertir en oro";
		a_zauber(42, v_i).f_kosten = 3;
		a_zauber(42, v_i).f_level = 6;
		a_zauber(42, v_i).f_dauer = 0;
		a_zauber(42, v_i).f_art = "illusion";
		a_zauber(42, v_i).f_besch_1[2] = "Verwandelt einen";
		a_zauber(42, v_i).f_besch_2[2] = "Gegenstand in Goldm\374nzen";
		a_zauber(42, v_i).f_besch_1[1] = "Turns an item into";
		a_zauber(42, v_i).f_besch_2[1] = "gold coins";
		a_zauber(42, v_i).f_besch_1[3] = "Convierte un objeto en ";
		a_zauber(42, v_i).f_besch_2[3] = "monedas de oro";
		a_zauber(43, v_i).f_name[2] = "Verschwinden";
		a_zauber(43, v_i).f_name[1] = "Vanish";
		a_zauber(43, v_i).f_name[3] = "Desvanecerse";
		a_zauber(43, v_i).f_kosten = 8;
		a_zauber(43, v_i).f_level = 8;
		a_zauber(43, v_i).f_dauer = 0;
		a_zauber(43, v_i).f_art = "illusion";
		a_zauber(43, v_i).f_besch_1[2] = "Der Magier verschwindet und";
		a_zauber(43, v_i).f_besch_2[2] = "taucht an einem anderen Ort auf";
		a_zauber(43, v_i).f_besch_1[1] = "The magician vanishes and";
		a_zauber(43, v_i).f_besch_2[1] = "appears in another place";
		a_zauber(43, v_i).f_besch_1[3] = "El mago se desvanece y ";
		a_zauber(43, v_i).f_besch_2[3] = "aparece en otro lugar";
		a_zauber(44, v_i).f_name[2] = "Terminus";
		a_zauber(44, v_i).f_name[1] = "Dispell Magic";
		a_zauber(44, v_i).f_name[3] = "Terminar";
		a_zauber(44, v_i).f_kosten = 0;
		a_zauber(44, v_i).f_level = 2;
		a_zauber(44, v_i).f_dauer = 0;
		a_zauber(44, v_i).f_art = "hohe";
		a_zauber(44, v_i).f_besch_1[2] = "Beendet alle aktiven Zauber. Der Magier";
		a_zauber(44, v_i).f_besch_2[2] = "erh\344lt 1 Punkt Mana pro Zauber zur\374ck";
		a_zauber(44, v_i).f_besch_1[1] = "Terminates all active spells. The";
		a_zauber(44, v_i).f_besch_2[1] = "magician regains 1 point Mana per spell";
		a_zauber(44, v_i).f_besch_1[3] = "Finaliza todos los hechizos activos. El";
		a_zauber(44, v_i).f_besch_2[3] = "mago gana 1 punto de Mana por hechizo.";
		a_zauber(45, v_i).f_name[2] = "Magieschutz";
		a_zauber(45, v_i).f_name[1] = "Ward against Magic";
		a_zauber(45, v_i).f_name[3] = "Proteccion magica";
		a_zauber(45, v_i).f_kosten = 1;
		a_zauber(45, v_i).f_level = 4;
		a_zauber(45, v_i).f_dauer = 5;
		a_zauber(45, v_i).f_art = "hohe";
		a_zauber(45, v_i).f_besch_1[2] = "Erh\366ht den Schutz des Magiers";
		a_zauber(45, v_i).f_besch_2[2] = "gegen Magie (aktiver Zauber)";
		a_zauber(45, v_i).f_besch_1[1] = "Increases the protection";
		a_zauber(45, v_i).f_besch_2[1] = "against magic (active spell)";
		a_zauber(45, v_i).f_besch_1[3] = "Incrementa la proteccion contra";
		a_zauber(45, v_i).f_besch_2[3] = "la magia (hechizo activo)";
		a_zauber(46, v_i).f_name[2] = "Schutz vor Geschossen";
		a_zauber(46, v_i).f_name[1] = "Ward against Missiles";
		a_zauber(46, v_i).f_name[3] = "Proteccion contra misiles";
		a_zauber(46, v_i).f_kosten = 2;
		a_zauber(46, v_i).f_level = 4;
		a_zauber(46, v_i).f_dauer = 5;
		a_zauber(46, v_i).f_art = "luft";
		a_zauber(46, v_i).f_besch_1[2] = "Erh\366ht den Schutz des Magiers";
		a_zauber(46, v_i).f_besch_2[2] = "gegen Geschosse (aktiver Zauber)";
		a_zauber(46, v_i).f_besch_1[1] = "Increases the protection";
		a_zauber(46, v_i).f_besch_2[1] = "against arrows (active spell)";
		a_zauber(46, v_i).f_besch_1[3] = "Incrementa la proteccion contra ";
		a_zauber(46, v_i).f_besch_2[3] = "flechas (hechizo activo)";
		a_zauber(47, v_i).f_name[2] = "Verl\344ngern";
		a_zauber(47, v_i).f_name[1] = "Extend";
		a_zauber(47, v_i).f_name[3] = "Extender";
		a_zauber(47, v_i).f_kosten = 4;
		a_zauber(47, v_i).f_level = 5;
		a_zauber(47, v_i).f_dauer = 0;
		a_zauber(47, v_i).f_art = "hohe";
		a_zauber(47, v_i).f_besch_1[2] = "Verl\344ngert die Dauer";
		a_zauber(47, v_i).f_besch_2[2] = "aller aktiven Zauber";
		a_zauber(47, v_i).f_besch_1[1] = "Extends the duration";
		a_zauber(47, v_i).f_besch_2[1] = "of all active spells";
		a_zauber(47, v_i).f_besch_1[3] = "Extende la duracion de ";
		a_zauber(47, v_i).f_besch_2[3] = "los hechizos activos";
		a_zauber(48, v_i).f_name[2] = "Fliegen";
		a_zauber(48, v_i).f_name[1] = "Fly";
		a_zauber(48, v_i).f_name[3] = "Volar";
		a_zauber(48, v_i).f_kosten = 3;
		a_zauber(48, v_i).f_level = 5;
		a_zauber(48, v_i).f_dauer = 5;
		a_zauber(48, v_i).f_art = "luft";
		a_zauber(48, v_i).f_besch_1[2] = "Der Zauberer schwebt \374ber Wasser";
		a_zauber(48, v_i).f_besch_2[2] = "und Fallgruben hinweg (Aktiver Zauber)";
		a_zauber(48, v_i).f_besch_1[1] = "The magician floats above";
		a_zauber(48, v_i).f_besch_2[1] = "water and pit traps (Active Spell)";
		a_zauber(48, v_i).f_besch_1[3] = "El mago vuela sobre agua y ";
		a_zauber(48, v_i).f_besch_2[3] = "trampas (hechizo activo)";
		a_zauber(49, v_i).f_name[2] = "\334bers Wasser gehen";
		a_zauber(49, v_i).f_name[1] = "Walk on Water";
		a_zauber(49, v_i).f_name[3] = "Caminar sobre el agua";
		a_zauber(49, v_i).f_kosten = 1;
		a_zauber(49, v_i).f_level = 5;
		a_zauber(49, v_i).f_dauer = 5;
		a_zauber(49, v_i).f_art = "wasser";
		a_zauber(49, v_i).f_besch_1[2] = "Der Magier kann \374ber Wasser-";
		a_zauber(49, v_i).f_besch_2[2] = "fl\344chen gehen (Aktiver Zauber)";
		a_zauber(49, v_i).f_besch_1[1] = "The magician can walk over";
		a_zauber(49, v_i).f_besch_2[1] = "bodies of water (active spell)";
		a_zauber(49, v_i).f_besch_1[3] = "El mago puede caminar sobre masas ";
		a_zauber(49, v_i).f_besch_2[3] = "de agua (hechizo activo)";
		a_zauber(50, v_i).f_name[2] = "Monster Auge";
		a_zauber(50, v_i).f_name[1] = "Monster Eye";
		a_zauber(50, v_i).f_name[3] = "Ojo de monstruo";
		a_zauber(50, v_i).f_kosten = 1;
		a_zauber(50, v_i).f_level = 1;
		a_zauber(50, v_i).f_dauer = 5;
		a_zauber(50, v_i).f_art = "hexerei";
		a_zauber(50, v_i).f_besch_1[2] = "Zeigt der Hexe alle Werte";
		a_zauber(50, v_i).f_besch_2[2] = "eines bestimmen Monsters";
		a_zauber(50, v_i).f_besch_1[1] = "Shows all attributes of";
		a_zauber(50, v_i).f_besch_2[1] = "one monster";
		a_zauber(50, v_i).f_besch_1[3] = "Muestra todas las caracteristicas ";
		a_zauber(50, v_i).f_besch_2[3] = "de un monstruo";
		a_zauber(51, v_i).f_name[2] = "Verhexen";
		a_zauber(51, v_i).f_name[1] = "Charm";
		a_zauber(51, v_i).f_name[3] = "Encanto";
		a_zauber(51, v_i).f_kosten = 2;
		a_zauber(51, v_i).f_level = 3;
		a_zauber(51, v_i).f_dauer = 0;
		a_zauber(51, v_i).f_art = "hexerei";
		a_zauber(51, v_i).f_besch_1[2] = "Bringt ein Monster dazu";
		a_zauber(51, v_i).f_besch_2[2] = "die Hexe als Freund zu sehen";
		a_zauber(51, v_i).f_besch_1[1] = "Befriends a monster";
		a_zauber(51, v_i).f_besch_2[1] = "";
		a_zauber(51, v_i).f_besch_1[3] = "Convierte a un monstruo ";
		a_zauber(51, v_i).f_besch_2[3] = "en aliado";
		a_zauber(52, v_i).f_name[2] = "Hexensicht";
		a_zauber(52, v_i).f_name[1] = "Witch Sight";
		a_zauber(52, v_i).f_name[3] = "Vista de bruja";
		a_zauber(52, v_i).f_kosten = 2;
		a_zauber(52, v_i).f_level = 4;
		a_zauber(52, v_i).f_dauer = 4;
		a_zauber(52, v_i).f_art = "hexerei";
		a_zauber(52, v_i).f_besch_1[2] = "Erh\366ht die Wahrnehmung";
		a_zauber(52, v_i).f_besch_2[2] = "(Aktiver Zauber)";
		a_zauber(52, v_i).f_besch_1[1] = "Increases the perception of";
		a_zauber(52, v_i).f_besch_2[1] = "the magician (active spell)";
		a_zauber(52, v_i).f_besch_1[3] = "Incrementa la percepcion ";
		a_zauber(52, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(53, v_i).f_name[2] = "Zauberschwert";
		a_zauber(53, v_i).f_name[1] = "Eldritch Sword";
		a_zauber(53, v_i).f_name[3] = "Espada superior";
		a_zauber(53, v_i).f_kosten = 3;
		a_zauber(53, v_i).f_level = 2;
		a_zauber(53, v_i).f_dauer = 0;
		a_zauber(53, v_i).f_art = "warlock";
		a_zauber(53, v_i).f_besch_1[2] = "Konjuriert ein magisches";
		a_zauber(53, v_i).f_besch_2[2] = "Schwert";
		a_zauber(53, v_i).f_besch_1[1] = "Conjures a magical";
		a_zauber(53, v_i).f_besch_2[1] = "sword";
		a_zauber(53, v_i).f_besch_1[3] = "Crea una espada ";
		a_zauber(53, v_i).f_besch_2[3] = "magica";
		a_zauber(54, v_i).f_name[2] = "Zauberpfeile";
		a_zauber(54, v_i).f_name[1] = "Magic Arrows";
		a_zauber(54, v_i).f_name[3] = "Flechas magicas";
		a_zauber(54, v_i).f_kosten = 2;
		a_zauber(54, v_i).f_level = 3;
		a_zauber(54, v_i).f_dauer = 0;
		a_zauber(54, v_i).f_art = "warlock";
		a_zauber(54, v_i).f_besch_1[2] = "Konjuriert einige magische Pfeile";
		a_zauber(54, v_i).f_besch_2[2] = "";
		a_zauber(54, v_i).f_besch_1[1] = "Conjures some magical arrows";
		a_zauber(54, v_i).f_besch_2[1] = "";
		a_zauber(54, v_i).f_besch_1[3] = "Crea\302\240unas cuantas ";
		a_zauber(54, v_i).f_besch_2[3] = "flechas magicas";
		a_zauber(55, v_i).f_name[2] = "Falle zerst\366ren";
		a_zauber(55, v_i).f_name[1] = "Destroy Trap";
		a_zauber(55, v_i).f_name[3] = "Destruir trampa";
		a_zauber(55, v_i).f_kosten = 3;
		a_zauber(55, v_i).f_level = 7;
		a_zauber(55, v_i).f_dauer = 0;
		a_zauber(55, v_i).f_art = "basis";
		a_zauber(55, v_i).f_besch_1[2] = "Zerst\366rt eine Falle";
		a_zauber(55, v_i).f_besch_2[2] = "";
		a_zauber(55, v_i).f_besch_1[1] = "Destroys a trap";
		a_zauber(55, v_i).f_besch_2[1] = "";
		a_zauber(55, v_i).f_besch_1[3] = "Destruye una trampa";
		a_zauber(55, v_i).f_besch_2[3] = "";
		a_zauber(56, v_i).f_name[2] = "Prismatisches Spray";
		a_zauber(56, v_i).f_name[1] = "Prismatic Spray";
		a_zauber(56, v_i).f_name[3] = "Espray prismatico";
		a_zauber(56, v_i).f_kosten = 4;
		a_zauber(56, v_i).f_level = 8;
		a_zauber(56, v_i).f_dauer = 0;
		a_zauber(56, v_i).f_art = "basis";
		a_zauber(56, v_i).f_besch_1[2] = "Vielfarbige Strahlen attackieren";
		a_zauber(56, v_i).f_besch_2[2] = "alle Monster in der Umgebung";
		a_zauber(56, v_i).f_besch_1[1] = "Many multicolored rays attack";
		a_zauber(56, v_i).f_besch_2[1] = "all monsters in the vicinity";
		a_zauber(56, v_i).f_besch_1[3] = "Muchos rayos multicolores atacan ";
		a_zauber(56, v_i).f_besch_2[3] = "a todos los monstruos cercanos";
		a_zauber(57, v_i).f_name[2] = "Vortex";
		a_zauber(57, v_i).f_name[1] = "Vortex";
		a_zauber(57, v_i).f_name[3] = "Vortice";
		a_zauber(57, v_i).f_kosten = 3;
		a_zauber(57, v_i).f_level = 10;
		a_zauber(57, v_i).f_dauer = 0;
		a_zauber(57, v_i).f_art = "basis";
		a_zauber(57, v_i).f_besch_1[2] = "Ein magischer Wirbel attackiert";
		a_zauber(57, v_i).f_besch_2[2] = "ein Monster";
		a_zauber(57, v_i).f_besch_1[1] = "A magical vortex attacks";
		a_zauber(57, v_i).f_besch_2[1] = "one monster";
		a_zauber(57, v_i).f_besch_1[3] = "Un vortice magico ataca ";
		a_zauber(57, v_i).f_besch_2[3] = "a un monstruo";
		a_zauber(58, v_i).f_name[2] = "Teleport";
		a_zauber(58, v_i).f_name[1] = "Teleport";
		a_zauber(58, v_i).f_name[3] = "Teletransporte";
		a_zauber(58, v_i).f_kosten = 12;
		a_zauber(58, v_i).f_level = 12;
		a_zauber(58, v_i).f_dauer = 0;
		a_zauber(58, v_i).f_art = "illusion";
		a_zauber(58, v_i).f_besch_1[2] = "Versetzt den Magier";
		a_zauber(58, v_i).f_besch_2[2] = "an einen anderen Ort";
		a_zauber(58, v_i).f_besch_1[1] = "Moves the magician";
		a_zauber(58, v_i).f_besch_2[1] = "to another place";
		a_zauber(58, v_i).f_besch_1[3] = "Mueve el mago a ";
		a_zauber(58, v_i).f_besch_2[3] = "otro lugar";
		a_zauber(59, v_i).f_name[2] = "Macht";
		a_zauber(59, v_i).f_name[1] = "Might";
		a_zauber(59, v_i).f_name[3] = "Poder";
		a_zauber(59, v_i).f_kosten = 5;
		a_zauber(59, v_i).f_level = 13;
		a_zauber(59, v_i).f_dauer = 1;
		a_zauber(59, v_i).f_art = "hohe";
		a_zauber(59, v_i).f_besch_1[2] = "Verdoppelt die Macht des";
		a_zauber(59, v_i).f_besch_2[2] = "Zauberers (aktiver Zauber)";
		a_zauber(59, v_i).f_besch_1[1] = "Doubles the power of the";
		a_zauber(59, v_i).f_besch_2[1] = "magician (active spell)";
		a_zauber(59, v_i).f_besch_1[3] = "Duplica el poder del mago ";
		a_zauber(59, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(61, v_i).f_name[2] = "Fallensinn";
		a_zauber(61, v_i).f_name[1] = "Trap Alert";
		a_zauber(61, v_i).f_name[3] = "Alarma de trampas";
		a_zauber(61, v_i).f_kosten = 3;
		a_zauber(61, v_i).f_level = 7;
		a_zauber(61, v_i).f_dauer = 5;
		a_zauber(61, v_i).f_art = "erde";
		a_zauber(61, v_i).f_besch_1[2] = "Erh\366ht die Chance Fallen";
		a_zauber(61, v_i).f_besch_2[2] = "zu entdecken (Aktiver Zauber)";
		a_zauber(61, v_i).f_besch_1[1] = "Increases the chance to";
		a_zauber(61, v_i).f_besch_2[1] = "spot traps (active spell)";
		a_zauber(61, v_i).f_besch_1[3] = "Incrementa las posibilitades de detectar ";
		a_zauber(61, v_i).f_besch_2[3] = "trampas (hechizo activo)";
		a_zauber(62, v_i).f_name[2] = "Versteinern";
		a_zauber(62, v_i).f_name[1] = "Turn to Stone";
		a_zauber(62, v_i).f_name[3] = "Convertir en piedra";
		a_zauber(62, v_i).f_kosten = 3;
		a_zauber(62, v_i).f_level = 8;
		a_zauber(62, v_i).f_dauer = 0;
		a_zauber(62, v_i).f_art = "erde";
		a_zauber(62, v_i).f_besch_1[2] = "L\344sst ein Monster";
		a_zauber(62, v_i).f_besch_2[2] = "versteinern";
		a_zauber(62, v_i).f_besch_1[1] = "Turns a monster";
		a_zauber(62, v_i).f_besch_2[1] = "into stone";
		a_zauber(62, v_i).f_besch_1[3] = "Convierte a un monstruo ";
		a_zauber(62, v_i).f_besch_2[3] = "en piedra";
		a_zauber(63, v_i).f_name[2] = "Erdbeben";
		a_zauber(63, v_i).f_name[1] = "Earthquake";
		a_zauber(63, v_i).f_name[3] = "Terremoto";
		a_zauber(63, v_i).f_kosten = 4;
		a_zauber(63, v_i).f_level = 10;
		a_zauber(63, v_i).f_dauer = 0;
		a_zauber(63, v_i).f_art = "erde";
		a_zauber(63, v_i).f_besch_1[2] = "Ein gewaltiger Erdschlag trifft";
		a_zauber(63, v_i).f_besch_2[2] = "alle nicht-fliegenden Monster";
		a_zauber(63, v_i).f_besch_1[1] = "A mighty blow attacks all";
		a_zauber(63, v_i).f_besch_2[1] = "non-flying monsters";
		a_zauber(63, v_i).f_besch_1[3] = "Un poderoso temblor ataca todos ";
		a_zauber(63, v_i).f_besch_2[3] = "los monstruos no voladores";
		a_zauber(64, v_i).f_name[2] = "Fallen entfernen";
		a_zauber(64, v_i).f_name[1] = "Remove Traps";
		a_zauber(64, v_i).f_name[3] = "Quitar trampas";
		a_zauber(64, v_i).f_kosten = 5;
		a_zauber(64, v_i).f_level = 12;
		a_zauber(64, v_i).f_dauer = 0;
		a_zauber(64, v_i).f_art = "erde";
		a_zauber(64, v_i).f_besch_1[2] = "Zerst\366rt alle Fallen in";
		a_zauber(64, v_i).f_besch_2[2] = "der unmittelbaren Umgebung";
		a_zauber(64, v_i).f_besch_1[1] = "Destroys all traps around";
		a_zauber(64, v_i).f_besch_2[1] = "the magician";
		a_zauber(64, v_i).f_besch_1[3] = "Destruye todas las trampas ";
		a_zauber(64, v_i).f_besch_2[3] = "cerca del mago";
		a_zauber(22, v_i).f_name[2] = "Drachenfeuer";
		a_zauber(22, v_i).f_name[1] = "Dragon Fire";
		a_zauber(22, v_i).f_name[3] = "Fuego de dragon";
		a_zauber(22, v_i).f_kosten = 3;
		a_zauber(22, v_i).f_level = 8;
		a_zauber(22, v_i).f_dauer = 0;
		a_zauber(22, v_i).f_art = "feuer";
		a_zauber(22, v_i).f_besch_1[2] = "Wirft Drachenfeuer auf ein";
		a_zauber(22, v_i).f_besch_2[2] = "Monster";
		a_zauber(22, v_i).f_besch_1[1] = "Throws Dragonfire onto one";
		a_zauber(22, v_i).f_besch_2[1] = "monster";
		a_zauber(22, v_i).f_besch_1[3] = "Lanza fuego de dragon ";
		a_zauber(22, v_i).f_besch_2[3] = "a un monstruo";
		a_zauber(66, v_i).f_name[2] = "Dunkles Mana";
		a_zauber(66, v_i).f_name[1] = "Dark Mana";
		a_zauber(66, v_i).f_name[3] = "Mana oscuro";
		a_zauber(66, v_i).f_kosten = 0;
		a_zauber(66, v_i).f_level = 7;
		a_zauber(66, v_i).f_dauer = 0;
		a_zauber(66, v_i).f_art = "schwarz";
		a_zauber(66, v_i).f_besch_1[2] = "Verwandelt ein Skelett";
		a_zauber(66, v_i).f_besch_2[2] = "in Mana";
		a_zauber(66, v_i).f_besch_1[1] = "Turns a skeleton into";
		a_zauber(66, v_i).f_besch_2[1] = "mana";
		a_zauber(66, v_i).f_besch_1[3] = "Convierte a un esqueleto ";
		a_zauber(66, v_i).f_besch_2[3] = "en mana";
		a_zauber(67, v_i).f_name[2] = "Wort des Todes";
		a_zauber(67, v_i).f_name[1] = "Word of Death";
		a_zauber(67, v_i).f_name[3] = "Palabra de muerte";
		a_zauber(67, v_i).f_kosten = 3;
		a_zauber(67, v_i).f_level = 12;
		a_zauber(67, v_i).f_dauer = 0;
		a_zauber(67, v_i).f_art = "schwarz";
		a_zauber(67, v_i).f_besch_1[2] = "T\366tet alles Menschen-";
		a_zauber(67, v_i).f_besch_2[2] = "\344hnliche";
		a_zauber(67, v_i).f_besch_1[1] = "Kills everything close";
		a_zauber(67, v_i).f_besch_2[1] = "to a human";
		a_zauber(67, v_i).f_besch_1[3] = "Mata todo lo cercano ";
		a_zauber(67, v_i).f_besch_2[3] = "a un hombre";
		a_zauber(68, v_i).f_name[2] = "Eisschild";
		a_zauber(68, v_i).f_name[1] = "Iceshield";
		a_zauber(68, v_i).f_name[3] = "Escudo antihielo";
		a_zauber(68, v_i).f_kosten = 1;
		a_zauber(68, v_i).f_level = 2;
		a_zauber(68, v_i).f_dauer = 5;
		a_zauber(68, v_i).f_art = "wasser";
		a_zauber(68, v_i).f_besch_1[2] = "Sch\374tzt den Magier vor Schaden";
		a_zauber(68, v_i).f_besch_2[2] = "durch K\344lte (Aktiver Zauber)";
		a_zauber(68, v_i).f_besch_1[1] = "Wards against cold and ice";
		a_zauber(68, v_i).f_besch_2[1] = "(active spell)";
		a_zauber(68, v_i).f_besch_1[3] = "Proteccion contra el frio y ";
		a_zauber(68, v_i).f_besch_2[3] = "el hielo (hechizo activo)";
		a_zauber(60, v_i).f_name[2] = "Feuer bannen";
		a_zauber(60, v_i).f_name[1] = "Banish Fire";
		a_zauber(60, v_i).f_name[3] = "Extinguir fuego";
		a_zauber(60, v_i).f_kosten = 2;
		a_zauber(60, v_i).f_level = 3;
		a_zauber(60, v_i).f_dauer = 0;
		a_zauber(60, v_i).f_art = "wasser";
		a_zauber(60, v_i).f_besch_1[2] = "L\366scht alle Feuerfelder";
		a_zauber(60, v_i).f_besch_2[2] = "in der n\344heren Umgebung";
		a_zauber(60, v_i).f_besch_1[1] = "Destroys all fire fields";
		a_zauber(60, v_i).f_besch_2[1] = "around the magician";
		a_zauber(60, v_i).f_besch_1[3] = "Apaga todos los fuegos ";
		a_zauber(60, v_i).f_besch_2[3] = "alrededor del mago";
		a_zauber(70, v_i).f_name[2] = "Winteratem";
		a_zauber(70, v_i).f_name[1] = "Breath of Winter";
		a_zauber(70, v_i).f_name[3] = "Aliento invernal";
		a_zauber(70, v_i).f_kosten = 3;
		a_zauber(70, v_i).f_level = 7;
		a_zauber(70, v_i).f_dauer = 5;
		a_zauber(70, v_i).f_art = "wasser";
		a_zauber(70, v_i).f_besch_1[2] = "Umh\374llt den Magier mit einer";
		a_zauber(70, v_i).f_besch_2[2] = "Aura der K\344lte (Aktiver Zauber)";
		a_zauber(70, v_i).f_besch_1[1] = "The magician receives an";
		a_zauber(70, v_i).f_besch_2[1] = "aura of coldness (active spell)";
		a_zauber(70, v_i).f_besch_1[3] = "El mago recibe un aura de ";
		a_zauber(70, v_i).f_besch_2[3] = "frescor (hechizho activo)";
		a_zauber(71, v_i).f_name[2] = "Flammenaura";
		a_zauber(71, v_i).f_name[1] = "Aura of Fire";
		a_zauber(71, v_i).f_name[3] = "Aura de fuego";
		a_zauber(71, v_i).f_kosten = 3;
		a_zauber(71, v_i).f_level = 7;
		a_zauber(71, v_i).f_dauer = 5;
		a_zauber(71, v_i).f_art = "feuer";
		a_zauber(71, v_i).f_besch_1[2] = "Umh\374llt den Magier mit einer";
		a_zauber(71, v_i).f_besch_2[2] = "Aura der Hitze (Aktiver Zauber)";
		a_zauber(71, v_i).f_besch_1[1] = "The magician receives an";
		a_zauber(71, v_i).f_besch_2[1] = "aura of fire (active spell)";
		a_zauber(71, v_i).f_besch_1[3] = "El mago recibe un aura de ";
		a_zauber(71, v_i).f_besch_2[3] = "fuego (hechizo activo)";
		a_zauber(72, v_i).f_name[2] = "Ewiger Winter";
		a_zauber(72, v_i).f_name[1] = "Eternal Winter";
		a_zauber(72, v_i).f_name[3] = "Invierno eterno";
		a_zauber(72, v_i).f_kosten = 3;
		a_zauber(72, v_i).f_level = 8;
		a_zauber(72, v_i).f_dauer = 0;
		a_zauber(72, v_i).f_art = "wasser";
		a_zauber(72, v_i).f_besch_1[2] = "L\344sst ein Monster einfrieren";
		a_zauber(72, v_i).f_besch_2[2] = "";
		a_zauber(72, v_i).f_besch_1[1] = "Turns a monster into ice";
		a_zauber(72, v_i).f_besch_2[1] = "";
		a_zauber(72, v_i).f_besch_1[3] = "Convierte un monstruo en hielo";
		a_zauber(72, v_i).f_besch_2[3] = "";
		a_zauber(73, v_i).f_name[2] = "Flutwelle";
		a_zauber(73, v_i).f_name[1] = "Tidal Wave";
		a_zauber(73, v_i).f_name[3] = "Ola de la marea";
		a_zauber(73, v_i).f_kosten = 4;
		a_zauber(73, v_i).f_level = 9;
		a_zauber(73, v_i).f_dauer = 0;
		a_zauber(73, v_i).f_art = "wasser";
		a_zauber(73, v_i).f_besch_1[2] = "Beschw\366rt eine gewaltige";
		a_zauber(73, v_i).f_besch_2[2] = "Flutwelle herbei";
		a_zauber(73, v_i).f_besch_1[1] = "Summons a gigantic tidal";
		a_zauber(73, v_i).f_besch_2[1] = "wave";
		a_zauber(73, v_i).f_besch_1[3] = "Envia una inundacion en ";
		a_zauber(73, v_i).f_besch_2[3] = "forma de ola gigante";
		a_zauber(74, v_i).f_name[2] = "Wahrlicht";
		a_zauber(74, v_i).f_name[1] = "True Light";
		a_zauber(74, v_i).f_name[3] = "Luz verdadera";
		a_zauber(74, v_i).f_kosten = 3;
		a_zauber(74, v_i).f_level = 8;
		a_zauber(74, v_i).f_dauer = 4;
		a_zauber(74, v_i).f_art = "sterne";
		a_zauber(74, v_i).f_besch_1[2] = "Das einzig wahre Licht";
		a_zauber(74, v_i).f_besch_2[2] = "(aktiver Zauber)";
		a_zauber(74, v_i).f_besch_1[1] = "The only real light";
		a_zauber(74, v_i).f_besch_2[1] = "(active spell)";
		a_zauber(74, v_i).f_besch_1[3] = "La unica luz real ";
		a_zauber(74, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(75, v_i).f_name[2] = "Gl\374ckszauber";
		a_zauber(75, v_i).f_name[1] = "Luck Spell";
		a_zauber(75, v_i).f_name[3] = "Conjuro de suerte";
		a_zauber(75, v_i).f_kosten = 4;
		a_zauber(75, v_i).f_level = 6;
		a_zauber(75, v_i).f_dauer = 4;
		a_zauber(75, v_i).f_art = "sterne";
		a_zauber(75, v_i).f_besch_1[2] = "Erh\366ht den Gl\374ckswert";
		a_zauber(75, v_i).f_besch_2[2] = "(aktiver Zauber)";
		a_zauber(75, v_i).f_besch_1[1] = "Increases Luck";
		a_zauber(75, v_i).f_besch_2[1] = "(active spell)";
		a_zauber(75, v_i).f_besch_1[3] = "Incrementa la suerte ";
		a_zauber(75, v_i).f_besch_2[3] = "(hechizo activo)";
		a_zauber(76, v_i).f_name[2] = "Sternenfeuer";
		a_zauber(76, v_i).f_name[1] = "Starfire";
		a_zauber(76, v_i).f_name[3] = "Fuego estelar";
		a_zauber(76, v_i).f_kosten = 4;
		a_zauber(76, v_i).f_level = 12;
		a_zauber(76, v_i).f_dauer = 0;
		a_zauber(76, v_i).f_art = "sterne";
		a_zauber(76, v_i).f_besch_1[2] = "Sternenfeuer attackiert alle";
		a_zauber(76, v_i).f_besch_2[2] = "nahen Monster";
		a_zauber(76, v_i).f_besch_1[1] = "Starfire attacks all";
		a_zauber(76, v_i).f_besch_2[1] = "nearby monsters";
		a_zauber(76, v_i).f_besch_1[3] = "Fuego estelar ataca todos ";
		a_zauber(76, v_i).f_besch_2[3] = "los monstruos cercanos";
		a_zauber(77, v_i).f_name[2] = "Fl\374che brechen";
		a_zauber(77, v_i).f_name[1] = "Remove Curses";
		a_zauber(77, v_i).f_name[3] = "Quitar maldiciones";
		a_zauber(77, v_i).f_kosten = 12;
		a_zauber(77, v_i).f_level = 9;
		a_zauber(77, v_i).f_dauer = 0;
		a_zauber(77, v_i).f_art = "weiss";
		a_zauber(77, v_i).f_besch_1[2] = "Befreit den Magier von";
		a_zauber(77, v_i).f_besch_2[2] = "allen Fl\374chen";
		a_zauber(77, v_i).f_besch_1[1] = "Removes all curses from";
		a_zauber(77, v_i).f_besch_2[1] = "the magician";
		a_zauber(77, v_i).f_besch_1[3] = "Quita todas las maldiciones ";
		a_zauber(77, v_i).f_besch_2[3] = "del mago";
		a_zauber(78, v_i).f_name[2] = "Allheilung";
		a_zauber(78, v_i).f_name[1] = "True Healing";
		a_zauber(78, v_i).f_name[3] = "Cura verdadera";
		a_zauber(78, v_i).f_kosten = 7;
		a_zauber(78, v_i).f_level = 10;
		a_zauber(78, v_i).f_dauer = 0;
		a_zauber(78, v_i).f_art = "weiss";
		a_zauber(78, v_i).f_besch_1[2] = "Der Magier erh\344lt alle verlorenen";
		a_zauber(78, v_i).f_besch_2[2] = "Lebenspunkte zur\374ck";
		a_zauber(78, v_i).f_besch_1[1] = "The magician regains all";
		a_zauber(78, v_i).f_besch_2[1] = "lost lifepoints";
		a_zauber(78, v_i).f_besch_1[3] = "El mago recupera totos ";
		a_zauber(78, v_i).f_besch_2[3] = "los puntos de vida";
		a_zauber(79, v_i).f_name[2] = "Lied der Magie";
		a_zauber(79, v_i).f_name[1] = "Song of Magic";
		a_zauber(79, v_i).f_name[3] = "Cancion de magia";
		a_zauber(79, v_i).f_kosten = 6;
		a_zauber(79, v_i).f_level = 6;
		a_zauber(79, v_i).f_dauer = 9999;
		a_zauber(79, v_i).f_art = "barde";
		a_zauber(79, v_i).f_besch_1[2] = "Sch\374tzt den Barden gegen";
		a_zauber(79, v_i).f_besch_2[2] = "Runenfallen";
		a_zauber(79, v_i).f_besch_1[1] = "Wards against runetraps";
		a_zauber(79, v_i).f_besch_2[1] = "";
		a_zauber(79, v_i).f_besch_1[3] = "Proteccion frente a ";
		a_zauber(79, v_i).f_besch_2[3] = "trampas de runa";
		a_zauber(80, v_i).f_name[2] = "Lied des Lebens";
		a_zauber(80, v_i).f_name[1] = "Song of Life";
		a_zauber(80, v_i).f_name[3] = "Cancion de vida";
		a_zauber(80, v_i).f_kosten = 7;
		a_zauber(80, v_i).f_level = 7;
		a_zauber(80, v_i).f_dauer = 9999;
		a_zauber(80, v_i).f_art = "barde";
		a_zauber(80, v_i).f_besch_1[2] = "Der Barde gewinnt pro Runde einen";
		a_zauber(80, v_i).f_besch_2[2] = "verlorenen Lebenspunkt zurck";
		a_zauber(80, v_i).f_besch_1[1] = "The bard regains one lost";
		a_zauber(80, v_i).f_besch_2[1] = "life point per round";
		a_zauber(80, v_i).f_besch_1[3] = "El bardo gana un punto ";
		a_zauber(80, v_i).f_besch_2[3] = "de vida por turno";
		a_zauber(81, v_i).f_name[2] = "Blitzschlag";
		a_zauber(81, v_i).f_name[1] = "Lightning Bolt";
		a_zauber(81, v_i).f_name[3] = "Relampago";
		a_zauber(81, v_i).f_kosten = 2;
		a_zauber(81, v_i).f_level = 6;
		a_zauber(81, v_i).f_dauer = 0;
		a_zauber(81, v_i).f_art = "hexerei";
		a_zauber(81, v_i).f_besch_1[2] = "Wirft einen t\366dlichen";
		a_zauber(81, v_i).f_besch_2[2] = "Blitz auf einen Gegner";
		a_zauber(81, v_i).f_besch_1[1] = "Throws a deadly lightning";
		a_zauber(81, v_i).f_besch_2[1] = "bolt against an enemy";
		a_zauber(81, v_i).f_besch_1[3] = "Lanza un relampago mortal";
		a_zauber(81, v_i).f_besch_2[3] = "contra un enemigo";
		a_zauber(82, v_i).f_name[2] = "Syphon";
		a_zauber(82, v_i).f_name[1] = "Syphon";
		a_zauber(82, v_i).f_name[3] = "Sifon";
		a_zauber(82, v_i).f_kosten = 7;
		a_zauber(82, v_i).f_level = 14;
		a_zauber(82, v_i).f_dauer = 4;
		a_zauber(82, v_i).f_art = "hohe";
		a_zauber(82, v_i).f_besch_1[2] = "Halbiert Manakosten";
		a_zauber(82, v_i).f_besch_2[2] = "aller Zauber";
		a_zauber(82, v_i).f_besch_1[1] = "Halves the cost of";
		a_zauber(82, v_i).f_besch_2[1] = "all spells";
		a_zauber(82, v_i).f_besch_1[3] = "Reduce el coste de los ";
		a_zauber(82, v_i).f_besch_2[3] = "hechizos a la mitad";
		a_zauber(83, v_i).f_name[2] = "Nexus";
		a_zauber(83, v_i).f_name[1] = "Nexus";
		a_zauber(83, v_i).f_name[3] = "Nexo";
		a_zauber(83, v_i).f_kosten = 5;
		a_zauber(83, v_i).f_level = 15;
		a_zauber(83, v_i).f_dauer = 0;
		a_zauber(83, v_i).f_art = "hohe";
		a_zauber(83, v_i).f_besch_1[2] = "Erschafft einen neuen";
		a_zauber(83, v_i).f_besch_2[2] = "Nexus";
		a_zauber(83, v_i).f_besch_1[1] = "Creates a new";
		a_zauber(83, v_i).f_besch_2[1] = "nexus";
		a_zauber(83, v_i).f_besch_1[3] = "Crea un nuevo ";
		a_zauber(83, v_i).f_besch_2[3] = "nexo";
		a_zauber(84, v_i).f_name[2] = "Zauberschild";
		a_zauber(84, v_i).f_name[1] = "Eldritch Shield";
		a_zauber(84, v_i).f_name[3] = "Escudo superior";
		a_zauber(84, v_i).f_kosten = 2;
		a_zauber(84, v_i).f_level = 7;
		a_zauber(84, v_i).f_dauer = 0;
		a_zauber(84, v_i).f_art = "warlock";
		a_zauber(84, v_i).f_besch_1[2] = "Konjuriert ein magisches";
		a_zauber(84, v_i).f_besch_2[2] = "Schild";
		a_zauber(84, v_i).f_besch_1[1] = "Conjures a magical";
		a_zauber(84, v_i).f_besch_2[1] = "shield";
		a_zauber(84, v_i).f_besch_1[3] = "Crea un escudo ";
		a_zauber(84, v_i).f_besch_2[3] = "magico";
		a_zauber(85, v_i).f_name[2] = "St\344rkezauber";
		a_zauber(85, v_i).f_name[1] = "Strength Spell";
		a_zauber(85, v_i).f_name[3] = "Hechizo de Fuerza";
		a_zauber(85, v_i).f_kosten = 2;
		a_zauber(85, v_i).f_level = 5;
		a_zauber(85, v_i).f_dauer = 4;
		a_zauber(85, v_i).f_art = "warlock";
		a_zauber(85, v_i).f_besch_1[2] = "Erh\366ht die St\344rke des";
		a_zauber(85, v_i).f_besch_2[2] = "Magiers (aktiver Zauber)";
		a_zauber(85, v_i).f_besch_1[1] = "Increases the strength of";
		a_zauber(85, v_i).f_besch_2[1] = "the magician (active spell)";
		a_zauber(85, v_i).f_besch_1[3] = "Aumenta la Fuerza del";
		a_zauber(85, v_i).f_besch_2[3] = "mago (hechizo activo)";
		a_zauber(86, v_i).f_name[2] = "Fledermausgestalt";
		a_zauber(86, v_i).f_name[1] = "Bat Shape";
		a_zauber(86, v_i).f_name[3] = "Cuerpo de Murcielago";
		a_zauber(86, v_i).f_kosten = 2;
		a_zauber(86, v_i).f_level = 2;
		a_zauber(86, v_i).f_dauer = 4;
		a_zauber(86, v_i).f_art = "schwarz";
		a_zauber(86, v_i).f_besch_1[2] = "Verwandelt den Magier in";
		a_zauber(86, v_i).f_besch_2[2] = "eine Fledermaus (aktiver Zauber)";
		a_zauber(86, v_i).f_besch_1[1] = "Turns the Magician into a";
		a_zauber(86, v_i).f_besch_2[1] = "bat (active spell)";
		a_zauber(86, v_i).f_besch_1[3] = "Transforma el Mago en un";
		a_zauber(86, v_i).f_besch_2[3] = "murcielago (hechizo activo)";
		a_zauber(87, v_i).f_name[2] = "Wolfsgestalt";
		a_zauber(87, v_i).f_name[1] = "Wolf Shape";
		a_zauber(87, v_i).f_name[3] = "Cuerpo de lobo";
		a_zauber(87, v_i).f_kosten = 3;
		a_zauber(87, v_i).f_level = 6;
		a_zauber(87, v_i).f_dauer = 5;
		a_zauber(87, v_i).f_art = "druide";
		a_zauber(87, v_i).f_besch_1[2] = "Verwandelt den Magier in";
		a_zauber(87, v_i).f_besch_2[2] = "einen Wolf (aktiver Zauber)";
		a_zauber(87, v_i).f_besch_1[1] = "Turns the Magician into a";
		a_zauber(87, v_i).f_besch_2[1] = "wolf (active spell)";
		a_zauber(87, v_i).f_besch_1[3] = "Transforma el Mago en un";
		a_zauber(87, v_i).f_besch_2[3] = "lobo (hechizo activo)";
		a_zauber(88, v_i).f_name[2] = "Vogelgestalt";
		a_zauber(88, v_i).f_name[1] = "Bird Shape";
		a_zauber(88, v_i).f_name[3] = "Cuerpo de pajaro";
		a_zauber(88, v_i).f_kosten = 1;
		a_zauber(88, v_i).f_level = 3;
		a_zauber(88, v_i).f_dauer = 5;
		a_zauber(88, v_i).f_art = "illusion";
		a_zauber(88, v_i).f_besch_1[2] = "Verwandelt den Magier in";
		a_zauber(88, v_i).f_besch_2[2] = "einen Vogel (aktiver Zauber)";
		a_zauber(88, v_i).f_besch_1[1] = "Turns the Magician into a";
		a_zauber(88, v_i).f_besch_2[1] = "bird (active spell)";
		a_zauber(88, v_i).f_besch_1[3] = "Transforma el Mago en un";
		a_zauber(88, v_i).f_besch_2[3] = "pajaro (hechizo activo)";
		a_zauber(89, v_i).f_name[2] = "Katzengestalt";
		a_zauber(89, v_i).f_name[1] = "Cat Shape";
		a_zauber(89, v_i).f_name[3] = "Cuerpo de gata";
		a_zauber(89, v_i).f_kosten = 1;
		a_zauber(89, v_i).f_level = 2;
		a_zauber(89, v_i).f_dauer = 5;
		a_zauber(89, v_i).f_art = "hexerei";
		a_zauber(89, v_i).f_besch_1[2] = "Verwandelt die Hexe in";
		a_zauber(89, v_i).f_besch_2[2] = "eine Katze (aktiver Zauber)";
		a_zauber(89, v_i).f_besch_1[1] = "Turns the Witch into a";
		a_zauber(89, v_i).f_besch_2[1] = "cat (active spell)";
		a_zauber(89, v_i).f_besch_1[3] = "Transforma la Bruja en una";
		a_zauber(89, v_i).f_besch_2[3] = "gata (hechizo activo)";
		a_zauber(90, v_i).f_name[2] = "Drachengestalt";
		a_zauber(90, v_i).f_name[1] = "Dragon Shape";
		a_zauber(90, v_i).f_name[3] = "Cuerpo de dragon";
		a_zauber(90, v_i).f_kosten = 30;
		a_zauber(90, v_i).f_level = 15;
		a_zauber(90, v_i).f_dauer = 2;
		a_zauber(90, v_i).f_art = "hexerei";
		a_zauber(90, v_i).f_besch_1[2] = "Verwandelt die Hexe in";
		a_zauber(90, v_i).f_besch_2[2] = "einen Drachen (aktiver Zauber)";
		a_zauber(90, v_i).f_besch_1[1] = "Turns the Witch into a";
		a_zauber(90, v_i).f_besch_2[1] = "dragon (active spell)";
		a_zauber(90, v_i).f_besch_1[3] = "Transforma la Bruja en un";
		a_zauber(90, v_i).f_besch_2[3] = "dragon (hechizo activo)";
		a_zauber(91, v_i).f_name[2] = "Homunkulus beschw\366ren";
		a_zauber(91, v_i).f_name[1] = "Summon Homunkulus";
		a_zauber(91, v_i).f_name[3] = "Conjurar Homunkulus";
		a_zauber(91, v_i).f_kosten = 3;
		a_zauber(91, v_i).f_level = 3;
		a_zauber(91, v_i).f_dauer = 0;
		a_zauber(91, v_i).f_art = "hohe";
		a_zauber(91, v_i).f_besch_1[2] = "Beschw\366rt einen magischen";
		a_zauber(91, v_i).f_besch_2[2] = "Diener auf dem Nexus";
		a_zauber(91, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(91, v_i).f_besch_2[1] = "servant on the nexus";
		a_zauber(91, v_i).f_besch_1[3] = "Conjura un criado magico";
		a_zauber(91, v_i).f_besch_2[3] = "en el nexo";
		a_summoning(91) = 1;
		a_zauber(147, v_i).f_name[2] = "Vogel beschw\366ren";
		a_zauber(147, v_i).f_name[1] = "Summon Bird";
		a_zauber(147, v_i).f_name[3] = "Conjurar Pajaro";
		a_zauber(147, v_i).f_kosten = 3;
		a_zauber(147, v_i).f_level = 4;
		a_zauber(147, v_i).f_dauer = 0;
		a_zauber(147, v_i).f_art = "druide";
		a_zauber(147, v_i).f_besch_1[2] = "Beschw\366rt einen Vogel";
		a_zauber(147, v_i).f_besch_2[2] = "herbei. (Fliegt)";
		a_zauber(147, v_i).f_besch_1[1] = "Summons a Bird";
		a_zauber(147, v_i).f_besch_2[1] = "(Flying)";
		a_zauber(147, v_i).f_besch_1[3] = "Conjura un pajaro";
		a_zauber(147, v_i).f_besch_2[3] = "(Volando)";
		a_summoning(147) = 1;
		a_zauber(92, v_i).f_name[2] = "Skelett beschw\366ren";
		a_zauber(92, v_i).f_name[1] = "Summon Skeleton";
		a_zauber(92, v_i).f_name[3] = "Conjurar Esqueleto";
		a_zauber(92, v_i).f_kosten = 3;
		a_zauber(92, v_i).f_level = 4;
		a_zauber(92, v_i).f_dauer = 0;
		a_zauber(92, v_i).f_art = "schwarz";
		a_zauber(92, v_i).f_besch_1[2] = "Beschw\366rt einen Skelettkrieger";
		a_zauber(92, v_i).f_besch_2[2] = "aus einem Skelett";
		a_zauber(92, v_i).f_besch_1[1] = "Summons a skeleton warrior";
		a_zauber(92, v_i).f_besch_2[1] = "from bones";
		a_zauber(92, v_i).f_besch_1[3] = "Conjura un esqueleto luchador";
		a_zauber(92, v_i).f_besch_2[3] = "desde unos huesos";
		a_summoning(92) = 1;
		a_zauber(93, v_i).f_name[2] = "Todesritter beschw\366ren";
		a_zauber(93, v_i).f_name[1] = "Summon Deathknight";
		a_zauber(93, v_i).f_name[3] = "Conjurar Caballero de Muerto";
		a_zauber(93, v_i).f_kosten = 7;
		a_zauber(93, v_i).f_level = 6;
		a_zauber(93, v_i).f_dauer = 0;
		a_zauber(93, v_i).f_art = "schwarz";
		a_zauber(93, v_i).f_besch_1[2] = "Beschw\366rt einen Todesritter";
		a_zauber(93, v_i).f_besch_2[2] = "aus einem Skelett";
		a_zauber(93, v_i).f_besch_1[1] = "Summons a deathknight";
		a_zauber(93, v_i).f_besch_2[1] = "from bones";
		a_zauber(93, v_i).f_besch_1[3] = "Conjura un caballero de muerto";
		a_zauber(93, v_i).f_besch_2[3] = "desde unos huesos";
		a_summoning(93) = 1;
		a_zauber(94, v_i).f_name[2] = "Sternenfee beschw\366ren";
		a_zauber(94, v_i).f_name[1] = "Summon Star Faerie";
		a_zauber(94, v_i).f_name[3] = "Conjurar hada de las estrellas";
		a_zauber(94, v_i).f_kosten = 3;
		a_zauber(94, v_i).f_level = 7;
		a_zauber(94, v_i).f_dauer = 0;
		a_zauber(94, v_i).f_art = "sterne";
		a_zauber(94, v_i).f_besch_1[2] = "Beschw\366rt eine Sternenfee";
		a_zauber(94, v_i).f_besch_2[2] = "(Kann durch W\344nde laufen, Nur Nexus!)";
		a_zauber(94, v_i).f_besch_1[1] = "Summons a small star faerie";
		a_zauber(94, v_i).f_besch_2[1] = "(Can move through walls, Nexus only!)";
		a_zauber(94, v_i).f_besch_1[3] = "Conjura una haga pequena";
		a_zauber(94, v_i).f_besch_2[3] = "(Puede atravesar pareds, en nexus!)";
		a_summoning(94) = 1;
		a_zauber(95, v_i).f_name[2] = "Tiger beschw\366ren";
		a_zauber(95, v_i).f_name[1] = "Summon Tiger";
		a_zauber(95, v_i).f_name[3] = "Conjurar tigre";
		a_zauber(95, v_i).f_kosten = 5;
		a_zauber(95, v_i).f_level = 7;
		a_zauber(95, v_i).f_dauer = 0;
		a_zauber(95, v_i).f_art = "hexerei";
		a_zauber(95, v_i).f_besch_1[2] = "Beschw\366rt einen wilden";
		a_zauber(95, v_i).f_besch_2[2] = "Tiger auf dem nexus herbei";
		a_zauber(95, v_i).f_besch_1[1] = "Summons a ferocious";
		a_zauber(95, v_i).f_besch_2[1] = "tiger on the nexus";
		a_zauber(95, v_i).f_besch_1[3] = "Conjura un tigre";
		a_zauber(95, v_i).f_besch_2[3] = "feroz en el nexus";
		a_summoning(95) = 1;
		a_zauber(96, v_i).f_name[2] = "Mumie beschw\366ren";
		a_zauber(96, v_i).f_name[1] = "Summon Mummy";
		a_zauber(96, v_i).f_name[3] = "Conjurar momia";
		a_zauber(96, v_i).f_kosten = 12;
		a_zauber(96, v_i).f_level = 8;
		a_zauber(96, v_i).f_dauer = 0;
		a_zauber(96, v_i).f_art = "schwarz";
		a_zauber(96, v_i).f_besch_1[2] = "Beschw\366rt eine uralte untote";
		a_zauber(96, v_i).f_besch_2[2] = "Mumie aus einem Skelett herbei";
		a_zauber(96, v_i).f_besch_1[1] = "Summons an ancient undead";
		a_zauber(96, v_i).f_besch_2[1] = "mummy from a skeleton";
		a_zauber(96, v_i).f_besch_1[3] = "Conjura una viejano muerto";
		a_zauber(96, v_i).f_besch_2[3] = "momia de un eskeleto";
		a_summoning(96) = 1;
		a_zauber(152, v_i).f_name[2] = "Golem beschw\366ren";
		a_zauber(152, v_i).f_name[1] = "Summon Golem";
		a_zauber(152, v_i).f_name[3] = "Conjurar golem";
		a_zauber(152, v_i).f_kosten = 15;
		a_zauber(152, v_i).f_level = 9;
		a_zauber(152, v_i).f_dauer = 0;
		a_zauber(152, v_i).f_art = "erde";
		a_zauber(152, v_i).f_besch_1[2] = "Erschafft einen magischen";
		a_zauber(152, v_i).f_besch_2[2] = "Diener auf dem nexus";
		a_zauber(152, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(152, v_i).f_besch_2[1] = "servant in the nexus";
		a_zauber(152, v_i).f_besch_1[3] = "Conjura un servidor";
		a_zauber(152, v_i).f_besch_2[3] = "magico en el nexus";
		a_summoning(152) = 1;
		a_zauber(153, v_i).f_name[2] = "Satyr beschw\366ren";
		a_zauber(153, v_i).f_name[1] = "Summon Satyr";
		a_zauber(153, v_i).f_name[3] = "Conjurar satiro";
		a_zauber(153, v_i).f_kosten = 15;
		a_zauber(153, v_i).f_level = 9;
		a_zauber(153, v_i).f_dauer = 0;
		a_zauber(153, v_i).f_art = "weiss";
		a_zauber(153, v_i).f_besch_1[2] = "Erschafft einen magischen";
		a_zauber(153, v_i).f_besch_2[2] = "Diener auf dem nexus";
		a_zauber(153, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(153, v_i).f_besch_2[1] = "servant in the nexus";
		a_zauber(153, v_i).f_besch_1[3] = "Conjura un servidor";
		a_zauber(153, v_i).f_besch_2[3] = "magico en el nexus";
		a_summoning(153) = 1;
		a_zauber(97, v_i).f_name[2] = "D\344mon beschw\366ren";
		a_zauber(97, v_i).f_name[1] = "Summon Demon";
		a_zauber(97, v_i).f_name[3] = "Conjurar demonio";
		a_zauber(97, v_i).f_kosten = 30;
		a_zauber(97, v_i).f_level = 10;
		a_zauber(97, v_i).f_dauer = 0;
		a_zauber(97, v_i).f_art = "schwarz";
		a_zauber(97, v_i).f_besch_1[2] = "Beschw\366rt einen D\344mon";
		a_zauber(97, v_i).f_besch_2[2] = "aus den Tiefen Gehennas";
		a_zauber(97, v_i).f_besch_1[1] = "Summons a demon from";
		a_zauber(97, v_i).f_besch_2[1] = "the depths of hell";
		a_zauber(97, v_i).f_besch_1[3] = "Conjura un demonio de";
		a_zauber(97, v_i).f_besch_2[3] = "la gehenna";
		a_summoning(97) = 1;
		a_zauber(98, v_i).f_name[2] = "Engel beschw\366ren";
		a_zauber(98, v_i).f_name[1] = "Summon Angel";
		a_zauber(98, v_i).f_name[3] = "Conjurar angelo";
		a_zauber(98, v_i).f_kosten = 30;
		a_zauber(98, v_i).f_level = 11;
		a_zauber(98, v_i).f_dauer = 0;
		a_zauber(98, v_i).f_art = "weiss";
		a_zauber(98, v_i).f_besch_1[2] = "Beschw\366rt einen";
		a_zauber(98, v_i).f_besch_2[2] = "strahlenden Engel";
		a_zauber(98, v_i).f_besch_1[1] = "Summons a radiant";
		a_zauber(98, v_i).f_besch_2[1] = "angelic being";
		a_zauber(98, v_i).f_besch_1[3] = "Conjura un brillante";
		a_zauber(98, v_i).f_besch_2[3] = "angelo";
		a_summoning(98) = 1;
		a_zauber(99, v_i).f_name[2] = "Drache beschw\366ren";
		a_zauber(99, v_i).f_name[1] = "Summon Dragon";
		a_zauber(99, v_i).f_name[3] = "Conjurar dragon";
		a_zauber(99, v_i).f_kosten = 30;
		a_zauber(99, v_i).f_level = 15;
		a_zauber(99, v_i).f_dauer = 0;
		a_zauber(99, v_i).f_art = "druide";
		a_zauber(99, v_i).f_besch_1[2] = "Beschw\366rt einen Drachen";
		a_zauber(99, v_i).f_besch_2[2] = "(Dieser schl\344gt T\374ren ein!)";
		a_zauber(99, v_i).f_besch_1[1] = "Summons a dragon";
		a_zauber(99, v_i).f_besch_2[1] = "(He breaks down doors!)";
		a_zauber(99, v_i).f_besch_1[3] = "Conjura un dragon";
		a_zauber(99, v_i).f_besch_2[3] = "(El quebra puertas!)";
		a_summoning(99) = 1;
		a_zauber(100, v_i).f_name[2] = "Andere Heilen";
		a_zauber(100, v_i).f_name[1] = "Heal Others";
		a_zauber(100, v_i).f_name[3] = "Curar otros";
		a_zauber(100, v_i).f_kosten = 2;
		a_zauber(100, v_i).f_level = 7;
		a_zauber(100, v_i).f_dauer = 0;
		a_zauber(100, v_i).f_art = "weiss";
		a_zauber(100, v_i).f_besch_1[2] = "Heilt einen anderen";
		a_zauber(100, v_i).f_besch_2[2] = "Spieler";
		a_zauber(100, v_i).f_besch_1[1] = "Heals another";
		a_zauber(100, v_i).f_besch_2[1] = "player";
		a_zauber(100, v_i).f_besch_1[3] = "Cura otro";
		a_zauber(100, v_i).f_besch_2[3] = "jugador";
		a_zauber(101, v_i).f_name[2] = "Andere Entgiften";
		a_zauber(101, v_i).f_name[1] = "Cure Poison of Others";
		a_zauber(101, v_i).f_name[3] = "Curar veneno de otros";
		a_zauber(101, v_i).f_kosten = 2;
		a_zauber(101, v_i).f_level = 12;
		a_zauber(101, v_i).f_dauer = 0;
		a_zauber(101, v_i).f_art = "weiss";
		a_zauber(101, v_i).f_besch_1[2] = "Entfernt vergiftung eines";
		a_zauber(101, v_i).f_besch_2[2] = "anderen Spielers";
		a_zauber(101, v_i).f_besch_1[1] = "Cures another player's";
		a_zauber(101, v_i).f_besch_2[1] = "poison";
		a_zauber(101, v_i).f_besch_1[3] = "Cura veneno de otro";
		a_zauber(101, v_i).f_besch_2[3] = "jugador";
		a_zauber(102, v_i).f_name[2] = "T\344uschung";
		a_zauber(102, v_i).f_name[1] = "Illusion";
		a_zauber(102, v_i).f_name[3] = "Illucion";
		a_zauber(102, v_i).f_kosten = 2;
		a_zauber(102, v_i).f_level = 7;
		a_zauber(102, v_i).f_dauer = 4;
		a_zauber(102, v_i).f_art = "illusion";
		a_zauber(102, v_i).f_besch_1[2] = "Monster treffen nur noch";
		a_zauber(102, v_i).f_besch_2[2] = "mit 50%";
		a_zauber(102, v_i).f_besch_1[1] = "Monsters hit you only";
		a_zauber(102, v_i).f_besch_2[1] = "half of the time";
		a_zauber(102, v_i).f_besch_1[3] = "Monstrues te alcanzan";
		a_zauber(102, v_i).f_besch_2[3] = "con 50% de las posibilidades";
		a_zauber(103, v_i).f_name[2] = "Doppelg\344nger";
		a_zauber(103, v_i).f_name[1] = "Doppelganger";
		a_zauber(103, v_i).f_name[3] = "Gemelo";
		a_zauber(103, v_i).f_kosten = 12;
		a_zauber(103, v_i).f_level = 8;
		a_zauber(103, v_i).f_dauer = 0;
		a_zauber(103, v_i).f_art = "illusion";
		a_zauber(103, v_i).f_besch_1[2] = "Erschafft eine Kopie";
		a_zauber(103, v_i).f_besch_2[2] = "des Magiers auf dem nexus";
		a_zauber(103, v_i).f_besch_1[1] = "Summons a copy of the";
		a_zauber(103, v_i).f_besch_2[1] = "magician in the nexus";
		a_zauber(103, v_i).f_besch_1[3] = "Conjura una copia del";
		a_zauber(103, v_i).f_besch_2[3] = "lanzador en el nexus";
		a_zauber(104, v_i).f_name[2] = "Zauberr\374stung";
		a_zauber(104, v_i).f_name[1] = "Magical Armor";
		a_zauber(104, v_i).f_name[3] = "Armadura Magica";
		a_zauber(104, v_i).f_kosten = 5;
		a_zauber(104, v_i).f_level = 10;
		a_zauber(104, v_i).f_dauer = 0;
		a_zauber(104, v_i).f_art = "warlock";
		a_zauber(104, v_i).f_besch_1[2] = "Erschafft eine";
		a_zauber(104, v_i).f_besch_2[2] = "magische R\374stung";
		a_zauber(104, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(104, v_i).f_besch_2[1] = "armor";
		a_zauber(104, v_i).f_besch_1[3] = "Conjura una armadura";
		a_zauber(104, v_i).f_besch_2[3] = "magica";
		a_zauber(105, v_i).f_name[2] = "Sternensicht";
		a_zauber(105, v_i).f_name[1] = "Starsight";
		a_zauber(105, v_i).f_name[3] = "Vista de las Estrellas";
		a_zauber(105, v_i).f_kosten = 3;
		a_zauber(105, v_i).f_level = 9;
		a_zauber(105, v_i).f_dauer = 0;
		a_zauber(105, v_i).f_art = "sterne";
		a_zauber(105, v_i).f_besch_1[2] = "Zeigt eine Karte mit allen ";
		a_zauber(105, v_i).f_besch_2[2] = "Details des Labyrinths";
		a_zauber(105, v_i).f_besch_1[1] = "Shows a map containing all ";
		a_zauber(105, v_i).f_besch_2[1] = "details of the actual level";
		a_zauber(105, v_i).f_besch_1[3] = "Muestra un mapa con todos los ";
		a_zauber(105, v_i).f_besch_2[3] = "detalles del nivel";
		a_zauber(106, v_i).f_name[2] = "Stein zerst\366ren";
		a_zauber(106, v_i).f_name[1] = "Break Boulder";
		a_zauber(106, v_i).f_name[3] = "Destruye Piedra";
		a_zauber(106, v_i).f_kosten = 4;
		a_zauber(106, v_i).f_level = 11;
		a_zauber(106, v_i).f_dauer = 0;
		a_zauber(106, v_i).f_art = "erde";
		a_zauber(106, v_i).f_besch_1[2] = "Zerst\366rt einen Stein";
		a_zauber(106, v_i).f_besch_2[2] = "";
		a_zauber(106, v_i).f_besch_1[1] = "Destroys a stone";
		a_zauber(106, v_i).f_besch_2[1] = "";
		a_zauber(106, v_i).f_besch_1[3] = "Destruye una piedra";
		a_zauber(106, v_i).f_besch_2[3] = "";
		a_zauber(107, v_i).f_name[2] = "Andere entfluchen";
		a_zauber(107, v_i).f_name[1] = "Break Curse of Others";
		a_zauber(107, v_i).f_name[3] = "Curar maldicion de otros";
		a_zauber(107, v_i).f_kosten = 5;
		a_zauber(107, v_i).f_level = 13;
		a_zauber(107, v_i).f_dauer = 0;
		a_zauber(107, v_i).f_art = "weiss";
		a_zauber(107, v_i).f_besch_1[2] = "Entfernt Fluch eines";
		a_zauber(107, v_i).f_besch_2[2] = "anderen Spielers";
		a_zauber(107, v_i).f_besch_1[1] = "Removes another character's";
		a_zauber(107, v_i).f_besch_2[1] = "curse";
		a_zauber(107, v_i).f_besch_1[3] = "Remueve la maldicion de";
		a_zauber(107, v_i).f_besch_2[3] = "otro jugador";
		a_zauber(108, v_i).f_name[2] = "Orkan";
		a_zauber(108, v_i).f_name[1] = "Hurricane";
		a_zauber(108, v_i).f_name[3] = "Huracan";
		a_zauber(108, v_i).f_kosten = 1;
		a_zauber(108, v_i).f_level = 7;
		a_zauber(108, v_i).f_dauer = 0;
		a_zauber(108, v_i).f_art = "luft";
		a_zauber(108, v_i).f_besch_1[2] = "Ruft einen Orkan herbei der ";
		a_zauber(108, v_i).f_besch_2[2] = "ein nahes Monster attackiert";
		a_zauber(108, v_i).f_besch_1[1] = "Summons a Hurricane to ";
		a_zauber(108, v_i).f_besch_2[1] = "attack a nearby monster";
		a_zauber(108, v_i).f_besch_1[3] = "Crea un Huracan para ";
		a_zauber(108, v_i).f_besch_2[3] = "atacar un monstruo cercano";
		a_zauber(109, v_i).f_name[2] = "Unsichtbares sehen";
		a_zauber(109, v_i).f_name[1] = "View Invisible";
		a_zauber(109, v_i).f_name[3] = "Ver el invisible";
		a_zauber(109, v_i).f_kosten = 1;
		a_zauber(109, v_i).f_level = 5;
		a_zauber(109, v_i).f_dauer = 5;
		a_zauber(109, v_i).f_art = "illusion";
		a_zauber(109, v_i).f_besch_1[2] = "Erm\366glicht dem Magier alles";
		a_zauber(109, v_i).f_besch_2[2] = "Unsichtbare zu sehen";
		a_zauber(109, v_i).f_besch_1[1] = "Reveals all invisible";
		a_zauber(109, v_i).f_besch_2[1] = "creatures to the magician";
		a_zauber(109, v_i).f_besch_1[3] = "El mago puede ver todo lo que";
		a_zauber(109, v_i).f_besch_2[3] = "es invisible";
		a_zauber(110, v_i).f_name[2] = "Unsichtbarkeit";
		a_zauber(110, v_i).f_name[1] = "Invisibility";
		a_zauber(110, v_i).f_name[3] = "Invisibilidad";
		a_zauber(110, v_i).f_kosten = 2;
		a_zauber(110, v_i).f_level = 10;
		a_zauber(110, v_i).f_dauer = 5;
		a_zauber(110, v_i).f_art = "illusion";
		a_zauber(110, v_i).f_besch_1[2] = "Verhindert das Monster den";
		a_zauber(110, v_i).f_besch_2[2] = "Magier sehen";
		a_zauber(110, v_i).f_besch_1[1] = "Prevents monsters from seeing";
		a_zauber(110, v_i).f_besch_2[1] = "the magician";
		a_zauber(110, v_i).f_besch_1[3] = "Preventa que los monstuos";
		a_zauber(110, v_i).f_besch_2[3] = "miran el mago";
		a_zauber(111, v_i).f_name[2] = "Geister bannen";
		a_zauber(111, v_i).f_name[1] = "Banish Ghosts";
		a_zauber(111, v_i).f_name[3] = "Castigar Fantasman";
		a_zauber(111, v_i).f_kosten = 1;
		a_zauber(111, v_i).f_level = 10;
		a_zauber(111, v_i).f_dauer = 0;
		a_zauber(111, v_i).f_art = "hexerei";
		a_zauber(111, v_i).f_besch_1[2] = "Vertreibt einen einzelnen";
		a_zauber(111, v_i).f_besch_2[2] = "Geist";
		a_zauber(111, v_i).f_besch_1[1] = "Banishes a single";
		a_zauber(111, v_i).f_besch_2[1] = "ghost";
		a_zauber(111, v_i).f_besch_1[3] = "Castiga una sola fantasma";
		a_zauber(111, v_i).f_besch_2[3] = "";
		a_zauber(112, v_i).f_name[2] = "Desintegration";
		a_zauber(112, v_i).f_name[1] = "Disintegration";
		a_zauber(112, v_i).f_name[3] = "Desintegracion";
		a_zauber(112, v_i).f_kosten = 3;
		a_zauber(112, v_i).f_level = 14;
		a_zauber(112, v_i).f_dauer = 0;
		a_zauber(112, v_i).f_art = "feuer";
		a_zauber(112, v_i).f_besch_1[2] = "L\366st ein Feld auf";
		a_zauber(112, v_i).f_besch_2[2] = "";
		a_zauber(112, v_i).f_besch_1[1] = "Destroys one field";
		a_zauber(112, v_i).f_besch_2[1] = "";
		a_zauber(112, v_i).f_besch_1[3] = "Limpia una zona";
		a_zauber(112, v_i).f_besch_2[3] = "";
		a_zauber(113, v_i).f_name[2] = "Mentalschlag";
		a_zauber(113, v_i).f_name[1] = "Mentalbolt";
		a_zauber(113, v_i).f_name[3] = "Rayo mental";
		a_zauber(113, v_i).f_kosten = 2;
		a_zauber(113, v_i).f_level = 8;
		a_zauber(113, v_i).f_dauer = 0;
		a_zauber(113, v_i).f_art = "warlock";
		a_zauber(113, v_i).f_besch_1[2] = "Greift ein einzelnes";
		a_zauber(113, v_i).f_besch_2[2] = "Monster an";
		a_zauber(113, v_i).f_besch_1[1] = "Attacks a single";
		a_zauber(113, v_i).f_besch_2[1] = "monster";
		a_zauber(113, v_i).f_besch_1[3] = "Ataca un monstruo";
		a_zauber(113, v_i).f_besch_2[3] = "";
		a_zauber(114, v_i).f_name[2] = "Feuerlanze";
		a_zauber(114, v_i).f_name[1] = "Flameburst";
		a_zauber(114, v_i).f_name[3] = "Lanza de Fuego";
		a_zauber(114, v_i).f_kosten = 2;
		a_zauber(114, v_i).f_level = 5;
		a_zauber(114, v_i).f_dauer = 0;
		a_zauber(114, v_i).f_art = "feuer";
		a_zauber(114, v_i).f_besch_1[2] = "Greift alle Monster in";
		a_zauber(114, v_i).f_besch_2[2] = "einer geraden an";
		a_zauber(114, v_i).f_besch_1[1] = "Attacks all monsters";
		a_zauber(114, v_i).f_besch_2[1] = "in a row";
		a_zauber(114, v_i).f_besch_1[3] = "Ataca todos los monstruos";
		a_zauber(114, v_i).f_besch_2[3] = "en una linea";
		a_zauber(115, v_i).f_name[2] = "Feuerball";
		a_zauber(115, v_i).f_name[1] = "Fireball";
		a_zauber(115, v_i).f_name[3] = "Bola de Fuego";
		a_zauber(115, v_i).f_kosten = 3;
		a_zauber(115, v_i).f_level = 10;
		a_zauber(115, v_i).f_dauer = 0;
		a_zauber(115, v_i).f_art = "feuer";
		a_zauber(115, v_i).f_besch_1[2] = "Verbrennt ein Feld und";
		a_zauber(115, v_i).f_besch_2[2] = "alle umliegenden";
		a_zauber(115, v_i).f_besch_1[1] = "Burns one square and";
		a_zauber(115, v_i).f_besch_2[1] = "surrounding ones";
		a_zauber(115, v_i).f_besch_1[3] = "Quema un campo y todos";
		a_zauber(115, v_i).f_besch_2[3] = "los alrededores";
		a_zauber(116, v_i).f_name[2] = "Armageddon";
		a_zauber(116, v_i).f_name[1] = "Armageddon";
		a_zauber(116, v_i).f_name[3] = "Armagedon";
		a_zauber(116, v_i).f_kosten = 10;
		a_zauber(116, v_i).f_level = 15;
		a_zauber(116, v_i).f_dauer = 0;
		a_zauber(116, v_i).f_art = "feuer";
		a_zauber(116, v_i).f_besch_1[2] = "Greift alle Monster der Ebene an";
		a_zauber(116, v_i).f_besch_2[2] = "Kostet Gegenstand! 1 mal pro Ebene";
		a_zauber(116, v_i).f_besch_1[1] = "Attacks all monsters in the current";
		a_zauber(116, v_i).f_besch_2[1] = "level. Costs item! 1 time per level";
		a_zauber(116, v_i).f_besch_1[3] = "Ataaa a todos los monstruos en este";
		a_zauber(116, v_i).f_besch_2[3] = "nivel. Cuesta un objeto! 1 vez por nivel";
		a_zauber(128, v_i).f_name[2] = "Pestilence";
		a_zauber(128, v_i).f_name[1] = "Pestilence";
		a_zauber(128, v_i).f_name[3] = "Pestilencia";
		a_zauber(128, v_i).f_kosten = 10;
		a_zauber(128, v_i).f_level = 15;
		a_zauber(128, v_i).f_dauer = 0;
		a_zauber(128, v_i).f_art = "schwarz";
		a_zauber(128, v_i).f_besch_1[2] = "Greift alle lebenden Monster der Ebene";
		a_zauber(128, v_i).f_besch_2[2] = "an. Kostet Gegenstand! 1 mal pro Ebene";
		a_zauber(128, v_i).f_besch_1[1] = "Attacks all living monsters in the";
		a_zauber(128, v_i).f_besch_2[1] = "current level. Costs item! 1 time per level";
		a_zauber(128, v_i).f_besch_1[3] = "Ataca a todos los monstruos viviendos en";
		a_zauber(128, v_i).f_besch_2[3] = "este nivel. Cuesta un objeto! 1 vez por nivel";
		a_zauber(117, v_i).f_name[2] = "Meteor";
		a_zauber(117, v_i).f_name[1] = "Meteor";
		a_zauber(117, v_i).f_name[3] = "Meteoro";
		a_zauber(117, v_i).f_kosten = 4;
		a_zauber(117, v_i).f_level = 10;
		a_zauber(117, v_i).f_dauer = 0;
		a_zauber(117, v_i).f_art = "sterne";
		a_zauber(117, v_i).f_besch_1[2] = "Zerst\366rt ein Feld und";
		a_zauber(117, v_i).f_besch_2[2] = "alle umliegenden (ohne LOS!)";
		a_zauber(117, v_i).f_besch_1[1] = "Destroys a field and all";
		a_zauber(117, v_i).f_besch_2[1] = "surrounding it (without LOS!)";
		a_zauber(117, v_i).f_besch_1[3] = "Destruye un campo y todos";
		a_zauber(117, v_i).f_besch_2[3] = "los alrededores (sin LOS!)";
		a_zauber(118, v_i).f_name[2] = "Schutz gegen Blitze";
		a_zauber(118, v_i).f_name[1] = "Protection: Lightning";
		a_zauber(118, v_i).f_name[3] = "Proteccion: Rayos";
		a_zauber(118, v_i).f_kosten = 1;
		a_zauber(118, v_i).f_level = 8;
		a_zauber(118, v_i).f_dauer = 5;
		a_zauber(118, v_i).f_art = "hexerei";
		a_zauber(118, v_i).f_besch_1[2] = "Besch\374tzt die Hexe";
		a_zauber(118, v_i).f_besch_2[2] = "vor Blitzen!";
		a_zauber(118, v_i).f_besch_1[1] = "Protects the Witch";
		a_zauber(118, v_i).f_besch_2[1] = "against lightning!";
		a_zauber(118, v_i).f_besch_1[3] = "Protege la Bruja de";
		a_zauber(118, v_i).f_besch_2[3] = "Rayos!";
		a_zauber(119, v_i).f_name[2] = "Schutz gegen Versteinern";
		a_zauber(119, v_i).f_name[1] = "Protection: Turn to Stone";
		a_zauber(119, v_i).f_name[3] = "Proteccion: Piedra";
		a_zauber(119, v_i).f_kosten = 1;
		a_zauber(119, v_i).f_level = 6;
		a_zauber(119, v_i).f_dauer = 5;
		a_zauber(119, v_i).f_art = "erde";
		a_zauber(119, v_i).f_besch_1[2] = "Besch\374tzt den Magier vor";
		a_zauber(119, v_i).f_besch_2[2] = "Versteinerung!";
		a_zauber(119, v_i).f_besch_1[1] = "Protects the Mage from";
		a_zauber(119, v_i).f_besch_2[1] = "getting turned to stone!";
		a_zauber(119, v_i).f_besch_1[3] = "Protege el mago de";
		a_zauber(119, v_i).f_besch_2[3] = "convertir a piedra!";
		a_zauber(120, v_i).f_name[2] = "1000 Klingen";
		a_zauber(120, v_i).f_name[1] = "1000 Blades";
		a_zauber(120, v_i).f_name[3] = "1000 Espadas";
		a_zauber(120, v_i).f_kosten = 1;
		a_zauber(120, v_i).f_level = 5;
		a_zauber(120, v_i).f_dauer = 5;
		a_zauber(120, v_i).f_art = "warlock";
		a_zauber(120, v_i).f_besch_1[2] = "Erh\366ht Chance auf";
		a_zauber(120, v_i).f_besch_2[2] = "kritische Treffer!";
		a_zauber(120, v_i).f_besch_1[1] = "Increases the chance to";
		a_zauber(120, v_i).f_besch_2[1] = "do critical hits!";
		a_zauber(120, v_i).f_besch_1[3] = "Aumenta la posibilidad";
		a_zauber(120, v_i).f_besch_2[3] = "de hacer un golpe critico!";
		a_zauber(121, v_i).f_name[2] = "Geistertanz";
		a_zauber(121, v_i).f_name[1] = "Dance of Ghosts";
		a_zauber(121, v_i).f_name[3] = "Danza de Fantasmas";
		a_zauber(121, v_i).f_kosten = 1;
		a_zauber(121, v_i).f_level = 6;
		a_zauber(121, v_i).f_dauer = 9999;
		a_zauber(121, v_i).f_art = "barde";
		a_zauber(121, v_i).f_besch_1[2] = "Der Barde kann";
		a_zauber(121, v_i).f_besch_2[2] = "Unsichtbares sehen!";
		a_zauber(121, v_i).f_besch_1[1] = "The Bard can see the";
		a_zauber(121, v_i).f_besch_2[1] = "invisible!";
		a_zauber(121, v_i).f_besch_1[3] = "El cantante puede ver";
		a_zauber(121, v_i).f_besch_2[3] = "lo invisible!";
		a_zauber(122, v_i).f_name[2] = "Nexus finden";
		a_zauber(122, v_i).f_name[1] = "Find Nexus";
		a_zauber(122, v_i).f_name[3] = "Encontrar Nexo";
		a_zauber(122, v_i).f_kosten = 2;
		a_zauber(122, v_i).f_level = 8;
		a_zauber(122, v_i).f_dauer = 0;
		a_zauber(122, v_i).f_art = "hohe";
		a_zauber(122, v_i).f_besch_1[2] = "Zeigt eine Karte mit";
		a_zauber(122, v_i).f_besch_2[2] = "dem Nexus!";
		a_zauber(122, v_i).f_besch_1[1] = "Shows a map with";
		a_zauber(122, v_i).f_besch_2[1] = "the nexus!";
		a_zauber(122, v_i).f_besch_1[3] = "Muestra un mapa con";
		a_zauber(122, v_i).f_besch_2[3] = "los nexo!";
		a_zauber(123, v_i).f_name[2] = "Sanktum finden";
		a_zauber(123, v_i).f_name[1] = "Find Sanktum";
		a_zauber(123, v_i).f_name[3] = "Encontrar Santuario";
		a_zauber(123, v_i).f_kosten = 2;
		a_zauber(123, v_i).f_level = 8;
		a_zauber(123, v_i).f_dauer = 0;
		a_zauber(123, v_i).f_art = "weiss";
		a_zauber(123, v_i).f_besch_1[2] = "Zeigt eine Karte mit";
		a_zauber(123, v_i).f_besch_2[2] = "dem Sanktum!";
		a_zauber(123, v_i).f_besch_1[1] = "Shows a map with the";
		a_zauber(123, v_i).f_besch_2[1] = "Sanktum!";
		a_zauber(123, v_i).f_besch_1[3] = "Muestra un mapa con";
		a_zauber(123, v_i).f_besch_2[3] = "los santuarios!";
		a_zauber(124, v_i).f_name[2] = "Unverwundbarkeit";
		a_zauber(124, v_i).f_name[1] = "Invulnerability";
		a_zauber(124, v_i).f_name[3] = "Invulnerabilidad";
		a_zauber(124, v_i).f_kosten = 5;
		a_zauber(124, v_i).f_level = 15;
		a_zauber(124, v_i).f_dauer = 1;
		a_zauber(124, v_i).f_art = "warlock";
		a_zauber(124, v_i).f_besch_1[2] = "Macht den Warlock f\374r kurze";
		a_zauber(124, v_i).f_besch_2[2] = "Zeit Unverwundbar!";
		a_zauber(124, v_i).f_besch_1[1] = "The Warlock becomes";
		a_zauber(124, v_i).f_besch_2[1] = "invulnerable for a short time!";
		a_zauber(124, v_i).f_besch_1[3] = "Nadie puede danar al Warlock";
		a_zauber(124, v_i).f_besch_2[3] = "por poco tiempo!";
		a_zauber(125, v_i).f_name[2] = "Vergiften";
		a_zauber(125, v_i).f_name[1] = "Poison";
		a_zauber(125, v_i).f_name[3] = "Envenenar";
		a_zauber(125, v_i).f_kosten = 2;
		a_zauber(125, v_i).f_level = 9;
		a_zauber(125, v_i).f_dauer = 5;
		a_zauber(125, v_i).f_art = "hexerei";
		a_zauber(125, v_i).f_besch_1[2] = "Vergiftet ein nahes";
		a_zauber(125, v_i).f_besch_2[2] = "Monster";
		a_zauber(125, v_i).f_besch_1[1] = "Poisons a nearby";
		a_zauber(125, v_i).f_besch_2[1] = "monster";
		a_zauber(125, v_i).f_besch_1[3] = "Envenena un monstruo";
		a_zauber(125, v_i).f_besch_2[3] = "cercano";
		a_zauber(126, v_i).f_name[2] = "Wiederbelebung";
		a_zauber(126, v_i).f_name[1] = "Resurrection";
		a_zauber(126, v_i).f_name[3] = "Resureccion";
		a_zauber(126, v_i).f_kosten = 5;
		a_zauber(126, v_i).f_level = 15;
		a_zauber(126, v_i).f_dauer = 0;
		a_zauber(126, v_i).f_art = "weiss";
		a_zauber(126, v_i).f_besch_1[2] = "Belebt alle toten";
		a_zauber(126, v_i).f_besch_2[2] = "Spieler wieder! (Mit LP/2)";
		a_zauber(126, v_i).f_besch_1[1] = "Resurrects all dead";
		a_zauber(126, v_i).f_besch_2[1] = "players! (With LP/2)";
		a_zauber(126, v_i).f_besch_1[3] = "Resucita todos los jugadores";
		a_zauber(126, v_i).f_besch_2[3] = "muertos! (Con PdV/2)";
		a_zauber(127, v_i).f_name[2] = "Schlaf";
		a_zauber(127, v_i).f_name[1] = "Sleep";
		a_zauber(127, v_i).f_name[3] = "Dormir";
		a_zauber(127, v_i).f_kosten = 1;
		a_zauber(127, v_i).f_level = 1;
		a_zauber(127, v_i).f_dauer = 0;
		a_zauber(127, v_i).f_art = "illusion";
		a_zauber(127, v_i).f_besch_1[2] = "Versetzt ein Monster in";
		a_zauber(127, v_i).f_besch_2[2] = "schlafenden Zustand";
		a_zauber(127, v_i).f_besch_1[1] = "Puts a monster to";
		a_zauber(127, v_i).f_besch_2[1] = "sleep";
		a_zauber(127, v_i).f_besch_1[3] = "Hace dormir a un";
		a_zauber(127, v_i).f_besch_2[3] = "montruo";
		a_zauber(129, v_i).f_name[2] = "Telekinesis";
		a_zauber(129, v_i).f_name[1] = "Telekinesis";
		a_zauber(129, v_i).f_name[3] = "Telequinesia";
		a_zauber(129, v_i).f_kosten = 2;
		a_zauber(129, v_i).f_level = 10;
		a_zauber(129, v_i).f_dauer = 0;
		a_zauber(129, v_i).f_art = "druide";
		a_zauber(129, v_i).f_besch_1[2] = "Bef\366rdert einen Gegenstand";
		a_zauber(129, v_i).f_besch_2[2] = "in Sichtweite zum Magier";
		a_zauber(129, v_i).f_besch_1[1] = "Moves an item in view towards";
		a_zauber(129, v_i).f_besch_2[1] = "the magician";
		a_zauber(129, v_i).f_besch_1[3] = "Mueve una cosa que este en";
		a_zauber(129, v_i).f_besch_2[3] = "la vista del mago";
		a_zauber(131, v_i).f_name[2] = "Vakuum";
		a_zauber(131, v_i).f_name[1] = "Vacuum";
		a_zauber(131, v_i).f_name[3] = "Vacuum";
		a_zauber(131, v_i).f_kosten = 5;
		a_zauber(131, v_i).f_level = 11;
		a_zauber(131, v_i).f_dauer = 0;
		a_zauber(131, v_i).f_art = "luft";
		a_zauber(131, v_i).f_besch_1[2] = "Entzieht einem Gegner";
		a_zauber(131, v_i).f_besch_2[2] = "jegliche Luft";
		a_zauber(131, v_i).f_besch_1[1] = "Sucks all air out of";
		a_zauber(131, v_i).f_besch_2[1] = "one enemy";
		a_zauber(131, v_i).f_besch_1[3] = "Roba todo el aire de";
		a_zauber(131, v_i).f_besch_2[3] = "un enemigo";
		a_zauber(130, v_i).f_name[2] = "Giftschutz";
		a_zauber(130, v_i).f_name[1] = "Poison Protection";
		a_zauber(130, v_i).f_name[3] = "Proteccion Veneno";
		a_zauber(130, v_i).f_kosten = 2;
		a_zauber(130, v_i).f_level = 7;
		a_zauber(130, v_i).f_dauer = 4;
		a_zauber(130, v_i).f_art = "druide";
		a_zauber(130, v_i).f_besch_1[2] = "Sch\374tzt den Druide vor";
		a_zauber(130, v_i).f_besch_2[2] = "Vergiftung";
		a_zauber(130, v_i).f_besch_1[1] = "Protects the Druid from";
		a_zauber(130, v_i).f_besch_2[1] = "poison";
		a_zauber(130, v_i).f_besch_1[3] = "Protege al druida de";
		a_zauber(130, v_i).f_besch_2[3] = "veneno";
		a_zauber(132, v_i).f_name[2] = "Pflanze zerst\366ren";
		a_zauber(132, v_i).f_name[1] = "Destroy Plant";
		a_zauber(132, v_i).f_name[3] = "Destruir Planta";
		a_zauber(132, v_i).f_kosten = 1;
		a_zauber(132, v_i).f_level = 8;
		a_zauber(132, v_i).f_dauer = 0;
		a_zauber(132, v_i).f_art = "druide";
		a_zauber(132, v_i).f_besch_1[2] = "Zerst\366rt eine Pflanze";
		a_zauber(132, v_i).f_besch_2[2] = "";
		a_zauber(132, v_i).f_besch_1[1] = "Destroys a plant";
		a_zauber(132, v_i).f_besch_2[1] = "";
		a_zauber(132, v_i).f_besch_1[3] = "Destruye una planta";
		a_zauber(132, v_i).f_besch_2[3] = "";
		a_zauber(133, v_i).f_name[2] = "Mit Tieren reden";
		a_zauber(133, v_i).f_name[1] = "Talk with animals";
		a_zauber(133, v_i).f_name[3] = "Hablar con animales";
		a_zauber(133, v_i).f_kosten = 2;
		a_zauber(133, v_i).f_level = 13;
		a_zauber(133, v_i).f_dauer = 0;
		a_zauber(133, v_i).f_art = "druide";
		a_zauber(133, v_i).f_besch_1[2] = "Die Hexe kann ein Tier nach dem";
		a_zauber(133, v_i).f_besch_2[2] = "Ausgang fragen!";
		a_zauber(133, v_i).f_besch_1[1] = "The witch can ask an animal";
		a_zauber(133, v_i).f_besch_2[1] = "for the exit!";
		a_zauber(133, v_i).f_besch_1[3] = "La bruja puede preguntar a un";
		a_zauber(133, v_i).f_besch_2[3] = "animal por la escalera!";
		a_zauber(134, v_i).f_name[2] = "Energie der Steine";
		a_zauber(134, v_i).f_name[1] = "Energy of the stones";
		a_zauber(134, v_i).f_name[3] = "Energia de las piedras";
		a_zauber(134, v_i).f_kosten = 0;
		a_zauber(134, v_i).f_level = 12;
		a_zauber(134, v_i).f_dauer = 0;
		a_zauber(134, v_i).f_art = "hexerei";
		a_zauber(134, v_i).f_besch_1[2] = "Die Hexe kann einen Edelstein";
		a_zauber(134, v_i).f_besch_2[2] = "in Mana verwandeln";
		a_zauber(134, v_i).f_besch_1[1] = "The witch can transform one";
		a_zauber(134, v_i).f_besch_2[1] = "gem into mana";
		a_zauber(134, v_i).f_besch_1[3] = "La bruja puede transformar";
		a_zauber(134, v_i).f_besch_2[3] = "une piedra preciosa a mana";
		a_zauber(135, v_i).f_name[2] = "Magischer Bogen";
		a_zauber(135, v_i).f_name[1] = "Magical Bow";
		a_zauber(135, v_i).f_name[3] = "Arco Magico";
		a_zauber(135, v_i).f_kosten = 4;
		a_zauber(135, v_i).f_level = 6;
		a_zauber(135, v_i).f_dauer = 0;
		a_zauber(135, v_i).f_art = "warlock";
		a_zauber(135, v_i).f_besch_1[2] = "Erschafft einen";
		a_zauber(135, v_i).f_besch_2[2] = "magischen Bogen";
		a_zauber(135, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(135, v_i).f_besch_2[1] = "bow";
		a_zauber(135, v_i).f_besch_1[3] = "Conjura un arco";
		a_zauber(135, v_i).f_besch_2[3] = "magico";
		a_zauber(136, v_i).f_name[2] = "Wegblasen";
		a_zauber(136, v_i).f_name[1] = "Blow Away";
		a_zauber(136, v_i).f_name[3] = "Refaga de viento";
		a_zauber(136, v_i).f_kosten = 3;
		a_zauber(136, v_i).f_level = 10;
		a_zauber(136, v_i).f_dauer = 0;
		a_zauber(136, v_i).f_art = "luft";
		a_zauber(136, v_i).f_besch_1[2] = "Bl\344st ein Monster auf ein";
		a_zauber(136, v_i).f_besch_2[2] = "anderes Feld im Level";
		a_zauber(136, v_i).f_besch_1[1] = "Blows a monster to another";
		a_zauber(136, v_i).f_besch_2[1] = "field in the level";
		a_zauber(136, v_i).f_besch_1[3] = "Mueve un monstro a otro";
		a_zauber(136, v_i).f_besch_2[3] = "campo en el nivel";
		a_zauber(137, v_i).f_name[2] = "Blenden";
		a_zauber(137, v_i).f_name[1] = "Turn Blind";
		a_zauber(137, v_i).f_name[3] = "Cegar";
		a_zauber(137, v_i).f_kosten = 2;
		a_zauber(137, v_i).f_level = 11;
		a_zauber(137, v_i).f_dauer = 4;
		a_zauber(137, v_i).f_art = "illusion";
		a_zauber(137, v_i).f_besch_1[2] = "Macht ein Monster blind";
		a_zauber(137, v_i).f_besch_2[2] = "(Trifft schlechter)";
		a_zauber(137, v_i).f_besch_1[1] = "Blinds a monster";
		a_zauber(137, v_i).f_besch_2[1] = "(Lowers the chance of hitting)";
		a_zauber(137, v_i).f_besch_1[3] = "Deja ciego al monstro";
		a_zauber(137, v_i).f_besch_2[3] = "(Alcanza peor en el combate)";
		a_zauber(138, v_i).f_name[2] = "Anker erschaffen";
		a_zauber(138, v_i).f_name[1] = "Create Anchor";
		a_zauber(138, v_i).f_name[3] = "Crear Ancla";
		a_zauber(138, v_i).f_kosten = 15;
		a_zauber(138, v_i).f_level = 14;
		a_zauber(138, v_i).f_dauer = 0;
		a_zauber(138, v_i).f_art = "illusion";
		a_zauber(138, v_i).f_besch_1[2] = "Erschafft einen Ankerpunkt";
		a_zauber(138, v_i).f_besch_2[2] = "f\303\274r Anker Teleportation";
		a_zauber(138, v_i).f_besch_1[1] = "Creates an anchor point";
		a_zauber(138, v_i).f_besch_2[1] = "for anchor teleport";
		a_zauber(138, v_i).f_besch_1[3] = "Crea an punto de ancla";
		a_zauber(138, v_i).f_besch_2[3] = "para ancla teleportacion";
		a_zauber(139, v_i).f_name[2] = "Anker Teleportation";
		a_zauber(139, v_i).f_name[1] = "Anchor Teleport";
		a_zauber(139, v_i).f_name[3] = "Teleportacion a ancla";
		a_zauber(139, v_i).f_kosten = 5;
		a_zauber(139, v_i).f_level = 15;
		a_zauber(139, v_i).f_dauer = 0;
		a_zauber(139, v_i).f_art = "illusion";
		a_zauber(139, v_i).f_besch_1[2] = "Teleportiert den Magier";
		a_zauber(139, v_i).f_besch_2[2] = "zum Ankerpunkt";
		a_zauber(139, v_i).f_besch_1[1] = "Teleports the magician";
		a_zauber(139, v_i).f_besch_2[1] = "to the anchor point";
		a_zauber(139, v_i).f_besch_1[3] = "Teleporta al mago al";
		a_zauber(139, v_i).f_besch_2[3] = "punto de ancla";
		a_zauber(140, v_i).f_name[2] = "Wasser stehlen";
		a_zauber(140, v_i).f_name[1] = "Steal Water";
		a_zauber(140, v_i).f_name[3] = "Robar aqua";
		a_zauber(140, v_i).f_kosten = 2;
		a_zauber(140, v_i).f_level = 5;
		a_zauber(140, v_i).f_dauer = 0;
		a_zauber(140, v_i).f_art = "hexerei";
		a_zauber(140, v_i).f_besch_1[2] = "Stiehlt einer Pflanze Wasser";
		a_zauber(140, v_i).f_besch_2[2] = "und richtet ein wenig Schaden an";
		a_zauber(140, v_i).f_besch_1[1] = "Robs a plant of its water";
		a_zauber(140, v_i).f_besch_2[1] = "and deals a little damage";
		a_zauber(140, v_i).f_besch_1[3] = "Roba el aqua de una planta";
		a_zauber(140, v_i).f_besch_2[3] = "y hace un poco de dano";
		a_zauber(141, v_i).f_name[2] = "Windmeister";
		a_zauber(141, v_i).f_name[1] = "Windmaster";
		a_zauber(141, v_i).f_name[3] = "Maestro de vientos";
		a_zauber(141, v_i).f_kosten = 4;
		a_zauber(141, v_i).f_level = 12;
		a_zauber(141, v_i).f_dauer = 4;
		a_zauber(141, v_i).f_art = "luft";
		a_zauber(141, v_i).f_besch_1[2] = "Gibt allen Spielern";
		a_zauber(141, v_i).f_besch_2[2] = "+2 Zugweite";
		a_zauber(141, v_i).f_besch_1[1] = "Gives all players";
		a_zauber(141, v_i).f_besch_2[1] = "+2 movement";
		a_zauber(141, v_i).f_besch_1[3] = "Da todos los jugadores";
		a_zauber(141, v_i).f_besch_2[3] = "+2 movimiento";
		a_zauber(142, v_i).f_name[2] = "Selbsthypnose";
		a_zauber(142, v_i).f_name[1] = "Self-hypnosis";
		a_zauber(142, v_i).f_name[3] = "Hypnotizar uno mismo";
		a_zauber(142, v_i).f_kosten = 2;
		a_zauber(142, v_i).f_level = 13;
		a_zauber(142, v_i).f_dauer = 5;
		a_zauber(142, v_i).f_art = "hexerei";
		a_zauber(142, v_i).f_besch_1[2] = "Verdoppelt die Zeit f\303\274r";
		a_zauber(142, v_i).f_besch_2[2] = "Verdursten/Verhungern der Hexe";
		a_zauber(142, v_i).f_besch_1[1] = "Halves the time the witch";
		a_zauber(142, v_i).f_besch_2[1] = "needs food and water";
		a_zauber(142, v_i).f_besch_1[3] = "Dobla el tiempo la bruja";
		a_zauber(142, v_i).f_besch_2[3] = "necesita aqua y comida";
		a_zauber(143, v_i).f_name[2] = "Lied des Schutzes";
		a_zauber(143, v_i).f_name[1] = "Song of Protection";
		a_zauber(143, v_i).f_name[3] = "Cancion de protecion";
		a_zauber(143, v_i).f_kosten = 1;
		a_zauber(143, v_i).f_level = 9;
		a_zauber(143, v_i).f_dauer = 9999;
		a_zauber(143, v_i).f_art = "barde";
		a_zauber(143, v_i).f_besch_1[2] = "Verhindert 3 Punkte Schaden";
		a_zauber(143, v_i).f_besch_2[2] = "jeder Monsterattacke";
		a_zauber(143, v_i).f_besch_1[1] = "Prevents 3 points of damage";
		a_zauber(143, v_i).f_besch_2[1] = "each monster attack";
		a_zauber(143, v_i).f_besch_1[3] = "Previene 3 puntos dano de cada";
		a_zauber(143, v_i).f_besch_2[3] = "ataque de un monstro";
		a_zauber(144, v_i).f_name[2] = "Dimensionentausch";
		a_zauber(144, v_i).f_name[1] = "Dimensional swap";
		a_zauber(144, v_i).f_name[3] = "Cambiar Dimensiones";
		a_zauber(144, v_i).f_kosten = 3;
		a_zauber(144, v_i).f_level = 14;
		a_zauber(144, v_i).f_dauer = 0;
		a_zauber(144, v_i).f_art = "luft";
		a_zauber(144, v_i).f_besch_1[2] = "Der Magier tauscht den Platz";
		a_zauber(144, v_i).f_besch_2[2] = "mit einem Monster";
		a_zauber(144, v_i).f_besch_1[1] = "The mage switches places";
		a_zauber(144, v_i).f_besch_2[1] = "with a monster";
		a_zauber(144, v_i).f_besch_1[3] = "El mago cambia campos con";
		a_zauber(144, v_i).f_besch_2[3] = "un monstro";
		a_zauber(145, v_i).f_name[2] = "Schock";
		a_zauber(145, v_i).f_name[1] = "Shocking grasp";
		a_zauber(145, v_i).f_name[3] = "Shock";
		a_zauber(145, v_i).f_kosten = 3;
		a_zauber(145, v_i).f_level = 6;
		a_zauber(145, v_i).f_dauer = 2;
		a_zauber(145, v_i).f_art = "luft";
		a_zauber(145, v_i).f_besch_1[2] = "Die Zauberkraft des Magiers";
		a_zauber(145, v_i).f_besch_2[2] = "addiert sich zu Angriff und Schaden";
		a_zauber(145, v_i).f_besch_1[1] = "The spellpower of the mage gets";
		a_zauber(145, v_i).f_besch_2[1] = "added to attack and damage";
		a_zauber(145, v_i).f_besch_1[3] = "El poder de hechizos del mago";
		a_zauber(145, v_i).f_besch_2[3] = "aumeta ataque y dano";
		a_zauber(146, v_i).f_name[2] = "Den Tod austricksen";
		a_zauber(146, v_i).f_name[1] = "Cheat death";
		a_zauber(146, v_i).f_name[3] = "Enganar al muerte";
		a_zauber(146, v_i).f_kosten = 10;
		a_zauber(146, v_i).f_level = 14;
		a_zauber(146, v_i).f_dauer = 0;
		a_zauber(146, v_i).f_art = "schwarz";
		a_zauber(146, v_i).f_besch_1[2] = "Verwandelt einen schwarzen";
		a_zauber(146, v_i).f_besch_2[2] = "Edelstein in steinernes Herz";
		a_zauber(146, v_i).f_besch_1[1] = "Transforms a black gem in";
		a_zauber(146, v_i).f_besch_2[1] = "a heart of stone";
		a_zauber(146, v_i).f_besch_1[3] = "Transforma una piedra preciosa";
		a_zauber(146, v_i).f_besch_2[3] = "negra en un corazon de piedra";
		a_zauber(148, v_i).f_name[2] = "Gift neutralisieren";
		a_zauber(148, v_i).f_name[1] = "Neutralize Poison";
		a_zauber(148, v_i).f_name[3] = "Neutralizar Veneno";
		a_zauber(148, v_i).f_kosten = 1;
		a_zauber(148, v_i).f_level = 9;
		a_zauber(148, v_i).f_dauer = 0;
		a_zauber(148, v_i).f_art = "druide";
		a_zauber(148, v_i).f_besch_1[2] = "Entfernt Gift von einem";
		a_zauber(148, v_i).f_besch_2[2] = "Feld";
		a_zauber(148, v_i).f_besch_1[1] = "Removes poison from a";
		a_zauber(148, v_i).f_besch_2[1] = "field";
		a_zauber(148, v_i).f_besch_1[3] = "Remueve veneno de un";
		a_zauber(148, v_i).f_besch_2[3] = "campo";
		a_zauber(149, v_i).f_name[2] = "Verdorren";
		a_zauber(149, v_i).f_name[1] = "Wither";
		a_zauber(149, v_i).f_name[3] = "Marchitarse";
		a_zauber(149, v_i).f_kosten = 2;
		a_zauber(149, v_i).f_level = 9;
		a_zauber(149, v_i).f_dauer = 0;
		a_zauber(149, v_i).f_art = "schwarz";
		a_zauber(149, v_i).f_besch_1[2] = "Halbiert die Lebenspunkte";
		a_zauber(149, v_i).f_besch_2[2] = "eines Monsters";
		a_zauber(149, v_i).f_besch_1[1] = "Halves the Lifepoints of";
		a_zauber(149, v_i).f_besch_2[1] = "a monster";
		a_zauber(149, v_i).f_besch_1[3] = "Corta los puntos de vida";
		a_zauber(149, v_i).f_besch_2[3] = "por la mitad";
		a_zauber(150, v_i).f_name[2] = "Todeswolke";
		a_zauber(150, v_i).f_name[1] = "Cloud of Death";
		a_zauber(150, v_i).f_name[3] = "Nube de muerte";
		a_zauber(150, v_i).f_kosten = 3;
		a_zauber(150, v_i).f_level = 13;
		a_zauber(150, v_i).f_dauer = 0;
		a_zauber(150, v_i).f_art = "schwarz";
		a_zauber(150, v_i).f_besch_1[2] = "T\366tet alle Monster mit weniger";
		a_zauber(150, v_i).f_besch_2[2] = "als Zaubermacht*3 Lebenspunkten";
		a_zauber(150, v_i).f_besch_1[1] = "Kills all monsters with less";
		a_zauber(150, v_i).f_besch_2[1] = "then Power*3 Lifepoints";
		a_zauber(150, v_i).f_besch_1[3] = "Mata a todos los monstruos con";
		a_zauber(150, v_i).f_besch_2[3] = "menos de Poder*3 Puntos de Vida";
		a_zauber(151, v_i).f_name[2] = "Regeneration";
		a_zauber(151, v_i).f_name[1] = "Regeneration";
		a_zauber(151, v_i).f_name[3] = "Regeneracion";
		a_zauber(151, v_i).f_kosten = 5;
		a_zauber(151, v_i).f_level = 11;
		a_zauber(151, v_i).f_dauer = 2;
		a_zauber(151, v_i).f_art = "druide";
		a_zauber(151, v_i).f_besch_1[2] = "Regeneriert einen Lebenspunkt";
		a_zauber(151, v_i).f_besch_2[2] = "pro Runde";
		a_zauber(151, v_i).f_besch_1[1] = "Regenerates one Lifepoint";
		a_zauber(151, v_i).f_besch_2[1] = "each round";
		a_zauber(151, v_i).f_besch_1[3] = "Regenera un punto de vida";
		a_zauber(151, v_i).f_besch_2[3] = "por turno";
		a_zauber(154, v_i).f_name[2] = "Lebensbund";
		a_zauber(154, v_i).f_name[1] = "Lifebond";
		a_zauber(154, v_i).f_name[3] = "Bondo de vida";
		a_zauber(154, v_i).f_kosten = 2;
		a_zauber(154, v_i).f_level = 14;
		a_zauber(154, v_i).f_dauer = 5;
		a_zauber(154, v_i).f_art = "hexerei";
		a_zauber(154, v_i).f_besch_1[2] = "Angreifende Monster bekommen";
		a_zauber(154, v_i).f_besch_2[2] = "den selben Schaden wie die Hexe";
		a_zauber(154, v_i).f_besch_1[1] = "Attacking monsters receive the same";
		a_zauber(154, v_i).f_besch_2[1] = "damage as the witch";
		a_zauber(154, v_i).f_besch_1[3] = "Monstros que ataquan reciben el";
		a_zauber(154, v_i).f_besch_2[3] = "mismo dano como la bruja";
		a_zauber(155, v_i).f_name[2] = "Insektenschwarm";
		a_zauber(155, v_i).f_name[1] = "Insectswarm";
		a_zauber(155, v_i).f_name[3] = "Nube de Insektos";
		a_zauber(155, v_i).f_kosten = 2;
		a_zauber(155, v_i).f_level = 12;
		a_zauber(155, v_i).f_dauer = 1;
		a_zauber(155, v_i).f_art = "druide";
		a_zauber(155, v_i).f_besch_1[2] = "Sie attackieren ein Monster";
		a_zauber(155, v_i).f_besch_2[2] = "f\374r Zauberkraft Runden";
		a_zauber(155, v_i).f_besch_1[1] = "They attack a monster for";
		a_zauber(155, v_i).f_besch_2[1] = "power turns";
		a_zauber(155, v_i).f_besch_1[3] = "Se ataquan a un montruo por";
		a_zauber(155, v_i).f_besch_2[3] = "poder de hechizos turnos";
		a_zauber(156, v_i).f_name[2] = "Tunnel";
		a_zauber(156, v_i).f_name[1] = "Tunnel";
		a_zauber(156, v_i).f_name[3] = "Tunel";
		a_zauber(156, v_i).f_kosten = 1;
		a_zauber(156, v_i).f_level = 7;
		a_zauber(156, v_i).f_dauer = 1;
		a_zauber(156, v_i).f_art = "hohe";
		a_zauber(156, v_i).f_besch_1[2] = "Erm\366glicht Zaubern durch";
		a_zauber(156, v_i).f_besch_2[2] = "W\344nde (Meta Magie)";
		a_zauber(156, v_i).f_besch_1[1] = "Permits casting a spell though";
		a_zauber(156, v_i).f_besch_2[1] = "Walls (Meta Magic)";
		a_zauber(156, v_i).f_besch_1[3] = "Permite hechizar a traves de";
		a_zauber(156, v_i).f_besch_2[3] = "pareds (Meta Magia)";
		a_zauber(157, v_i).f_name[2] = "Verl\344ngern2";
		a_zauber(157, v_i).f_name[1] = "Extend2";
		a_zauber(157, v_i).f_name[3] = "Extender2";
		a_zauber(157, v_i).f_kosten = 1;
		a_zauber(157, v_i).f_level = 6;
		a_zauber(157, v_i).f_dauer = 0;
		a_zauber(157, v_i).f_art = "hohe";
		a_zauber(157, v_i).f_besch_1[2] = "Verdoppelt die Dauer des n\344chsten";
		a_zauber(157, v_i).f_besch_2[2] = "Zaubers (Meta Magie)";
		a_zauber(157, v_i).f_besch_1[1] = "Double the duration of the next";
		a_zauber(157, v_i).f_besch_2[1] = "spell (Meta Magic)";
		a_zauber(157, v_i).f_besch_1[3] = "Dobla la duracion del hechizo";
		a_zauber(157, v_i).f_besch_2[3] = "proximo (Meta Magia)";
		a_zauber(158, v_i).f_name[2] = "Schnellzauber";
		a_zauber(158, v_i).f_name[1] = "Quickening";
		a_zauber(158, v_i).f_name[3] = "Hechizo Rapido";
		a_zauber(158, v_i).f_kosten = 1;
		a_zauber(158, v_i).f_level = 12;
		a_zauber(158, v_i).f_dauer = 1;
		a_zauber(158, v_i).f_art = "hohe";
		a_zauber(158, v_i).f_besch_1[2] = "Der n\344chste Spruch kostet nicht";
		a_zauber(158, v_i).f_besch_2[2] = "den Zug (Meta Magie)";
		a_zauber(158, v_i).f_besch_1[1] = "The next cast spell does not";
		a_zauber(158, v_i).f_besch_2[1] = "cost the turn (Meta Magic)";
		a_zauber(158, v_i).f_besch_1[3] = "El hechizo proximo no te cuesta";
		a_zauber(158, v_i).f_besch_2[3] = "el turno (Meta Magia)";
		a_zauber(159, v_i).f_name[2] = "Brecher";
		a_zauber(159, v_i).f_name[1] = "Breaking";
		a_zauber(159, v_i).f_name[3] = "Romper";
		a_zauber(159, v_i).f_kosten = 1;
		a_zauber(159, v_i).f_level = 9;
		a_zauber(159, v_i).f_dauer = 1;
		a_zauber(159, v_i).f_art = "hohe";
		a_zauber(159, v_i).f_besch_1[2] = "F\374r den n\344chsten Spruch wird die";
		a_zauber(159, v_i).f_besch_2[2] = "R\374stung des Monsters ignoriert (Meta Magie)";
		a_zauber(159, v_i).f_besch_1[1] = "For the next spell the armor of a";
		a_zauber(159, v_i).f_besch_2[1] = "monster is ignored (Meta Magic)";
		a_zauber(159, v_i).f_besch_1[3] = "Por el proximo hechizo se ignoran el";
		a_zauber(159, v_i).f_besch_2[3] = "armor del monstruo (Meta Magia)";
		a_zauber(160, v_i).f_name[2] = "Penetration";
		a_zauber(160, v_i).f_name[1] = "Penetration";
		a_zauber(160, v_i).f_name[3] = "Penetracion";
		a_zauber(160, v_i).f_kosten = 1;
		a_zauber(160, v_i).f_level = 10;
		a_zauber(160, v_i).f_dauer = 1;
		a_zauber(160, v_i).f_art = "hohe";
		a_zauber(160, v_i).f_besch_1[2] = "Dispel und Immunities eines Monsters";
		a_zauber(160, v_i).f_besch_2[2] = "werden ignoriert (Meta Magie)";
		a_zauber(160, v_i).f_besch_1[1] = "Dispel and Immunities of a monster do";
		a_zauber(160, v_i).f_besch_2[1] = "not work (Meta Magic)";
		a_zauber(160, v_i).f_besch_1[3] = "Dispel y imunidades de un monstruo no";
		a_zauber(160, v_i).f_besch_2[3] = "funcionan (Meta Magia)";
		a_zauber(161, v_i).f_name[2] = "Verdoppeln";
		a_zauber(161, v_i).f_name[1] = "Fork";
		a_zauber(161, v_i).f_name[3] = "Doblar";
		a_zauber(161, v_i).f_kosten = 1;
		a_zauber(161, v_i).f_level = 11;
		a_zauber(161, v_i).f_dauer = 1;
		a_zauber(161, v_i).f_art = "hohe";
		a_zauber(161, v_i).f_besch_1[2] = "Zaubert den n\344chsten Zauber zweimal";
		a_zauber(161, v_i).f_besch_2[2] = "(Meta Magie)";
		a_zauber(161, v_i).f_besch_1[1] = "Casts the next spell twice";
		a_zauber(161, v_i).f_besch_2[1] = "(Meta Magic)";
		a_zauber(161, v_i).f_besch_1[3] = "Hechiza el proximo hechizo dos veces";
		a_zauber(161, v_i).f_besch_2[3] = "(Meta Magia)";
		a_zauber(162, v_i).f_name[2] = "Feuerelementar beschw\366ren";
		a_zauber(162, v_i).f_name[1] = "Summon Fireelemental";
		a_zauber(162, v_i).f_name[3] = "Conjurar elementar de Fuego";
		a_zauber(162, v_i).f_kosten = 15;
		a_zauber(162, v_i).f_level = 11;
		a_zauber(162, v_i).f_dauer = 0;
		a_zauber(162, v_i).f_art = "feuer";
		a_zauber(162, v_i).f_besch_1[2] = "Beschw\366rt einen magischen";
		a_zauber(162, v_i).f_besch_2[2] = "Diener auf dem Nexus";
		a_zauber(162, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(162, v_i).f_besch_2[1] = "Servant in the nexus";
		a_zauber(162, v_i).f_besch_1[3] = "Conjura un servidor";
		a_zauber(162, v_i).f_besch_2[3] = "magico en el nexus";
		a_summoning(162) = 1;
		a_zauber(163, v_i).f_name[2] = "Wasserelementar beschw\366ren";
		a_zauber(163, v_i).f_name[1] = "Summon Waterelemental";
		a_zauber(163, v_i).f_name[3] = "Conjurar elementar de Aqua";
		a_zauber(163, v_i).f_kosten = 15;
		a_zauber(163, v_i).f_level = 11;
		a_zauber(163, v_i).f_dauer = 0;
		a_zauber(163, v_i).f_art = "wasser";
		a_zauber(163, v_i).f_besch_1[2] = "Beschw\366rt einen magischen";
		a_zauber(163, v_i).f_besch_2[2] = "Diener auf dem Nexus";
		a_zauber(163, v_i).f_besch_1[1] = "Summons a magical";
		a_zauber(163, v_i).f_besch_2[1] = "Servant in the nexus";
		a_zauber(163, v_i).f_besch_1[3] = "Conjura un servidor";
		a_zauber(163, v_i).f_besch_2[3] = "magico en el nexus";
		a_summoning(163) = 1;
		a_zauber(164, v_i).f_name[2] = "Regen";
		a_zauber(164, v_i).f_name[1] = "Rain";
		a_zauber(164, v_i).f_name[3] = "Lluvia";
		a_zauber(164, v_i).f_kosten = 2;
		a_zauber(164, v_i).f_level = 12;
		a_zauber(164, v_i).f_dauer = 0;
		a_zauber(164, v_i).f_art = "wasser";
		a_zauber(164, v_i).f_besch_1[2] = "F\374llt das Labyrinth mit trinkbaren";
		a_zauber(164, v_i).f_besch_2[2] = "Wasserfeldern";
		a_zauber(164, v_i).f_besch_1[1] = "Fills the labyrinth with drinkable";
		a_zauber(164, v_i).f_besch_2[1] = "watertiles";
		a_zauber(164, v_i).f_besch_1[3] = "Llena el labirinto con campos de aqua";
		a_zauber(164, v_i).f_besch_2[3] = "bebibles";
		a_zauber(165, v_i).f_name[2] = "Lied des Schlafes";
		a_zauber(165, v_i).f_name[1] = "Song of Sleep";
		a_zauber(165, v_i).f_name[3] = "Cancion de dormir";
		a_zauber(165, v_i).f_kosten = 3;
		a_zauber(165, v_i).f_level = 13;
		a_zauber(165, v_i).f_dauer = 9999;
		a_zauber(165, v_i).f_art = "barde";
		a_zauber(165, v_i).f_besch_1[2] = "L\344sst manche monster die ihn h\366ren";
		a_zauber(165, v_i).f_besch_2[2] = "einschlafen";
		a_zauber(165, v_i).f_besch_1[1] = "Puts some monsters that hear it to";
		a_zauber(165, v_i).f_besch_2[1] = "sleep";
		a_zauber(165, v_i).f_besch_1[3] = "Hace dormir a algunos monstruos que";
		a_zauber(165, v_i).f_besch_2[3] = "la oian";
		a_zauber(166, v_i).f_name[2] = "Lied des Selbstmords";
		a_zauber(166, v_i).f_name[1] = "Song of Suicide";
		a_zauber(166, v_i).f_name[3] = "Cancion del suicidio";
		a_zauber(166, v_i).f_kosten = 5;
		a_zauber(166, v_i).f_level = 15;
		a_zauber(166, v_i).f_dauer = 9999;
		a_zauber(166, v_i).f_art = "barde";
		a_zauber(166, v_i).f_besch_1[2] = "T\366tet einige monster die ihn";
		a_zauber(166, v_i).f_besch_2[2] = "h\366ren";
		a_zauber(166, v_i).f_besch_1[1] = "Kills some monsters that hear";
		a_zauber(166, v_i).f_besch_2[1] = "it";
		a_zauber(166, v_i).f_besch_1[3] = "Destruye algunos monstruos";
		a_zauber(166, v_i).f_besch_2[3] = "que la oian";
		a_zauber(167, v_i).f_name[2] = "Heile Kreatur";
		a_zauber(167, v_i).f_name[1] = "Heal creature";
		a_zauber(167, v_i).f_name[3] = "Curar kriatura";
		a_zauber(167, v_i).f_kosten = 1;
		a_zauber(167, v_i).f_level = 3;
		a_zauber(167, v_i).f_dauer = 0;
		a_zauber(167, v_i).f_art = "beschw\366rer";
		a_zauber(167, v_i).f_besch_1[2] = "Gibt einer Kreatur verlorene";
		a_zauber(167, v_i).f_besch_2[2] = "Lebenspunkte zur\374ck";
		a_zauber(167, v_i).f_besch_1[1] = "Gives a creature back lost";
		a_zauber(167, v_i).f_besch_2[1] = "lifepoints";
		a_zauber(167, v_i).f_besch_1[3] = "Revuelve puntos de vida perdidas";
		a_zauber(167, v_i).f_besch_2[3] = "de una kriatura";
		a_zauber(168, v_i).f_name[2] = "Verzaubere Kreatur 1";
		a_zauber(168, v_i).f_name[1] = "Enchant creature 1";
		a_zauber(168, v_i).f_name[3] = "Mejorar kriatura 1";
		a_zauber(168, v_i).f_kosten = 1;
		a_zauber(168, v_i).f_level = 5;
		a_zauber(168, v_i).f_dauer = 0;
		a_zauber(168, v_i).f_art = "beschw\366rer";
		a_zauber(168, v_i).f_besch_1[2] = "Gibt einer Kreatur schaden +1";
		a_zauber(168, v_i).f_besch_2[2] = "und attacke +1";
		a_zauber(168, v_i).f_besch_1[1] = "Gives a creature damage +1";
		a_zauber(168, v_i).f_besch_2[1] = "and attack +1";
		a_zauber(168, v_i).f_besch_1[3] = "Mejora una criatura de";
		a_zauber(168, v_i).f_besch_2[3] = "ataque +1 and dano +1";
		a_zauber(169, v_i).f_name[2] = "Verzaubere Kreatur 2";
		a_zauber(169, v_i).f_name[1] = "Enchant creature 2";
		a_zauber(169, v_i).f_name[3] = "Mejorar kriatura 2";
		a_zauber(169, v_i).f_kosten = 1;
		a_zauber(169, v_i).f_level = 8;
		a_zauber(169, v_i).f_dauer = 0;
		a_zauber(169, v_i).f_art = "beschw\366rer";
		a_zauber(169, v_i).f_besch_1[2] = "Gibt einer Kreatur Schaden +2,";
		a_zauber(169, v_i).f_besch_2[2] = "Attacke +2 und Geschwindigkeit +1";
		a_zauber(169, v_i).f_besch_1[1] = "Gives a creature damage +2,";
		a_zauber(169, v_i).f_besch_2[1] = "attack +2, speed +1";
		a_zauber(169, v_i).f_besch_1[3] = "Mejora una criatura de";
		a_zauber(169, v_i).f_besch_2[3] = "ataque +2, dano +2 y velocidad +1";
		a_zauber(170, v_i).f_name[2] = "Verzaubere Kreatur 3";
		a_zauber(170, v_i).f_name[1] = "Enchant creature 3";
		a_zauber(170, v_i).f_name[3] = "Mejorar kriatura 3";
		a_zauber(170, v_i).f_kosten = 1;
		a_zauber(170, v_i).f_level = 11;
		a_zauber(170, v_i).f_dauer = 0;
		a_zauber(170, v_i).f_art = "beschw\366rer";
		a_zauber(170, v_i).f_besch_1[2] = "Gibt einer Kreatur schaden +3,";
		a_zauber(170, v_i).f_besch_2[2] = "attacke +3 und Geschwindigkeit +2";
		a_zauber(170, v_i).f_besch_1[1] = "Gives a creature damage +3,";
		a_zauber(170, v_i).f_besch_2[1] = "attack +3, speed +2";
		a_zauber(170, v_i).f_besch_1[3] = "Mejora una criatura de";
		a_zauber(170, v_i).f_besch_2[3] = "ataque +3, dano +3 y velocidad +2";
		a_zauber(171, v_i).f_name[2] = "Verzaubere Kreatur 4";
		a_zauber(171, v_i).f_name[1] = "Enchant creature 4";
		a_zauber(171, v_i).f_name[3] = "Mejorar kriatura 4";
		a_zauber(171, v_i).f_kosten = 1;
		a_zauber(171, v_i).f_level = 15;
		a_zauber(171, v_i).f_dauer = 0;
		a_zauber(171, v_i).f_art = "beschw\366rer";
		a_zauber(171, v_i).f_besch_1[2] = "Gibt einer Kreatur Schaden +4,";
		a_zauber(171, v_i).f_besch_2[2] = "Attacke +4 und Geschwindigkeit +3";
		a_zauber(171, v_i).f_besch_1[1] = "Gives a creature damage +4,";
		a_zauber(171, v_i).f_besch_2[1] = "attack +4 and speed +3";
		a_zauber(171, v_i).f_besch_1[3] = "Mejora una criatura de";
		a_zauber(171, v_i).f_besch_2[3] = "ataque +4, dano +4 y velocidad +3";
		a_zauber(172, v_i).f_name[2] = "Heile Krankheit";
		a_zauber(172, v_i).f_name[1] = "Heal disease";
		a_zauber(172, v_i).f_name[3] = "Curar enfermedad";
		a_zauber(172, v_i).f_kosten = 2;
		a_zauber(172, v_i).f_level = 5;
		a_zauber(172, v_i).f_dauer = 0;
		a_zauber(172, v_i).f_art = "weiss";
		a_zauber(172, v_i).f_besch_1[2] = "Heilt jegliche Krankheit des weissen";
		a_zauber(172, v_i).f_besch_2[2] = "Magiers";
		a_zauber(172, v_i).f_besch_1[1] = "Cures all diseases of the white mage";
		a_zauber(172, v_i).f_besch_2[1] = "";
		a_zauber(172, v_i).f_besch_1[3] = "Cura todos los enfermedades del";
		a_zauber(172, v_i).f_besch_2[3] = "mago blanco";
		a_zauber(173, v_i).f_name[2] = "Chaos";
		a_zauber(173, v_i).f_name[1] = "Chaos";
		a_zauber(173, v_i).f_name[3] = "Chaos";
		a_zauber(173, v_i).f_kosten = 1;
		a_zauber(173, v_i).f_level = 1;
		a_zauber(173, v_i).f_dauer = 0;
		a_zauber(173, v_i).f_art = "hohe";
		a_zauber(173, v_i).f_besch_1[2] = "Zaubert einen zuf\344lligen Level 1 Spruch";
		a_zauber(173, v_i).f_besch_2[2] = "";
		a_zauber(173, v_i).f_besch_1[1] = "Casts a random level 1 spell";
		a_zauber(173, v_i).f_besch_2[1] = "";
		a_zauber(173, v_i).f_besch_1[3] = "Hechiza un hechizo de circulo 1 de suerte";
		a_zauber(173, v_i).f_besch_2[3] = "";
		a_zauber(174, v_i).f_name[2] = "Transmigration";
		a_zauber(174, v_i).f_name[1] = "Transmigration";
		a_zauber(174, v_i).f_name[3] = "Transmigracion";
		a_zauber(174, v_i).f_kosten = 10;
		a_zauber(174, v_i).f_level = 9;
		a_zauber(174, v_i).f_dauer = 0;
		a_zauber(174, v_i).f_art = "basis";
		a_zauber(174, v_i).f_besch_1[2] = "Vertauscht permanent Mana/Lebenspunkte";
		a_zauber(174, v_i).f_besch_2[2] = "";
		a_zauber(174, v_i).f_besch_1[1] = "Swaps permanently Mana/Lifepoints";
		a_zauber(174, v_i).f_besch_2[1] = "";
		a_zauber(174, v_i).f_besch_1[3] = "Cambia permanente Puntos de Mana y Vida";
		a_zauber(174, v_i).f_besch_2[3] = "";
		a_zauber(175, v_i).f_name[2] = "Konzentration";
		a_zauber(175, v_i).f_name[1] = "Concentration";
		a_zauber(175, v_i).f_name[3] = "Concentracion";
		a_zauber(175, v_i).f_kosten = 1;
		a_zauber(175, v_i).f_level = 9;
		a_zauber(175, v_i).f_dauer = 5;
		a_zauber(175, v_i).f_art = "warlock";
		a_zauber(175, v_i).f_besch_1[2] = "Erh\366ht die Geschicklichkeit des Warlock";
		a_zauber(175, v_i).f_besch_2[2] = "";
		a_zauber(175, v_i).f_besch_1[1] = "Raises the dexterity of the warlock";
		a_zauber(175, v_i).f_besch_2[1] = "";
		a_zauber(175, v_i).f_besch_1[3] = "Aumenta la destreza del warlock";
		a_zauber(175, v_i).f_besch_2[3] = "";
		a_zauber(176, v_i).f_name[2] = "Pr\344zision";
		a_zauber(176, v_i).f_name[1] = "Precision";
		a_zauber(176, v_i).f_name[3] = "Precicion";
		a_zauber(176, v_i).f_kosten = 1;
		a_zauber(176, v_i).f_level = 11;
		a_zauber(176, v_i).f_dauer = 5;
		a_zauber(176, v_i).f_art = "warlock";
		a_zauber(176, v_i).f_besch_1[2] = "Erh\366ht den Angriff des Warlock";
		a_zauber(176, v_i).f_besch_2[2] = "";
		a_zauber(176, v_i).f_besch_1[1] = "Raises the attack of the warlock";
		a_zauber(176, v_i).f_besch_2[1] = "";
		a_zauber(176, v_i).f_besch_1[3] = "Aumenta la ataque del warlock";
		a_zauber(176, v_i).f_besch_2[3] = "";
		a_zauber(177, v_i).f_name[2] = "Erschaffe Besen";
		a_zauber(177, v_i).f_name[1] = "Create Broomstick";
		a_zauber(177, v_i).f_name[3] = "Crear Escoba";
		a_zauber(177, v_i).f_kosten = 10;
		a_zauber(177, v_i).f_level = 11;
		a_zauber(177, v_i).f_dauer = 0;
		a_zauber(177, v_i).f_art = "hexerei";
		a_zauber(177, v_i).f_besch_1[2] = "Erschafft einen fliegenden";
		a_zauber(177, v_i).f_besch_2[2] = "Besen";
		a_zauber(177, v_i).f_besch_1[1] = "Creates a Broomstick";
		a_zauber(177, v_i).f_besch_2[1] = "";
		a_zauber(177, v_i).f_besch_1[3] = "Crea un escoba volando";
		a_zauber(177, v_i).f_besch_2[3] = "";
		a_zauber(200, v_i).f_name[2] = "Lichtzauber";
		a_zauber(200, v_i).f_name[1] = "Light Spell";
		a_zauber(200, v_i).f_name[3] = "Hechizo de Luz";
		a_zauber(200, v_i).f_kosten = 0;
		a_zauber(200, v_i).f_level = 0;
		a_zauber(200, v_i).f_dauer = 0;
		a_zauber(200, v_i).f_art = "";
		a_zauber(200, v_i).f_besch_1[2] = "";
		a_zauber(200, v_i).f_besch_2[2] = "";
		a_zauber(200, v_i).f_besch_1[1] = "";
		a_zauber(200, v_i).f_besch_2[1] = "";
		a_zauber(200, v_i).f_besch_1[3] = "";
		a_zauber(200, v_i).f_besch_2[3] = "";
	}
}

static int32_t p_init_traenke() {
	int32_t v_i = 0;
	int32_t v_k = 0;
	int32_t v_nach = 0;
	int16_t v_pos1 = 0;
	int16_t v_pos2 = 0;
	int16_t v_trank = 0;
	int32_t v_von = 0;
	struct st_gs v_zw_geg;
	for (v_i = 1; v_i <= 100; v_i += 1) {
		v_von = (75 + p_random(37));
		v_nach = (75 + p_random(37));
		for (v_k = 1; v_k <= 3; v_k += 1) {
			v_zw_geg.f_name[v_k] = a_gegenstand(v_von).f_name[v_k];
		}
		v_zw_geg.f_art = a_gegenstand(v_von).f_art;
		v_zw_geg.f_einkauf = a_gegenstand(v_von).f_einkauf;
		v_zw_geg.f_verkauf = a_gegenstand(v_von).f_verkauf;
		for (v_k = 1; v_k <= 3; v_k += 1) {
			a_gegenstand(v_von).f_name[v_k] = a_gegenstand(v_nach).f_name[v_k];
		}
		a_gegenstand(v_von).f_art = a_gegenstand(v_nach).f_art;
		a_gegenstand(v_von).f_einkauf = a_gegenstand(v_nach).f_einkauf;
		a_gegenstand(v_von).f_verkauf = a_gegenstand(v_nach).f_verkauf;
		for (v_k = 1; v_k <= 3; v_k += 1) {
			a_gegenstand(v_nach).f_name[v_k] = v_zw_geg.f_name[v_k];
		}
		a_gegenstand(v_nach).f_art = v_zw_geg.f_art;
		a_gegenstand(v_nach).f_einkauf = v_zw_geg.f_einkauf;
		a_gegenstand(v_nach).f_verkauf = v_zw_geg.f_verkauf;
	}
	for (v_i = 1; v_i <= 38; v_i += 1) {
		a_mischen(v_i).f_trank1 = ((75 + v_i) - 1);
		a_mischen(v_i).f_trank2 = ((75 + v_i) - 1);
		if ((p_random(100) > 90)) {
			a_mischen(v_i).f_trank3 = 9999;
		} else {
			a_mischen(v_i).f_trank3 = (p_random(37) + 75);
		}
	}
	for (v_i = 1; v_i <= 100; v_i += 1) {
		v_pos1 = (p_random(37) + 1);
		v_pos2 = (p_random(37) + 1);
		v_trank = a_mischen(v_pos1).f_trank2;
		a_mischen(v_pos1).f_trank2 = a_mischen(v_pos2).f_trank2;
		a_mischen(v_pos2).f_trank2 = v_trank;
	}
}

static int32_t p_inv() {
	int16_t v_a = 0;
	int32_t v_aktuell = 0;
	int16_t v_b = 0;
	int16_t v_bew_geg = 0;
	int16_t v_bew_geg_pos = 0;
	int16_t v_bew_geg_x = 0;
	int16_t v_bew_geg_y = 0;
	int16_t v_bew_ziel = 0;
	int16_t v_c = 0;
	int16_t v_d = 0;
	int16_t v_gew = 0;
	int32_t v_i = 0;
	int32_t v_itemmmenue_aktiv = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_jb2 = 0;
	static int32_t v_lastselected;
	int16_t v_menuposx = 0;
	int16_t v_menuposy = 0;
	int32_t v_mmouse_xdif = 0;
	int32_t v_mmouse_xtemp = 0;
	int32_t v_mmouse_ydif = 0;
	int32_t v_mmouse_ytemp = 0;
	int32_t v_pos = 0;
	int32_t v_result = 0;
	int16_t v_save_ring = 0;
	int16_t v_save_waffe = 0;
	int16_t v_schnellinventory_nach = 0;
	int16_t v_schnellinventory_pos = 0;
	int16_t v_sel_x = 0;
	int16_t v_sel_y = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int16_t v_xxx = 0;
	int32_t v_y = 0;
	int16_t v_yyy = 0;
	v_sel_x = 1;
	v_sel_y = 1;
	g_benutzen = 0;
	g_bewegen = 0;
	v_bew_geg_x = 0;
	v_bew_geg_y = 0;
	v_bew_geg = 0;
	v_schnellinventory_pos = 0;
	v_schnellinventory_nach = 0;
	do {
		p_fenster(0);
		p_doubleclick(1);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			g_mmouse_x = p_mousex();
			g_mmouse_y = p_mousey();
			v_mmouse_xdif = (v_mmouse_xtemp - g_mmouse_x);
			v_mmouse_ydif = (v_mmouse_ytemp - g_mmouse_y);
			v_mmouse_xtemp = p_mousex();
			v_mmouse_ytemp = p_mousey();
			g_mmouse_links = p_mousebutton(1);
			g_mmouse_rechts = p_mousebutton(2);
		}
		p_examinekeyboard();
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		if ((g_itemmenue_aktiv == 0)) {
			a_addelaymax(1) = 100;
			if ((p_keyboardpushed(275) || (v_jax == 1))) {
				if (p_autodelay(1, 1, -2)) {
					p_autodelay(1, 2, -2);
					v_sel_x = (v_sel_x + 1);
					if ((v_sel_x > 8)) {
						v_sel_x = 8;
					}
				}
			} else {
				if ((p_keyboardpushed(276) || (v_jax == -1))) {
					if (p_autodelay(1, 1, -2)) {
						p_autodelay(1, 2, -2);
						v_sel_x = (v_sel_x - 1);
						if ((v_sel_x < 1)) {
							v_sel_x = 1;
						}
					}
				} else {
					if ((p_keyboardpushed(274) || (v_jay == 1))) {
						if (p_autodelay(1, 1, -2)) {
							p_autodelay(1, 2, -2);
							v_sel_y = (v_sel_y + 1);
							if ((v_sel_y > 5)) {
								v_sel_y = 5;
							}
						}
					} else {
						if ((p_keyboardpushed(273) || (v_jay == -1))) {
							if (p_autodelay(1, 1, -2)) {
								p_autodelay(1, 2, -2);
								v_sel_y = (v_sel_y - 1);
								if ((v_sel_y < 1)) {
									v_sel_y = 1;
								}
							}
						} else {
							p_autodelay(1, 3, -2);
						}
					}
				}
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(0, 0, 0));
		p_box(366, 15, 258, 220, -1);
		p_stopdrawing();
		v_x = 366;
		v_y = 15;
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 5; v_j += 1) {
				v_a = (v_x + ((v_i * 32) - 32));
				v_b = (v_x + (v_i * 32));
				v_c = (v_y + ((v_j * 32) - 32));
				v_d = (v_y + (v_j * 32));
				if (((((g_mmouse_x > v_a) && (g_mmouse_x < v_b)) && (g_mmouse_y > v_c)) && (g_mmouse_y < v_d))) {
					p_clipsprite(8, 224, 320, 32, 32);
					p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					v_bew_ziel = (v_i + ((8 * v_j) - 8));
					if (((g_bewegen == 0) && (p_doubleclick(0) == 2))) {
						g_feld = 99;
						g_bewegen = 1;
						v_bew_geg = a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_name;
						v_bew_geg_pos = (v_i + ((8 * v_j) - 8));
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						v_lastselected = (v_i + ((8 * v_j) - 8));
					}
					if ((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == (v_i + ((8 * v_j) - 8))))) {
						g_aktion = 1;
						g_mmouse_links = 0;
						if ((a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_benutzt == 0)) {
							g_do_it = 1;
						} else {
							g_do_it2 = 1;
						}
					}
					if ((g_mmouse_links == 1)) {
						if (((g_bewegen == 0) && ((v_mmouse_xdif != 0) || (v_mmouse_ydif != 0)))) {
							g_feld = 99;
							g_bewegen = 1;
							v_bew_geg = a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_name;
							v_bew_geg_pos = (v_i + ((8 * v_j) - 8));
							v_bew_geg_x = v_bew_geg;
							v_bew_geg_y = 0;
							if ((v_bew_geg_x > 16)) {
								do {
									v_bew_geg_y = (v_bew_geg_y + 1);
									v_bew_geg_x = (v_bew_geg_x - 16);
								} while (!(v_bew_geg_x < 17));
							}
						}
					}
				} else {
					p_clipsprite(8, 480, 64, 32, 32);
					p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				}
				if ((((v_i == v_sel_x) && (v_j == v_sel_y)) && (v_itemmmenue_aktiv == 0))) {
					p_clipsprite(1, 0, 32, 32, 32);
					p_displaytransparentsprite(1, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						g_feld = 99;
						g_itemmenue_aktiv = 1;
					}
					if ((p_keyboardpushed(27) || (v_jb2 != 0))) {
						g_feld = 1;
						g_itemmenue_aktiv = 0;
					}
				}
				v_pos = (v_i + ((8 * v_j) - 8));
				if ((g_feld == 99)) {
					g_feld = v_pos;
				}
				if ((a_inventory(v_pos, g_akt_spieler).f_benutzt == 1)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_frontcolor(p_rgb(120, 120, 120));
					p_box((v_x + ((v_i * 32) - 31)), (v_y + ((v_j * 32) - 31)), 30, 30, -1);
					p_stopdrawing();
				}
				v_sprite_x = a_inventory(v_pos, g_akt_spieler).f_name;
				if (((v_sprite_x == 46) && (a_inventory(v_pos, g_akt_spieler).f_benutzt == 1))) {
					v_sprite_x = 47;
				}
				if (((v_sprite_x == 39) && (a_inventory(v_pos, g_akt_spieler).f_benutzt == 1))) {
					v_sprite_x = 40;
				}
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				if ((a_inventory(v_pos, g_akt_spieler).f_anzahl > 0)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawingmode(1);
					p_drawtext(((v_x + ((v_i * 32) - 32)) + 22), ((v_y + ((v_j * 32) - 32)) + 18), p_str((a_inventory(v_pos, g_akt_spieler).f_anzahl + 1)), -1, 0);
					p_stopdrawing();
				}
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(0, 0, 0));
		p_box(15, 15, 335, 397, -1);
		p_stopdrawing();
		p_clipsprite(45, 1, 1, 165, 393);
		p_displaysprite(45, 90, 15);
		v_aktuell = 0;
		if (((((g_mmouse_x > 207) && (g_mmouse_x < 239)) && (g_mmouse_y > 18)) && (g_mmouse_y < 50))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 207, 18);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 207, 18);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 6) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 207, 18);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 100) && (g_mmouse_x < 132)) && (g_mmouse_y > 40)) && (g_mmouse_y < 72))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 100, 40);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 100, 40);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 21) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 100, 40);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 225) && (g_mmouse_x < 257)) && (g_mmouse_y > 55)) && (g_mmouse_y < 87))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 225, 55);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 225, 55);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 20) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 225, 55);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 260) && (g_mmouse_x < 292)) && (g_mmouse_y > 210)) && (g_mmouse_y < 242))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 260, 210);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 260, 210);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 7) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 260, 210);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		v_save_waffe = 0;
		if (((((g_mmouse_x > 72) && (g_mmouse_x < 104)) && (g_mmouse_y > 245)) && (g_mmouse_y < 277))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 72, 245);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 72, 245);
		}
		v_i = 1;
		do {
			p_fenster(0);
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_save_waffe = v_i;
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 72, 245);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
			v_i = (v_i + 1);
		} while (!((v_i > 50) || (v_save_waffe > 0)));
		v_aktuell = 0;
		if (((((g_mmouse_x > 260) && (g_mmouse_x < 292)) && (g_mmouse_y > 245)) && (g_mmouse_y < 277))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 260, 245);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 260, 245);
		}
		if ((v_save_waffe > 0)) {
			v_i = (v_save_waffe + 1);
			v_save_waffe = 0;
			do {
				p_fenster(0);
				if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
					v_save_waffe = v_i;
					v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
					v_sprite_y = 0;
					if ((v_sprite_x > 16)) {
						do {
							v_sprite_y = (v_sprite_y + 1);
							v_sprite_x = (v_sprite_x - 16);
						} while (!(v_sprite_x < 17));
					}
					p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
					p_displaytransparentsprite(8, 260, 245);
					if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
						g_feld = 99;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						v_lastselected = v_i;
					}
					if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
						g_bewegen = 5;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
					}
					if ((g_mmouse_links == 1)) {
						if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
							g_feld = 99;
							g_bewegen = 2;
							v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
							v_bew_geg_pos = v_i;
							v_bew_geg_x = v_bew_geg;
							v_bew_geg_y = 0;
							if ((v_bew_geg_x > 16)) {
								do {
									v_bew_geg_y = (v_bew_geg_y + 1);
									v_bew_geg_x = (v_bew_geg_x - 16);
								} while (!(v_bew_geg_x < 17));
							}
						}
					}
				}
				v_i = (v_i + 1);
			} while (!((v_i > 50) || (v_save_waffe > 0)));
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 300) && (g_mmouse_x < 332)) && (g_mmouse_y > 245)) && (g_mmouse_y < 277))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 300, 245);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 300, 245);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 11) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 300, 245);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		v_save_ring = 0;
		if (((((g_mmouse_x > 235) && (g_mmouse_x < 267)) && (g_mmouse_y > 282)) && (g_mmouse_y < 314))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 235, 282);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 235, 282);
		}
		v_i = 1;
		do {
			p_fenster(0);
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 18) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_save_ring = v_i;
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 235, 282);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
			v_i = (v_i + 1);
		} while (!((v_i > 50) || (v_save_ring > 0)));
		v_aktuell = 0;
		if (((((g_mmouse_x > 270) && (g_mmouse_x < 302)) && (g_mmouse_y > 282)) && (g_mmouse_y < 314))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 270, 282);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 270, 282);
		}
		if ((v_save_ring > 0)) {
			v_i = (v_save_ring + 1);
			v_save_ring = 0;
			do {
				p_fenster(0);
				if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 18) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
					v_save_ring = v_i;
					v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
					v_sprite_y = 0;
					if ((v_sprite_x > 16)) {
						do {
							v_sprite_y = (v_sprite_y + 1);
							v_sprite_x = (v_sprite_x - 16);
						} while (!(v_sprite_x < 17));
					}
					p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
					p_displaytransparentsprite(8, 270, 282);
					if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
						g_feld = 99;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						v_lastselected = v_i;
					}
					if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
						g_bewegen = 5;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
					}
					if ((g_mmouse_links == 1)) {
						if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
							g_feld = 99;
							g_bewegen = 2;
							v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
							v_bew_geg_pos = v_i;
							v_bew_geg_x = v_bew_geg;
							v_bew_geg_y = 0;
							if ((v_bew_geg_x > 16)) {
								do {
									v_bew_geg_y = (v_bew_geg_y + 1);
									v_bew_geg_x = (v_bew_geg_x - 16);
								} while (!(v_bew_geg_x < 17));
							}
						}
					}
				}
				v_i = (v_i + 1);
			} while (!((v_i > 50) || (v_save_ring > 0)));
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 305) && (g_mmouse_x < 337)) && (g_mmouse_y > 282)) && (g_mmouse_y < 314))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 305, 282);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 305, 282);
		}
		if ((v_save_ring > 0)) {
			v_i = (v_save_ring + 1);
			v_save_ring = 0;
			do {
				p_fenster(0);
				if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 18) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
					v_save_ring = v_i;
					v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
					v_sprite_y = 0;
					if ((v_sprite_x > 16)) {
						do {
							v_sprite_y = (v_sprite_y + 1);
							v_sprite_x = (v_sprite_x - 16);
						} while (!(v_sprite_x < 17));
					}
					p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
					p_displaytransparentsprite(8, 305, 282);
					if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
						g_feld = 99;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						v_lastselected = v_i;
					}
					if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
						g_bewegen = 5;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
					}
					if ((g_mmouse_links == 1)) {
						if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
							g_feld = 99;
							g_bewegen = 2;
							v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
							v_bew_geg_pos = v_i;
							v_bew_geg_x = v_bew_geg;
							v_bew_geg_y = 0;
							if ((v_bew_geg_x > 16)) {
								do {
									v_bew_geg_y = (v_bew_geg_y + 1);
									v_bew_geg_x = (v_bew_geg_x - 16);
								} while (!(v_bew_geg_x < 17));
							}
						}
					}
				}
				v_i = (v_i + 1);
			} while (!((v_i > 50) || (v_save_ring > 0)));
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 60) && (g_mmouse_x < 92)) && (g_mmouse_y > 130)) && (g_mmouse_y < 162))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 60, 130);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 60, 130);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 9) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 60, 130);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 260) && (g_mmouse_x < 292)) && (g_mmouse_y > 120)) && (g_mmouse_y < 152))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 260, 120);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 260, 120);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 10) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 260, 120);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 297) && (g_mmouse_x < 329)) && (g_mmouse_y > 120)) && (g_mmouse_y < 152))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 297, 120);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 297, 120);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 13) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 297, 120);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 70) && (g_mmouse_x < 102)) && (g_mmouse_y > 180)) && (g_mmouse_y < 212))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 70, 180);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 70, 180);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 19) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 70, 180);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		v_aktuell = 0;
		if (((((g_mmouse_x > 225) && (g_mmouse_x < 257)) && (g_mmouse_y > 365)) && (g_mmouse_y < 397))) {
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, 225, 365);
			v_aktuell = 1;
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, 225, 365);
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 8) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = a_inventory(v_i, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, 225, 365);
				if ((((g_bewegen == 0) && (p_doubleclick(0) == 2)) && (v_aktuell == 1))) {
					g_feld = 99;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					g_bewegen = 2;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
					v_lastselected = v_i;
				}
				if (((((g_bewegen == 0) && (p_doubleclick(0) == 3)) && (v_lastselected == v_i)) && (v_aktuell == 1))) {
					g_bewegen = 5;
					v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
					v_bew_geg_pos = v_i;
					v_bew_geg_x = v_bew_geg;
					v_bew_geg_y = 0;
				}
				if ((g_mmouse_links == 1)) {
					if ((((g_bewegen == 0) && (v_aktuell == 1)) && ((((v_mmouse_xdif < -1) || (v_mmouse_xdif > 1)) || (v_mmouse_ydif < -1)) || (v_mmouse_ydif > 1)))) {
						g_feld = 99;
						g_bewegen = 2;
						v_bew_geg = a_inventory(v_i, g_akt_spieler).f_name;
						v_bew_geg_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
L_endjump: ;
		if ((g_bewegen == 2)) {
			g_feld = v_bew_geg_pos;
		}
		v_menuposx = 23;
		v_menuposy = 431;
		for (v_i = 1; v_i <= 10; v_i += 1) {
			v_aktuell = 0;
			if ((a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1)) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(120, 120, 120));
				p_box((v_menuposx + ((v_i * 32) - 31)), (v_menuposy + 1), 30, 30, -1);
				p_stopdrawing();
			}
			if (((((g_mmouse_x > ((v_menuposx + (v_i * 32)) - 32)) && (g_mmouse_x < (v_menuposx + (v_i * 32)))) && (g_mmouse_y > v_menuposy)) && (g_mmouse_y < (v_menuposy + 32)))) {
				p_clipsprite(8, 224, 320, 32, 32);
				p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
				v_aktuell = 1;
				if ((g_bewegen == 0)) {
					v_schnellinventory_pos = v_i;
				} else {
					v_schnellinventory_nach = v_i;
				}
			} else {
				p_clipsprite(8, 480, 64, 32, 32);
				p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
			}
			if ((a_inventory((v_i + 40), g_akt_spieler).f_name != 0)) {
				v_sprite_x = a_inventory((v_i + 40), g_akt_spieler).f_name;
				if (((v_sprite_x == 46) && (a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1))) {
					v_sprite_x = 47;
				}
				if (((v_sprite_x == 39) && (a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1))) {
					v_sprite_x = 40;
				}
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
				if ((a_inventory((v_i + 40), g_akt_spieler).f_anzahl > 0)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawingmode(1);
					p_drawtext(((v_menuposx + ((v_i * 32) - 32)) + 22), (v_menuposy + 18), p_str((a_inventory((v_i + 40), g_akt_spieler).f_anzahl + 1)), -1, 0);
					p_stopdrawing();
				}
				if ((g_mmouse_links == 1)) {
					if (((g_bewegen == 0) && (v_aktuell == 1))) {
						g_bewegen = 3;
						v_bew_geg = a_inventory((v_i + 40), g_akt_spieler).f_name;
						v_schnellinventory_pos = v_i;
						v_bew_geg_x = v_bew_geg;
						v_bew_geg_y = 0;
						if ((v_bew_geg_x > 16)) {
							do {
								v_bew_geg_y = (v_bew_geg_y + 1);
								v_bew_geg_x = (v_bew_geg_x - 16);
							} while (!(v_bew_geg_x < 17));
						}
					}
				}
			}
		}
		if ((a_skills(28, g_akt_spieler).f_gewaehlt == 1)) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 22));
			v_xxx = 375;
			v_yyy = 410;
			p_drawtext(v_xxx, (v_yyy - 20), a_skills(28, g_akt_spieler).f_name[(g_sprache + 1)], -1, 0);
			p_drawtext((v_xxx + 40), (v_yyy + 8), a_nachricht_text((709 + a_spieler(g_akt_spieler).f_style), (g_sprache + 1)), -1, 0);
			p_stopdrawing();
			v_result = p_examinemouse();
			g_mmouse_x = p_mousex();
			g_mmouse_y = p_mousey();
			g_mmouse_links = p_mousebutton(1);
			if (((((g_mmouse_x > v_xxx) && (g_mmouse_x < (v_xxx + 32))) && (g_mmouse_y > v_yyy)) && (g_mmouse_y < (v_yyy + 32)))) {
				p_clipsprite(6, 96, 0, 31, 31);
				if ((g_mmouse_links == 1)) {
					if ((a_spieler(g_akt_spieler).f_style > 0)) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						if (((a_spieler(g_akt_spieler).f_style == 9) && (p_ich_trage(8) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 8) && (p_ich_trage(5) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 7) && (p_ich_trage(7) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 6) && (p_ich_trage(6) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 5) && (p_ich_trage(1) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 4) && (p_ich_trage(3) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						if (((a_spieler(g_akt_spieler).f_style == 3) && (p_ich_trage(4) == 0))) {
							a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style - 1);
						}
						p_delay(100);
					}
				}
			} else {
				p_clipsprite(6, 32, 0, 31, 31);
			}
			p_displaytransparentsprite(6, v_xxx, v_yyy);
			v_xxx = (v_xxx + 200);
			if (((((g_mmouse_x > v_xxx) && (g_mmouse_x < (v_xxx + 32))) && (g_mmouse_y > v_yyy)) && (g_mmouse_y < (v_yyy + 32)))) {
				p_clipsprite(6, 63, 0, 31, 31);
				if ((g_mmouse_links == 1)) {
					a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					if ((a_spieler(g_akt_spieler).f_style > 9)) {
						a_spieler(g_akt_spieler).f_style = 9;
					}
					if (((a_spieler(g_akt_spieler).f_style == 3) && (p_ich_trage(4) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 4) && (p_ich_trage(3) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 5) && (p_ich_trage(1) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 6) && (p_ich_trage(6) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 7) && (p_ich_trage(7) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 8) && (p_ich_trage(5) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if (((a_spieler(g_akt_spieler).f_style == 9) && (p_ich_trage(8) == 0))) {
						a_spieler(g_akt_spieler).f_style = (a_spieler(g_akt_spieler).f_style + 1);
					}
					if ((a_spieler(g_akt_spieler).f_style > 9)) {
						a_spieler(g_akt_spieler).f_style = 0;
					}
					p_delay(100);
				}
			} else {
				p_clipsprite(6, 0, 0, 31, 31);
			}
			p_displaytransparentsprite(6, v_xxx, v_yyy);
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawingmode(1);
		v_gew = (p_gewicht() / 5);
		p_drawtext(500, 178, ((a_nachricht_text(597, (1 + g_sprache)) + p_str(v_gew)) + a_nachricht_text(598, (1 + g_sprache))), -1, 0);
		p_frontcolor(p_rgb(247, 36, 61));
		p_drawtext(375, 450, a_nachricht_text(878, (g_sprache + 1)), -1, 0);
		p_drawtext(455, 450, ((p_str(a_spieler(g_akt_spieler).f_lifepoints) + "/") + p_str(p_maxlife())), -1, 0);
		p_frontcolor(p_rgb(130, 125, 250));
		p_drawtext(510, 450, a_nachricht_text(879, (g_sprache + 1)), -1, 0);
		p_drawtext(590, 450, ((p_str(a_spieler(g_akt_spieler).f_mana) + "/") + p_str(p_maxmana())), -1, 0);
		p_stopdrawing();
		if ((((g_feld > 0) || (g_do_it > 0)) || (g_do_it2 > 0))) {
			if (((a_inventory(g_feld, g_akt_spieler).f_name == 0) && (g_itemmenue_aktiv == 1))) {
				g_abbrechen = 1;
				g_feld = 0;
				g_itemmenue_aktiv = 0;
			}
			if (((g_do_it > 0) || (g_do_it2 > 0))) {
				g_feld = v_bew_geg_pos;
			}
			p_itemtest();
		}
		if ((g_do_it3 > 0)) {
			if (((a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 0) && (v_bew_geg_pos > 0))) {
				if ((a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name == 0)) {
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name = a_inventory(v_bew_geg_pos, g_akt_spieler).f_name;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_art = a_inventory(v_bew_geg_pos, g_akt_spieler).f_art;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_status = a_inventory(v_bew_geg_pos, g_akt_spieler).f_status;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_benutzt = a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_anzahl = a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri1 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri2 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri3 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri4 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri5 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_name = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_art = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_status = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1 = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2 = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3 = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4 = 0;
					a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5 = 0;
					v_bew_geg = 0;
					v_bew_geg_pos = 0;
					v_bew_ziel = 0;
					v_bew_geg_x = 0;
					v_bew_geg_y = 0;
					v_schnellinventory_pos = 0;
				} else {
					if ((((((((a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name == a_inventory(v_bew_geg_pos, g_akt_spieler).f_name) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_status == a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_status)) && (a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt == 0)) && (a_gegenstand(a_inventory(v_bew_geg_pos, g_akt_spieler).f_name).f_attri1 == a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri1)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 39)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 193))) {
						a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_anzahl = (a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_anzahl + 1);
						p_leeren(v_bew_geg_pos);
						v_bew_geg = 0;
						v_bew_geg_pos = 0;
						v_bew_ziel = 0;
						v_bew_geg_x = 0;
						v_bew_geg_y = 0;
						v_schnellinventory_pos = 0;
					}
				}
			}
		}
		if ((g_do_it4 > 0)) {
			if ((((a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name != 0) && (v_schnellinventory_pos > 0)) && (v_bew_ziel > 0))) {
				if ((a_inventory(v_bew_ziel, g_akt_spieler).f_name == 0)) {
					a_inventory(v_bew_ziel, g_akt_spieler).f_name = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name;
					a_inventory(v_bew_ziel, g_akt_spieler).f_art = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_art;
					a_inventory(v_bew_ziel, g_akt_spieler).f_status = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_status;
					a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_benutzt;
					a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_anzahl;
					a_inventory(v_bew_ziel, g_akt_spieler).f_attri1 = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri1;
					a_inventory(v_bew_ziel, g_akt_spieler).f_attri2 = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri2;
					a_inventory(v_bew_ziel, g_akt_spieler).f_attri3 = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri3;
					a_inventory(v_bew_ziel, g_akt_spieler).f_attri4 = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri4;
					a_inventory(v_bew_ziel, g_akt_spieler).f_attri5 = a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri5;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_art = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_status = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_benutzt = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_anzahl = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri1 = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri2 = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri3 = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri4 = 0;
					a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri5 = 0;
					v_bew_geg = 0;
					v_bew_geg_pos = 0;
					v_bew_ziel = 0;
					v_bew_geg_x = 0;
					v_bew_geg_y = 0;
					v_schnellinventory_pos = 0;
				} else {
					if ((((((((a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name == a_inventory(v_bew_ziel, g_akt_spieler).f_name) && (a_inventory(v_bew_ziel, g_akt_spieler).f_status == a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_status)) && (a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt == 0)) && (a_gegenstand(a_inventory(v_bew_ziel, g_akt_spieler).f_name).f_attri1 == a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_attri1)) && (a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name != 39)) && (a_inventory((v_schnellinventory_pos + 40), g_akt_spieler).f_name != 193))) {
						a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = (a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl + 1);
						p_leeren((v_schnellinventory_pos + 40));
						v_bew_geg = 0;
						v_bew_geg_pos = 0;
						v_bew_ziel = 0;
						v_bew_geg_x = 0;
						v_bew_geg_y = 0;
						v_schnellinventory_pos = 0;
					}
				}
			}
		}
		g_do_it = 0;
		g_do_it2 = 0;
		g_do_it3 = 0;
		g_do_it4 = 0;
		if ((g_mmouse_links == 0)) {
			if ((g_bewegen == 1)) {
				if ((g_mmouse_x < 340)) {
					g_aktion = 1;
					if ((g_mmouse_y > 425)) {
						g_do_it3 = 1;
					} else {
						g_do_it = 1;
					}
				} else {
					if ((v_bew_ziel != v_bew_geg_pos)) {
						if ((((a_inventory(v_bew_ziel, g_akt_spieler).f_name == 0) && (v_bew_ziel != 0)) && (v_bew_geg_pos != 0))) {
							a_inventory(v_bew_ziel, g_akt_spieler).f_name = a_inventory(v_bew_geg_pos, g_akt_spieler).f_name;
							a_inventory(v_bew_ziel, g_akt_spieler).f_art = a_inventory(v_bew_geg_pos, g_akt_spieler).f_art;
							a_inventory(v_bew_ziel, g_akt_spieler).f_status = a_inventory(v_bew_geg_pos, g_akt_spieler).f_status;
							a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt = a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt;
							a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl;
							a_inventory(v_bew_ziel, g_akt_spieler).f_attri1 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1;
							a_inventory(v_bew_ziel, g_akt_spieler).f_attri2 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2;
							a_inventory(v_bew_ziel, g_akt_spieler).f_attri3 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3;
							a_inventory(v_bew_ziel, g_akt_spieler).f_attri4 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4;
							a_inventory(v_bew_ziel, g_akt_spieler).f_attri5 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_name = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_art = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_status = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1 = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2 = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3 = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4 = 0;
							a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5 = 0;
							v_bew_geg = 0;
							v_bew_geg_pos = 0;
							v_bew_ziel = 0;
							v_bew_geg_x = 0;
							v_bew_geg_y = 0;
							v_schnellinventory_pos = 0;
						}
						if ((((((((((((a_inventory(v_bew_ziel, g_akt_spieler).f_name == a_inventory(v_bew_geg_pos, g_akt_spieler).f_name) && (a_inventory(v_bew_ziel, g_akt_spieler).f_status == a_inventory(v_bew_geg_pos, g_akt_spieler).f_status)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_name != 0)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_attri1 == a_gegenstand(a_inventory(v_bew_ziel, g_akt_spieler).f_name).f_attri1)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1 == a_gegenstand(a_inventory(v_bew_geg_pos, g_akt_spieler).f_name).f_attri1)) && (v_bew_ziel != 0)) && (v_bew_geg_pos != 0)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 39)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 193))) {
							a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = (a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl + 1);
							p_leeren(v_bew_geg_pos);
							v_bew_geg = 0;
							v_bew_geg_pos = 0;
							v_bew_ziel = 0;
							v_bew_geg_x = 0;
							v_bew_geg_y = 0;
							v_schnellinventory_pos = 0;
						}
					}
				}
				g_bewegen = 0;
			}
			if ((g_bewegen == 5)) {
				g_do_it2 = 1;
				g_bewegen = 0;
			}
			if ((g_bewegen == 2)) {
				if ((g_mmouse_x > 340)) {
					g_aktion = 1;
					if ((g_mmouse_y > 425)) {
						g_do_it3 = 1;
					} else {
						g_do_it2 = 1;
					}
				}
				g_bewegen = 0;
			}
			if ((g_bewegen == 3)) {
				if ((g_mmouse_x > 340)) {
					g_do_it4 = 1;
				} else {
					if ((g_mmouse_y > 425)) {
						v_bew_geg_pos = (v_schnellinventory_pos + 40);
						v_bew_ziel = (v_schnellinventory_nach + 40);
						if ((v_bew_ziel != v_bew_geg_pos)) {
							if ((((a_inventory(v_bew_ziel, g_akt_spieler).f_name == 0) && (v_bew_ziel != 0)) && (v_bew_geg_pos != 0))) {
								a_inventory(v_bew_ziel, g_akt_spieler).f_name = a_inventory(v_bew_geg_pos, g_akt_spieler).f_name;
								a_inventory(v_bew_ziel, g_akt_spieler).f_art = a_inventory(v_bew_geg_pos, g_akt_spieler).f_art;
								a_inventory(v_bew_ziel, g_akt_spieler).f_status = a_inventory(v_bew_geg_pos, g_akt_spieler).f_status;
								a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt = a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt;
								a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl;
								a_inventory(v_bew_ziel, g_akt_spieler).f_attri1 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1;
								a_inventory(v_bew_ziel, g_akt_spieler).f_attri2 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2;
								a_inventory(v_bew_ziel, g_akt_spieler).f_attri3 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3;
								a_inventory(v_bew_ziel, g_akt_spieler).f_attri4 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4;
								a_inventory(v_bew_ziel, g_akt_spieler).f_attri5 = a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_name = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_art = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_status = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_anzahl = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1 = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri2 = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri3 = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri4 = 0;
								a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri5 = 0;
								v_bew_geg = 0;
								v_bew_geg_pos = 0;
								v_bew_ziel = 0;
								v_bew_geg_x = 0;
								v_bew_geg_y = 0;
								v_schnellinventory_pos = 0;
							}
							if ((((((((((((a_inventory(v_bew_ziel, g_akt_spieler).f_name == a_inventory(v_bew_geg_pos, g_akt_spieler).f_name) && (a_inventory(v_bew_ziel, g_akt_spieler).f_status == a_inventory(v_bew_geg_pos, g_akt_spieler).f_status)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_name != 0)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_bew_ziel, g_akt_spieler).f_attri1 == a_gegenstand(a_inventory(v_bew_ziel, g_akt_spieler).f_name).f_attri1)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_attri1 == a_gegenstand(a_inventory(v_bew_geg_pos, g_akt_spieler).f_name).f_attri1)) && (v_bew_ziel != 0)) && (v_bew_geg_pos != 0)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 39)) && (a_inventory(v_bew_geg_pos, g_akt_spieler).f_name != 193))) {
								a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl = (a_inventory(v_bew_ziel, g_akt_spieler).f_anzahl + 1);
								p_leeren(v_bew_geg_pos);
								v_bew_geg = 0;
								v_bew_geg_pos = 0;
								v_bew_ziel = 0;
								v_bew_geg_x = 0;
								v_bew_geg_y = 0;
								v_schnellinventory_pos = 0;
							}
						}
					} else {
						v_bew_geg_pos = (v_schnellinventory_pos + 40);
						g_do_it = 1;
					}
				}
				g_bewegen = 0;
			}
		}
		if ((g_no_mouse == 0)) {
			if (((g_bewegen == 0) || (g_bewegen == 5))) {
				p_clipsprite(8, 192, 288, 32, 32);
				p_displaytransparentsprite(8, g_mmouse_x, g_mmouse_y);
			} else {
				p_clipsprite(8, ((v_bew_geg_x * 32) - 32), (v_bew_geg_y * 32), 32, 32);
				p_displaytransparentsprite(8, g_mmouse_x, g_mmouse_y);
			}
		}
		p_flipbuffers(1);
		p_examinekeyboard();
	} while (!(((g_mmouse_rechts == 1) || (g_abbrechen == 1)) || p_keyboardpushed(27)));
	g_abbrechen = 0;
	p_autodelay(1, 5, -2);
}

static int32_t p_isthydra(int16_t v_x, int16_t v_y) {
	if (((((((((((((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 137) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 138)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 139)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 140)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 141)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 142)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 143)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 144)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 145)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 146)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 147)) || (a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 148))) {
		return 1;
	} else {
		return 0;
	}
}

static int32_t p_istmonster(int16_t v_x, int16_t v_y) {
	if ((a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
		return 1;
	} else {
		return 0;
	}
}

static int32_t p_itemmenue(std::string v_text1, std::string v_text2, std::string v_text3, std::string v_info1) {
	int16_t v_gew = 0;
	int16_t v_jay = 0;
	int32_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mouse_l = 0;
	int32_t v_result = 0;
	int32_t v_selectdelay = 0;
	std::string v_text4;
	std::string v_text5;
	std::string v_text6;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	if ((g_bewegen == 0)) {
		if ((g_itemmenue_aktiv == 1)) {
			p_examinekeyboard();
			v_jay = 0;
			v_jb2 = 0;
			if ((g_joystick_used == 1)) {
				p_examinejoystick();
				v_jay = p_joystickaxisy();
				v_jb1 = p_joystickbutton(1);
				v_jb2 = p_joystickbutton(2);
			}
			a_addelaymax(1) = (v_selectdelay + 50);
			if ((p_keyboardpushed(273) || (v_jay == -1))) {
				if (p_autodelay(1, 1, -2)) {
					p_autodelay(1, 2, -2);
					g_aktuell = (g_aktuell - 1);
					if ((g_aktuell < 0)) {
						g_aktuell = 0;
					}
				}
			} else {
				if ((p_keyboardpushed(274) || (v_jay == 1))) {
					if (p_autodelay(1, 1, -2)) {
						p_autodelay(1, 2, -2);
						g_aktuell = (g_aktuell + 1);
						if ((g_aktuell > 5)) {
							g_aktuell = 5;
						}
					}
				} else {
					if (((p_keyboardpushed(276) || p_keyboardpushed(275)) || v_jb1)) {
						g_itemmenue_aktiv = 0;
					} else {
						p_autodelay(1, 3, -2);
					}
				}
			}
		}
	}
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		v_mouse_l = p_mousebutton(1);
	}
	v_text4 = a_nachricht_text(649, (1 + g_sprache));
	v_text5 = a_nachricht_text(704, (1 + g_sprache));
	v_text6 = a_nachricht_text(650, (1 + g_sprache));
	v_x = 400;
	v_y = 185;
	p_beschreiben(g_feld, v_x, v_y);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 1));
	v_y = (v_y + 15);
	p_frontcolor(p_rgb(255, 255, 1));
	v_gew = (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_gewicht / 5);
	p_drawtext((v_x - 20), v_y, (((v_info1 + " (") + p_str(v_gew)) + " Kg)"), -1, 0);
	v_y = (v_y + 20);
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 230)) && (g_mmouse_y < 248)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			g_benutzen = 1;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 0) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			g_benutzen = 1;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text1, -1, 0);
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 247)) && (g_mmouse_y < 266)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			g_benutzen = 2;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 1) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			g_benutzen = 2;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text2, -1, 0);
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 265)) && (g_mmouse_y < 280)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			g_benutzen = 5;
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 2) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			g_benutzen = 5;
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text3, -1, 0);
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 279)) && (g_mmouse_y < 294)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			g_benutzen = 3;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 3) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			g_benutzen = 3;
			g_aktion = 1;
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text4, -1, 0);
	v_y = (v_y + 15);
	if ((((a_skills(96, g_akt_spieler).f_gewaehlt == 1) && ((a_inventory(g_feld, g_akt_spieler).f_status == 1) || (a_inventory(g_feld, g_akt_spieler).f_status == 2))) && ((((((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 1) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 6)) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 7)) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 8)) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 9)) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 11)))) {
		if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 294)) && (g_mmouse_y < 309)) && (g_bewegen == 0))) {
			p_frontcolor(p_rgb(1, 1, 255));
			if ((v_mouse_l == 1)) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_reparieren(g_feld);
			}
		} else {
			p_frontcolor(p_rgb(255, 255, 255));
		}
		if (((g_aktuell == 3) && (g_itemmenue_aktiv == 1))) {
			p_frontcolor(p_rgb(100, 100, 100));
			if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_reparieren(g_feld);
			}
		}
		p_drawtext(v_x, v_y, a_nachricht_text(563, (g_sprache + 1)), -1, 0);
	}
	if (((a_skills(96, g_akt_spieler).f_gewaehlt == 1) && (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 16))) {
		if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 294)) && (g_mmouse_y < 309)) && (g_bewegen == 0))) {
			p_frontcolor(p_rgb(1, 1, 255));
			if ((v_mouse_l == 1)) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_umwandeln(g_feld);
			}
		} else {
			p_frontcolor(p_rgb(255, 255, 255));
		}
		if (((g_aktuell == 3) && (g_itemmenue_aktiv == 1))) {
			p_frontcolor(p_rgb(100, 100, 100));
			if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_umwandeln(g_feld);
			}
		}
		p_drawtext(v_x, v_y, a_nachricht_text(564, (g_sprache + 1)), -1, 0);
	}
	if (((a_skills(43, g_akt_spieler).f_gewaehlt == 1) && (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 4))) {
		if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 294)) && (g_mmouse_y < 309)) && (g_bewegen == 0))) {
			p_frontcolor(p_rgb(1, 1, 255));
			if ((v_mouse_l == 1)) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_mischung(g_feld);
			}
		} else {
			p_frontcolor(p_rgb(255, 255, 255));
		}
		if (((g_aktuell == 3) && (g_itemmenue_aktiv == 1))) {
			p_frontcolor(p_rgb(100, 100, 100));
			if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_mischung(g_feld);
			}
		}
		p_drawtext(v_x, v_y, a_nachricht_text(728, (g_sprache + 1)), -1, 0);
	}
	if (((a_skills(43, g_akt_spieler).f_gewaehlt == 1) && (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 17))) {
		if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 294)) && (g_mmouse_y < 309)) && (g_bewegen == 0))) {
			p_frontcolor(p_rgb(1, 1, 255));
			if ((v_mouse_l == 1)) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_alchemie(g_feld);
			}
		} else {
			p_frontcolor(p_rgb(255, 255, 255));
		}
		if (((g_aktuell == 3) && (g_itemmenue_aktiv == 1))) {
			p_frontcolor(p_rgb(100, 100, 100));
			if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
				g_itemmenue_aktiv = 0;
				g_aktion = 1;
				p_alchemie(g_feld);
			}
		}
		p_drawtext(v_x, v_y, a_nachricht_text(617, (g_sprache + 1)), -1, 0);
	}
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 309)) && (g_mmouse_y < 324)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			p_zerstoeren(g_feld);
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 4) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			p_zerstoeren(g_feld);
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text5, -1, 0);
	if ((((((g_mmouse_x > 400) && (g_mmouse_x < 500)) && (g_mmouse_y > 324)) && (g_mmouse_y < 339)) && (g_bewegen == 0))) {
		p_frontcolor(p_rgb(1, 1, 255));
		if ((v_mouse_l == 1)) {
			g_benutzen = 4;
			g_itemmenue_aktiv = 0;
		}
	} else {
		p_frontcolor(p_rgb(255, 255, 255));
	}
	if (((g_aktuell == 5) && (g_itemmenue_aktiv == 1))) {
		p_frontcolor(p_rgb(100, 100, 100));
		if ((p_keyboardpushed(32) || (v_jb2 != 0))) {
			g_benutzen = 4;
			g_itemmenue_aktiv = 0;
		}
	}
	v_y = (v_y + 15);
	p_drawtext(v_x, v_y, v_text6, -1, 0);
	p_stopdrawing();
}

static int32_t p_itemtest() {
	int32_t v_akt_item = 0;
	int32_t v_aktion = 0;
	int32_t v_amulett = 0;
	int16_t v_angriff = 0;
	int32_t v_bew_geg_pos = 0;
	int16_t v_bogen = 0;
	int16_t v_brechfaktor = 0;
	int16_t v_chance = 0;
	int16_t v_egon = 0;
	int16_t v_foodvalue = 0;
	std::string v_gegstat;
	int32_t v_guertel = 0;
	int8_t v_handschuhe = 0;
	int8_t v_helm = 0;
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	std::string v_info1;
	int16_t v_kritisch = 0;
	int32_t v_lampe = 0;
	int16_t v_mag_geg = 0;
	int32_t v_maske = 0;
	int16_t v_max = 0;
	int16_t v_min = 0;
	int8_t v_munition = 0;
	int8_t v_neu2h = 0;
	int32_t v_ring = 0;
	int8_t v_ruestung = 0;
	int16_t v_schaden = 0;
	int8_t v_schild = 0;
	int32_t v_spell = 0;
	int8_t v_stiefel = 0;
	int16_t v_testfeld = 0;
	std::string v_text1;
	std::string v_text2;
	std::string v_text3;
	std::string v_text4;
	std::string v_typ;
	int8_t v_waffe = 0;
	int8_t v_waffe2h = 0;
	int32_t v_welcher = 0;
	int8_t v_zweih = 0;
	if (((a_inventory(g_feld, g_akt_spieler).f_name == 46) || (a_inventory(g_feld, g_akt_spieler).f_name == 47))) {
		v_info1 = (a_nachricht_text(526, (g_sprache + 1)) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1));
		v_text1 = a_nachricht_text(527, (g_sprache + 1));
		v_text2 = a_nachricht_text(528, (g_sprache + 1));
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
					p_laby_screen();
					p_delay(g_mydelay);
					a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
					a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light + 3);
					a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
					if ((a_inventory(g_feld, g_akt_spieler).f_attri1 < 1)) {
						if ((a_inventory(g_feld, g_akt_spieler).f_anzahl > 0)) {
							a_inventory(g_feld, g_akt_spieler).f_anzahl = (a_inventory(g_feld, g_akt_spieler).f_anzahl - 1);
							a_inventory(g_feld, g_akt_spieler).f_attri1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1;
						} else {
							a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
							a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 3);
						}
					}
					p_sound(13);
					p_laby_screen();
					p_delay(g_mydelay);
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if (((a_inventory(g_feld, g_akt_spieler).f_name == 39) || (a_inventory(g_feld, g_akt_spieler).f_name == 40))) {
		v_info1 = (a_nachricht_text(526, (g_sprache + 1)) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1));
		v_text1 = a_nachricht_text(527, (g_sprache + 1));
		v_text2 = a_nachricht_text(528, (g_sprache + 1));
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
					p_laby_screen();
					p_delay(g_mydelay);
					a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
					a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light + 4);
					a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
					if ((a_inventory(g_feld, g_akt_spieler).f_attri1 < 1)) {
						if ((a_inventory(g_feld, g_akt_spieler).f_anzahl > 0)) {
							a_inventory(g_feld, g_akt_spieler).f_anzahl = (a_inventory(g_feld, g_akt_spieler).f_anzahl - 1);
							a_inventory(g_feld, g_akt_spieler).f_attri1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1;
						} else {
							a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
							a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 4);
						}
					}
					p_sound(13);
					p_laby_screen();
					p_delay(g_mydelay);
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 4);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 3)) {
		v_text1 = a_nachricht_text(529, (g_sprache + 1));
		v_info1 = (a_nachricht_text(530, (g_sprache + 1)) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			v_foodvalue = a_inventory(g_feld, g_akt_spieler).f_attri1;
			if ((a_skills(93, g_akt_spieler).f_gewaehlt == 1)) {
				v_foodvalue = (v_foodvalue * 2);
			}
			a_spieler(g_akt_spieler).f_hunger = (a_spieler(g_akt_spieler).f_hunger - v_foodvalue);
			if ((a_spieler(g_akt_spieler).f_hunger < 1)) {
				a_spieler(g_akt_spieler).f_hunger = 0;
			}
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 53)) {
				a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - a_inventory(g_feld, g_akt_spieler).f_attri1);
				if ((a_spieler(g_akt_spieler).f_durst < 1)) {
					a_spieler(g_akt_spieler).f_durst = 0;
				}
			}
			p_sound(14);
			p_leeren(g_feld);
			p_delay(g_mydelay);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 23)) {
		v_text1 = a_nachricht_text(549, (g_sprache + 1));
		v_info1 = (a_nachricht_text(530, (g_sprache + 1)) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			v_foodvalue = a_inventory(g_feld, g_akt_spieler).f_attri1;
			if ((a_skills(93, g_akt_spieler).f_gewaehlt == 1)) {
				v_foodvalue = (v_foodvalue * 2);
			}
			a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - v_foodvalue);
			if ((a_spieler(g_akt_spieler).f_durst < 1)) {
				a_spieler(g_akt_spieler).f_durst = 0;
			}
			if ((p_random(100) <= p_max(p_min(((a_inventory(g_feld, g_akt_spieler).f_attri2 * 2) - (p_staerke() * 5)), 10), 90))) {
				a_spieler(g_akt_spieler).f_betrunken = (p_random((a_inventory(g_feld, g_akt_spieler).f_attri2 / 2)) + 1);
			}
			p_sound(14);
			p_leeren(g_feld);
			p_delay(g_mydelay);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((((a_inventory(g_feld, g_akt_spieler).f_name == 353) || (a_inventory(g_feld, g_akt_spieler).f_name == 351)) || (a_inventory(g_feld, g_akt_spieler).f_name == 354))) {
		v_text1 = a_nachricht_text(529, (g_sprache + 1));
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 354)) {
			v_info1 = a_nachricht_text(610, (g_sprache + 1));
		} else {
			v_info1 = a_nachricht_text(531, (g_sprache + 1));
		}
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 353)) {
				a_spieler(g_akt_spieler).f_lifepoints = ((a_spieler(g_akt_spieler).f_lifepoints + p_random(5)) + 1);
			}
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 351)) {
				a_spieler(g_akt_spieler).f_lifepoints = ((a_spieler(g_akt_spieler).f_lifepoints + p_random(15)) + 5);
				a_spieler(g_akt_spieler).f_gift = 0;
				a_spieler(g_akt_spieler).f_giftdauer = 0;
			}
			if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
				a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
			}
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 354)) {
				a_spieler(g_akt_spieler).f_mana = ((a_spieler(g_akt_spieler).f_mana + p_random(5)) + 1);
			}
			if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
				a_spieler(g_akt_spieler).f_mana = p_maxmana();
			}
			p_sound(14);
			p_leeren(g_feld);
			p_nachricht(39, 2);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 8)) {
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_gegstat = "";
		v_min = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_max = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_min = (v_min / 2);
			v_max = (v_max / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_min = 0;
			v_max = 0;
		}
		v_info1 = ((((((v_gegstat + a_nachricht_text(534, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(535, (g_sprache + 1))) + p_str(v_min)) + "/") + p_str(v_max));
		if (((((a_inventory(g_feld, g_akt_spieler).f_name == 200) || (a_inventory(g_feld, g_akt_spieler).f_name == 347)) || (a_inventory(g_feld, g_akt_spieler).f_name == 348)) || (a_inventory(g_feld, g_akt_spieler).f_name == 349))) {
			v_info1 = (v_info1 + a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)]);
		}
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_stiefel = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 8) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_stiefel = 1;
						}
					}
					if ((v_stiefel == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 200)) {
							a_spieler(g_akt_spieler).f_zugweitegegenstand = (a_spieler(g_akt_spieler).f_zugweitegegenstand + 3);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 347)) {
							p_eintragen(49, 1, 9999, 347);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 349)) {
							p_eintragen(7, 1, 9999, 348);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 348)) {
							p_eintragen(68, 1, 9999, 349);
						}
					} else {
						p_nachricht(225, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((g_do_it2 > 0)) {
				g_feld = v_bew_geg_pos;
			}
			g_do_it2 = 0;
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 200)) {
					a_spieler(g_akt_spieler).f_zugweitegegenstand = (a_spieler(g_akt_spieler).f_zugweitegegenstand - 3);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 347)) {
					p_terminate(49, 347);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 349)) {
					p_terminate(7, 348);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 348)) {
					p_terminate(68, 349);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 6)) {
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_gegstat = "";
		v_min = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_max = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_min = (v_min / 2);
			v_max = (v_max / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_min = 0;
			v_max = 0;
		}
		if ((((((a_inventory(g_feld, g_akt_spieler).f_name == 260) || (a_inventory(g_feld, g_akt_spieler).f_name == 51)) || (a_inventory(g_feld, g_akt_spieler).f_name == 54)) || (a_inventory(g_feld, g_akt_spieler).f_name == 229)) || (a_inventory(g_feld, g_akt_spieler).f_name == 230))) {
			v_info1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)];
		} else {
			v_info1 = ((((((v_gegstat + a_nachricht_text(534, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(535, (g_sprache + 1))) + p_str(v_min)) + "/") + p_str(v_max));
		}
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_helm = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 6) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_helm = 1;
						}
					}
					if ((v_helm == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 260)) {
							a_spieler(g_akt_spieler).f_bogentreffergegenstand = (a_spieler(g_akt_spieler).f_bogentreffergegenstand + 10);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 51)) {
							a_spieler(g_akt_spieler).f_lifepointgegenstand = (a_spieler(g_akt_spieler).f_lifepointgegenstand + 8);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 54)) {
							a_spieler(g_akt_spieler).f_managegenstand = (a_spieler(g_akt_spieler).f_managegenstand + 7);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 229)) {
							a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand + 2);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 230)) {
							a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand + 2);
						}
					} else {
						p_nachricht(226, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 260)) {
					a_spieler(g_akt_spieler).f_bogentreffergegenstand = (a_spieler(g_akt_spieler).f_bogentreffergegenstand - 10);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 51)) {
					a_spieler(g_akt_spieler).f_lifepointgegenstand = (a_spieler(g_akt_spieler).f_lifepointgegenstand - 8);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 54)) {
					a_spieler(g_akt_spieler).f_managegenstand = (a_spieler(g_akt_spieler).f_managegenstand - 7);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 229)) {
					a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand - 2);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 230)) {
					a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand - 2);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 1)) {
		v_gegstat = "";
		v_angriff = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1;
		v_schaden = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_kritisch = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_angriff = (v_angriff / 2);
			v_schaden = (v_schaden / 2);
			v_kritisch = (v_kritisch / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_angriff = 0;
			v_schaden = 0;
			v_kritisch = 0;
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 3)) {
			v_gegstat = a_nachricht_text(538, (g_sprache + 1));
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 4)) {
			v_gegstat = a_nachricht_text(539, (g_sprache + 1));
		}
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_text3 = " ";
		if ((((a_inventory(g_feld, g_akt_spieler).f_name == 1) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_klasse == 2)) || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_klasse == 3))) {
			v_text3 = a_nachricht_text(542, (g_sprache + 1));
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 163)) {
			v_text3 = a_nachricht_text(656, (g_sprache + 1));
		}
		v_info1 = ((((((v_gegstat + a_nachricht_text(543, (g_sprache + 1))) + p_str(v_angriff)) + a_nachricht_text(544, (g_sprache + 1))) + p_str(v_schaden)) + a_nachricht_text(545, (g_sprache + 1))) + p_str(v_kritisch));
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(138, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(873, 3);
				} else {
					v_waffe = 0;
					v_schild = 0;
					v_waffe2h = 0;
					v_neu2h = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_waffe = (v_waffe + 1);
						}
					}
					if ((a_skills(119, g_akt_spieler).f_gewaehlt == 0)) {
						for (v_i = 1; v_i <= 50; v_i += 1) {
							if ((((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_attri4 == 2)) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
								v_waffe2h = 1;
							}
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_attri4 == 2)) {
							v_neu2h = 1;
							for (v_i = 1; v_i <= 50; v_i += 1) {
								if (((a_inventory(v_i, g_akt_spieler).f_art == 11) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
									v_schild = 1;
								}
							}
						}
					}
					if (((v_waffe > 0) && (v_neu2h > 0))) {
						p_nachricht(230, 3);
					} else {
						if ((v_schild == 0)) {
							if (((v_waffe == 0) || ((a_skills(12, g_akt_spieler).f_gewaehlt == 1) && (v_waffe == 1)))) {
								if ((v_waffe2h == 0)) {
									a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
									a_spieler(g_akt_spieler).f_style = 0;
									p_delay(g_mydelay);
									v_akt_item = a_inventory(g_feld, g_akt_spieler).f_name;
									if ((((v_akt_item == 237) || (v_akt_item == 49)) || (v_akt_item == 236))) {
										a_spieler(g_akt_spieler).f_lichtgegenstand = (a_spieler(g_akt_spieler).f_lichtgegenstand + 2);
									}
									if (((((v_akt_item == 142) || (v_akt_item == 376)) || (v_akt_item == 377)) || (v_akt_item == 233))) {
										p_eintragen(71, 1, 9999, v_akt_item);
									}
									if (((((v_akt_item == 143) || (v_akt_item == 378)) || (v_akt_item == 379)) || (v_akt_item == 235))) {
										p_eintragen(70, 1, 9999, v_akt_item);
									}
								} else {
									p_nachricht(434, 3);
								}
							} else {
								if (((a_skills(12, g_akt_spieler).f_gewaehlt == 1) && (v_waffe > 1))) {
									p_nachricht(435, 3);
								} else {
									p_nachricht(224, 3);
								}
							}
						} else {
							p_nachricht(230, 3);
						}
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				v_akt_item = a_inventory(g_feld, g_akt_spieler).f_name;
				if ((((v_akt_item == 237) || (v_akt_item == 49)) || (v_akt_item == 236))) {
					a_spieler(g_akt_spieler).f_lichtgegenstand = (a_spieler(g_akt_spieler).f_lichtgegenstand - 2);
				}
				if (((((v_akt_item == 142) || (v_akt_item == 376)) || (v_akt_item == 377)) || (v_akt_item == 233))) {
					p_terminate(71, v_akt_item);
				}
				if (((((v_akt_item == 143) || (v_akt_item == 378)) || (v_akt_item == 379)) || (v_akt_item == 235))) {
					p_terminate(70, v_akt_item);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
		if ((g_benutzen == 5)) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 163)) {
				p_leeren(g_feld);
			} else {
				p_werfen();
				g_abbrechen = 1;
			}
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 13)) {
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 4)) {
			v_info1 = a_nachricht_text(539, (g_sprache + 1));
		}
		v_info1 = ((((((((v_info1 + a_nachricht_text(546, (g_sprache + 1))) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1)) + a_nachricht_text(543, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2)) + a_nachricht_text(544, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3)) + a_nachricht_text(545, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri4));
		g_benutzen = 0;
		v_text3 = " ";
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 147)) {
			v_text3 = a_nachricht_text(656, (g_sprache + 1));
		}
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(139, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(874, 3);
				} else {
					v_munition = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 13) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_munition = 1;
						}
					}
					if ((v_munition == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
					} else {
						p_nachricht(224, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 5)) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 147)) {
				p_leeren(g_feld);
			}
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 10)) {
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_info1 = (((((a_nachricht_text(543, (g_sprache + 1)) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(544, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2)) + a_nachricht_text(545, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3));
		g_benutzen = 0;
		v_text3 = " ";
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 157)) {
			v_text3 = a_nachricht_text(656, (g_sprache + 1));
		}
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(139, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(874, 3);
				} else {
					v_bogen = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 10) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_bogen = 1;
						}
					}
					if ((v_bogen == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
					} else {
						p_nachricht(433, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
		if ((g_benutzen == 5)) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 157)) {
				p_leeren(g_feld);
			}
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 9)) {
		v_gegstat = "";
		v_min = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_max = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_min = (v_min / 2);
			v_max = (v_max / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_min = 0;
			v_max = 0;
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 3)) {
			v_gegstat = a_nachricht_text(538, (g_sprache + 1));
		}
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_info1 = ((((((v_gegstat + a_nachricht_text(534, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(535, (g_sprache + 1))) + p_str(v_min)) + "/") + p_str(v_max));
		if (((((((a_inventory(g_feld, g_akt_spieler).f_name == 222) || (a_inventory(g_feld, g_akt_spieler).f_name == 223)) || (a_inventory(g_feld, g_akt_spieler).f_name == 153)) || (a_inventory(g_feld, g_akt_spieler).f_name == 228)) || (a_inventory(g_feld, g_akt_spieler).f_name == 224)) || (a_inventory(g_feld, g_akt_spieler).f_name == 225))) {
			if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_qualitaet > 0)) {
				v_info1 = ((v_info1 + " +") + p_str(a_inventory(g_feld, g_akt_spieler).f_status));
			}
			v_info1 = ((v_info1 + " ") + a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)]);
		}
		g_benutzen = 0;
		v_text3 = " ";
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 156)) {
			v_text3 = a_nachricht_text(656, (g_sprache + 1));
		}
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_ruestung = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 9) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_ruestung = 1;
						}
					}
					if ((v_ruestung == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 222)) {
							a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 223)) {
							a_spieler(g_akt_spieler).f_lifepointgegenstand = (a_spieler(g_akt_spieler).f_lifepointgegenstand + 1);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 153)) {
							a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand + 2);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 228)) {
							a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 224)) {
							a_spieler(g_akt_spieler).f_magieresistenz = (a_spieler(g_akt_spieler).f_magieresistenz + 20);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 225)) {
							p_eintragen(70, 1, 9999, 225);
						}
					} else {
						p_nachricht(228, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 222)) {
					a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 223)) {
					a_spieler(g_akt_spieler).f_lifepointgegenstand = (a_spieler(g_akt_spieler).f_lifepointgegenstand - 1);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 153)) {
					a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand - 2);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 228)) {
					a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 224)) {
					a_spieler(g_akt_spieler).f_magieresistenz = (a_spieler(g_akt_spieler).f_magieresistenz - 20);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 225)) {
					p_terminate(70, 225);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
		if ((g_benutzen == 5)) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 156)) {
				p_leeren(g_feld);
			}
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 7)) {
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_gegstat = "";
		v_min = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_max = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_min = (v_min / 2);
			v_max = (v_max / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_min = 0;
			v_max = 0;
		}
		v_info1 = ((((((v_gegstat + a_nachricht_text(534, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(535, (g_sprache + 1))) + p_str(v_min)) + "/") + p_str(v_max));
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 239)) {
			v_info1 = (v_info1 + a_nachricht_text(547, (g_sprache + 1)));
		}
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_handschuhe = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 7) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_handschuhe = 1;
						}
					}
					if ((v_handschuhe == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 239)) {
							a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand + 2);
						}
					} else {
						p_nachricht(227, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 239)) {
					a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand - 2);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 11)) {
		v_gegstat = "";
		v_min = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2;
		v_max = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri3;
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_gegstat = a_nachricht_text(536, (g_sprache + 1));
			v_min = (v_min / 2);
			v_max = (v_max / 2);
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_gegstat = a_nachricht_text(537, (g_sprache + 1));
			v_min = 0;
			v_max = 0;
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 3)) {
			v_gegstat = a_nachricht_text(538, (g_sprache + 1));
		}
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_info1 = ((((((v_gegstat + a_nachricht_text(534, (g_sprache + 1))) + p_str(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri1)) + a_nachricht_text(535, (g_sprache + 1))) + p_str(v_min)) + "/") + p_str(v_max));
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_schild = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 11) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_schild = 1;
						}
					}
					v_zweih = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if ((((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1)) && (a_inventory(v_i, g_akt_spieler).f_attri4 == 2))) {
							v_zweih = 1;
						}
					}
					if ((v_zweih == 0)) {
						if ((v_schild == 0)) {
							a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
							p_delay(g_mydelay);
						} else {
							p_nachricht(229, 3);
						}
					} else {
						p_nachricht(231, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 240)) {
		v_text1 = " ";
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = (a_nachricht_text(548, (g_sprache + 1)) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1));
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if ((g_benutzen == 3)) {
			p_nachricht(281, 3);
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 150)) {
		v_text1 = " ";
		v_text2 = " ";
		v_text3 = a_nachricht_text(606, (g_sprache + 1));
		v_info1 = (p_str(a_inventory(g_feld, g_akt_spieler).f_attri1) + a_nachricht_text(8, (g_sprache + 1)));
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
		if ((g_benutzen == 5)) {
			if ((p_gold_anzahl() >= 5000)) {
				p_aufsteigen(2);
				p_gold_verlieren(5000);
			}
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 193)) {
		v_text1 = a_nachricht_text(549, (g_sprache + 1));
		v_info1 = (p_str(a_inventory(g_feld, g_akt_spieler).f_attri1) + a_nachricht_text(550, (g_sprache + 1)));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if (((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0) && (a_spieler(g_akt_spieler).f_durst > 0))) {
				a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
				a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst - 60);
				if ((a_spieler(g_akt_spieler).f_durst < 1)) {
					a_spieler(g_akt_spieler).f_durst = 0;
				}
				a_spieler(g_akt_spieler).f_verdursten = 0;
				p_sound(14);
				p_delay(g_mydelay);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 38)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		if ((((a_skills(47, g_akt_spieler).f_gewaehlt == 1) || (a_skills(64, g_akt_spieler).f_gewaehlt == 1)) || (a_inventory(g_feld, g_akt_spieler).f_status == 1))) {
			a_inventory(g_feld, g_akt_spieler).f_status = 1;
			v_info1 = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
		} else {
			v_info1 = a_nachricht_text(553, (g_sprache + 1));
		}
		if (((a_skills(64, g_akt_spieler).f_gewaehlt == 1) && ((a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_level + 2) <= a_spieler(g_akt_spieler).f_circle))) {
			v_text3 = a_nachricht_text(552, (g_sprache + 1));
		} else {
			v_text3 = " ";
		}
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[2];
			g_schriftrolle = 1;
			p_laby_screen();
			p_cast_it();
			p_leeren(g_feld);
			g_schriftrolle = 0;
			p_delay(g_mydelay);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
		if ((g_benutzen == 5)) {
			if ((a_skills(64, g_akt_spieler).f_gewaehlt == 1)) {
				if (((a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_level + 2) <= a_spieler(g_akt_spieler).f_circle)) {
					a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_erlernt = 1;
					p_nachricht(483, 2);
				} else {
					p_nachricht(482, 2);
				}
			}
			p_leeren(g_feld);
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 231)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_nachricht_text(554, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				v_aktion = 1;
				p_sound(19);
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
						p_nachricht(524, 1);
					} else {
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
						p_leeren(g_feld);
						g_abbrechen = 1;
					}
				}
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 62)) {
					a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 63;
					p_leeren(g_feld);
					g_abbrechen = 1;
				}
			} else {
				p_nachricht(255, 1);
			}
			p_laby_screen();
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 219)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_nachricht_text(554, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				v_aktion = 1;
				p_sound(19);
				a_zauber(v_spell, g_akt_spieler).f_chance = (a_zauber(v_spell, g_akt_spieler).f_chance + 5);
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 70)) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
						p_nachricht(524, 1);
					} else {
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
						p_leeren(g_feld);
						g_abbrechen = 1;
					}
				}
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 67)) {
					a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 68;
					p_leeren(g_feld);
					g_abbrechen = 1;
				}
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 62)) {
					a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 63;
					p_leeren(g_feld);
					g_abbrechen = 1;
				}
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 193)) {
					a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] = 194;
					p_leeren(g_feld);
					g_abbrechen = 1;
				}
			} else {
				p_nachricht(255, 1);
			}
			p_laby_screen();
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 267)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[2];
			g_schriftrolle = 1;
			p_cast_it();
			g_schriftrolle = 0;
			if ((p_random(100) <= a_inventory(g_feld, g_akt_spieler).f_attri2)) {
				p_nachricht(33, 3);
				p_leeren(g_feld);
			}
			g_schriftrolle = 0;
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_art == 22)) {
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 0)) {
			v_typ = a_nachricht_text(695, (1 + g_sprache));
			v_brechfaktor = 20;
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 1)) {
			v_typ = a_nachricht_text(696, (1 + g_sprache));
			v_brechfaktor = 10;
		}
		if ((a_inventory(g_feld, g_akt_spieler).f_status == 2)) {
			v_typ = a_nachricht_text(697, (1 + g_sprache));
			v_brechfaktor = 5;
		}
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = (v_typ + a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)]);
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[2];
			g_schriftrolle = 1;
			p_laby_screen();
			p_cast_it();
			if ((p_random(100) <= v_brechfaktor)) {
				p_leeren(g_feld);
				p_nachricht(34, 3);
			}
			g_schriftrolle = 0;
			p_delay(g_mydelay);
			g_abbrechen = 1;
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 241)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber((91 + p_random(8)), g_akt_spieler).f_name[2];
			g_schriftrolle = 1;
			p_cast_it();
			p_leeren(g_feld);
			g_abbrechen = 1;
			g_schriftrolle = 0;
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 169)) {
		v_text1 = a_nachricht_text(555, (g_sprache + 1));
		v_info1 = a_zauber(a_inventory(g_feld, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)];
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Erde sp\374hren";
			g_schriftrolle = 1;
			p_cast_it();
			g_schriftrolle = 0;
			if (((a_spieler(g_akt_spieler).f_level > 11) && (p_random(100) > 90))) {
				p_leeren(g_feld);
				p_nachricht(251, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_nachricht(281, 1);
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if (((a_inventory(g_feld, g_akt_spieler).f_name == 247) || (a_inventory(g_feld, g_akt_spieler).f_name == 244))) {
		v_text1 = a_nachricht_text(555, (g_sprache + 1));
		v_info1 = (a_nachricht_text(556, (g_sprache + 1)) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Sternensicht";
				g_schriftrolle = 1;
				p_cast_it();
				g_schriftrolle = 0;
				a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
			} else {
				p_nachricht(262, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_art == 4)) {
		if ((((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2] == "Schwaches Gift") || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2] == "Starkes Gift")) && ((a_skills(116, g_akt_spieler).f_gewaehlt == 1) || (a_skills(113, g_akt_spieler).f_gewaehlt == 1)))) {
			v_text1 = a_nachricht_text(557, (g_sprache + 1));
		} else {
			v_text1 = a_nachricht_text(549, (g_sprache + 1));
		}
		v_info1 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2] == "Schwaches Gift") || (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2] == "Starkes Gift")) && ((a_skills(116, g_akt_spieler).f_gewaehlt == 1) || (a_skills(113, g_akt_spieler).f_gewaehlt == 1)))) {
				p_vergiften();
			} else {
				p_trinken(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2]);
			}
			p_leeren(g_feld);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_art == 16)) {
		v_text1 = a_nachricht_text(558, (g_sprache + 1));
		v_info1 = " ";
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_skills(44, g_akt_spieler).f_gewaehlt == 1)) {
				v_mag_geg = 0;
				v_i = 0;
				do {
					v_i = (v_i + 1);
				} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
				if ((v_i <= 50)) {
					v_egon = (p_random(2) + 1);
					switch (v_egon) {
					case 1:
						v_hugo = p_random(7);
						v_mag_geg = (177 + v_hugo);
						break;
					case 2:
						v_hugo = p_random(6);
						v_mag_geg = (295 + v_hugo);
						break;
					case 3:
						v_hugo = p_random(8);
						v_mag_geg = (387 + v_hugo);
						break;
					}
					a_inventory(v_i, g_akt_spieler).f_name = v_mag_geg;
					a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_mag_geg).f_art;
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					a_inventory(v_i, g_akt_spieler).f_anzahl = 0;
					a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(v_mag_geg).f_attri1;
					a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_mag_geg).f_attri2;
					a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_mag_geg).f_attri3;
					a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_mag_geg).f_attri4;
					p_leeren(g_feld);
				}
			} else {
				p_nachricht(328, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_art == 17)) {
		v_text1 = a_nachricht_text(529, (g_sprache + 1));
		v_info1 = " ";
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			p_pilz_essen(a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_name[2]);
			p_leeren(g_feld);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 134)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			p_sound(27);
			v_lampe = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if (((a_inventory(v_i, g_akt_spieler).f_name == 39) || (a_inventory(v_i, g_akt_spieler).f_name == 40))) {
					if ((a_inventory(v_i, g_akt_spieler).f_attri1 == 0)) {
						v_lampe = v_i;
					}
				}
			}
			if ((v_lampe > 0)) {
				a_inventory(v_lampe, g_akt_spieler).f_attri1 = 150;
				p_leeren(g_feld);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 232)) {
		v_text1 = a_nachricht_text(559, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = "";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 73)) {
				p_sound(18);
				p_nachricht(5, 2);
				if (((a_spieler(g_akt_spieler).f_level + 1) > a_spieler(g_akt_spieler).f_maxlevel)) {
					p_aufsteigen(1);
				}
				p_neuer_level();
				g_abbrechen = 1;
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 355)) {
		v_text1 = a_nachricht_text(560, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = "";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				v_aktion = 1;
				v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
				if (((((((v_testfeld == 54) || (v_testfeld == 53)) || (v_testfeld == 160)) || (v_testfeld == 161)) || (v_testfeld == 162)) || (v_testfeld == 163))) {
					if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_objekt[a_spieler(g_akt_spieler).f_level] == 0)) {
						a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_objekt[a_spieler(g_akt_spieler).f_level] = 1;
						v_chance = (10 + p_luck());
						if ((a_skills(93, g_akt_spieler).f_gewaehlt == 1)) {
							v_chance = (v_chance * 2);
						}
						g_abbrechen = 1;
						if ((p_random(100) < v_chance)) {
							v_i = 0;
							do {
								v_i = (v_i + 1);
							} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
							if ((v_i <= 50)) {
								if ((p_random(100) < 95)) {
									a_inventory(v_i, g_akt_spieler).f_name = 356;
									a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(356).f_art;
									a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(356).f_attri1;
									a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(356).f_attri2;
									a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(356).f_attri3;
									a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(356).f_attri4;
								} else {
									a_inventory(v_i, g_akt_spieler).f_name = 26;
									a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(26).f_art;
									a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(26).f_attri1;
									a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(26).f_attri2;
									a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(26).f_attri3;
									a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(26).f_attri4;
								}
								p_nachricht(496, 1);
							}
						} else {
							p_nachricht(495, 1);
						}
					} else {
						p_nachricht(494, 1);
					}
				} else {
					p_nachricht(497, 3);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 186)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_spieler(g_akt_spieler).f_zauberbuch == 1)) {
				a_spieler(g_akt_spieler).f_zauberbuch = 0;
				v_i = 0;
				do {
					v_i = (v_i + 1);
				} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
				if ((v_i <= 50)) {
					a_inventory(v_i, g_akt_spieler).f_name = 38;
					a_inventory(v_i, g_akt_spieler).f_art = 5;
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					do {
						a_inventory(v_i, g_akt_spieler).f_attri1 = (p_random(176) + 1);
					} while (!((a_zauber(a_inventory(v_i, g_akt_spieler).f_attri1, g_akt_spieler).f_dauer != 9999) && (a_zauber(a_inventory(v_i, g_akt_spieler).f_attri1, g_akt_spieler).f_name[2] != " ")));
					a_inventory(v_i, g_akt_spieler).f_attri2 = (p_random(6) + 2);
				}
			} else {
				p_nachricht(35, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 269)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)];
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 112) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 80))) {
					p_sound(31);
					if ((p_random(100) > 50)) {
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
					} else {
						if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 112)) {
							if ((p_random(100) > 50)) {
								p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 291, a_gegenstand(291).f_attri1, 0);
							} else {
								p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 292, a_gegenstand(292).f_attri1, 0);
							}
						} else {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 206, 0, 0, 0);
						}
					}
					p_nachricht(247, 1);
					if ((p_random(100) > 90)) {
						p_leeren(g_feld);
						p_nachricht(253, 3);
					}
					g_abbrechen = 1;
				}
			} else {
				p_nachricht(233, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 270)) {
		v_text1 = a_nachricht_text(561, (g_sprache + 1));
		v_info1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)];
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			g_spell_x = 0;
			g_spell_y = 0;
			p_feld_waehlen();
			g_blocked = 0;
			p_los();
			if ((g_blocked == 0)) {
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 93)) {
					p_sound(31);
					if ((p_random(100) > 50)) {
						if ((p_random(100) > 80)) {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 68, 0, 0, p_finden2());
						} else {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 67, 0, 0, p_finden2());
						}
					} else {
						if ((p_random(100) > 50)) {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 6, 0, 0, p_finden1());
						} else {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
						}
					}
					p_nachricht(248, 5);
					if ((p_random(100) > 90)) {
						p_leeren(g_feld);
						p_nachricht(252, 3);
					}
					g_abbrechen = 1;
				}
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level] == 69)) {
					p_sound(31);
					if ((p_random(100) > 50)) {
						if ((p_random(100) > 80)) {
							if ((p_random(100) > 80)) {
								p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 68, 0, 0, p_finden2());
							} else {
								p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 67, 0, 0, p_finden2());
							}
						} else {
							p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 6, 0, 0, p_finden1());
						}
					} else {
						p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
					}
					p_nachricht(248, 5);
					if ((p_random(100) > 90)) {
						p_leeren(g_feld);
						p_nachricht(252, 3);
					}
				}
			} else {
				p_nachricht(233, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((((a_inventory(g_feld, g_akt_spieler).f_name == 212) || (a_inventory(g_feld, g_akt_spieler).f_name == 165)) || (a_inventory(g_feld, g_akt_spieler).f_name == 289))) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)];
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 212)) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(27, g_akt_spieler).f_name[2];
			}
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 165)) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(81, g_akt_spieler).f_name[2];
			}
			if ((a_inventory(g_feld, g_akt_spieler).f_name == 289)) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_zauber(55, g_akt_spieler).f_name[2];
			}
			g_schriftrolle = 1;
			p_cast_it();
			if ((p_random(100) < a_inventory(g_feld, g_akt_spieler).f_attri1)) {
				p_sound(23);
				p_leeren(g_feld);
				p_nachricht(254, 3);
			}
			g_abbrechen = 1;
			g_schriftrolle = 0;
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 18)) {
		v_text1 = a_nachricht_text(532, (g_sprache + 1));
		v_text2 = a_nachricht_text(533, (g_sprache + 1));
		v_info1 = "";
		if ((a_inventory(g_feld, g_akt_spieler).f_name == 221)) {
			v_info1 = ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)] + a_nachricht_text(548, (g_sprache + 1))) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1));
		} else {
			if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_qualitaet > 0)) {
				v_info1 = ((v_info1 + " +") + p_str(a_inventory(g_feld, g_akt_spieler).f_status));
			}
			v_info1 = (v_info1 + a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)]);
		}
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				v_ring = 0;
				for (v_i = 1; v_i <= 50; v_i += 1) {
					if (((a_inventory(v_i, g_akt_spieler).f_art == 18) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
						v_ring = 1;
					}
				}
				if (((v_ring == 0) || ((a_skills(91, g_akt_spieler).f_gewaehlt == 1) && (a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)))) {
					a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
					p_delay(g_mydelay);
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 149)) {
						a_spieler(g_akt_spieler).f_managegenstand = (a_spieler(g_akt_spieler).f_managegenstand + 4);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 220)) {
						p_eintragen(26, 2, 9999, 220);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 221)) {
						p_eintragen(80, 1, 9999, 221);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 255)) {
						a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 256)) {
						a_spieler(g_akt_spieler).f_perceptiongegenstand = (a_spieler(g_akt_spieler).f_perceptiongegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 257)) {
						a_spieler(g_akt_spieler).f_damagegegenstand = (a_spieler(g_akt_spieler).f_damagegegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 253)) {
						a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 302)) {
						a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 303)) {
						a_spieler(g_akt_spieler).f_bogentreffergegenstand = (a_spieler(g_akt_spieler).f_bogentreffergegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 304)) {
						a_spieler(g_akt_spieler).f_bogenschadengegenstand = (a_spieler(g_akt_spieler).f_bogenschadengegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 305)) {
						a_spieler(g_akt_spieler).f_magieresistenz = (a_spieler(g_akt_spieler).f_magieresistenz + (a_inventory(g_feld, g_akt_spieler).f_status * 10));
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 306)) {
						p_eintragen(71, 1, 9999, 306);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 307)) {
						p_eintragen(70, 1, 9999, 307);
					}
				} else {
					p_nachricht(260, 3);
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 149)) {
					a_spieler(g_akt_spieler).f_managegenstand = (a_spieler(g_akt_spieler).f_managegenstand - 4);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 220)) {
					p_terminate(26, 220);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 221)) {
					p_terminate(80, 221);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 255)) {
					a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 256)) {
					a_spieler(g_akt_spieler).f_perceptiongegenstand = (a_spieler(g_akt_spieler).f_perceptiongegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 257)) {
					a_spieler(g_akt_spieler).f_damagegegenstand = (a_spieler(g_akt_spieler).f_damagegegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 253)) {
					a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 302)) {
					a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 303)) {
					a_spieler(g_akt_spieler).f_bogentreffergegenstand = (a_spieler(g_akt_spieler).f_bogentreffergegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 304)) {
					a_spieler(g_akt_spieler).f_bogenschadengegenstand = (a_spieler(g_akt_spieler).f_bogenschadengegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 305)) {
					a_spieler(g_akt_spieler).f_magieresistenz = (a_spieler(g_akt_spieler).f_magieresistenz - (a_inventory(g_feld, g_akt_spieler).f_status * 10));
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 306)) {
					p_terminate(71, 306);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 307)) {
					p_terminate(70, 307);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 20)) {
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_info1 = "";
		if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_qualitaet > 0)) {
			v_info1 = ((v_info1 + " +") + p_str(a_inventory(g_feld, g_akt_spieler).f_status));
		}
		v_info1 = (v_info1 + a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)]);
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				v_amulett = 0;
				for (v_i = 1; v_i <= 50; v_i += 1) {
					if (((a_inventory(v_i, g_akt_spieler).f_art == 20) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
						v_amulett = 1;
					}
				}
				if ((v_amulett == 0)) {
					a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
					p_delay(g_mydelay);
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 135)) {
						p_eintragen(109, 1, 9999, 135);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 136)) {
						p_eintragen(118, 1, 9999, 136);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 137)) {
						p_eintragen(119, 1, 9999, 137);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 138)) {
						a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 139)) {
						p_eintragen(70, 1, 9999, 139);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 140)) {
						p_eintragen(71, 1, 9999, 140);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 261)) {
						p_eintragen(26, 1, 9999, 261);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 262)) {
						p_eintragen(75, 1, 9999, 262);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 263)) {
						p_eintragen(103, 1, 9999, 263);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 264)) {
						p_eintragen(110, 1, 9999, 264);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 265)) {
						p_eintragen(40, a_inventory(g_feld, g_akt_spieler).f_status, 9999, 265);
					}
					if ((a_inventory(g_feld, g_akt_spieler).f_name == 266)) {
						p_eintragen(49, 1, 9999, 266);
					}
				} else {
					p_nachricht(418, 3);
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 135)) {
					p_terminate(109, 135);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 136)) {
					p_terminate(118, 136);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 137)) {
					p_terminate(119, 137);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 138)) {
					a_spieler(g_akt_spieler).f_powergegenstand = (a_spieler(g_akt_spieler).f_powergegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 139)) {
					p_terminate(70, 139);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 140)) {
					p_terminate(71, 140);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 261)) {
					p_terminate(26, 261);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 262)) {
					p_terminate(75, 262);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 263)) {
					p_terminate(103, 263);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 264)) {
					p_terminate(110, 264);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 265)) {
					p_terminate(40, 265);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 266)) {
					p_terminate(49, 266);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 21)) {
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_info1 = a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)];
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_maske = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 21) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_maske = 1;
						}
					}
					if ((v_maske == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						a_spieler(g_akt_spieler).f_perceptiongegenstand = (a_spieler(g_akt_spieler).f_perceptiongegenstand + 2);
					} else {
						p_nachricht(419, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				a_spieler(g_akt_spieler).f_perceptiongegenstand = (a_spieler(g_akt_spieler).f_perceptiongegenstand - 2);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 146)) {
		v_text1 = " ";
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_art == 19)) {
		v_text1 = a_nachricht_text(540, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_info1 = "";
		if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_qualitaet > 0)) {
			v_info1 = ((v_info1 + " +") + p_str(a_inventory(g_feld, g_akt_spieler).f_status));
		}
		if (((a_inventory(g_feld, g_akt_spieler).f_name == 201) || (a_inventory(g_feld, g_akt_spieler).f_name == 145))) {
			v_info1 = (v_info1 + a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_info[(1 + g_sprache)]);
		}
		g_benutzen = 0;
		v_text3 = " ";
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(140, g_akt_spieler).f_gewaehlt == 1)) {
					p_nachricht(872, 3);
				} else {
					v_guertel = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 19) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_guertel = 1;
						}
					}
					if ((v_guertel == 0)) {
						a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
						p_delay(g_mydelay);
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 201)) {
							a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand + 10);
						}
						if ((a_inventory(g_feld, g_akt_spieler).f_name == 145)) {
							a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand + a_inventory(g_feld, g_akt_spieler).f_status);
						}
					} else {
						p_nachricht(417, 3);
					}
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_delay(g_mydelay);
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 201)) {
					a_spieler(g_akt_spieler).f_stealthgegenstand = (a_spieler(g_akt_spieler).f_stealthgegenstand - 10);
				}
				if ((a_inventory(g_feld, g_akt_spieler).f_name == 145)) {
					a_spieler(g_akt_spieler).f_staerkegegenstand = (a_spieler(g_akt_spieler).f_staerkegegenstand - a_inventory(g_feld, g_akt_spieler).f_status);
				}
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 248)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_text2 = " ";
		v_text3 = " ";
		v_info1 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_spieler(g_akt_spieler).f_kessel == 1)) {
				a_spieler(g_akt_spieler).f_kessel = 0;
				v_i = 0;
				do {
					v_i = (v_i + 1);
				} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
				if ((v_i <= 50)) {
					do {
						v_welcher = (p_random(37) + 75);
					} while (!((a_gegenstand(v_welcher).f_name[2] != "Trank der G\357\277\275ter") && (a_gegenstand(v_welcher).f_name[2] != " ")));
					a_inventory(v_i, g_akt_spieler).f_name = v_welcher;
					a_inventory(v_i, g_akt_spieler).f_art = 4;
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
				}
			} else {
				p_nachricht(35, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 249)) {
		switch (a_inventory(g_feld, g_akt_spieler).f_attri1) {
		case 1:
			v_info1 = a_nachricht_text(618, (1 + g_sprache));
			break;
		case 2:
			v_info1 = a_nachricht_text(619, (1 + g_sprache));
			break;
		case 3:
			v_info1 = a_nachricht_text(620, (1 + g_sprache));
			break;
		case 4:
			v_info1 = a_nachricht_text(621, (1 + g_sprache));
			break;
		case 5:
			v_info1 = a_nachricht_text(622, (1 + g_sprache));
			break;
		case 6:
			v_info1 = a_nachricht_text(623, (1 + g_sprache));
			break;
		case 7:
			v_info1 = a_nachricht_text(628, (1 + g_sprache));
			break;
		}
		v_text1 = a_nachricht_text(624, (1 + g_sprache));
		v_text2 = " ";
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			switch (a_inventory(g_feld, g_akt_spieler).f_attri1) {
			case 1:
				a_spieler(g_akt_spieler).f_goblinlehre = (a_spieler(g_akt_spieler).f_goblinlehre + 1);
				break;
			case 2:
				a_spieler(g_akt_spieler).f_spinnenlehre = (a_spieler(g_akt_spieler).f_spinnenlehre + 1);
				break;
			case 3:
				a_spieler(g_akt_spieler).f_untotenlehre = (a_spieler(g_akt_spieler).f_untotenlehre + 1);
				break;
			case 4:
				a_spieler(g_akt_spieler).f_tierkunde = (a_spieler(g_akt_spieler).f_tierkunde + 1);
				break;
			case 5:
				a_spieler(g_akt_spieler).f_fallenlehre = (a_spieler(g_akt_spieler).f_fallenlehre + 1);
				break;
			case 6:
				a_spieler(g_akt_spieler).f_giftlehre = (a_spieler(g_akt_spieler).f_giftlehre + 1);
				break;
			case 7:
				a_spieler(g_akt_spieler).f_pflanzenlehre = (a_spieler(g_akt_spieler).f_pflanzenlehre + 1);
				break;
			}
			p_nachricht(625, 2);
			p_leeren(g_feld);
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 159)) {
		v_text1 = a_nachricht_text(634, (g_sprache + 1));
		v_info1 = ((("(" + a_nachricht_text(548, (g_sprache + 1))) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1)) + ")");
		v_text2 = a_nachricht_text(635, (g_sprache + 1));
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Anker erschaffen";
				g_schriftrolle = 1;
				p_cast_it();
				g_schriftrolle = 0;
				a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
			} else {
				p_nachricht(262, 3);
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Anker Teleportation";
			g_schriftrolle = 1;
			p_laby_screen();
			p_cast_it();
			g_schriftrolle = 0;
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 400)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_text2 = a_nachricht_text(541, (g_sprache + 1));
		v_text3 = " ";
		v_info1 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
				if ((a_skills(58, g_akt_spieler).f_gewaehlt == 0)) {
					p_nachricht(864, 3);
				} else {
					a_inventory(g_feld, g_akt_spieler).f_benutzt = 1;
					p_eintragen(48, 1, 9999, 400);
				}
			}
		}
		if (((g_benutzen == 2) || (g_do_it2 > 0))) {
			if ((g_do_it2 > 0)) {
				g_feld = v_bew_geg_pos;
			}
			g_do_it2 = 0;
			if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 1)) {
				a_inventory(g_feld, g_akt_spieler).f_benutzt = 0;
				p_terminate(48, 400);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 399)) {
		v_text1 = a_nachricht_text(866, (g_sprache + 1));
		v_info1 = ((("(" + a_nachricht_text(548, (g_sprache + 1))) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1)) + ")");
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					p_laby_screen2();
					p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
					p_displaytransparentsprite(37, 160, 160);
					p_flipbuffers(1);
					p_delay(90);
				}
				a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
				a_spieler(g_akt_spieler).f_character_x = a_spieler(g_akt_spieler).f_old_pos_x;
				a_spieler(g_akt_spieler).f_character_y = a_spieler(g_akt_spieler).f_old_pos_y;
				a_spieler(g_akt_spieler).f_lifepoints = a_spieler(g_akt_spieler).f_old_lp;
				a_spieler(g_akt_spieler).f_maxlifepoints = a_spieler(g_akt_spieler).f_old_max_lp;
				a_spieler(g_akt_spieler).f_mana = a_spieler(g_akt_spieler).f_old_mp;
				a_spieler(g_akt_spieler).f_maxmana = a_spieler(g_akt_spieler).f_old_max_mp;
				for (v_i = 1; v_i <= 8; v_i += 1) {
					p_laby_screen2();
					p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
					p_displaytransparentsprite(37, 160, 160);
					p_flipbuffers(1);
					p_delay(90);
				}
			} else {
				p_nachricht(262, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
	if ((a_inventory(g_feld, g_akt_spieler).f_name == 401)) {
		v_text1 = a_nachricht_text(551, (g_sprache + 1));
		v_info1 = ((("(" + a_nachricht_text(548, (g_sprache + 1))) + p_str(a_inventory(g_feld, g_akt_spieler).f_attri1)) + ")");
		v_text3 = " ";
		g_benutzen = 0;
		p_itemmenue(v_text1, v_text2, v_text3, v_info1);
		if (((g_benutzen == 1) || (g_do_it > 0))) {
			if ((a_inventory(g_feld, g_akt_spieler).f_attri1 > 0)) {
				p_duplizieren();
				a_inventory(g_feld, g_akt_spieler).f_attri1 = (a_inventory(g_feld, g_akt_spieler).f_attri1 - 1);
			} else {
				p_nachricht(262, 3);
			}
		}
		if ((g_benutzen == 3)) {
			p_ablegen();
		}
		if ((g_benutzen == 4)) {
			g_abbrechen = 1;
			g_feld = 0;
		}
	}
}

static int32_t p_kaempfer() {
	p_waehlen(132);
	p_waehlen(133);
	p_waehlen(124);
	p_waehlen(85);
	p_waehlen(2);
	p_waehlen(19);
	p_waehlen(20);
	p_waehlen(6);
	p_waehlen(21);
	p_waehlen(87);
	p_waehlen(77);
	p_waehlen(93);
	p_waehlen(1);
}

static int32_t p_kampf() {
	int32_t v_akt_item = 0;
	int32_t v_aktwaffe = 0;
	int16_t v_aktwaffe2 = 0;
	int16_t v_angriff = 0;
	int16_t v_brechfaktor = 0;
	int16_t v_counter = 0;
	int16_t v_critical = 0;
	int32_t v_critical_chance = 0;
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int16_t v_maxi = 0;
	int16_t v_mini = 0;
	int16_t v_name = 0;
	int16_t v_nr = 0;
	int16_t v_nr_of_monsters = 0;
	int32_t v_regeneration = 0;
	int32_t v_schaden = 0;
	int32_t v_spell_x = 0;
	int32_t v_spell_y = 0;
	int16_t v_treffer = 0;
	int32_t v_wohin = 0;
	int32_t v_xx = 0;
	int32_t v_yy = 0;
	int16_t v_zw = 0;
	if ((a_skills(136, g_akt_spieler).f_gewaehlt == 1)) {
		p_nachricht(708, 3);
	} else {
		if ((((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 17) > 0) && (p_ich_trage4() == 0)) && (a_skills(16, g_akt_spieler).f_gewaehlt == 0))) {
			p_nachricht(736, 3);
		} else {
			p_draw_tile(a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level], 5, 5, 0, 0);
			if ((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
				p_draw_monster(v_name, v_nr, 5, 5, 0, 0);
			}
			if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
				p_draw_item(v_name, 5, 5, 0, 0);
			}
			p_draw_character(a_spieler(g_akt_spieler).f_face, 1, -3);
			if ((a_skills(18, g_akt_spieler).f_gewaehlt == 1)) {
				v_nr_of_monsters = 0;
				if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					v_nr_of_monsters = (v_nr_of_monsters + 1);
				}
				if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					v_nr_of_monsters = (v_nr_of_monsters + 1);
				}
				if ((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					v_nr_of_monsters = (v_nr_of_monsters + 1);
				}
				if ((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					v_nr_of_monsters = (v_nr_of_monsters + 1);
				}
				if ((v_nr_of_monsters > 1)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					for (v_i = 1; v_i <= 12; v_i += 1) {
						p_laby_screen2();
						p_clipsprite(70, (-32 + (32 * v_i)), 0, 32, 32);
						p_displaytransparentsprite(70, (156 + (v_spell_x * 32)), (156 + (v_spell_y * 32)));
						p_flipbuffers(1);
						p_delay(90);
					}
					p_stopdrawing();
				}
			}
			v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
			v_inhalt_y = 0;
			if ((v_inhalt_x > 10)) {
				do {
					v_inhalt_y = (v_inhalt_y + 1);
					v_inhalt_x = (v_inhalt_x - 10);
				} while (!(v_inhalt_x < 11));
			}
			if ((v_inhalt_x == 10)) {
				v_inhalt_x = 0;
				v_inhalt_y = (v_inhalt_y + 1);
			}
			v_zw = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level];
			g_sprite_x = v_zw;
			g_sprite_y = 0;
			if ((g_sprite_x > 10)) {
				do {
					g_sprite_y = (g_sprite_y + 1);
					g_sprite_x = (g_sprite_x - 10);
				} while (!(g_sprite_x < 11));
			}
			if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 36) > 0) && (p_habich(87) > 0))) {
				a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 3;
			}
			if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 37) > 0) && (p_habich(86) > 0))) {
				a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 3;
			}
			if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 38) > 0) && (p_habich(89) > 0))) {
				a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 3;
			}
			v_angriff = p_spieler_angriffswert();
			v_angriff = (v_angriff - (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_abwehr * 10));
			if ((v_angriff > 90)) {
				v_angriff = 90;
			}
			if ((v_angriff < 10)) {
				v_angriff = 10;
			}
			v_mini = p_schaden_min();
			v_maxi = p_schaden_max();
			if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 3)) {
			} else {
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1) && (a_skills(13, g_akt_spieler).f_gewaehlt == 1))) {
					v_angriff = (v_angriff + 3);
					v_mini = (v_mini + 3);
					v_maxi = (v_maxi + 3);
				}
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 2) && (a_skills(15, g_akt_spieler).f_gewaehlt == 1))) {
					v_angriff = (v_angriff + 3);
					v_mini = (v_mini + 3);
					v_maxi = (v_maxi + 3);
				}
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 3) && (a_skills(14, g_akt_spieler).f_gewaehlt == 1))) {
					v_angriff = (v_angriff + 3);
					v_mini = (v_mini + 3);
					v_maxi = (v_maxi + 3);
				}
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 10) && (a_skills(16, g_akt_spieler).f_gewaehlt == 1))) {
					v_angriff = (v_angriff + 5);
					v_mini = (v_mini + 5);
					v_maxi = (v_maxi + 5);
				}
				if ((p_habich(145) > 0)) {
					v_mini = (v_mini + p_power(145));
					v_maxi = (v_maxi + p_power(145));
					v_angriff = (v_angriff + p_power(145));
				}
				if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 33) == 1)) {
					v_angriff = (v_angriff + (a_spieler(g_akt_spieler).f_goblinlehre * 2));
					v_mini = (v_mini + (a_spieler(g_akt_spieler).f_goblinlehre * 2));
					v_maxi = (v_maxi + (a_spieler(g_akt_spieler).f_goblinlehre * 2));
				}
				if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 32) == 1)) {
					v_angriff = (v_angriff + (a_spieler(g_akt_spieler).f_spinnenlehre * 2));
					v_mini = (v_mini + (a_spieler(g_akt_spieler).f_spinnenlehre * 2));
					v_maxi = (v_maxi + (a_spieler(g_akt_spieler).f_spinnenlehre * 2));
				}
				if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 34) == 1)) {
					v_angriff = (v_angriff + (a_spieler(g_akt_spieler).f_untotenlehre * 2));
					v_mini = (v_mini + (a_spieler(g_akt_spieler).f_untotenlehre * 2));
					v_maxi = (v_maxi + (a_spieler(g_akt_spieler).f_untotenlehre * 2));
				}
				if ((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1)) {
					v_angriff = (v_angriff + (a_spieler(g_akt_spieler).f_tierkunde * 2));
					v_mini = (v_mini + (a_spieler(g_akt_spieler).f_tierkunde * 2));
					v_maxi = (v_maxi + (a_spieler(g_akt_spieler).f_tierkunde * 2));
				}
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 8) && p_ich_trage2(164))) {
					v_angriff = (v_angriff + 7);
					v_mini = (v_mini + 7);
					v_maxi = (v_maxi + 7);
				}
				if (((a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 7) && p_ich_trage2(162))) {
					v_angriff = (v_angriff + 7);
					v_mini = (v_mini + 7);
					v_maxi = (v_maxi + 7);
				}
				if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 35) > 0) && (p_habich(89) > 0))) {
					v_angriff = (v_angriff + 3);
					v_mini = (v_mini + 3);
					v_maxi = (v_maxi + 3);
				}
				v_critical_chance = p_schaden_critical();
				v_critical = 0;
				v_treffer = (p_random(99) + 1);
				if ((v_treffer < v_angriff)) {
					p_clipsprite(38, 0, 224, 32, 32);
					p_displaytransparentsprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
					p_sound((p_random(6) + 1));
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if ((a_aktive(v_i, g_akt_spieler).f_nr == 110)) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							a_aktive(v_i, g_akt_spieler).f_dauer = 0;
						}
					}
					v_counter = 1;
					do {
						v_schaden = (p_random((v_maxi - 1)) + 1);
						v_counter = (v_counter + 1);
					} while (!((v_schaden >= v_mini) || (v_counter > 500)));
					if ((v_counter > 500)) {
						v_schaden = 1;
					}
					if ((a_spieler(g_akt_spieler).f_style != 3)) {
						v_schaden = (v_schaden - p_random(a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level]).f_ruestung));
					}
					if (((a_spieler(g_akt_spieler).f_style == 5) || (a_spieler(g_akt_spieler).f_style == 6))) {
						v_schaden = ((v_schaden / 4) * 3);
					}
					if (((a_spieler(g_akt_spieler).f_style == 8) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] != 1))) {
						v_schaden = (v_schaden * 2);
					}
					if ((v_schaden < 1)) {
						v_schaden = 0;
					}
					if (((v_treffer < v_critical_chance) && (v_schaden > 0))) {
						p_clipsprite(38, 96, 224, 32, 32);
						p_displaytransparentsprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
						v_critical = 1;
					}
					if ((v_critical == 0)) {
						v_wohin = p_screenoutput();
						p_startdrawing(v_wohin);
						p_drawingmode(1);
						v_xx = (172 + (g_xmod * 32));
						v_yy = (168 + (g_ymod * 32));
						if ((v_schaden < 10)) {
							v_xx = (172 + (g_xmod * 32));
							v_yy = (168 + (g_ymod * 32));
						}
						if ((v_schaden >= 10)) {
							v_xx = (166 + (g_xmod * 32));
							v_yy = (168 + (g_ymod * 32));
						}
						if ((v_schaden >= 100)) {
							v_xx = (163 + (g_xmod * 32));
							v_yy = (168 + (g_ymod * 32));
						}
						p_drawtext(v_xx, v_yy, p_str(v_schaden), 16777215, 0);
						p_stopdrawing();
					}
					p_flipbuffers(1);
					p_delay(g_mydelay);
					v_i = 1;
					do {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_aktwaffe = v_i;
						}
						v_i = (v_i + 1);
					} while (!((v_aktwaffe > 0) || (v_i > 50)));
					v_aktwaffe2 = 0;
					for (v_i = (v_aktwaffe + 1); v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_aktwaffe2 = v_i;
						}
					}
					v_brechfaktor = 5;
					if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 39) == 1)) {
						v_brechfaktor = 25;
					}
					if ((a_spieler(g_akt_spieler).f_fluch == 25)) {
						v_brechfaktor = (v_brechfaktor * 2);
					}
					if (((p_random(2999) + 1) <= v_brechfaktor)) {
						if ((v_aktwaffe > 0)) {
							if ((a_inventory(v_aktwaffe, g_akt_spieler).f_status == 1)) {
								a_inventory(v_aktwaffe, g_akt_spieler).f_status = 2;
								p_nachricht(449, 3);
							}
							if ((a_inventory(v_aktwaffe, g_akt_spieler).f_status == 0)) {
								a_inventory(v_aktwaffe, g_akt_spieler).f_status = 1;
								p_nachricht(448, 3);
							}
						}
					}
					if (((p_random(2999) + 1) <= v_brechfaktor)) {
						if ((v_aktwaffe2 > 0)) {
							if ((a_inventory(v_aktwaffe2, g_akt_spieler).f_status == 1)) {
								a_inventory(v_aktwaffe2, g_akt_spieler).f_status = 2;
								p_nachricht(449, 3);
							}
							if ((a_inventory(v_aktwaffe2, g_akt_spieler).f_status == 0)) {
								a_inventory(v_aktwaffe2, g_akt_spieler).f_status = 1;
								p_nachricht(448, 3);
							}
						}
					}
					v_akt_item = a_inventory(v_aktwaffe, g_akt_spieler).f_name;
					if ((((((a_inventory(v_aktwaffe, g_akt_spieler).f_status == 4) || (v_akt_item == 144)) || (v_akt_item == 381)) || (v_akt_item == 382)) || (v_akt_item == 238))) {
						if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 3) == 0)) {
							if ((a_inventory(v_aktwaffe, g_akt_spieler).f_name != 144)) {
								a_inventory(v_aktwaffe, g_akt_spieler).f_status = 0;
							}
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 4;
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_duration[a_spieler(g_akt_spieler).f_level] = (p_random(20) + 5);
						} else {
							p_nachricht(456, 4);
						}
					}
					a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] - v_schaden);
					if (((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1) || (v_critical == 1))) {
						p_zerstoert(g_xmod, g_ymod);
					} else {
						if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 0)) {
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 1;
						}
						if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 2)) {
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 0;
						}
						if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 30) > 0)) {
							p_clipsprite(1, 64, 224, 32, 32);
							p_displaysprite(1, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
						} else {
							p_clipsprite(1, (v_inhalt_x * 32), (v_inhalt_y * 32), 32, 32);
							p_displaysprite(1, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
						}
						p_clipsprite(9, ((g_sprite_x * 32) - 32), (g_sprite_y * 32), 32, 32);
						p_displaytransparentsprite(9, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
						p_laby_screen2();
						if ((v_regeneration == 1)) {
							p_laby_screen();
						}
					}
				} else {
					p_sound(29);
					p_nachricht(286, 3);
				}
			}
		}
	}
}

static int32_t p_karte(int8_t v_x_offset, int8_t v_y_offset) {
	int16_t v_get_out = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int16_t v_offset = 0;
	int32_t v_result = 0;
	int8_t v_x = 0;
	int16_t v_x_akt = 0;
	int32_t v_xx = 0;
	int8_t v_y = 0;
	int16_t v_y_akt = 0;
	v_x_akt = 0;
	v_y_akt = 0;
	v_offset = 10;
	v_get_out = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		for (v_y = -1; v_y <= 20; v_y += 1) {
			for (v_x = -1; v_x <= 20; v_x += 1) {
				if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1) || ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1))) {
					p_draw_small_tile(a_mit_was(a_spieler(g_akt_spieler).f_level), v_x, v_y, v_x_offset, v_y_offset);
				} else {
					p_draw_small_tile(a_labyrinth((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt), (((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt)).f_feld[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
					p_draw_small_monster(a_laby_monster(v_x, v_y).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, v_x_offset, v_y_offset);
					for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
						if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) == a_spieler(v_xx).f_character_x) && ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) == a_spieler(v_xx).f_character_y))) {
							if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level))) {
								if ((a_spieler(v_xx).f_fluch == 23)) {
									p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 0, 16, 16);
									p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
								} else {
									if (p_hater(86, v_xx)) {
										p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 64, 16, 16);
										p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
									} else {
										if (p_hater(87, v_xx)) {
											p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 32, 16, 16);
											p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
										} else {
											if (p_hater(88, v_xx)) {
												p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 48, 16, 16);
												p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
											} else {
												if (p_hater(89, v_xx)) {
													p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 16, 16, 16);
													p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
												} else {
													if (p_hater(90, v_xx)) {
														p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 80, 16, 16);
														p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
													} else {
														p_clipsprite(25, ((a_spieler(v_xx).f_face * 16) * 2), ((a_spieler(v_xx).f_maennchen * 16) - 16), 16, 16);
														p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
													}
												}
											}
										}
									}
								}
							}
						}
					}
					for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
						if ((a_spieler(v_xx).f_creature_typ > 0)) {
							if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) == a_spieler(v_xx).f_creature_x) && ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) == a_spieler(v_xx).f_creature_y))) {
								if (((a_spieler(v_xx).f_level == a_spieler(g_akt_spieler).f_level) && (a_spieler(v_xx).f_status == 1))) {
									if ((a_spieler(v_xx).f_creature_typ == 1)) {
										p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 128, 16, 16);
										p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
									} else {
										if ((a_spieler(v_xx).f_creature_typ == 2)) {
											p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 96, 16, 16);
											p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
										} else {
											if ((a_spieler(v_xx).f_creature_typ == 3)) {
												p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 176, 16, 16);
												p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
											} else {
												if ((a_spieler(v_xx).f_creature_typ == 4)) {
													p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 192, 16, 16);
													p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
												} else {
													if ((a_spieler(v_xx).f_creature_typ == 5)) {
														p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 208, 16, 16);
														p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
													} else {
														if ((a_spieler(v_xx).f_creature_typ == 6)) {
															p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 160, 16, 16);
															p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
														} else {
															if ((a_spieler(v_xx).f_creature_typ == 7)) {
																p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 112, 16, 16);
																p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
															} else {
																if ((a_spieler(v_xx).f_creature_typ == 8)) {
																	p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 144, 16, 16);
																	p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																} else {
																	if ((a_spieler(v_xx).f_creature_typ == 9)) {
																		p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 80, 16, 16);
																		p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																	} else {
																		if ((a_spieler(v_xx).f_creature_typ == 10)) {
																			p_clipsprite(25, ((a_spieler(v_xx).f_creature_heading * 16) * 2), ((a_spieler(v_xx).f_maennchen * 16) - 16), 16, 16);
																			p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																		} else {
																			if ((a_spieler(v_xx).f_creature_typ == 11)) {
																				p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 48, 16, 16);
																				p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																			} else {
																				if ((a_spieler(v_xx).f_creature_typ == 12)) {
																					p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 240, 16, 16);
																					p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																				} else {
																					if ((a_spieler(v_xx).f_creature_typ == 14)) {
																						p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 272, 16, 16);
																						p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																					} else {
																						if ((a_spieler(v_xx).f_creature_typ == 15)) {
																							p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 288, 16, 16);
																							p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																						} else {
																							if ((a_spieler(v_xx).f_creature_typ == 13)) {
																								p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 256, 16, 16);
																								p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																							} else {
																								if ((a_spieler(v_xx).f_creature_typ == 20)) {
																									p_clipsprite(25, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 304, 16, 16);
																									p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																								}
																							}
																						}
																					}
																				}
																			}
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_examinekeyboard();
		v_jax = 0;
		v_jay = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
		}
		v_get_out = 0;
		if (p_keyboardpushed(27)) {
			v_get_out = 1;
		}
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			v_x_akt = (v_x_akt + 1);
			if ((v_x_akt > a_groesse(a_spieler(g_akt_spieler).f_level))) {
				v_x_akt = a_groesse(a_spieler(g_akt_spieler).f_level);
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			v_x_akt = (v_x_akt - 1);
			if (((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1)) {
				v_x_akt = 0;
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_y_akt = (v_y_akt - 1);
			if (((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1)) {
				v_y_akt = 0;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_y_akt = (v_y_akt + 1);
			if ((v_y_akt > a_groesse(a_spieler(g_akt_spieler).f_level))) {
				v_y_akt = a_groesse(a_spieler(g_akt_spieler).f_level);
			}
		}
		v_result = p_examinemouse();
		v_mouse_x = p_mousex();
		v_mouse_y = p_mousey();
		v_mouse_links = 0;
		v_mouse_rechts = 0;
		v_mouse_links = p_mousebutton(1);
		v_mouse_rechts = p_mousebutton(2);
		if (((((v_mouse_x >= 437) && (v_mouse_x <= 469)) && (v_mouse_y >= 249)) && (v_mouse_y <= 281))) {
			p_clipsprite(6, 96, 0, 31, 31);
			p_displaytransparentsprite(6, 437, 249);
			if ((v_mouse_links == 1)) {
				v_x_akt = (v_x_akt - 1);
				if (((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1)) {
					v_x_akt = 0;
				}
			}
		} else {
			p_clipsprite(6, 32, 0, 31, 31);
			p_displaytransparentsprite(6, 437, 249);
		}
		if (((((v_mouse_x >= 525) && (v_mouse_x <= 557)) && (v_mouse_y >= 249)) && (v_mouse_y <= 281))) {
			p_clipsprite(6, 63, 0, 31, 31);
			p_displaytransparentsprite(6, 525, 249);
			if ((v_mouse_links == 1)) {
				v_x_akt = (v_x_akt + 1);
				if ((v_x_akt > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_x_akt = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
			}
		} else {
			p_clipsprite(6, 0, 0, 31, 31);
			p_displaytransparentsprite(6, 525, 249);
		}
		if (((((v_mouse_x >= 480) && (v_mouse_x <= 512)) && (v_mouse_y >= 211)) && (v_mouse_y <= 243))) {
			p_clipsprite(6, 192, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 211);
			if ((v_mouse_links == 1)) {
				v_y_akt = (v_y_akt - 1);
				if (((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1)) {
					v_y_akt = 0;
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 211);
		}
		if (((((v_mouse_x > 480) && (v_mouse_x < 512)) && (v_mouse_y > 295)) && (v_mouse_y < 327))) {
			p_clipsprite(6, 224, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 295);
			if ((v_mouse_links == 1)) {
				v_y_akt = (v_y_akt + 1);
				if ((v_y_akt > a_groesse(a_spieler(g_akt_spieler).f_level))) {
					v_y_akt = a_groesse(a_spieler(g_akt_spieler).f_level);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 295);
		}
		if (((((v_mouse_x > 480) && (v_mouse_x < 512)) && (v_mouse_y > 250)) && (v_mouse_y < 282))) {
			p_clipsprite(6, 32, 32, 29, 32);
			p_displaytransparentsprite(6, 480, 250);
			if ((v_mouse_links == 1)) {
				v_x_akt = 0;
				v_y_akt = 0;
			}
		} else {
			p_clipsprite(6, 0, 32, 29, 32);
			p_displaytransparentsprite(6, 480, 250);
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!((v_mouse_rechts == 1) || (v_get_out == 1)));
}

static std::string p_keyboard_string(std::string v_text, int8_t v_typ) {
	static int8_t v_counter;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int16_t v_jb3 = 0;
	std::string v_key;
	int32_t v_keychoice = 0;
	std::string v_letter;
	std::string v_neu_letter;
	static std::string v_oldkey;
	std::string v_tkey;
	static int32_t v_wait;
	p_examinekeyboard();
	if ((v_typ == 0)) {
		if (p_keyboardpushed(97)) {
			v_key = "A";
		}
		if (p_keyboardpushed(98)) {
			v_key = "B";
		}
		if (p_keyboardpushed(99)) {
			v_key = "C";
		}
		if (p_keyboardpushed(100)) {
			v_key = "D";
		}
		if (p_keyboardpushed(101)) {
			v_key = "E";
		}
		if (p_keyboardpushed(102)) {
			v_key = "F";
		}
		if (p_keyboardpushed(103)) {
			v_key = "G";
		}
		if (p_keyboardpushed(104)) {
			v_key = "H";
		}
		if (p_keyboardpushed(105)) {
			v_key = "I";
		}
		if (p_keyboardpushed(106)) {
			v_key = "J";
		}
		if (p_keyboardpushed(107)) {
			v_key = "K";
		}
		if (p_keyboardpushed(108)) {
			v_key = "L";
		}
		if (p_keyboardpushed(109)) {
			v_key = "M";
		}
		if (p_keyboardpushed(110)) {
			v_key = "N";
		}
		if (p_keyboardpushed(111)) {
			v_key = "O";
		}
		if (p_keyboardpushed(112)) {
			v_key = "P";
		}
		if (p_keyboardpushed(113)) {
			v_key = "Q";
		}
		if (p_keyboardpushed(114)) {
			v_key = "R";
		}
		if (p_keyboardpushed(115)) {
			v_key = "S";
		}
		if (p_keyboardpushed(116)) {
			v_key = "T";
		}
		if (p_keyboardpushed(117)) {
			v_key = "U";
		}
		if (p_keyboardpushed(118)) {
			v_key = "V";
		}
		if (p_keyboardpushed(119)) {
			v_key = "W";
		}
		if (p_keyboardpushed(120)) {
			v_key = "X";
		}
		if (p_keyboardpushed(121)) {
			v_key = "Y";
		}
		if (p_keyboardpushed(122)) {
			v_key = "Z";
		}
		if (p_keyboardpushed(45)) {
			v_key = "-";
		}
	}
	if (p_keyboardpushed(49)) {
		v_key = "1";
	}
	if (p_keyboardpushed(50)) {
		v_key = "2";
	}
	if (p_keyboardpushed(51)) {
		v_key = "3";
	}
	if (p_keyboardpushed(52)) {
		v_key = "4";
	}
	if (p_keyboardpushed(53)) {
		v_key = "5";
	}
	if (p_keyboardpushed(54)) {
		v_key = "6";
	}
	if (p_keyboardpushed(55)) {
		v_key = "7";
	}
	if (p_keyboardpushed(56)) {
		v_key = "8";
	}
	if (p_keyboardpushed(57)) {
		v_key = "9";
	}
	if (p_keyboardpushed(48)) {
		v_key = "0";
	}
	v_key = p_lcase(v_key);
	if ((v_typ == 0)) {
		if (((p_keyboardpushed(301) || p_keyboardpushed(303)) || p_keyboardpushed(304))) {
			v_key = p_ucase(v_key);
		}
		if (p_keyboardpushed(32)) {
			v_key = "_";
		}
	}
	if (p_keyboardpushed(127)) {
		v_key = "DEL";
	}
	if (p_keyboardpushed(8)) {
		v_key = "BACK";
	}
	v_tkey = v_key;
	v_keychoice = 1;
	if ((v_wait == 0)) {
		if ((v_key == "")) {
			v_counter = 0;
			v_keychoice = 0;
		} else {
			if ((((v_counter == 0) && (v_oldkey == v_key)) && (v_key != ""))) {
				v_wait = g_keydelay;
				v_key = "";
				v_counter = 1;
			} else {
				if ((((v_counter == 1) && (v_oldkey == v_key)) && (v_key != ""))) {
					v_wait = g_keydelay2;
				}
			}
		}
	} else {
		p_delay(10);
		v_wait -= 1;
		if ((v_oldkey != v_key)) {
			v_wait = 0;
			v_counter = 0;
		}
		if ((v_oldkey == v_key)) {
			v_key = "";
		}
	}
	v_oldkey = v_tkey;
	if (((v_key == "DEL") || (v_key == "BACK"))) {
		v_text = p_mid(v_text, 1, (p_len(v_text) - 1));
	} else {
		v_text = (v_text + v_key);
	}
	if ((v_typ > 0)) {
		while (((p_mid(v_text, 1, 1) == "0") || (p_mid(v_text, 1, 1) == "0"))) {
			v_text = p_mid(v_text, 2, p_len(v_text));
		}
		if (((p_len(v_text) == 0) && (v_typ > 0))) {
			v_text = "0";
		}
	}
	v_jax = 0;
	v_jay = 0;
	v_jb1 = 0;
	v_jb2 = 0;
	v_jb3 = 0;
	if ((v_typ > 0)) {
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
			v_jb3 = p_joystickbutton(3);
			if (((p_len(v_text) == 0) && (v_typ <= 0))) {
				v_text = "A";
			}
			v_letter = p_mid(v_text, p_len(v_text), 1);
			v_neu_letter = "";
			if ((((v_jay == -1) || p_keyboardpushed(273)) && (v_wait == 0))) {
				v_text = p_mid(v_text, 1, (p_len(v_text) - 1));
				v_letter = p_ucase(v_letter);
				if ((v_typ <= 0)) {
					if (v_letter == "A") {
						v_neu_letter = "B";
					} else if (v_letter == "B") {
						v_neu_letter = "C";
					} else if (v_letter == "C") {
						v_neu_letter = "D";
					} else if (v_letter == "D") {
						v_neu_letter = "E";
					} else if (v_letter == "E") {
						v_neu_letter = "F";
					} else if (v_letter == "F") {
						v_neu_letter = "G";
					} else if (v_letter == "G") {
						v_neu_letter = "H";
					} else if (v_letter == "H") {
						v_neu_letter = "I";
					} else if (v_letter == "I") {
						v_neu_letter = "J";
					} else if (v_letter == "J") {
						v_neu_letter = "K";
					} else if (v_letter == "K") {
						v_neu_letter = "L";
					} else if (v_letter == "L") {
						v_neu_letter = "M";
					} else if (v_letter == "M") {
						v_neu_letter = "N";
					} else if (v_letter == "N") {
						v_neu_letter = "O";
					} else if (v_letter == "O") {
						v_neu_letter = "P";
					} else if (v_letter == "P") {
						v_neu_letter = "Q";
					} else if (v_letter == "Q") {
						v_neu_letter = "R";
					} else if (v_letter == "R") {
						v_neu_letter = "S";
					} else if (v_letter == "S") {
						v_neu_letter = "T";
					} else if (v_letter == "T") {
						v_neu_letter = "U";
					} else if (v_letter == "U") {
						v_neu_letter = "V";
					} else if (v_letter == "V") {
						v_neu_letter = "W";
					} else if (v_letter == "W") {
						v_neu_letter = "X";
					} else if (v_letter == "X") {
						v_neu_letter = "Y";
					} else if (v_letter == "Y") {
						v_neu_letter = "Z";
					} else if (v_letter == "Z") {
						v_neu_letter = "A";
					} else {}
					if ((v_jb2 == 1)) {
						v_letter = p_lcase(v_letter);
					}
				}
				if (((v_typ > 0) || (v_jb3 == 1))) {
					if (v_letter == "1") {
						v_neu_letter = "2";
					} else if (v_letter == "2") {
						v_neu_letter = "3";
					} else if (v_letter == "3") {
						v_neu_letter = "4";
					} else if (v_letter == "4") {
						v_neu_letter = "5";
					} else if (v_letter == "5") {
						v_neu_letter = "6";
					} else if (v_letter == "6") {
						v_neu_letter = "7";
					} else if (v_letter == "7") {
						v_neu_letter = "8";
					} else if (v_letter == "8") {
						v_neu_letter = "9";
					} else if (v_letter == "9") {
						v_neu_letter = "0";
					} else if (v_letter == "0") {
						v_neu_letter = "1";
					} else {}
				}
				v_text = (v_text + v_neu_letter);
			}
			if ((((v_jay == 1) || p_keyboardpushed(274)) && (v_wait == 0))) {
				v_text = p_mid(v_text, 1, (p_len(v_text) - 1));
				v_letter = p_ucase(v_letter);
				if ((v_typ <= 0)) {
					if (v_letter == "A") {
						v_neu_letter = "Z";
					} else if (v_letter == "B") {
						v_neu_letter = "A";
					} else if (v_letter == "C") {
						v_neu_letter = "B";
					} else if (v_letter == "D") {
						v_neu_letter = "C";
					} else if (v_letter == "E") {
						v_neu_letter = "D";
					} else if (v_letter == "F") {
						v_neu_letter = "E";
					} else if (v_letter == "G") {
						v_neu_letter = "F";
					} else if (v_letter == "H") {
						v_neu_letter = "G";
					} else if (v_letter == "I") {
						v_neu_letter = "H";
					} else if (v_letter == "J") {
						v_neu_letter = "I";
					} else if (v_letter == "K") {
						v_neu_letter = "J";
					} else if (v_letter == "L") {
						v_neu_letter = "K";
					} else if (v_letter == "M") {
						v_neu_letter = "L";
					} else if (v_letter == "N") {
						v_neu_letter = "M";
					} else if (v_letter == "O") {
						v_neu_letter = "N";
					} else if (v_letter == "P") {
						v_neu_letter = "O";
					} else if (v_letter == "Q") {
						v_neu_letter = "P";
					} else if (v_letter == "R") {
						v_neu_letter = "Q";
					} else if (v_letter == "S") {
						v_neu_letter = "R";
					} else if (v_letter == "T") {
						v_neu_letter = "S";
					} else if (v_letter == "U") {
						v_neu_letter = "T";
					} else if (v_letter == "V") {
						v_neu_letter = "U";
					} else if (v_letter == "W") {
						v_neu_letter = "V";
					} else if (v_letter == "X") {
						v_neu_letter = "W";
					} else if (v_letter == "Y") {
						v_neu_letter = "X";
					} else if (v_letter == "Z") {
						v_neu_letter = "Y";
					} else {}
					if ((v_jb2 == 1)) {
						v_letter = p_lcase(v_letter);
					}
				}
				if (((v_typ > 0) || (v_jb3 == 1))) {
					if (v_letter == "1") {
						v_neu_letter = "0";
					} else if (v_letter == "2") {
						v_neu_letter = "1";
					} else if (v_letter == "3") {
						v_neu_letter = "2";
					} else if (v_letter == "4") {
						v_neu_letter = "3";
					} else if (v_letter == "5") {
						v_neu_letter = "4";
					} else if (v_letter == "6") {
						v_neu_letter = "5";
					} else if (v_letter == "7") {
						v_neu_letter = "6";
					} else if (v_letter == "8") {
						v_neu_letter = "7";
					} else if (v_letter == "9") {
						v_neu_letter = "8";
					} else if (v_letter == "0") {
						v_neu_letter = "9";
					} else {}
				}
				v_text = (v_text + v_neu_letter);
			}
			if (((v_neu_letter != "") && (v_jay == 0))) {
				v_wait = (g_keydelay2 + 5);
			}
			if ((((((v_jax == 1) || p_keyboardpushed(275)) && (v_wait == 0)) && (v_jay == 0)) && (v_text != "0"))) {
				if ((v_typ <= 0)) {
					v_text += "A";
				} else {
					if ((v_typ > 0)) {
						v_text += "0";
					}
				}
			}
			if (((((v_jax == -1) || p_keyboardpushed(276)) && (v_wait == 0)) && (v_jay == 0))) {
				v_text = (p_mid(v_text, 1, 1) + p_mid(v_text, 2, (p_len(v_text) - 2)));
			}
			if ((v_wait == 0)) {
				if ((((((v_jay != 0) || (v_jax != 0)) || p_keyboardpushed(275)) || p_keyboardpushed(276)) && (v_counter == 0))) {
					v_wait = g_keydelay;
					v_counter = 1;
				} else {
					if ((((((v_jay != 0) || (v_jax != 0)) || p_keyboardpushed(275)) || p_keyboardpushed(276)) && (v_counter == 1))) {
						v_wait = (g_keydelay2 + 5);
					} else {
						if ((v_keychoice == 0)) {
							v_counter = 0;
						}
					}
				}
			}
		}
	}
	if ((v_typ > 0)) {
		v_text = p_mid(v_text, 1, v_typ);
		while ((p_len(v_text) < v_typ)) {
			v_text = ("0" + v_text);
		}
	}
	return v_text;
}

static int32_t p_kleinhaendler_init(int16_t v_level) {
	int32_t v_i = 0;
	int16_t v_welchen = 0;
	int32_t v_welcher = 0;
	switch (p_random(7)) {
	case 0:
		a_haendler_objekte(1, v_level) = 56;
		a_haendler_objekte(2, v_level) = 56;
		break;
	case 1:
		a_haendler_objekte(1, v_level) = 46;
		a_haendler_objekte(2, v_level) = 46;
		break;
	case 2:
		a_haendler_objekte(1, v_level) = 38;
		do {
			a_haendler_schriftrolle(1, v_level) = (p_random(176) + 1);
		} while (!(a_zauber(a_haendler_schriftrolle(1, v_level), g_akt_spieler).f_dauer != 9999));
		a_haendler_staerke(1, v_level) = (p_random(6) + 2);
		a_haendler_objekte(2, v_level) = 38;
		do {
			a_haendler_schriftrolle(2, v_level) = (p_random(176) + 1);
		} while (!(a_zauber(a_haendler_schriftrolle(2, v_level), g_akt_spieler).f_dauer != 9999));
		a_haendler_staerke(2, v_level) = (p_random(6) + 2);
		break;
	case 3:
		a_haendler_objekte(1, v_level) = 231;
		a_haendler_objekte(2, v_level) = 219;
		break;
	case 4:
		a_haendler_objekte(1, v_level) = 270;
		a_haendler_objekte(2, v_level) = 269;
		break;
	case 5:
		v_welchen = (75 + p_random(37));
		a_haendler_objekte(1, v_level) = v_welchen;
		v_welchen = (75 + p_random(37));
		a_haendler_objekte(2, v_level) = v_welchen;
		break;
	case 6:
		v_welcher = (p_random(4) + 1);
		switch (v_welcher) {
		case 1:
			a_haendler_objekte(1, v_level) = 197;
			break;
		case 2:
			a_haendler_objekte(1, v_level) = 198;
			break;
		case 3:
			a_haendler_objekte(1, v_level) = 199;
			break;
		case 4:
			a_haendler_objekte(1, v_level) = 209;
			break;
		case 5:
			a_haendler_objekte(1, v_level) = 210;
			break;
		}
		v_welcher = (p_random(4) + 1);
		switch (v_welcher) {
		case 1:
			a_haendler_objekte(2, v_level) = 197;
			break;
		case 2:
			a_haendler_objekte(2, v_level) = 198;
			break;
		case 3:
			a_haendler_objekte(2, v_level) = 199;
			break;
		case 4:
			a_haendler_objekte(2, v_level) = 209;
			break;
		case 5:
			a_haendler_objekte(2, v_level) = 210;
			break;
		}
		break;
	case 7:
		a_haendler_objekte(1, v_level) = 193;
		a_haendler_objekte(2, v_level) = 193;
		break;
	}
	for (v_i = 3; v_i <= 40; v_i += 1) {
		a_haendler_objekte(v_i, v_level) = 0;
	}
	for (v_i = 1; v_i <= 40; v_i += 1) {
		if ((a_gegenstand(a_haendler_objekte(v_i, v_level)).f_qualitaet > 0)) {
			a_haendler_staerke(v_i, v_level) = (p_random(2) + 1);
		}
	}
}

static int32_t p_kopiere_matrix() {
	int32_t v_x = 0;
	int32_t v_y = 0;
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if (((((a_spieler(g_akt_spieler).f_character_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_character_y - 5) + v_y) > 0))) {
				if ((p_blockiert(((a_spieler(g_akt_spieler).f_character_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_character_y - 5) + v_y), a_spieler(g_akt_spieler).f_level) == 0)) {
					a_matrix((v_x + 1), (v_y + 1)) = 9998;
				} else {
					a_matrix((v_x + 1), (v_y + 1)) = 9999;
				}
			}
		}
	}
}

static int32_t p_kopiere_matrix2() {
	int32_t v_x = 0;
	int32_t v_y = 0;
	for (v_y = -1; v_y <= 11; v_y += 1) {
		for (v_x = -1; v_x <= 11; v_x += 1) {
			if (((((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x) > 0) && (((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y) > 0))) {
				if ((p_blockiert(((a_spieler(g_akt_spieler).f_creature_x - 5) + v_x), ((a_spieler(g_akt_spieler).f_creature_y - 5) + v_y), a_spieler(g_akt_spieler).f_level) == 0)) {
					a_matrix((v_x + 1), (v_y + 1)) = 9998;
				} else {
					a_matrix((v_x + 1), (v_y + 1)) = 9999;
				}
			}
		}
	}
}

static int32_t p_laby_rahmen() {
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(365, 15, 51, 449, -1);
	p_box(15, 365, 335, 51, -1);
	p_stopdrawing();
	p_clipsprite(54, 0, 0, 640, 17);
	p_displaysprite(54, 0, 0);
	p_clipsprite(56, 0, 0, 17, 480);
	p_displaysprite(56, 0, 0);
	p_clipsprite(57, 0, 0, 640, 17);
	p_displaysprite(57, 0, 464);
	p_clipsprite(59, 0, 0, 17, 480);
	p_displaysprite(59, 624, 0);
	p_clipsprite(63, 0, 0, 640, 17);
	p_displaysprite(63, 0, 350);
	p_clipsprite(63, 0, 0, 365, 17);
	p_displaysprite(63, 0, 414);
	p_clipsprite(61, 0, 0, 274, 16);
	p_displaysprite(61, 350, 87);
	p_clipsprite(62, 0, 0, 274, 16);
	p_displaysprite(62, 350, 167);
	p_clipsprite(60, 0, 0, 17, 480);
	p_displaysprite(60, 350, 0);
}

static int32_t p_laby_screen() {
	p_screen2();
	p_flipbuffers(1);
}

static int32_t p_laby_screen2() {
	p_screen2();
}

static int32_t p_laby_screen3() {
	int32_t v_result = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_draw_screen2(0, 0);
	p_draw_screen5(0, 0);
	p_draw_screen6(0, 0);
	p_draw_creature(g_frame, 0);
	p_laby_rahmen();
	p_show_logo();
	p_show_varys2();
	p_show_sight2();
	p_show_buttons2();
	v_result = p_examinemouse();
	g_mmouse_x = p_mousex();
	g_mmouse_y = p_mousey();
	g_mmouse_links = p_mousebutton(1);
	g_mmouse_rechts = p_mousebutton(2);
	g_mouse_x_old = g_mmouse_x;
	g_mouse_y_old = g_mmouse_y;
	p_flipbuffers(1);
}

static int32_t p_laby_screen4() {
	int32_t v_result = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_draw_screen2(0, 0);
	p_draw_screen5(0, 0);
	p_draw_screen6(0, 0);
	p_draw_creature(g_frame, 0);
	p_laby_rahmen();
	p_show_logo();
	p_show_varys2();
	p_show_sight2();
	p_show_buttons2();
	v_result = p_examinemouse();
	g_mmouse_x = p_mousex();
	g_mmouse_y = p_mousey();
	g_mmouse_links = p_mousebutton(1);
	g_mmouse_rechts = p_mousebutton(2);
	g_mouse_x_old = g_mmouse_x;
	g_mouse_y_old = g_mmouse_y;
}

static int32_t p_leeren(int32_t v_feld) {
	if ((a_inventory(v_feld, g_akt_spieler).f_anzahl > 0)) {
		a_inventory(v_feld, g_akt_spieler).f_anzahl = (a_inventory(v_feld, g_akt_spieler).f_anzahl - 1);
		a_inventory(v_feld, g_akt_spieler).f_attri1 = a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_attri1;
		if ((a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_art != 13)) {
			a_inventory(v_feld, g_akt_spieler).f_status = 0;
		}
	} else {
		if ((a_inventory(v_feld, g_akt_spieler).f_name == 150)) {
			a_inventory(v_feld, g_akt_spieler).f_attri1 = ((a_inventory(v_feld, g_akt_spieler).f_attri1 - p_random((a_spieler(g_akt_spieler).f_level * 2))) + 1);
			if ((a_inventory(v_feld, g_akt_spieler).f_attri1 < 1)) {
				a_inventory(v_feld, g_akt_spieler).f_attri1 = 0;
			}
		} else {
			a_inventory(v_feld, g_akt_spieler).f_name = 0;
			a_inventory(v_feld, g_akt_spieler).f_art = 0;
			a_inventory(v_feld, g_akt_spieler).f_benutzt = 0;
			a_inventory(v_feld, g_akt_spieler).f_status = 0;
			a_inventory(v_feld, g_akt_spieler).f_anzahl = 0;
			a_inventory(v_feld, g_akt_spieler).f_attri1 = 0;
			a_inventory(v_feld, g_akt_spieler).f_attri2 = 0;
			a_inventory(v_feld, g_akt_spieler).f_attri3 = 0;
			a_inventory(v_feld, g_akt_spieler).f_attri4 = 0;
			a_inventory(v_feld, g_akt_spieler).f_attri5 = 0;
		}
	}
}

static int32_t p_lehrer(int32_t v_welcher) {
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_kosten = 0;
	int16_t v_lernen = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_sel = 0;
	int32_t v_wohin = 0;
	v_sel = 1;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_raus = 0;
		v_lernen = 0;
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = 1;
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = 2;
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, 25, a_nachricht_text((202 + v_welcher), (1 + g_sprache)), -1, 0);
		switch (v_welcher) {
		case 1:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_luck_score);
			break;
		case 2:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_attack);
			break;
		case 3:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_dexterity);
			break;
		case 4:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_strength);
			break;
		case 5:
			v_kosten = (30 * (a_spieler(g_akt_spieler).f_maxlifepoints / a_spieler(g_akt_spieler).f_managain));
			break;
		case 6:
			v_kosten = (5 * a_spieler(g_akt_spieler).f_maxspeed);
			break;
		case 7:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_perception);
			break;
		case 8:
			v_kosten = (30 * (a_spieler(g_akt_spieler).f_mana / a_spieler(g_akt_spieler).f_lifegain));
			break;
		case 9:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_power_score);
			break;
		case 10:
			v_kosten = (30 * a_spieler(g_akt_spieler).f_circle);
			break;
		}
		if ((a_skills(114, g_akt_spieler).f_gewaehlt == 1)) {
			v_kosten = (int32_t)((v_kosten * 0.75));
		}
		p_drawtext(100, 100, (a_nachricht_text(213, (1 + g_sprache)) + p_str(v_kosten)), -1, 0);
		switch (v_welcher) {
		case 1:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_luck_score)), -1, 0);
			break;
		case 2:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_attack)), -1, 0);
			break;
		case 3:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_dexterity)), -1, 0);
			break;
		case 4:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_strength)), -1, 0);
			break;
		case 5:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_maxlifepoints)), -1, 0);
			break;
		case 6:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_maxspeed)), -1, 0);
			break;
		case 7:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_perception)), -1, 0);
			break;
		case 8:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_mana)), -1, 0);
			break;
		case 9:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_power_score)), -1, 0);
			break;
		case 10:
			p_drawtext(100, 125, ((a_nachricht_text(216, (1 + g_sprache)) + "  ") + p_str(a_spieler(g_akt_spieler).f_circle)), -1, 0);
			break;
		}
		if ((g_sprache == 0)) {
			p_drawtext(100, 150, ("Your Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 1)) {
			p_drawtext(100, 150, ("Dein Gold: " + p_str(p_gold_anzahl())), -1, 0);
		}
		if ((g_sprache == 2)) {
			p_drawtext(100, 150, ("Tu oro: " + p_str(p_gold_anzahl())), -1, 0);
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		if (((((v_mmouse_x > 90) && (v_mmouse_x < 190)) && (v_mmouse_y > 200)) && (v_mmouse_y < 220))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(90, 200, 100, 20, -1);
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(100, 200, a_nachricht_text(214, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_lernen = 1;
			}
		} else {
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_lernen = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(100, 200, a_nachricht_text(214, (1 + g_sprache)), -1, 0);
		}
		if (((((v_mmouse_x > 90) && (v_mmouse_x < 190)) && (v_mmouse_y > 220)) && (v_mmouse_y < 240))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(90, 220, 100, 20, -1);
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(100, 220, a_nachricht_text(416, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
			}
		} else {
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(100, 220, a_nachricht_text(416, (1 + g_sprache)), -1, 0);
		}
		p_stopdrawing();
		if ((v_lernen == 1)) {
			if ((a_spieler(g_akt_spieler).f_lehrer > 0)) {
				if ((p_gold_anzahl() >= v_kosten)) {
					p_gold_verlieren(v_kosten);
					a_spieler(g_akt_spieler).f_lehrer = (a_spieler(g_akt_spieler).f_lehrer - 1);
					v_raus = 1;
					switch (v_welcher) {
					case 1:
						a_spieler(g_akt_spieler).f_luck_score = (a_spieler(g_akt_spieler).f_luck_score + 1);
						break;
					case 2:
						a_spieler(g_akt_spieler).f_attack = (a_spieler(g_akt_spieler).f_attack + 1);
						break;
					case 3:
						a_spieler(g_akt_spieler).f_dexterity = (a_spieler(g_akt_spieler).f_dexterity + 1);
						break;
					case 4:
						a_spieler(g_akt_spieler).f_strength = (a_spieler(g_akt_spieler).f_strength + 1);
						break;
					case 5:
						a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + 3);
						a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 3);
						break;
					case 6:
						a_spieler(g_akt_spieler).f_speed = (a_spieler(g_akt_spieler).f_speed + 1);
						a_spieler(g_akt_spieler).f_maxspeed = (a_spieler(g_akt_spieler).f_maxspeed + 1);
						break;
					case 7:
						a_spieler(g_akt_spieler).f_perception = (a_spieler(g_akt_spieler).f_perception + 1);
						break;
					case 8:
						a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + 3);
						a_spieler(g_akt_spieler).f_maxmana = (a_spieler(g_akt_spieler).f_maxmana + 3);
						break;
					case 9:
						a_spieler(g_akt_spieler).f_power_score = (a_spieler(g_akt_spieler).f_power_score + 1);
						break;
					case 10:
						a_spieler(g_akt_spieler).f_circle = (a_spieler(g_akt_spieler).f_circle + 1);
						break;
					}
					p_nachricht(217, 1);
				} else {
					p_nachricht(215, 5);
					v_raus = 1;
				}
			} else {
				p_nachricht(232, 1);
			}
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	g_aktion = 1;
}

static int32_t p_lernen(int16_t v_x, int16_t v_y) {
	if (p_hat_eigenschaft(v_x, v_y, 32)) {
		if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_spinnenlehre))) {
			a_spieler(g_akt_spieler).f_spinnenlehre = (a_spieler(g_akt_spieler).f_spinnenlehre + 1);
			p_nachricht(625, 2);
		}
	}
	if (p_hat_eigenschaft(v_x, v_y, 34)) {
		if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_untotenlehre))) {
			a_spieler(g_akt_spieler).f_untotenlehre = (a_spieler(g_akt_spieler).f_untotenlehre + 1);
			p_nachricht(625, 2);
		}
	}
	if (p_hat_eigenschaft(v_x, v_y, 33)) {
		if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_goblinlehre))) {
			a_spieler(g_akt_spieler).f_goblinlehre = (a_spieler(g_akt_spieler).f_goblinlehre + 1);
			p_nachricht(625, 2);
		}
	}
	if ((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 1)) {
		if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_tierkunde))) {
			a_spieler(g_akt_spieler).f_tierkunde = (a_spieler(g_akt_spieler).f_tierkunde + 1);
			p_nachricht(625, 2);
		}
	}
	if ((a_monster(a_laby_monster(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level]).f_art == 4)) {
		if ((p_random(100) <= (5 - a_spieler(g_akt_spieler).f_pflanzenlehre))) {
			a_spieler(g_akt_spieler).f_pflanzenlehre = (a_spieler(g_akt_spieler).f_pflanzenlehre + 1);
			p_nachricht(625, 2);
		}
	}
}

static int32_t p_levelmodtext(int16_t v_welcher) {
	int16_t v_jb1 = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	p_sound(32);
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_clipsprite(14, 1, 1, 335, 335);
		p_displaytransparentsprite(14, 16, 16);
		v_x = 20;
		v_y = 35;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawingmode(1);
		switch (v_welcher) {
		case 1:
			p_drawtext(v_x, v_y, p_nachricht4(377), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(378), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(379), -1, 0);
			break;
		case 2:
			p_drawtext(v_x, v_y, p_nachricht4(380), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(381), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(382), -1, 0);
			break;
		case 3:
			p_drawtext(v_x, v_y, p_nachricht4(383), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(384), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(385), -1, 0);
			break;
		case 4:
			p_drawtext(v_x, v_y, p_nachricht4(386), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(387), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(388), -1, 0);
			break;
		case 5:
			p_drawtext(v_x, v_y, p_nachricht4(390), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(391), -1, 0);
			break;
		case 6:
			p_drawtext(v_x, v_y, p_nachricht4(392), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(393), -1, 0);
			break;
		case 7:
			p_drawtext(v_x, v_y, p_nachricht4(394), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(395), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(396), -1, 0);
			break;
		case 8:
			p_drawtext(v_x, v_y, p_nachricht4(397), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(398), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(399), -1, 0);
			break;
		case 9:
			p_drawtext(v_x, v_y, p_nachricht4(420), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(421), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(422), -1, 0);
			break;
		case 10:
			p_drawtext(v_x, v_y, p_nachricht4(423), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(424), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(425), -1, 0);
			break;
		case 11:
			p_drawtext(v_x, v_y, p_nachricht4(607), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(608), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(609), -1, 0);
			break;
		case 12:
			p_drawtext(v_x, v_y, p_nachricht4(651), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(652), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(653), -1, 0);
			break;
		case 13:
			p_drawtext(v_x, v_y, p_nachricht4(809), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(810), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(811), -1, 0);
			break;
		case 14:
			p_drawtext(v_x, v_y, p_nachricht4(812), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(813), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(814), -1, 0);
			break;
		case 15:
			p_drawtext(v_x, v_y, p_nachricht4(815), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(816), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(817), -1, 0);
			break;
		}
		p_stopdrawing();
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!((p_keyboardpushed(13) || (v_mmouse_rechts == 1)) || (v_jb1 != 0)));
	p_delay(g_mydelay);
}

static int32_t p_liste_leeren() {
	int16_t v_i = 0;
	int16_t v_j = 0;
	for (v_i = 1; v_i <= 177; v_i += 1) {
		for (v_j = 1; v_j <= 3; v_j += 1) {
			a_zauberliste(v_i).f_name[v_j] = "";
		}
	}
}

static int32_t p_load(std::string v_name) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_k = 0;
	int16_t v_load = 0;
	int32_t v_nr_of_saves = 0;
	std::string v_version;
	int32_t v_y = 0;
	v_load = 0;
	if (p_readfile(0, ((g_environment + "/") + v_name))) {
		v_load = 1;
	} else {
		if (p_readfile(0, ("./" + v_name))) {
			v_load = 1;
		}
	}
	if ((v_load == 1)) {
		v_version = p_readstring(0);
		v_nr_of_saves = p_readword(0);
		if (((v_version != "10.06.2008") && (g_test == 0))) {
			p_nachricht(320, 3);
		} else {
			g_anz_spieler = p_readword(0);
			g_sprache = p_readword(0);
			g_anfangszeit = p_readstring(0);
			g_anz_levels = p_readword(0);
			for (v_j = 1; v_j <= 20; v_j += 1) {
				a_pilz(v_j).f_nr = p_readword(0);
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_pilz(v_j).f_wirkung[v_k] = p_readstring(0);
				}
			}
			for (v_j = 0; v_j <= 37; v_j += 1) {
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_gegenstand((75 + v_j)).f_name[v_k] = p_readstring(0);
				}
				a_gegenstand((75 + v_j)).f_art = p_readword(0);
				a_gegenstand((75 + v_j)).f_einkauf = p_readword(0);
				a_gegenstand((75 + v_j)).f_verkauf = p_readword(0);
			}
			for (v_j = 0; v_j <= 9; v_j += 1) {
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_gegenstand((65 + v_j)).f_name[v_k] = p_readstring(0);
				}
				a_gegenstand((65 + v_j)).f_art = p_readword(0);
				a_gegenstand((65 + v_j)).f_einkauf = p_readword(0);
				a_gegenstand((65 + v_j)).f_verkauf = p_readword(0);
			}
			for (v_j = 1; v_j <= 38; v_j += 1) {
				a_mischen(v_j).f_trank1 = p_readword(0);
				a_mischen(v_j).f_trank2 = p_readword(0);
				a_mischen(v_j).f_trank3 = p_readword(0);
			}
			for (v_j = 1; v_j <= 200; v_j += 1) {
				for (v_k = 1; v_k <= 200; v_k += 1) {
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_labyrinth(v_j, v_k).f_feld[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_labyrinth(v_j, v_k).f_lebenspunkte[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_labyrinth(v_j, v_k).f_objekt[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_labyrinth(v_j, v_k).f_status[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_automap(v_j, v_k).f_feld[v_y] = p_readword(0);
					}
				}
			}
			for (v_j = 1; v_j <= 200; v_j += 1) {
				for (v_k = 1; v_k <= 200; v_k += 1) {
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_monster(v_j, v_k).f_name[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_monster(v_j, v_k).f_graphic[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_monster(v_j, v_k).f_lifepoints[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_monster(v_j, v_k).f_status[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_monster(v_j, v_k).f_duration[v_y] = p_readword(0);
					}
				}
			}
			for (v_j = 1; v_j <= 200; v_j += 1) {
				for (v_k = 1; v_k <= 200; v_k += 1) {
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_item(v_j, v_k).f_name[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_item(v_j, v_k).f_anzahl[v_y] = p_readword(0);
					}
					for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
						a_laby_item(v_j, v_k).f_status[v_y] = p_readword(0);
					}
				}
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_raeume(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_raumx(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_raumy(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_ausgangx(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_ausgangy(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_eingangx(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_eingangy(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_sonderlevel(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_levelmod(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_groesse(v_j) = 0;
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_groesse(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_inhalt(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_mit_was(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_visionen(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_fluss(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_spinnenkoenigin(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_goblinkoenig(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
				a_untotenherr(v_j) = p_readword(0);
			}
			for (v_j = 1; v_j <= 40; v_j += 1) {
				for (v_k = 1; v_k <= g_anz_levels; v_k += 1) {
					a_haendler_objekte(v_j, v_k) = p_readword(0);
					a_haendler_schriftrolle(v_j, v_k) = p_readword(0);
					a_haendler_staerke(v_j, v_k) = p_readword(0);
				}
			}
			for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
				a_spieler(v_i).f_status = p_readword(0);
				a_spieler(v_i).f_verifikation = p_readstring(0);
				a_spieler(v_i).f_level = p_readword(0);
				a_spieler(v_i).f_maxlevel = p_readword(0);
				a_spieler(v_i).f_maennchen = p_readword(0);
				a_spieler(v_i).f_lifepoints = p_readword(0);
				a_spieler(v_i).f_maxlifepoints = p_readword(0);
				a_spieler(v_i).f_lifegain = p_readword(0);
				a_spieler(v_i).f_mana = p_readword(0);
				a_spieler(v_i).f_maxmana = p_readword(0);
				a_spieler(v_i).f_managain = p_readword(0);
				a_spieler(v_i).f_attack = p_readword(0);
				a_spieler(v_i).f_dexterity = p_readword(0);
				a_spieler(v_i).f_strength = p_readword(0);
				a_spieler(v_i).f_maxspeed = p_readword(0);
				a_spieler(v_i).f_speed = p_readword(0);
				a_spieler(v_i).f_perception = p_readword(0);
				a_spieler(v_i).f_luck_score = p_readword(0);
				a_spieler(v_i).f_power_score = p_readword(0);
				a_spieler(v_i).f_circle = p_readword(0);
				a_spieler(v_i).f_magieresistenz = p_readword(0);
				a_spieler(v_i).f_spellweaving = p_readword(0);
				a_spieler(v_i).f_style = p_readword(0);
				a_spieler(v_i).f_light = p_readword(0);
				a_spieler(v_i).f_hunger = p_readword(0);
				a_spieler(v_i).f_durst = p_readword(0);
				a_spieler(v_i).f_betrunken = p_readword(0);
				a_spieler(v_i).f_weisheit = p_readword(0);
				a_spieler(v_i).f_schleichen = p_readword(0);
				a_spieler(v_i).f_mks = p_readword(0);
				a_spieler(v_i).f_fluch = p_readword(0);
				a_spieler(v_i).f_fluchdauer = p_readword(0);
				a_spieler(v_i).f_krankheit = p_readword(0);
				a_spieler(v_i).f_krankheitdauer = p_readword(0);
				a_spieler(v_i).f_gift = p_readword(0);
				a_spieler(v_i).f_giftdauer = p_readword(0);
				a_spieler(v_i).f_verhungern = p_readword(0);
				a_spieler(v_i).f_verdursten = p_readword(0);
				a_spieler(v_i).f_lifepointgegenstand = p_readword(0);
				a_spieler(v_i).f_managegenstand = p_readword(0);
				a_spieler(v_i).f_staerkegegenstand = p_readword(0);
				a_spieler(v_i).f_zugweitegegenstand = p_readword(0);
				a_spieler(v_i).f_dexteritygegenstand = p_readword(0);
				a_spieler(v_i).f_gluecksgegenstand = p_readword(0);
				a_spieler(v_i).f_bogentreffergegenstand = p_readword(0);
				a_spieler(v_i).f_bogenschadengegenstand = p_readword(0);
				a_spieler(v_i).f_powergegenstand = p_readword(0);
				a_spieler(v_i).f_perceptiongegenstand = p_readword(0);
				a_spieler(v_i).f_attackgegenstand = p_readword(0);
				a_spieler(v_i).f_stealthgegenstand = p_readword(0);
				a_spieler(v_i).f_damagegegenstand = p_readword(0);
				a_spieler(v_i).f_lichtgegenstand = p_readword(0);
				a_spieler(v_i).f_diebstahlgegenstand = p_readword(0);
				a_spieler(v_i).f_goblinlehre = p_readword(0);
				a_spieler(v_i).f_spinnenlehre = p_readword(0);
				a_spieler(v_i).f_untotenlehre = p_readword(0);
				a_spieler(v_i).f_pflanzenlehre = p_readword(0);
				a_spieler(v_i).f_tierkunde = p_readword(0);
				a_spieler(v_i).f_fallenlehre = p_readword(0);
				a_spieler(v_i).f_giftlehre = p_readword(0);
				a_spieler(v_i).f_pos_zaubermenue = p_readword(0);
				a_spieler(v_i).f_dumm = p_readword(0);
				a_spieler(v_i).f_face = p_readword(0);
				a_spieler(v_i).f_hinterhalt = p_readword(0);
				a_spieler(v_i).f_portal = p_readword(0);
				a_spieler(v_i).f_teleport = p_readword(0);
				a_spieler(v_i).f_nexus = p_readword(0);
				a_spieler(v_i).f_stehlen = p_readword(0);
				a_spieler(v_i).f_schriftrolle = p_readword(0);
				a_spieler(v_i).f_zauberbuch = p_readword(0);
				a_spieler(v_i).f_kessel = p_readword(0);
				a_spieler(v_i).f_armageddon = p_readword(0);
				a_spieler(v_i).f_pestilence = p_readword(0);
				a_spieler(v_i).f_drachenform = p_readword(0);
				a_spieler(v_i).f_macht = p_readword(0);
				a_spieler(v_i).f_heal = p_readword(0);
				a_spieler(v_i).f_udjat_ben = p_readword(0);
				a_spieler(v_i).f_akt_zauber = p_readword(0);
				a_spieler(v_i).f_schule = p_readstring(0);
				a_spieler(v_i).f_lehrer = p_readword(0);
				a_spieler(v_i).f_stabteile = p_readword(0);
				a_spieler(v_i).f_moves = p_readword(0);
				a_spieler(v_i).f_anker_x = p_readword(0);
				a_spieler(v_i).f_anker_y = p_readword(0);
				a_spieler(v_i).f_anker_level = p_readword(0);
				a_spieler(v_i).f_old_pos_x = p_readword(0);
				a_spieler(v_i).f_old_pos_y = p_readword(0);
				a_spieler(v_i).f_old_lp = p_readword(0);
				a_spieler(v_i).f_old_max_lp = p_readword(0);
				a_spieler(v_i).f_old_mp = p_readword(0);
				a_spieler(v_i).f_old_max_mp = p_readword(0);
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_spieler(v_i).f_sterbegrund[v_k] = p_readstring(0);
				}
				a_spieler(v_i).f_character_x = p_readword(0);
				a_spieler(v_i).f_character_y = p_readword(0);
				a_spieler(v_i).f_creature_typ = p_readword(0);
				a_spieler(v_i).f_creature_lifepoints = p_readword(0);
				a_spieler(v_i).f_creature_attack = p_readword(0);
				a_spieler(v_i).f_creature_schaden_min = p_readword(0);
				a_spieler(v_i).f_creature_schaden_max = p_readword(0);
				a_spieler(v_i).f_creature_speed = p_readword(0);
				a_spieler(v_i).f_creature_maxspeed = p_readword(0);
				a_spieler(v_i).f_creature_x = p_readword(0);
				a_spieler(v_i).f_creature_y = p_readword(0);
				a_spieler(v_i).f_creature_heading = p_readword(0);
				for (v_j = 1; v_j <= 15; v_j += 1) {
					a_aktive(v_j, v_i).f_nr = p_readword(0);
					a_aktive(v_j, v_i).f_staerke = p_readword(0);
					a_aktive(v_j, v_i).f_dauer = p_readword(0);
					a_aktive(v_j, v_i).f_source = p_readword(0);
				}
				for (v_j = 1; v_j <= 141; v_j += 1) {
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_skills(v_j, v_i).f_name[v_k] = p_readstring(0);
					}
					a_skills(v_j, v_i).f_nummer = p_readword(0);
					a_skills(v_j, v_i).f_kosten = p_readword(0);
					a_skills(v_j, v_i).f_gruppe = p_readword(0);
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_skills(v_j, v_i).f_beschreibung_1[v_k] = p_readstring(0);
						a_skills(v_j, v_i).f_beschreibung_2[v_k] = p_readstring(0);
					}
					a_skills(v_j, v_i).f_gewaehlt = p_readword(0);
					a_skills(v_j, v_i).f_gelocked = p_readword(0);
				}
				for (v_j = 1; v_j <= 50; v_j += 1) {
					a_inventory(v_j, v_i).f_name = p_readword(0);
					a_inventory(v_j, v_i).f_art = p_readword(0);
					a_inventory(v_j, v_i).f_benutzt = p_readword(0);
					a_inventory(v_j, v_i).f_anzahl = p_readword(0);
					a_inventory(v_j, v_i).f_status = p_readword(0);
					a_inventory(v_j, v_i).f_attri1 = p_readword(0);
					a_inventory(v_j, v_i).f_attri2 = p_readword(0);
					a_inventory(v_j, v_i).f_attri3 = p_readword(0);
					a_inventory(v_j, v_i).f_attri4 = p_readword(0);
					a_inventory(v_j, v_i).f_attri5 = p_readword(0);
				}
				for (v_j = 1; v_j <= 150; v_j += 1) {
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_zauber(v_j, v_i).f_name[v_k] = p_readstring(0);
					}
					a_zauber(v_j, v_i).f_level = p_readword(0);
					a_zauber(v_j, v_i).f_kosten = p_readword(0);
					a_zauber(v_j, v_i).f_dauer = p_readword(0);
					a_zauber(v_j, v_i).f_chance = p_readword(0);
					a_zauber(v_j, v_i).f_anhaltend = p_readword(0);
					a_zauber(v_j, v_i).f_erlernt = p_readword(0);
					a_zauber(v_j, v_i).f_art = p_readstring(0);
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_zauber(v_j, v_i).f_besch_1[v_k] = p_readstring(0);
						a_zauber(v_j, v_i).f_besch_2[v_k] = p_readstring(0);
					}
				}
				for (v_j = 1; v_j <= 10; v_j += 1) {
					a_schnellzauber(v_j, v_i) = p_readstring(0);
				}
				for (v_j = 1; v_j <= 8; v_j += 1) {
					a_schnellzauber2(v_j, v_i) = p_readstring(0);
				}
			}
			p_nachricht(299, 1);
			p_closefile(0);
			if ((g_silent == 0)) {
				p_stopmodule(-1);
			}
			throw Lv_geladen;
		}
	} else {
		p_nachricht(406, 3);
	}
}

static int32_t p_load_graphics() {
	if (p_openpack("graphics.pak")) {
		p_usejpegimagedecoder();
		p_usepngimagedecoder();
		p_catchsprite(17, p_nextpackfile());
		p_catchsprite(2, p_nextpackfile());
		p_catchsprite(3, p_nextpackfile());
		p_catchsprite(4, p_nextpackfile());
		p_catchsprite(5, p_nextpackfile());
		p_catchsprite(6, p_nextpackfile());
		p_catchsprite(7, p_nextpackfile());
		p_catchsprite(0, p_nextpackfile());
		p_catchsprite(19, p_nextpackfile());
		p_catchsprite(35, p_nextpackfile());
		p_catchsprite(14, p_nextpackfile());
		p_catchsprite(15, p_nextpackfile());
		p_catchsprite(27, p_nextpackfile());
		p_catchsprite(28, p_nextpackfile());
		p_catchsprite(29, p_nextpackfile());
		p_catchsprite(30, p_nextpackfile());
		p_catchsprite(31, p_nextpackfile());
		p_catchsprite(32, p_nextpackfile());
		p_catchsprite(33, p_nextpackfile());
		p_catchsprite(39, p_nextpackfile());
		p_catchsprite(40, p_nextpackfile());
		p_catchsprite(41, p_nextpackfile());
		p_catchsprite(42, p_nextpackfile());
		p_catchsprite(43, p_nextpackfile());
		p_catchsprite(44, p_nextpackfile());
		p_catchsprite(48, p_nextpackfile());
		p_catchsprite(49, p_nextpackfile());
		p_catchsprite(50, p_nextpackfile());
		p_catchsprite(51, p_nextpackfile());
		p_catchsprite(52, p_nextpackfile());
		p_catchsprite(11, p_nextpackfile());
		p_catchsprite(12, p_nextpackfile());
		p_catchsprite(9, p_nextpackfile());
		p_catchsprite(16, p_nextpackfile());
		p_catchsprite(25, p_nextpackfile());
		p_catchsprite(23, p_nextpackfile());
		p_catchsprite(46, p_nextpackfile());
		p_catchsprite(22, p_nextpackfile());
		p_catchsprite(20, p_nextpackfile());
		p_catchsprite(1, p_nextpackfile());
		p_catchsprite(18, p_nextpackfile());
		p_catchsprite(26, p_nextpackfile());
		p_catchsprite(8, p_nextpackfile());
		p_catchsprite(34, p_nextpackfile());
		p_catchsprite(36, p_nextpackfile());
		p_catchsprite(37, p_nextpackfile());
		p_catchsprite(38, p_nextpackfile());
		p_catchsprite(45, p_nextpackfile());
		p_catchsprite(47, p_nextpackfile());
		p_catchsprite(54, p_nextpackfile());
		p_catchsprite(55, p_nextpackfile());
		p_catchsprite(56, p_nextpackfile());
		p_catchsprite(57, p_nextpackfile());
		p_catchsprite(58, p_nextpackfile());
		p_catchsprite(59, p_nextpackfile());
		p_catchsprite(60, p_nextpackfile());
		p_catchsprite(61, p_nextpackfile());
		p_catchsprite(62, p_nextpackfile());
		p_catchsprite(63, p_nextpackfile());
		p_catchsprite(24, p_nextpackfile());
		p_catchsprite(64, p_nextpackfile());
		p_catchsprite(65, p_nextpackfile());
		p_catchsprite(66, p_nextpackfile());
		p_catchsprite(67, p_nextpackfile());
		p_catchsprite(68, p_nextpackfile());
		p_catchsprite(69, p_nextpackfile());
		p_catchsprite(70, p_nextpackfile());
	} else {
		exit(0);
	}
}

static int32_t p_load_settings() {
	int16_t v_load = 0;
	std::string v_zw;
	std::string v_zw2;
	v_load = 0;
	if (p_readfile(0, (g_environment + "/settings.txt"))) {
		v_load = 1;
	} else {
		if (p_readfile(0, "./settings.txt")) {
			v_load = 1;
		}
	}
	if ((v_load == 1)) {
		v_zw = p_readstring(0);
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 7) == "english")) {
			g_sprache = 0;
		}
		if ((p_mid(v_zw, 12, 6) == "german")) {
			g_sprache = 1;
		}
		if ((p_mid(v_zw, 12, 7) == "spanish")) {
			g_sprache = 2;
		}
		v_zw = p_readstring(0);
		v_zw2 = p_mid(v_zw, 12, 5);
		g_mydelay = p_val(v_zw2);
		v_zw = p_readstring(0);
		v_zw2 = p_mid(v_zw, 12, 5);
		g_mydelay2 = p_val(v_zw2);
		v_zw = p_readstring(0);
		v_zw2 = p_mid(v_zw, 12, 5);
		g_mydelay3 = p_val(v_zw2);
		v_zw = p_readstring(0);
		v_zw2 = p_mid(v_zw, 12, 5);
		g_mydelay4 = p_val(v_zw2);
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 2) == "no")) {
			g_joystick_used = 0;
		}
		if ((p_mid(v_zw, 12, 3) == "yes")) {
			g_joystick_used = 1;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 2) == "no")) {
			g_no_mouse = 0;
		}
		if ((p_mid(v_zw, 12, 3) == "yes")) {
			g_no_mouse = 1;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 2) == "no")) {
			g_win_mode = 1;
		}
		if ((p_mid(v_zw, 12, 3) == "yes")) {
			g_win_mode = 2;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 9, 3) == "yes")) {
			g_sound = 1;
		}
		if ((p_mid(v_zw, 9, 2) == "no")) {
			g_sound = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 9, 3) == "yes")) {
			g_music = 1;
		}
		if ((p_mid(v_zw, 9, 2) == "no")) {
			g_music = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 3) == "yes")) {
			g_klicking = 1;
		}
		if ((p_mid(v_zw, 12, 2) == "no")) {
			g_klicking = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 15, 3) == "yes")) {
			g_autopickup = 1;
		}
		if ((p_mid(v_zw, 15, 2) == "no")) {
			g_autopickup = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 11, 3) == "yes")) {
			g_knopf5 = 1;
		}
		if ((p_mid(v_zw, 11, 2) == "no")) {
			g_knopf5 = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 8, 3) == "yes")) {
			g_flaschen = 1;
		}
		if ((p_mid(v_zw, 8, 2) == "no")) {
			g_flaschen = 0;
		}
		v_zw = p_readstring(0);
		if ((p_mid(v_zw, 12, 3) == "yes")) {
			g_roomtest = 1;
		}
		if ((p_mid(v_zw, 12, 2) == "no")) {
			g_roomtest = 0;
		}
		p_closefile(0);
		if ((g_joystick_used == 1)) {
			if ((p_initjoystick() == 0)) {
			}
		}
	}
}

static int32_t p_load_sounds() {
	if (p_openpack("sounds.pak")) {
		p_catchsound(1, p_nextpackfile());
		p_catchsound(2, p_nextpackfile());
		p_catchsound(3, p_nextpackfile());
		p_catchsound(4, p_nextpackfile());
		p_catchsound(5, p_nextpackfile());
		p_catchsound(6, p_nextpackfile());
		p_catchsound(7, p_nextpackfile());
		p_catchsound(26, p_nextpackfile());
		p_catchsound(20, p_nextpackfile());
		p_catchsound(25, p_nextpackfile());
		p_catchsound(24, p_nextpackfile());
		p_catchsound(21, p_nextpackfile());
		p_catchsound(17, p_nextpackfile());
		p_catchsound(18, p_nextpackfile());
		p_catchsound(13, p_nextpackfile());
		p_catchsound(14, p_nextpackfile());
		p_catchsound(12, p_nextpackfile());
		p_catchsound(11, p_nextpackfile());
		p_catchsound(19, p_nextpackfile());
		p_catchsound(22, p_nextpackfile());
		p_catchsound(16, p_nextpackfile());
		p_catchsound(10, p_nextpackfile());
		p_catchsound(8, p_nextpackfile());
		p_catchsound(27, p_nextpackfile());
		p_catchsound(9, p_nextpackfile());
		p_catchsound(15, p_nextpackfile());
		p_catchsound(23, p_nextpackfile());
		p_catchsound(30, p_nextpackfile());
		p_catchsound(31, p_nextpackfile());
		p_catchsound(29, p_nextpackfile());
		p_catchsound(32, p_nextpackfile());
		p_catchsound(33, p_nextpackfile());
		p_catchsound(34, p_nextpackfile());
		p_catchsound(35, p_nextpackfile());
		p_catchsound(36, p_nextpackfile());
		p_catchsound(37, p_nextpackfile());
		p_catchsound(38, p_nextpackfile());
		p_catchsound(39, p_nextpackfile());
		p_catchsound(40, p_nextpackfile());
		p_catchsound(41, p_nextpackfile());
		p_catchsound(42, p_nextpackfile());
		p_catchsound(43, p_nextpackfile());
		p_catchsound(44, p_nextpackfile());
		p_catchsound(45, p_nextpackfile());
		p_catchsound(46, p_nextpackfile());
		p_catchsound(47, p_nextpackfile());
		p_loadmodule(0, "archonsoflight.xm");
		p_loadmodule(1, "ballada.mod");
	}
}

static int32_t p_loading_screen() {
	std::string v_akt_datum;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_load = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_raus = 0;
	int32_t v_result = 0;
	int32_t v_sel = 0;
	int32_t v_willi = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_raus = 0;
	v_load = 0;
	if (p_readfile(0, (g_environment + "/savenames.sav"))) {
		v_load = 1;
	} else {
		if (p_readfile(0, "./savenames.sav")) {
			v_load = 1;
		}
	}
	if ((v_load == 1)) {
		for (v_i = 1; v_i <= 10; v_i += 1) {
			a_savenames(v_i) = p_readstring(0);
			a_savedatum(v_i) = p_readstring(0);
		}
		p_closefile(0);
	}
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_yy = 65;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, v_yy, a_nachricht_text(570, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(190, v_yy, a_nachricht_text(569, (1 + g_sprache)), -1, 0);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = (v_sel - 1);
			if ((v_sel < 1)) {
				v_sel = 1;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = (v_sel + 1);
			if ((v_sel > 10)) {
				v_sel = 10;
			}
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		for (v_willi = 1; v_willi <= 10; v_willi += 1) {
			if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > (100 + (v_willi * 20)))) && (v_mmouse_y < (120 + (v_willi * 20))))) {
				p_frontcolor(p_rgb(150, 150, 150));
				p_box(40, (100 + (v_willi * 20)), 400, 20, -1);
				if ((v_sel == 1)) {
					p_frontcolor(p_rgb(1, 1, 255));
				} else {
					p_frontcolor(p_rgb(255, 255, 255));
				}
				p_drawtext(40, (100 + (v_willi * 20)), p_str(v_willi), -1, 0);
				if ((v_mmouse_links == 1)) {
					v_raus = 1;
					v_load = v_willi;
				}
			} else {
				if ((v_sel == v_willi)) {
					p_frontcolor(p_rgb(1, 1, 255));
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						v_raus = 1;
						v_load = v_willi;
					}
				} else {
					p_frontcolor(p_rgb(255, 255, 255));
				}
				p_drawtext(40, (100 + (v_willi * 20)), p_str(v_willi), -1, 0);
			}
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(150, (100 + (v_willi * 20)), a_savenames(v_willi), -1, 0);
			if ((a_savedatum(v_willi) != "")) {
				v_akt_datum = p_formatdate("%dd.%mm.%yyyy %hh:%ii", p_parsedate("%yyyy%mm%dd%hh%ii%ss", a_savedatum(v_willi)));
				p_drawtext(450, (100 + (v_willi * 20)), v_akt_datum, -1, 0);
			}
		}
		p_stopdrawing();
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
		p_delay(50);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	if ((v_load > 0)) {
		p_load((("laby" + p_str(v_load)) + ".sav"));
	}
}

static int32_t p_locken(int16_t v_welche) {
	int16_t v_iii = 0;
	int16_t v_jjj = 0;
	for (v_iii = 1; v_iii <= 216; v_iii += 1) {
		if ((a_unmoeglich(v_iii).f_name == a_skills(v_welche, g_akt_spieler).f_nummer)) {
			for (v_jjj = 0; v_jjj <= 140; v_jjj += 1) {
				if ((a_unmoeglich(v_iii).f_locked == a_skills(v_jjj, g_akt_spieler).f_nummer)) {
					a_skills(v_jjj, g_akt_spieler).f_gelocked += 1;
				}
			}
		}
	}
}

static int32_t p_los() {
	int32_t v_i = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	g_blocked = 0;
	if (((g_spell_x == 0) || (g_spell_y == 0))) {
		if ((g_spell_x < -1)) {
			v_x = ((a_spieler(g_akt_spieler).f_character_x + g_spell_x) + 1);
			v_y = a_spieler(g_akt_spieler).f_character_y;
			for (v_i = v_x; v_i <= a_spieler(g_akt_spieler).f_character_x; v_i += 1) {
				if ((p_blockiert(v_x, v_y, a_spieler(g_akt_spieler).f_level) == 1)) {
					g_blocked = 1;
				}
				v_x = (v_x + 1);
			}
		}
		if ((g_spell_x > 1)) {
			v_x = a_spieler(g_akt_spieler).f_character_x;
			v_y = a_spieler(g_akt_spieler).f_character_y;
			for (v_i = v_x; v_i <= ((a_spieler(g_akt_spieler).f_character_x + g_spell_x) - 1); v_i += 1) {
				if ((p_blockiert(v_x, v_y, a_spieler(g_akt_spieler).f_level) == 1)) {
					g_blocked = 1;
				}
				v_x = (v_x + 1);
			}
		}
		if ((g_spell_y < -1)) {
			v_x = a_spieler(g_akt_spieler).f_character_x;
			v_y = ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) + 1);
			for (v_i = v_y; v_i <= a_spieler(g_akt_spieler).f_character_y; v_i += 1) {
				if ((p_blockiert(v_x, v_y, a_spieler(g_akt_spieler).f_level) == 1)) {
					g_blocked = 1;
				}
				v_y = (v_y + 1);
			}
		}
		if ((g_spell_y > 1)) {
			v_x = a_spieler(g_akt_spieler).f_character_x;
			v_y = a_spieler(g_akt_spieler).f_character_y;
			for (v_i = v_y; v_i <= ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) - 1); v_i += 1) {
				if ((p_blockiert(v_x, v_y, a_spieler(g_akt_spieler).f_level) == 1)) {
					g_blocked = 1;
				}
				v_y = (v_y + 1);
			}
		}
	} else {
		g_blocked = 1;
	}
	if ((p_habich(156) == 1)) {
		g_blocked = 0;
	}
}

static int32_t p_luck() {
	int16_t v_akt_luck = 0;
	v_akt_luck = a_spieler(g_akt_spieler).f_luck_score;
	if ((p_habich(75) > 0)) {
		v_akt_luck = (v_akt_luck + p_habich(75));
	}
	v_akt_luck = (v_akt_luck + a_spieler(g_akt_spieler).f_gluecksgegenstand);
	if ((v_akt_luck > 15)) {
		v_akt_luck = 15;
	}
	return v_akt_luck;
}

static int32_t p_maennchen_auswaehlen() {
	int16_t v_back_button = 0;
	int16_t v_face = 0;
	int16_t v_frame = 0;
	int16_t v_gew = 0;
	int16_t v_gewaehlt = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_k = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_nr = 0;
	int16_t v_pos_aktuell_x = 0;
	int16_t v_pos_aktuell_y = 0;
	int32_t v_result = 0;
	int16_t v_warten = 0;
	int16_t v_warten2 = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_pos_aktuell_x = 1;
	v_pos_aktuell_y = 1;
	v_warten2 = 0;
	v_frame = 0;
	v_face = 2;
	v_gewaehlt = 0;
	v_warten = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if (p_keyboardpushed(27)) {
			if ((g_released == 0)) {
				v_result = p_releasemouse(1);
				g_released = 1;
				p_delay(g_mydelay);
			} else {
				v_result = p_releasemouse(0);
				g_released = 0;
				p_delay(g_mydelay);
			}
		}
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_pos_aktuell_x = (v_pos_aktuell_x + 1);
				if ((v_pos_aktuell_x > 7)) {
					v_pos_aktuell_x = 1;
					if ((g_maennchen_menu == 1)) {
						g_maennchen_menu = 2;
					}
				}
				v_warten2 = 10;
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_pos_aktuell_x = (v_pos_aktuell_x - 1);
				if ((v_pos_aktuell_x < 1)) {
					v_pos_aktuell_x = 7;
					if ((g_maennchen_menu == 2)) {
						g_maennchen_menu = 1;
					}
				}
				v_warten2 = 10;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_pos_aktuell_y = (v_pos_aktuell_y + 1);
				if ((v_pos_aktuell_y > 4)) {
					v_pos_aktuell_y = 1;
				}
				v_warten2 = 10;
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_pos_aktuell_y = (v_pos_aktuell_y - 1);
				if ((v_pos_aktuell_y < 1)) {
					v_pos_aktuell_y = 4;
				}
				v_warten2 = 10;
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(195, 25, ((a_nachricht_text(644, (1 + g_sprache)) + p_str(g_akt_spieler)) + ")"), -1, 0);
		p_stopdrawing();
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaysprite(55, 0, 0);
		p_clipsprite(63, 0, 0, 640, 17);
		p_displaysprite(63, 0, 46);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaysprite(58, 0, 464);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaysprite(56, 0, 0);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaysprite(59, 624, 0);
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
			if ((v_mmouse_links == 1)) {
				if ((g_maennchen_menu == 1)) {
					for (v_x = 1; v_x <= 7; v_x += 1) {
						for (v_y = 1; v_y <= 4; v_y += 1) {
							if (((((v_mmouse_x > (34 + (v_x * 64))) && (v_mmouse_x < (98 + (v_x * 64)))) && (v_mmouse_y > (8 + (v_y * 64)))) && (v_mmouse_y < (72 + (v_y * 64))))) {
								v_wohin = p_screenoutput();
								p_startdrawing(v_wohin);
								p_frontcolor(p_rgb(255, 255, 1));
								p_box((34 + (v_x * 64)), (8 + (v_y * 64)), 64, 64, -1);
								p_stopdrawing();
								a_spieler(g_akt_spieler).f_maennchen = (((v_y - 1) * 7) + v_x);
								v_gewaehlt = 1;
							}
						}
					}
				} else {
					for (v_x = 1; v_x <= 7; v_x += 1) {
						for (v_y = 1; v_y <= 4; v_y += 1) {
							if (((((v_mmouse_x > (34 + (v_x * 64))) && (v_mmouse_x < (98 + (v_x * 64)))) && (v_mmouse_y > (8 + (v_y * 64)))) && (v_mmouse_y < (72 + (v_y * 64))))) {
								v_wohin = p_screenoutput();
								p_startdrawing(v_wohin);
								p_frontcolor(p_rgb(255, 255, 1));
								p_box((34 + (v_x * 64)), (8 + (v_y * 64)), 64, 64, -1);
								p_stopdrawing();
								a_spieler(g_akt_spieler).f_maennchen = (((v_y + 3) * 7) + v_x);
								v_gewaehlt = 1;
							}
						}
					}
				}
			}
		}
		if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
			if ((g_maennchen_menu == 1)) {
				for (v_x = 1; v_x <= 7; v_x += 1) {
					for (v_y = 1; v_y <= 4; v_y += 1) {
						if (((v_x == v_pos_aktuell_x) && (v_y == v_pos_aktuell_y))) {
							v_wohin = p_screenoutput();
							p_startdrawing(v_wohin);
							p_frontcolor(p_rgb(255, 255, 1));
							p_box((34 + (v_x * 64)), (8 + (v_y * 64)), 64, 64, -1);
							p_stopdrawing();
							a_spieler(g_akt_spieler).f_maennchen = (((v_y - 1) * 7) + v_x);
							v_gewaehlt = 1;
						}
					}
				}
			} else {
				for (v_x = 1; v_x <= 7; v_x += 1) {
					for (v_y = 1; v_y <= 4; v_y += 1) {
						if (((v_x == v_pos_aktuell_x) && (v_y == v_pos_aktuell_y))) {
							v_wohin = p_screenoutput();
							p_startdrawing(v_wohin);
							p_frontcolor(p_rgb(255, 255, 1));
							p_box((34 + (v_x * 64)), (8 + (v_y * 64)), 64, 64, -1);
							p_stopdrawing();
							a_spieler(g_akt_spieler).f_maennchen = (((v_y + 3) * 7) + v_x);
							v_gewaehlt = 1;
						}
					}
				}
			}
		}
		if ((g_maennchen_menu == 1)) {
			v_nr = 1;
			for (v_j = 1; v_j <= 4; v_j += 1) {
				for (v_i = 1; v_i <= 7; v_i += 1) {
					v_gew = 0;
					for (v_k = 1; v_k <= (g_akt_spieler - 1); v_k += 1) {
						if ((v_nr == a_spieler(v_k).f_maennchen)) {
							v_gew = 1;
						}
					}
					if ((v_gew == 0)) {
						p_clipsprite(0, (((v_face * 32) * 2) + (v_frame * 32)), ((v_nr * 32) - 32), 32, 32);
						p_displaytransparentsprite(0, (50 + ((32 * v_i) * 2)), (25 + ((32 * v_j) * 2)));
					}
					v_nr = (v_nr + 1);
				}
			}
		} else {
			v_nr = 29;
			for (v_j = 1; v_j <= 4; v_j += 1) {
				for (v_i = 1; v_i <= 7; v_i += 1) {
					v_gew = 0;
					for (v_k = 1; v_k <= (g_akt_spieler - 1); v_k += 1) {
						if ((v_nr == a_spieler(v_k).f_maennchen)) {
							v_gew = 1;
						}
					}
					if ((v_gew == 0)) {
						p_clipsprite(0, (((v_face * 32) * 2) + (v_frame * 32)), ((v_nr * 32) - 32), 32, 32);
						p_displaytransparentsprite(0, (50 + ((32 * v_i) * 2)), (25 + ((32 * v_j) * 2)));
					}
					v_nr = (v_nr + 1);
				}
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(150, 150, 150));
		p_line((48 + ((32 * v_pos_aktuell_x) * 2)), (58 + ((32 * v_pos_aktuell_y) * 2)), 38, 0, -1);
		p_stopdrawing();
		v_warten = (v_warten + 1);
		p_delay(1);
		if ((v_warten > 3)) {
			v_warten = 1;
			v_frame = (v_frame + 1);
			if ((v_frame > 1)) {
				v_frame = 0;
			}
		}
		if ((g_maennchen_menu == 2)) {
			if (((((v_mmouse_x > 550) && (v_mmouse_x < 582)) && (v_mmouse_y > 350)) && (v_mmouse_y < 382))) {
				p_clipsprite(6, 96, 0, 32, 31);
				if ((v_mmouse_links == 1)) {
					g_maennchen_menu = 1;
				}
			} else {
				p_clipsprite(6, 32, 0, 32, 31);
			}
		} else {
			p_clipsprite(6, 288, 0, 32, 31);
		}
		p_displaytransparentsprite(6, 550, 350);
		if ((g_maennchen_menu == 1)) {
			if (((((v_mmouse_x > 584) && (v_mmouse_x < 616)) && (v_mmouse_y > 350)) && (v_mmouse_y < 382))) {
				p_clipsprite(6, 64, 0, 32, 31);
				if ((v_mmouse_links == 1)) {
					g_maennchen_menu = 2;
				}
			} else {
				p_clipsprite(6, 0, 0, 32, 31);
			}
		} else {
			p_clipsprite(6, 256, 0, 32, 31);
		}
		p_displaytransparentsprite(6, 584, 350);
		v_back_button = 0;
		if (((((v_mmouse_x > 529) && (v_mmouse_x < 616)) && (v_mmouse_y > 409)) && (v_mmouse_y < 439))) {
			p_clipsprite(4, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_back_button = 1;
			}
		} else {
			p_clipsprite(4, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(4, 530, 410);
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
		p_delay(50);
	} while (!((v_gewaehlt == 1) || (v_back_button == 1)));
	p_delay(g_mydelay);
	if ((v_back_button == 1)) {
		throw Lv_again;
	}
}

static int32_t p_mana_verlieren(int16_t v_spell) {
	int16_t v_kosten = 0;
	if ((g_schriftrolle == 0)) {
		v_kosten = p_zauberkosten(v_spell);
		if ((p_habich(82) > 0)) {
			v_kosten = (v_kosten / 2);
			if ((v_kosten <= 1)) {
				v_kosten = 1;
			}
		}
		a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana - v_kosten);
	}
}

static int32_t p_max(int16_t v_zahl1, int16_t v_zahl2) {
	if ((v_zahl1 < v_zahl2)) {
		return v_zahl2;
	}
	if ((v_zahl1 >= v_zahl2)) {
		return v_zahl1;
	}
}

static int32_t p_maxlife() {
	int16_t v_akt_maxlife = 0;
	int32_t v_okay = 0;
	v_akt_maxlife = a_spieler(g_akt_spieler).f_maxlifepoints;
	v_okay = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
		v_akt_maxlife = 1;
		v_okay = 1;
	}
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_akt_maxlife = (a_spieler(g_akt_spieler).f_maxlifepoints / 3);
		v_okay = 1;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_akt_maxlife = (a_spieler(g_akt_spieler).f_maxlifepoints / 3);
		v_okay = 1;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_akt_maxlife = (a_spieler(g_akt_spieler).f_maxlifepoints / 2);
		v_okay = 1;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_akt_maxlife = (a_spieler(g_akt_spieler).f_maxlifepoints * 3);
	}
	v_akt_maxlife = (v_akt_maxlife + a_spieler(g_akt_spieler).f_lifepointgegenstand);
	if ((a_skills(98, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_maxlife = (v_akt_maxlife + (a_spieler(g_akt_spieler).f_strength * 2));
	}
	if ((v_akt_maxlife > 150)) {
		v_akt_maxlife = 150;
	}
	if ((a_skills(121, g_akt_spieler).f_gewaehlt == 1)) {
		if ((v_akt_maxlife > 50)) {
			v_akt_maxlife = 50;
		}
	}
	return v_akt_maxlife;
}

static int32_t p_maxmana() {
	int32_t v_akt_maxlife = 0;
	int16_t v_akt_maxmana = 0;
	v_akt_maxmana = a_spieler(g_akt_spieler).f_maxmana;
	v_akt_maxmana = (v_akt_maxmana + a_spieler(g_akt_spieler).f_managegenstand);
	if ((v_akt_maxmana > 150)) {
		v_akt_maxmana = 150;
	}
	if ((a_skills(124, g_akt_spieler).f_gewaehlt == 1)) {
		if ((v_akt_maxlife > 50)) {
			v_akt_maxlife = 50;
		}
	}
	return v_akt_maxmana;
}

static int32_t p_maxspeed() {
	int16_t v_akt_maxspeed = 0;
	int16_t v_akt_save = 0;
	int32_t v_i = 0;
	int16_t v_kundschafter = 0;
	int16_t v_meister = 0;
	int32_t v_okay = 0;
	v_akt_maxspeed = a_spieler(g_akt_spieler).f_maxspeed;
	v_okay = 0;
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_akt_maxspeed = 10;
		v_okay = 1;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_akt_maxspeed = 10;
		v_okay = 1;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_akt_maxspeed = 10;
		v_okay = 1;
	}
	if (((p_habich(87) > 0) && (v_okay == 0))) {
		v_akt_maxspeed = 10;
		v_okay = 1;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_akt_maxspeed = 5;
	}
	v_akt_maxspeed = (v_akt_maxspeed + p_habich(40));
	v_akt_maxspeed = (v_akt_maxspeed + a_spieler(g_akt_spieler).f_zugweitegegenstand);
	v_kundschafter = 0;
	for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
		if ((a_skills(78, v_i).f_gewaehlt == 1)) {
			v_kundschafter = 2;
		}
	}
	v_akt_maxspeed = (v_akt_maxspeed + v_kundschafter);
	v_meister = 0;
	v_akt_save = g_akt_spieler;
	for (g_akt_spieler = 1; g_akt_spieler <= g_anz_spieler; g_akt_spieler += 1) {
		if ((p_habich(141) > 0)) {
			v_meister = 2;
		}
	}
	v_akt_maxspeed = (v_akt_maxspeed + v_meister);
	g_akt_spieler = v_akt_save;
	if ((a_spieler(g_akt_spieler).f_schleichen > 0)) {
		v_akt_maxspeed = (v_akt_maxspeed / 2);
	}
	v_akt_maxspeed = (v_akt_maxspeed - p_belastung());
	v_akt_maxspeed = (v_akt_maxspeed - a_spieler(g_akt_spieler).f_krankheit);
	if ((a_skills(135, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_maxspeed = (v_akt_maxspeed / 2);
		if ((v_akt_maxspeed < 1)) {
			v_akt_maxspeed = 1;
		}
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 5)) {
		v_akt_maxspeed = 1;
	}
	if ((v_akt_maxspeed <= 1)) {
		v_akt_maxspeed = 1;
	}
	if ((v_akt_maxspeed > 25)) {
		v_akt_maxspeed = 25;
	}
	return v_akt_maxspeed;
}

static int32_t p_min(int16_t v_zahl1, int16_t v_zahl2) {
	if ((v_zahl1 > v_zahl2)) {
		return v_zahl2;
	}
	if ((v_zahl1 <= v_zahl2)) {
		return v_zahl1;
	}
}

static int32_t p_mischung(int16_t v_feld) {
	int16_t v_geg = 0;
	int16_t v_gewa = 0;
	int16_t v_prob = 0;
	int32_t v_welche = 0;
	v_geg = 0;
	v_welche = p_select_inventory(729);
	v_gewa = 0;
	if ((v_feld == v_welche)) {
		p_nachricht(731, 1);
	} else {
		if ((a_gegenstand(a_inventory(v_welche, g_akt_spieler).f_name).f_art == 4)) {
			v_prob = a_mischen((a_inventory(v_welche, g_akt_spieler).f_name - 75)).f_trank3;
			p_leeren(v_feld);
			p_leeren(v_welche);
			if ((v_prob == 9999)) {
				p_nachricht(732, 1);
				p_spielerschaden(2, 1, 5);
			} else {
				p_in_rucksack(v_prob, 1);
				p_nachricht(733, 1);
			}
		} else {
			p_nachricht(730, 1);
		}
	}
}

static int32_t p_misslungen() {
	int32_t v_skt_spieler = 0;
	if ((p_random(1000) <= 5)) {
		p_nachricht(738, 2);
		p_spielerschaden((2 + p_random((a_spieler(v_skt_spieler).f_level / 3))), 3, 15);
	} else {
		p_nachricht(48, 2);
	}
}

static int32_t p_monster_angriff(int16_t v_x_r, int16_t v_y_r) {
	int32_t v_aktaktschild = 0;
	int16_t v_aktarmor = 0;
	int16_t v_akthandschuhe = 0;
	int16_t v_akthelm = 0;
	int16_t v_aktruestung = 0;
	int16_t v_aktschild = 0;
	int16_t v_aktstiefel = 0;
	int16_t v_angriff = 0;
	int16_t v_ausweichen = 0;
	int16_t v_brechfaktor = 0;
	int16_t v_chance = 0;
	int16_t v_counter = 0;
	int16_t v_egon = 0;
	int8_t v_geg = 0;
	int16_t v_geklaut = 0;
	int32_t v_habich = 0;
	int16_t v_hugo = 0;
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_k = 0;
	int16_t v_schaden = 0;
	int32_t v_schaden_save = 0;
	int16_t v_schleichen = 0;
	int16_t v_schutz = 0;
	std::string v_temp_text;
	int16_t v_wasele = 0;
	int32_t v_wohin = 0;
	int32_t v_xx = 0;
	int32_t v_yy = 0;
	int32_t v_zaehler = 0;
	int32_t v_zw_x = 0;
	int32_t v_zw_y = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	v_ausweichen = 0;
	if ((((a_skills(6, g_akt_spieler).f_gewaehlt == 1) || (a_spieler(g_akt_spieler).f_style == 6)) && (p_random(100) > 50))) {
		v_ausweichen = 1;
	}
	v_schleichen = 0;
	if ((a_spieler(g_akt_spieler).f_schleichen > 0)) {
		if ((a_skills(73, g_akt_spieler).f_gewaehlt == 1)) {
			v_chance = ((p_reflexe() + p_luck()) * 2);
		} else {
			v_chance = (p_reflexe() + p_luck());
		}
		if ((a_laby_monster(v_x_r, v_y_r).f_status[a_spieler(g_akt_spieler).f_level] == 5)) {
			v_chance = (v_chance * 2);
		}
		if ((v_chance > 90)) {
			v_chance = 90;
		}
		if (((p_random(100) <= v_chance) && (a_laby_monster(v_x_r, v_y_r).f_status[a_spieler(g_akt_spieler).f_level] != 1))) {
			v_schleichen = 1;
		}
	}
	if (((v_ausweichen == 0) && (v_schleichen == 0))) {
		v_angriff = 50;
		if ((p_hat_eigenschaft(v_x_r, v_y_r, 32) && (a_spinnenkoenigin(a_spieler(g_akt_spieler).f_level) == 1))) {
			v_angriff = (v_angriff + 20);
		}
		if ((p_hat_eigenschaft(v_x_r, v_y_r, 33) && (a_goblinkoenig(a_spieler(g_akt_spieler).f_level) == 1))) {
			v_angriff = (v_angriff + 20);
		}
		if ((p_hat_eigenschaft(v_x_r, v_y_r, 34) && (a_untotenherr(a_spieler(g_akt_spieler).f_level) == 1))) {
			v_angriff = (v_angriff + 20);
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 22)) {
			v_egon = (a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_angriff * 15);
		} else {
			v_egon = (a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_angriff * 10);
		}
		v_angriff = (v_angriff + v_egon);
		if ((p_habich(102) > 0)) {
			v_angriff = (v_angriff / 2);
		}
		if (((a_laby_monster(v_x_r, v_y_r).f_status[a_spieler(g_akt_spieler).f_level] >= 5) && (a_laby_monster(v_x_r, v_y_r).f_status[a_spieler(g_akt_spieler).f_level] < 6))) {
			v_angriff = (v_angriff / 2);
		}
		v_angriff = (v_angriff - (p_reflexe() * 10));
		if (((a_spieler(g_akt_spieler).f_style == 1) || (a_spieler(g_akt_spieler).f_style == 2))) {
			v_angriff = (v_angriff - 20);
		}
		if ((v_angriff > 90)) {
			v_angriff = 90;
		}
		if ((v_angriff < 10)) {
			v_angriff = 10;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 21)) {
			v_angriff = 90;
		}
		if (((p_random(99) + 1) < v_angriff)) {
			if ((p_hat_eigenschaft(v_x_r, v_y_r, 10) == 1)) {
				p_sound(25);
				if (((a_skills(100, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) > 50))) {
					p_nachricht(880, 2);
				} else {
					v_geg = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_name != 0) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 0))) {
							v_geg = 1;
						}
					}
					if ((v_geg == 1)) {
						v_geklaut = 0;
						v_counter = 1;
						do {
							v_wasele = (p_random(49) + 1);
							if (((a_inventory(v_wasele, g_akt_spieler).f_name != 0) && (a_inventory(v_wasele, g_akt_spieler).f_benutzt == 0))) {
								v_geklaut = 1;
								v_temp_text = (a_nachricht_text(871, (g_sprache + 1)) + a_gegenstand(a_inventory(v_wasele, g_akt_spieler).f_name).f_name[(g_sprache + 1)]);
								p_nachricht7(v_temp_text, 2);
								p_leeren(v_wasele);
							}
							v_counter = (v_counter + 1);
						} while (!((v_geklaut == 1) || (v_counter > 500)));
						if ((v_counter > 500)) {
							p_nachricht(37, 2);
						}
					} else {
						p_nachricht(37, 2);
					}
				}
			} else {
				p_zeige_unsichtbare(v_x_r, v_y_r);
				v_schaden = (p_random(a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke) + 1);
				if ((p_habich(124) > 0)) {
					p_nachricht(431, 2);
				} else {
					if ((p_hat_eigenschaft(v_x_r, v_y_r, 32) && (a_spinnenkoenigin(a_spieler(g_akt_spieler).f_level) == 1))) {
						v_schaden = (v_schaden + 2);
					}
					if ((p_hat_eigenschaft(v_x_r, v_y_r, 33) && (a_goblinkoenig(a_spieler(g_akt_spieler).f_level) == 1))) {
						v_schaden = (v_schaden + 2);
					}
					if ((p_hat_eigenschaft(v_x_r, v_y_r, 34) && (a_untotenherr(a_spieler(g_akt_spieler).f_level) == 1))) {
						v_schaden = (v_schaden + 2);
					}
					if ((a_spieler(g_akt_spieler).f_fluch == 7)) {
						v_schaden = (v_schaden * 2);
					}
					v_schutz = 0;
					if ((a_spieler(g_akt_spieler).f_fluch != 9)) {
						p_schutz();
						v_zaehler = 1;
						do {
							v_schutz = (p_random((g_schutz_max - 1)) + 1);
							v_zaehler = (v_zaehler + 1);
						} while (!((v_schutz >= g_schutz_min) || (v_zaehler > 500)));
						if ((v_zaehler > 500)) {
							v_schutz = 0;
						}
						v_schaden = (v_schaden - v_schutz);
					}
					if ((a_skills(8, g_akt_spieler).f_gewaehlt == 1)) {
						v_schaden = (v_schaden - 1);
					}
					if ((p_habich(143) > 1)) {
						v_schaden = (v_schaden - 3);
					}
					if ((v_schaden < 1)) {
						v_schaden = 0;
					}
					if (((p_random(100) > 50) && (v_schaden == 0))) {
						v_schaden = 1;
					}
					v_habich = 0;
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if ((a_aktive(v_i, g_akt_spieler).f_nr == 18)) {
							v_habich = v_i;
						}
					}
					if ((v_habich > 0)) {
						v_schaden_save = v_schaden;
						v_schaden = (v_schaden - a_aktive(v_habich, g_akt_spieler).f_staerke);
						if ((v_schaden < 0)) {
							v_schaden = 0;
						}
						a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints - v_schaden);
						a_aktive(v_habich, g_akt_spieler).f_staerke = (a_aktive(v_habich, g_akt_spieler).f_staerke - v_schaden_save);
						if ((a_aktive(v_habich, g_akt_spieler).f_staerke < 1)) {
							a_aktive(v_habich, g_akt_spieler).f_staerke = 0;
							a_aktive(v_habich, g_akt_spieler).f_dauer = 0;
							a_aktive(v_habich, g_akt_spieler).f_nr = 0;
						}
					}
					p_clipsprite(38, 0, 224, 32, 32);
					p_displaytransparentsprite(38, 160, 160);
					if (((a_labyrinth(v_x_r, v_y_r).f_feld[a_spieler(g_akt_spieler).f_level] >= 137) && (a_labyrinth(v_x_r, v_y_r).f_feld[a_spieler(g_akt_spieler).f_level] <= 148))) {
						p_sound(44);
					} else {
						if ((a_monster(a_labyrinth(v_x_r, v_y_r).f_objekt[a_spieler(g_akt_spieler).f_level]).f_sound == 0)) {
							p_sound((p_random(6) + 1));
						} else {
							p_sound(a_monster(a_labyrinth(v_x_r, v_y_r).f_objekt[a_spieler(g_akt_spieler).f_level]).f_sound);
						}
					}
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					if ((v_schaden < 10)) {
						v_xx = 172;
						v_yy = 168;
					}
					if ((v_schaden >= 10)) {
						v_xx = 166;
						v_yy = 168;
					}
					if ((v_schaden >= 100)) {
						v_xx = 163;
						v_yy = 168;
					}
					p_frontcolor(p_rgb(255, 255, 255));
					p_drawtext(v_xx, v_yy, p_str(v_schaden), -1, 0);
					p_stopdrawing();
					p_flipbuffers(1);
					p_delay(g_mydelay);
					a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints - v_schaden);
				}
				if (((v_schaden > 0) && (p_hat_eigenschaft(v_x_r, v_y_r, 3) == 1))) {
					if ((p_habich(130) > 0)) {
						p_nachricht(256, 4);
					} else {
						a_spieler(g_akt_spieler).f_gift = p_max(1, a_spieler(g_akt_spieler).f_gift);
						a_spieler(g_akt_spieler).f_giftdauer = ((a_spieler(g_akt_spieler).f_giftdauer + p_random(10)) + 1);
					}
				}
				if ((((v_schaden > 0) && (p_hat_eigenschaft(v_x_r, v_y_r, 44) == 1)) && (p_random(100) > 90))) {
					if ((a_spieler(g_akt_spieler).f_krankheit == 0)) {
						a_spieler(g_akt_spieler).f_krankheit = 1;
					} else {
						a_spieler(g_akt_spieler).f_krankheit = (a_spieler(g_akt_spieler).f_krankheit + 1);
					}
					a_spieler(g_akt_spieler).f_krankheitdauer = ((a_spieler(g_akt_spieler).f_krankheitdauer + p_random(30)) + 1);
				}
				v_brechfaktor = 5;
				if ((p_hat_eigenschaft(v_x_r, v_y_r, 40) == 1)) {
					v_brechfaktor = 25;
				}
				if ((a_spieler(g_akt_spieler).f_fluch == 25)) {
					v_brechfaktor = (v_brechfaktor * 2);
				}
				if (((p_random(2999) + 1) <= v_brechfaktor)) {
					v_aktruestung = 0;
					v_aktarmor = 0;
					v_aktschild = 0;
					v_akthelm = 0;
					v_akthandschuhe = 0;
					v_aktstiefel = 0;
					for (v_i = 1; v_i <= 50; v_i += 1) {
						if (((a_inventory(v_i, g_akt_spieler).f_art == 6) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_akthelm = v_i;
						}
						if (((a_inventory(v_i, g_akt_spieler).f_art == 7) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_akthandschuhe = v_i;
						}
						if (((a_inventory(v_i, g_akt_spieler).f_art == 8) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_aktstiefel = v_i;
						}
						if (((a_inventory(v_i, g_akt_spieler).f_art == 9) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_aktarmor = v_i;
						}
						if (((a_inventory(v_i, g_akt_spieler).f_art == 11) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
							v_aktschild = v_i;
						}
					}
					if ((((((v_akthelm > 0) || (v_akthandschuhe > 0)) || (v_aktstiefel > 0)) || (v_aktschild > 0)) || (v_aktarmor > 0))) {
						do {
							v_hugo = (p_random(4) + 1);
							switch (v_hugo) {
							case 1:
								if ((v_akthelm > 0)) {
									v_aktruestung = v_akthelm;
								}
								break;
							case 2:
								if ((v_akthandschuhe > 0)) {
									v_aktruestung = v_akthandschuhe;
								}
								break;
							case 3:
								if ((v_aktstiefel > 0)) {
									v_aktruestung = v_aktstiefel;
								}
								break;
							case 4:
								if ((v_aktarmor > 0)) {
									v_aktruestung = v_aktarmor;
								}
								break;
							case 5:
								if ((v_aktaktschild > 0)) {
									v_aktruestung = v_aktschild;
								}
								break;
							}
						} while (!(v_aktruestung > 0));
					}
					if ((v_aktruestung > 0)) {
						if ((a_inventory(v_aktruestung, g_akt_spieler).f_status == 1)) {
							a_inventory(v_aktruestung, g_akt_spieler).f_status = 2;
							p_nachricht(451, 3);
						}
						if ((a_inventory(v_aktruestung, g_akt_spieler).f_status == 0)) {
							a_inventory(v_aktruestung, g_akt_spieler).f_status = 1;
							p_nachricht(450, 3);
						}
					}
				}
				if ((a_spieler(g_akt_spieler).f_lifepoints < 1)) {
					for (v_k = 1; v_k <= 3; v_k += 1) {
						a_spieler(g_akt_spieler).f_sterbegrund[v_k] = (a_nachricht_text(626, 1) + a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_name[v_k]);
					}
					p_tot();
				}
			}
		} else {
			p_zeige_unsichtbare(v_x_r, v_y_r);
			p_sound(29);
			p_nachricht(291, 3);
		}
		if ((g_von_ferne == 0)) {
			v_zw_x = (v_x_r - a_spieler(g_akt_spieler).f_character_x);
			v_zw_y = (v_y_r - a_spieler(g_akt_spieler).f_character_y);
			if ((p_habich(71) == 1)) {
				p_clipsprite(38, 0, 224, 32, 32);
				p_displaytransparentsprite(38, ((v_zw_x * 32) + 160), ((v_zw_y * 32) + 160));
				p_sound((p_random(6) + 1));
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(((v_zw_x * 32) + 172), ((v_zw_y * 32) + 168), "1", -1, 0);
				p_stopdrawing();
				p_flipbuffers(1);
				p_delay(g_mydelay);
				a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] - 1);
				if ((a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
					a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
					p_setmonster(v_x_r, v_y_r, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0, 0);
					p_clipsprite(1, 128, 1, 32, 32);
					p_displaysprite(1, (160 + (v_zw_x * 32)), (160 + (v_zw_y * 32)));
				} else {
					p_laby_screen();
				}
			}
			if ((p_habich(70) == 1)) {
				p_clipsprite(38, 64, 224, 32, 32);
				p_displaytransparentsprite(38, ((v_zw_x * 32) + 160), ((v_zw_y * 32) + 160));
				p_sound((p_random(6) + 1));
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(((v_zw_x * 32) + 172), ((v_zw_y * 32) + 168), "1", -1, 0);
				p_stopdrawing();
				p_flipbuffers(1);
				p_delay(g_mydelay);
				a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] - 1);
				if ((a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
					a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
					p_setmonster(v_x_r, v_y_r, a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
					p_clipsprite(1, 128, 1, 32, 32);
					p_displaysprite(1, (160 + (v_zw_x * 32)), (160 + (v_zw_y * 32)));
				} else {
					p_laby_screen();
				}
			}
			if ((p_habich(154) == 1)) {
				p_clipsprite(38, 64, 224, 32, 32);
				p_displaytransparentsprite(38, ((v_zw_x * 32) + 160), ((v_zw_y * 32) + 160));
				p_sound((p_random(6) + 1));
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(((v_zw_x * 32) + 172), ((v_zw_y * 32) + 168), p_str(v_schaden), -1, 0);
				p_stopdrawing();
				p_flipbuffers(1);
				p_delay(g_mydelay);
				a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] - v_schaden);
				if ((a_laby_monster(v_x_r, v_y_r).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
					a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
					p_setmonster(v_x_r, v_y_r, a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
					p_clipsprite(1, 128, 1, 32, 32);
					p_displaysprite(1, (160 + (v_zw_x * 32)), (160 + (v_zw_y * 32)));
				} else {
					p_laby_screen();
				}
			}
		}
	} else {
		if ((v_schleichen > 0)) {
			p_nachricht(701, 2);
		} else {
			if ((v_ausweichen > 0)) {
				p_sound(29);
				p_nachricht(178, 3);
			}
		}
	}
}

static int32_t p_monster_angriff2(int16_t v_x_r, int16_t v_y_r) {
	int16_t v_angriff = 0;
	int16_t v_egon = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_schaden = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	v_angriff = 50;
	v_egon = (a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_angriff * 10);
	v_angriff = (v_angriff + v_egon);
	v_angriff = (v_angriff * 10);
	if ((v_angriff > 90)) {
		v_angriff = 90;
	}
	if ((v_angriff < 10)) {
		v_angriff = 10;
	}
	if (((p_random(99) + 1) < v_angriff)) {
		v_schaden = (p_random(a_monster(a_laby_monster(v_x_r, v_y_r).f_name[a_spieler(g_akt_spieler).f_level]).f_staerke) + 1);
		p_creature_schaden(v_schaden);
	} else {
		p_sound(29);
		p_nachricht(291, 3);
	}
}

static int32_t p_monster_random(int16_t v_level, int16_t v_sonderlevel) {
	int16_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_r = 0;
	int16_t v_zaehler = 0;
	switch (v_sonderlevel) {
	case 0:
		v_zaehler = 1;
		do {
			v_hugo = (p_random(169) + 1);
			v_zaehler = (v_zaehler + 1);
		} while (!(((a_monster(v_hugo).f_minlevel <= v_level) && (p_hat_eigenschaft2(v_hugo, 30) != 1)) || (v_zaehler > 500)));
		if ((v_zaehler > 500)) {
			v_hugo = 1;
		}
		if ((v_hugo == 121)) {
			if ((a_spinnenkoenigin(v_level) == 1)) {
				v_hugo = 19;
			} else {
				a_spinnenkoenigin(v_level) = 1;
			}
		}
		if ((v_hugo == 122)) {
			if ((a_goblinkoenig(v_level) == 1)) {
				v_hugo = v_r;
			} else {
				a_goblinkoenig(v_level) = 1;
			}
		}
		if ((v_hugo == 123)) {
			if ((a_untotenherr(v_level) == 1)) {
				v_hugo = 4;
			} else {
				a_untotenherr(v_level) = 1;
			}
		}
		break;
	case 1:
		v_i = (p_random(3) + 1);
		switch ((p_random(3) + 1)) {
		case 1:
			v_hugo = 51;
			break;
		case 2:
			v_hugo = 57;
			break;
		case 3:
			v_hugo = 64;
			break;
		case 4:
			v_hugo = 142;
			break;
		}
		break;
	case 2:
		switch ((p_random(5) + 1)) {
		case 1:
			v_hugo = 32;
			break;
		case 2:
			v_hugo = 35;
			break;
		case 3:
			v_hugo = 51;
			break;
		case 4:
			v_hugo = 53;
			break;
		case 5:
			v_hugo = 56;
			break;
		case 6:
			v_hugo = 67;
			break;
		}
		break;
	case 3:
		switch ((p_random(13) + 1)) {
		case 1:
			v_hugo = 4;
			break;
		case 2:
			v_hugo = 16;
			break;
		case 3:
			v_hugo = 20;
			break;
		case 4:
			v_hugo = 26;
			break;
		case 5:
			v_hugo = 29;
			break;
		case 6:
			v_hugo = 33;
			break;
		case 7:
			v_hugo = 40;
			break;
		case 8:
			v_hugo = 41;
			break;
		case 9:
			v_hugo = 42;
			break;
		case 10:
			v_hugo = 44;
			break;
		case 11:
			v_hugo = 54;
			break;
		case 12:
			v_hugo = 65;
			break;
		case 13:
			v_hugo = 99;
			break;
		case 14:
			v_hugo = 104;
			break;
		}
		break;
	case 4:
		switch ((p_random(15) + 1)) {
		case 1:
			v_hugo = 3;
			break;
		case 2:
			v_hugo = 5;
			break;
		case 3:
			v_hugo = 15;
			break;
		case 4:
			v_hugo = 21;
			break;
		case 5:
			v_hugo = 27;
			break;
		case 6:
			v_hugo = 67;
			break;
		case 7:
			v_hugo = 132;
			break;
		case 8:
			v_hugo = 133;
			break;
		case 9:
			v_hugo = 134;
			break;
		case 10:
			v_hugo = 135;
			break;
		case 11:
			v_hugo = 136;
			break;
		case 12:
			v_hugo = 137;
			break;
		case 13:
			v_hugo = 138;
			break;
		case 14:
			v_hugo = 139;
			break;
		case 15:
			v_hugo = 140;
			break;
		case 16:
			v_hugo = 141;
			break;
		}
		break;
	case 5:
		switch ((p_random(2) + 1)) {
		case 1:
			v_hugo = 9;
			break;
		case 2:
			v_hugo = 34;
			break;
		case 3:
			v_hugo = 100;
			break;
		}
		break;
	case 6:
		switch ((p_random(7) + 1)) {
		case 1:
			v_hugo = 7;
			break;
		case 2:
			v_hugo = 8;
			break;
		case 3:
			v_hugo = 10;
			break;
		case 4:
			v_hugo = 28;
			break;
		case 5:
			v_hugo = 31;
			break;
		case 6:
			v_hugo = 102;
			break;
		case 7:
			v_hugo = 39;
			break;
		case 8:
			v_hugo = 128;
			break;
		}
		break;
	case 7:
		switch ((p_random(7) + 1)) {
		case 1:
			v_hugo = 12;
			break;
		case 2:
			v_hugo = 20;
			break;
		case 3:
			v_hugo = 29;
			break;
		case 4:
			v_hugo = 37;
			break;
		case 5:
			v_hugo = 40;
			break;
		case 6:
			v_hugo = 47;
			break;
		case 7:
			v_hugo = 80;
			break;
		case 8:
			v_hugo = 131;
			break;
		}
		break;
	case 8:
		switch ((p_random(4) + 1)) {
		case 1:
			v_hugo = 19;
			break;
		case 2:
			v_hugo = 101;
			break;
		case 3:
			v_hugo = 46;
			break;
		case 4:
			v_hugo = 124;
			break;
		case 5:
			v_hugo = 125;
			break;
		}
		break;
	case 9:
		switch ((p_random(6) + 1)) {
		case 1:
			v_hugo = 6;
			break;
		case 2:
			v_hugo = 10;
			break;
		case 3:
			v_hugo = 18;
			break;
		case 4:
			v_hugo = 36;
			break;
		case 5:
			v_hugo = 90;
			break;
		case 6:
			v_hugo = 98;
			break;
		case 7:
			v_hugo = 106;
			break;
		}
		break;
	case 10:
		switch ((p_random(9) + 1)) {
		case 1:
			v_hugo = 38;
			break;
		case 2:
			v_hugo = 43;
			break;
		case 3:
			v_hugo = 48;
			break;
		case 4:
			v_hugo = 75;
			break;
		case 5:
			v_hugo = 76;
			break;
		case 6:
			v_hugo = 116;
			break;
		case 7:
			v_hugo = 117;
			break;
		case 8:
			v_hugo = 118;
			break;
		case 9:
			v_hugo = 119;
			break;
		case 10:
			v_hugo = 120;
			break;
		}
		break;
	case 11:
		switch ((p_random(11) + 1)) {
		case 1:
			v_hugo = 8;
			break;
		case 2:
			v_hugo = 10;
			break;
		case 3:
			v_hugo = 11;
			break;
		case 4:
			v_hugo = 13;
			break;
		case 5:
			v_hugo = 14;
			break;
		case 6:
			v_hugo = 16;
			break;
		case 7:
			v_hugo = 20;
			break;
		case 8:
			v_hugo = 28;
			break;
		case 9:
			v_hugo = 42;
			break;
		case 10:
			v_hugo = 113;
			break;
		case 11:
			v_hugo = 143;
			break;
		case 12:
			v_hugo = 150;
			break;
		}
		break;
	}
	return v_hugo;
}

static int32_t p_monster_setzen(int32_t v_level, int32_t v_welches) {
	int32_t v_hugo = 0;
	int16_t v_monstat = 0;
	int16_t v_x = 0;
	int16_t v_y = 0;
	int16_t v_zaehler = 0;
	v_x = 0;
	v_y = 0;
	v_zaehler = 1;
	do {
		v_x = (p_random((a_groesse(v_level) - 3)) + 2);
		v_y = (p_random((a_groesse(v_level) - 3)) + 2);
		v_zaehler = (v_zaehler + 1);
	} while (!((p_blockiert2(v_x, v_y, v_level) == 0) || (v_zaehler > 500)));
	if ((v_zaehler <= 500)) {
		v_monstat = 0;
		if (((p_random(100) > 90) || (a_levelmod(v_level) == 11))) {
			if (((p_random(100) > 50) && (a_levelmod(v_level) != 11))) {
				if ((p_hat_eigenschaft2(v_hugo, 29) == 1)) {
					v_monstat = 2;
				} else {
					v_monstat = 1;
				}
			} else {
				v_monstat = 1;
			}
		}
		p_setmonster(v_x, v_y, v_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, v_monstat, 0);
	}
}

static int32_t p_monsterkunde() {
	int16_t v_akt_nachricht = 0;
	int16_t v_akt_tile = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_mon = 0;
	int16_t v_okay = 0;
	int32_t v_result = 0;
	std::string v_tempart;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_yn = 0;
	int32_t v_yplus = 0;
	g_spell_x = 0;
	g_spell_y = 0;
	v_yplus = 20;
	p_feld_waehlen();
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_clipsprite(27, 1, 1, 335, 335);
		p_displaytransparentsprite(27, 16, 16);
		v_okay = 0;
		if (((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1) && (p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 19) == 0))) {
			v_okay = 1;
			v_x = 175;
			v_yn = 30;
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			v_mon = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level];
			p_drawtext(v_x, v_yn, p_nachricht5(115, v_mon), -1, 0);
			if (((a_skills(115, g_akt_spieler).f_gewaehlt == 1) || (g_monsterauge == 1))) {
				v_yn = (v_yn + v_yplus);
				v_tempart = "";
				switch (a_monster(v_mon).f_art) {
				case 1:
					v_tempart = a_nachricht_text(118, (1 + g_sprache));
					break;
				case 2:
					v_tempart = a_nachricht_text(119, (1 + g_sprache));
					break;
				case 3:
					v_tempart = a_nachricht_text(120, (1 + g_sprache));
					break;
				case 4:
					v_tempart = a_nachricht_text(121, (1 + g_sprache));
					break;
				case 5:
					v_tempart = a_nachricht_text(400, (1 + g_sprache));
					break;
				case 7:
					v_tempart = a_nachricht_text(401, (1 + g_sprache));
					break;
				case 8:
					v_tempart = a_nachricht_text(402, (1 + g_sprache));
					break;
				case 9:
					v_tempart = a_nachricht_text(403, (1 + g_sprache));
					break;
				case 10:
					v_tempart = a_nachricht_text(404, (1 + g_sprache));
					break;
				}
				p_drawtext(v_x, v_yn, p_nachricht6(116, v_tempart), -1, 0);
				v_yn = (v_yn + v_yplus);
				p_drawtext(v_x, v_yn, p_nachricht6(55, p_str(a_monster(v_mon).f_lebenspunkte)), -1, 0);
				v_yn = (v_yn + v_yplus);
				p_drawtext(v_x, v_yn, p_nachricht6(117, ((p_str(a_monster(v_mon).f_angriff) + "/") + p_str(a_monster(v_mon).f_abwehr))), -1, 0);
				v_yn = (v_yn + v_yplus);
				p_drawtext(v_x, v_yn, p_nachricht6(54, p_str(a_monster(v_mon).f_staerke)), -1, 0);
				v_yn = (v_yn + v_yplus);
				p_drawtext(v_x, v_yn, p_nachricht6(87, p_str(a_monster(v_mon).f_ruestung)), -1, 0);
				p_frontcolor(p_rgb(255, 255, 255));
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft1, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft2, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft3, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft4, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft5, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft6, v_yn);
				v_yn = (v_yn + v_yplus);
				p_explain(a_monster(v_mon).f_eigenschaft7, v_yn);
			}
			p_stopdrawing();
		}
		if ((v_okay == 0)) {
			v_akt_tile = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_feld[a_spieler(g_akt_spieler).f_level];
			if ((v_akt_tile <= 211)) {
				switch (v_akt_tile) {
				case 0:
					v_akt_nachricht = 752;
					break;
				case 1:
					v_akt_nachricht = 753;
					break;
				case 2:
					v_akt_nachricht = 754;
					break;
				case 3:
					v_akt_nachricht = 755;
					break;
				case 4:
					v_akt_nachricht = 756;
					break;
				case 5:
					v_akt_nachricht = 757;
					break;
				case 6:
					v_akt_nachricht = 758;
					break;
				case 7:
					v_akt_nachricht = 759;
					break;
				case 8:
					v_akt_nachricht = 760;
					break;
				case 9:
					v_akt_nachricht = 8;
					break;
				case 15:
					v_akt_nachricht = 761;
					break;
				case 16:
					v_akt_nachricht = 761;
					break;
				case 17:
					v_akt_nachricht = 762;
					break;
				case 18:
					v_akt_nachricht = 762;
					break;
				case 19:
					v_akt_nachricht = 763;
					break;
				case 20:
					v_akt_nachricht = 756;
					break;
				case 21:
					v_akt_nachricht = 764;
					break;
				case 22:
					v_akt_nachricht = 756;
					break;
				case 23:
					v_akt_nachricht = 756;
					break;
				case 24:
					v_akt_nachricht = 756;
					break;
				case 25:
					v_akt_nachricht = 756;
					break;
				case 26:
					v_akt_nachricht = 756;
					break;
				case 27:
					v_akt_nachricht = 756;
					break;
				case 28:
					v_akt_nachricht = 756;
					break;
				case 29:
					v_akt_nachricht = 756;
					break;
				case 30:
					v_akt_nachricht = 756;
					break;
				case 31:
					v_akt_nachricht = 765;
					break;
				case 32:
					v_akt_nachricht = 766;
					break;
				case 33:
					v_akt_nachricht = 767;
					break;
				case 34:
					v_akt_nachricht = 768;
					break;
				case 35:
					v_akt_nachricht = 768;
					break;
				case 36:
					v_akt_nachricht = 768;
					break;
				case 37:
					v_akt_nachricht = 768;
					break;
				case 38:
					v_akt_nachricht = 769;
					break;
				case 39:
					v_akt_nachricht = 768;
					break;
				case 40:
					v_akt_nachricht = 770;
					break;
				case 41:
					v_akt_nachricht = 770;
					break;
				case 42:
					v_akt_nachricht = 770;
					break;
				case 43:
					v_akt_nachricht = 771;
					break;
				case 44:
					v_akt_nachricht = 771;
					break;
				case 45:
					v_akt_nachricht = 771;
					break;
				case 46:
					v_akt_nachricht = 757;
					break;
				case 47:
					v_akt_nachricht = 772;
					break;
				case 48:
					v_akt_nachricht = 763;
					break;
				case 49:
					v_akt_nachricht = 773;
					break;
				case 50:
					v_akt_nachricht = 773;
					break;
				case 51:
					v_akt_nachricht = 773;
					break;
				case 52:
					v_akt_nachricht = 773;
					break;
				case 53:
					v_akt_nachricht = 774;
					break;
				case 54:
					v_akt_nachricht = 775;
					break;
				case 55:
					v_akt_nachricht = 776;
					break;
				case 56:
					v_akt_nachricht = 777;
					break;
				case 57:
					v_akt_nachricht = 777;
					break;
				case 58:
					v_akt_nachricht = 777;
					break;
				case 59:
					v_akt_nachricht = 777;
					break;
				case 60:
					v_akt_nachricht = 777;
					break;
				case 61:
					v_akt_nachricht = 777;
					break;
				case 62:
					v_akt_nachricht = 758;
					break;
				case 63:
					v_akt_nachricht = 758;
					break;
				case 64:
					v_akt_nachricht = 778;
					break;
				case 65:
					v_akt_nachricht = 770;
					break;
				case 66:
					v_akt_nachricht = 778;
					break;
				case 67:
					v_akt_nachricht = 758;
					break;
				case 68:
					v_akt_nachricht = 758;
					break;
				case 69:
					v_akt_nachricht = 757;
					break;
				case 70:
					v_akt_nachricht = 764;
					break;
				case 71:
					v_akt_nachricht = 764;
					break;
				case 72:
					v_akt_nachricht = 774;
					break;
				case 73:
					v_akt_nachricht = 779;
					break;
				case 74:
					v_akt_nachricht = 780;
					break;
				case 75:
					v_akt_nachricht = 756;
					break;
				case 77:
					v_akt_nachricht = 781;
					break;
				case 78:
					v_akt_nachricht = 782;
					break;
				case 79:
					v_akt_nachricht = 782;
					break;
				case 80:
					v_akt_nachricht = 783;
					break;
				case 81:
					v_akt_nachricht = 784;
					break;
				case 82:
					v_akt_nachricht = 778;
					break;
				case 83:
					v_akt_nachricht = 778;
					break;
				case 84:
					v_akt_nachricht = 778;
					break;
				case 85:
					v_akt_nachricht = 778;
					break;
				case 86:
					v_akt_nachricht = 778;
					break;
				case 87:
					v_akt_nachricht = 778;
					break;
				case 88:
					v_akt_nachricht = 753;
					break;
				case 89:
					v_akt_nachricht = 756;
					break;
				case 90:
					v_akt_nachricht = 753;
					break;
				case 91:
					v_akt_nachricht = 756;
					break;
				case 94:
					v_akt_nachricht = 787;
					break;
				case 95:
					v_akt_nachricht = 787;
					break;
				case 96:
					v_akt_nachricht = 788;
					break;
				case 97:
					v_akt_nachricht = 758;
					break;
				case 100:
					v_akt_nachricht = 757;
					break;
				case 101:
					v_akt_nachricht = 753;
					break;
				case 102:
					v_akt_nachricht = 753;
					break;
				case 103:
					v_akt_nachricht = 753;
					break;
				case 104:
					v_akt_nachricht = 753;
					break;
				case 105:
					v_akt_nachricht = 756;
					break;
				case 106:
					v_akt_nachricht = 756;
					break;
				case 107:
					v_akt_nachricht = 756;
					break;
				case 108:
					v_akt_nachricht = 756;
					break;
				case 109:
					v_akt_nachricht = 756;
					break;
				case 110:
					v_akt_nachricht = 789;
					break;
				case 112:
					v_akt_nachricht = 790;
					break;
				case 113:
					v_akt_nachricht = 756;
					break;
				case 114:
					v_akt_nachricht = 756;
					break;
				case 115:
					v_akt_nachricht = 756;
					break;
				case 116:
					v_akt_nachricht = 756;
					break;
				case 118:
					v_akt_nachricht = 791;
					break;
				case 119:
					v_akt_nachricht = 792;
					break;
				case 120:
					v_akt_nachricht = 778;
					break;
				case 121:
					v_akt_nachricht = 778;
					break;
				case 122:
					v_akt_nachricht = 785;
					break;
				case 123:
					v_akt_nachricht = 785;
					break;
				case 124:
					v_akt_nachricht = 785;
					break;
				case 125:
					v_akt_nachricht = 785;
					break;
				case 126:
					v_akt_nachricht = 785;
					break;
				case 127:
					v_akt_nachricht = 785;
					break;
				case 128:
					v_akt_nachricht = 785;
					break;
				case 129:
					v_akt_nachricht = 785;
					break;
				case 130:
					v_akt_nachricht = 785;
					break;
				case 131:
					v_akt_nachricht = 785;
					break;
				case 135:
					v_akt_nachricht = 793;
					break;
				case 136:
					v_akt_nachricht = 777;
					break;
				case 137:
					v_akt_nachricht = 786;
					break;
				case 138:
					v_akt_nachricht = 786;
					break;
				case 139:
					v_akt_nachricht = 786;
					break;
				case 140:
					v_akt_nachricht = 786;
					break;
				case 141:
					v_akt_nachricht = 786;
					break;
				case 142:
					v_akt_nachricht = 786;
					break;
				case 143:
					v_akt_nachricht = 786;
					break;
				case 144:
					v_akt_nachricht = 786;
					break;
				case 145:
					v_akt_nachricht = 786;
					break;
				case 146:
					v_akt_nachricht = 786;
					break;
				case 147:
					v_akt_nachricht = 786;
					break;
				case 148:
					v_akt_nachricht = 786;
					break;
				case 149:
					v_akt_nachricht = 794;
					break;
				case 150:
					v_akt_nachricht = 795;
					break;
				case 151:
					v_akt_nachricht = 795;
					break;
				case 152:
					v_akt_nachricht = 795;
					break;
				case 153:
					v_akt_nachricht = 795;
					break;
				case 154:
					v_akt_nachricht = 795;
					break;
				case 155:
					v_akt_nachricht = 795;
					break;
				case 156:
					v_akt_nachricht = 795;
					break;
				case 157:
					v_akt_nachricht = 795;
					break;
				case 158:
					v_akt_nachricht = 794;
					break;
				case 159:
					v_akt_nachricht = 794;
					break;
				case 160:
					v_akt_nachricht = 8;
					break;
				case 161:
					v_akt_nachricht = 758;
					break;
				case 162:
					v_akt_nachricht = 758;
					break;
				case 163:
					v_akt_nachricht = 757;
					break;
				case 164:
					v_akt_nachricht = 796;
					break;
				case 165:
					v_akt_nachricht = 753;
					break;
				case 166:
					v_akt_nachricht = 780;
					break;
				case 167:
					v_akt_nachricht = 780;
					break;
				case 168:
					v_akt_nachricht = 780;
					break;
				case 169:
					v_akt_nachricht = 780;
					break;
				case 170:
					v_akt_nachricht = 780;
					break;
				case 171:
					v_akt_nachricht = 780;
					break;
				case 172:
					v_akt_nachricht = 780;
					break;
				case 173:
					v_akt_nachricht = 780;
					break;
				case 174:
					v_akt_nachricht = 780;
					break;
				case 175:
					v_akt_nachricht = 780;
					break;
				case 176:
					v_akt_nachricht = 780;
					break;
				case 177:
					v_akt_nachricht = 797;
					break;
				case 178:
					v_akt_nachricht = 797;
					break;
				case 179:
					v_akt_nachricht = 797;
					break;
				case 180:
					v_akt_nachricht = 797;
					break;
				case 181:
					v_akt_nachricht = 797;
					break;
				case 182:
					v_akt_nachricht = 798;
					break;
				case 183:
					v_akt_nachricht = 798;
					break;
				case 184:
					v_akt_nachricht = 798;
					break;
				case 185:
					v_akt_nachricht = 798;
					break;
				case 186:
					v_akt_nachricht = 799;
					break;
				case 187:
					v_akt_nachricht = 799;
					break;
				case 188:
					v_akt_nachricht = 780;
					break;
				case 189:
					v_akt_nachricht = 780;
					break;
				case 190:
					v_akt_nachricht = 780;
					break;
				case 191:
					v_akt_nachricht = 757;
					break;
				case 192:
					v_akt_nachricht = 758;
					break;
				case 193:
					v_akt_nachricht = 758;
					break;
				case 194:
					v_akt_nachricht = 758;
					break;
				case 195:
					v_akt_nachricht = 800;
					break;
				case 196:
					v_akt_nachricht = 800;
					break;
				case 197:
					v_akt_nachricht = 800;
					break;
				case 198:
					v_akt_nachricht = 801;
					break;
				case 199:
					v_akt_nachricht = 801;
					break;
				case 200:
					v_akt_nachricht = 802;
					break;
				case 201:
					v_akt_nachricht = 784;
					break;
				case 202:
					v_akt_nachricht = 803;
					break;
				case 203:
					v_akt_nachricht = 803;
					break;
				case 204:
					v_akt_nachricht = 804;
					break;
				case 205:
					v_akt_nachricht = 780;
					break;
				case 206:
					v_akt_nachricht = 774;
					break;
				case 207:
					v_akt_nachricht = 805;
					break;
				case 208:
					v_akt_nachricht = 836;
					break;
				case 209:
					v_akt_nachricht = 837;
					break;
				case 210:
					v_akt_nachricht = 837;
					break;
				}
				if ((v_akt_nachricht > 0)) {
					v_x = 175;
					v_yn = 30;
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					p_drawtext(v_x, v_yn, a_nachricht_text(v_akt_nachricht, (1 + g_sprache)), -1, 0);
					p_stopdrawing();
				}
			}
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(p_keyboardpushed(13) || (v_mmouse_rechts == 1)));
}

static int32_t p_monsterschaden(int16_t v_schaden) {
	int16_t v_explo = 0;
	int32_t v_i = 0;
	std::string v_willi;
	int32_t v_wohin = 0;
	int32_t v_xx = 0;
	int32_t v_yy = 0;
	if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
		for (v_i = 1; v_i <= 15; v_i += 1) {
			if (((a_aktive(v_i, g_akt_spieler).f_nr == 110) && (a_aktive(v_i, g_akt_spieler).f_dauer != 9999))) {
				a_aktive(v_i, g_akt_spieler).f_nr = 0;
				a_aktive(v_i, g_akt_spieler).f_staerke = 0;
				a_aktive(v_i, g_akt_spieler).f_dauer = 0;
			}
		}
		p_laby_screen2();
		if (((((g_spell_x > -6) && (g_spell_x < 6)) && (g_spell_y > -6)) && (g_spell_y < 6))) {
			p_clipsprite(38, 0, 224, 32, 32);
			p_displaytransparentsprite(38, (160 + (g_spell_x * 32)), (160 + (g_spell_y * 32)));
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			if ((v_schaden < 10)) {
				v_xx = (172 + (g_spell_x * 32));
				v_yy = (168 + (g_spell_y * 32));
			}
			if ((v_schaden >= 10)) {
				v_xx = (166 + (g_spell_x * 32));
				v_yy = (168 + (g_spell_y * 32));
			}
			if ((v_schaden >= 100)) {
				v_xx = (163 + (g_spell_x * 32));
				v_yy = (168 + (g_spell_y * 32));
			}
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(v_xx, v_yy, p_str(v_schaden), -1, 0);
			p_stopdrawing();
		}
		if ((p_habich(159) == 0)) {
			v_schaden = (v_schaden - p_random(a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_ruestung));
			if ((v_schaden < 1)) {
				v_schaden = 0;
			}
		}
		a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] - v_schaden);
		if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
			v_explo = 0;
			if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 42) > 0)) {
				v_explo = 1;
			}
			v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, (g_sprache + 1)));
			p_nachricht7(v_willi, 3);
			p_lernen((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
			p_gott_check();
			if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 30) > 0)) {
				p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
			} else {
				p_hinterlassen((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y));
			}
			a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
			if ((v_explo == 1)) {
				p_explodiert();
			}
		} else {
			if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 0)) {
				a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 1;
			}
			if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 2)) {
				a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 0;
			}
			p_flipbuffers(1);
			p_delay(g_mydelay);
		}
	}
	p_laby_screen();
}

static int32_t p_mystisch() {
	int16_t v_angriff = 0;
	int8_t v_bogen = 0;
	int16_t v_kritisch = 0;
	int32_t v_level = 0;
	int8_t v_pfeil = 0;
	int16_t v_schaden = 0;
	v_bogen = 0;
	v_pfeil = 0;
	v_angriff = 0;
	v_schaden = 0;
	v_kritisch = 0;
	g_spell_x = 0;
	g_spell_y = 0;
	p_feld_waehlen();
	g_blocked = 0;
	p_los();
	if ((g_blocked == 0)) {
		if ((a_spieler(g_akt_spieler).f_lifepoints > 1)) {
			if (((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1) || (p_isthydra((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1))) {
				g_aktion = 1;
				p_sound(26);
				p_attack_spell(2);
				v_angriff = 70;
				if ((p_random(100) < v_angriff)) {
					v_schaden = (p_random((10 + v_level)) + 4);
					p_hydra_zauber(v_schaden);
					p_monsterschaden(v_schaden);
				} else {
					p_nachricht(16, 3);
				}
				p_spielerschaden(1, 3, 0);
			} else {
				p_nachricht(246, 1);
			}
		} else {
			p_nachricht(409, 1);
		}
	}
}

static int32_t p_nach_zug() {
	int16_t v_akt_hinterhalt = 0;
	int16_t v_art_n = 0;
	int32_t v_gef = 0;
	int16_t v_hat_monster = 0;
	int16_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_ii = 0;
	int32_t v_iii = 0;
	int32_t v_j = 0;
	int32_t v_jjj = 0;
	int32_t v_level = 0;
	int16_t v_posx = 0;
	int16_t v_posy = 0;
	int32_t v_ring = 0;
	int16_t v_schaden = 0;
	int32_t v_spell_x = 0;
	int32_t v_spell_y = 0;
	int16_t v_status = 0;
	int16_t v_unsichtbar = 0;
	int16_t v_weg = 0;
	int16_t v_welches = 0;
	int32_t v_wohin = 0;
	int16_t v_x = 0;
	int16_t v_xx = 0;
	int16_t v_y = 0;
	int16_t v_yy = 0;
	int16_t v_zaehler = 0;
	a_spieler(g_akt_spieler).f_moves = (a_spieler(g_akt_spieler).f_moves + 1);
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9998)) {
			a_aktive(v_i, g_akt_spieler).f_dauer = 0;
			a_aktive(v_i, g_akt_spieler).f_nr = 0;
			a_aktive(v_i, g_akt_spieler).f_staerke = 0;
		}
	}
	a_spieler(g_akt_spieler).f_old_pos_x = a_spieler(g_akt_spieler).f_character_x;
	a_spieler(g_akt_spieler).f_old_pos_y = a_spieler(g_akt_spieler).f_character_y;
	a_spieler(g_akt_spieler).f_old_lp = a_spieler(g_akt_spieler).f_lifepoints;
	a_spieler(g_akt_spieler).f_old_max_lp = a_spieler(g_akt_spieler).f_maxlifepoints;
	a_spieler(g_akt_spieler).f_old_mp = a_spieler(g_akt_spieler).f_mana;
	a_spieler(g_akt_spieler).f_old_max_mp = a_spieler(g_akt_spieler).f_maxmana;
	v_unsichtbar = 0;
	v_hat_monster = 0;
	if (((p_habich(110) == 1) && (p_random(100) < 50))) {
		v_unsichtbar = 1;
	}
	if ((v_unsichtbar == 0)) {
		v_xx = a_spieler(g_akt_spieler).f_character_x;
		v_yy = (a_spieler(g_akt_spieler).f_character_y + 1);
		if ((p_istmonster(v_xx, v_yy) == 1)) {
			if (((a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
				g_von_ferne = 0;
				v_hat_monster = 1;
				v_x = 5;
				v_y = 6;
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
				}
				p_restaurieren();
				p_monster_angriff(v_xx, v_yy);
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				p_restaurieren();
			}
		}
		v_xx = a_spieler(g_akt_spieler).f_character_x;
		v_yy = (a_spieler(g_akt_spieler).f_character_y - 1);
		if ((p_istmonster(v_xx, v_yy) == 1)) {
			if (((a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
				g_von_ferne = 0;
				v_hat_monster = 1;
				v_x = 5;
				v_y = 4;
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
				p_restaurieren();
				p_monster_angriff(v_xx, v_yy);
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				p_restaurieren();
			}
		}
		v_xx = (a_spieler(g_akt_spieler).f_character_x + 1);
		v_yy = a_spieler(g_akt_spieler).f_character_y;
		if ((p_istmonster(v_xx, v_yy) == 1)) {
			if (((a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
				g_von_ferne = 0;
				v_hat_monster = 1;
				v_x = 6;
				v_y = 5;
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
				p_restaurieren();
				p_monster_angriff(v_xx, v_yy);
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				p_restaurieren();
			}
		}
		v_xx = (a_spieler(g_akt_spieler).f_character_x - 1);
		v_yy = a_spieler(g_akt_spieler).f_character_y;
		if ((p_istmonster(v_xx, v_yy) == 1)) {
			if (((a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 2) && (a_laby_monster(v_xx, v_yy).f_status[a_spieler(g_akt_spieler).f_level] != 3))) {
				g_von_ferne = 0;
				v_hat_monster = 1;
				v_x = 4;
				v_y = 5;
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, -3);
				p_restaurieren();
				p_monster_angriff(v_xx, v_yy);
				if ((p_hat_eigenschaft(v_xx, v_yy, 30) > 0)) {
					p_draw_tile(53, v_x, v_y, 0, 0);
				} else {
					p_draw_tile(a_inhalt(a_spieler(g_akt_spieler).f_level), v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_item(a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				if ((a_laby_item(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
					p_draw_monster(a_laby_monster(v_xx, v_yy).f_name[a_spieler(g_akt_spieler).f_level], a_laby_monster(v_xx, v_yy).f_graphic[a_spieler(g_akt_spieler).f_level], v_x, v_y, 0, 0);
				}
				p_restaurieren();
			}
		}
	} else {
		p_nachricht(444, 2);
	}
	p_fernkampf();
	if ((p_habich(165) > 0)) {
		for (v_spell_x = -3; v_spell_x <= 3; v_spell_x += 1) {
			for (v_spell_y = -3; v_spell_y <= 3; v_spell_y += 1) {
				if ((((a_spieler(g_akt_spieler).f_character_x + v_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + v_spell_y) > 0))) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + v_spell_x), (a_spieler(g_akt_spieler).f_character_y + v_spell_y)) == 1)) {
						if ((p_random(100) > 90)) {
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + v_spell_x), (a_spieler(g_akt_spieler).f_character_y + v_spell_y), 29) == 1)) {
								p_sound(17);
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
									p_displaytransparentsprite(37, (160 + (v_spell_x * 32)), (160 + (v_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
									p_displaytransparentsprite(37, (160 + (v_spell_x * 32)), (160 + (v_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								a_laby_monster((a_spieler(g_akt_spieler).f_character_x + v_spell_x), (a_spieler(g_akt_spieler).f_character_y + v_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 2;
							}
						}
					}
				}
			}
		}
	}
	if ((p_habich(166) > 0)) {
		for (v_spell_x = -3; v_spell_x <= 3; v_spell_x += 1) {
			for (v_spell_y = -3; v_spell_y <= 3; v_spell_y += 1) {
				if ((((a_spieler(g_akt_spieler).f_character_x + v_spell_x) > 0) && ((a_spieler(g_akt_spieler).f_character_y + v_spell_y) > 0))) {
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + v_spell_x), (a_spieler(g_akt_spieler).f_character_y + v_spell_y)) == 1)) {
						if ((p_random(100) > 90)) {
							v_art_n = a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + v_spell_x), (a_spieler(g_akt_spieler).f_character_y + v_spell_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_art;
							if (((v_art_n == 1) || (v_art_n == 2))) {
								p_sound(10);
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 383, 31, 31);
									p_displaytransparentsprite(37, (160 + (v_spell_x * 32)), (160 + (v_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								for (v_i = 1; v_i <= 8; v_i += 1) {
									p_clipsprite(37, ((v_i * 31) - 31), 414, 31, 31);
									p_displaytransparentsprite(37, (160 + (v_spell_x * 32)), (160 + (v_spell_y * 32)));
									p_flipbuffers(1);
									p_delay(90);
								}
								p_zerstoert(v_spell_x, v_spell_y);
							}
						}
					}
				}
			}
		}
	}
	if (((((p_ich_trage3(326) == 1) || (p_habich(142) > 0)) && (p_random(100) > 50)) || ((p_ich_trage3(326) == 0) && (p_habich(142) == 0)))) {
		a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst + 1);
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 14)) {
		a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst + 1);
	}
	if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 9)) {
		a_spieler(g_akt_spieler).f_durst = (a_spieler(g_akt_spieler).f_durst + 1);
	}
	if ((a_spieler(g_akt_spieler).f_durst < 60)) {
		a_spieler(g_akt_spieler).f_verdursten = 0;
	}
	if (((a_spieler(g_akt_spieler).f_durst > 59) && (a_spieler(g_akt_spieler).f_durst < 90))) {
		a_spieler(g_akt_spieler).f_verdursten = 1;
	}
	if (((a_spieler(g_akt_spieler).f_durst > 89) && (a_spieler(g_akt_spieler).f_durst < 120))) {
		a_spieler(g_akt_spieler).f_verdursten = 2;
	}
	if (((a_spieler(g_akt_spieler).f_durst > 119) && (a_spieler(g_akt_spieler).f_durst < 320))) {
		a_spieler(g_akt_spieler).f_verdursten = 3;
		p_spielerschaden(1, 3, 8);
	}
	if ((a_spieler(g_akt_spieler).f_durst > 319)) {
		a_spieler(g_akt_spieler).f_verdursten = 3;
		p_spielerschaden(2, 3, 8);
	}
	if (((((p_ich_trage3(327) == 1) || (p_habich(142) > 0)) && (p_random(100) > 50)) || ((p_ich_trage3(327) == 0) && (p_habich(142) == 0)))) {
		a_spieler(g_akt_spieler).f_hunger = (a_spieler(g_akt_spieler).f_hunger + 1);
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 13)) {
		a_spieler(g_akt_spieler).f_hunger = (a_spieler(g_akt_spieler).f_hunger + 1);
	}
	if ((a_spieler(g_akt_spieler).f_hunger < 80)) {
		a_spieler(g_akt_spieler).f_verhungern = 0;
	}
	if (((a_spieler(g_akt_spieler).f_hunger > 79) && (a_spieler(g_akt_spieler).f_hunger < 120))) {
		a_spieler(g_akt_spieler).f_verhungern = 1;
	}
	if (((a_spieler(g_akt_spieler).f_hunger > 119) && (a_spieler(g_akt_spieler).f_hunger < 160))) {
		a_spieler(g_akt_spieler).f_verhungern = 2;
	}
	if (((a_spieler(g_akt_spieler).f_hunger > 159) && (a_spieler(g_akt_spieler).f_hunger < 350))) {
		a_spieler(g_akt_spieler).f_verhungern = 3;
		p_spielerschaden(1, 3, 9);
	}
	if ((a_spieler(g_akt_spieler).f_hunger > 349)) {
		a_spieler(g_akt_spieler).f_verhungern = 3;
		p_spielerschaden(2, 3, 9);
	}
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if ((a_aktive(v_i, g_akt_spieler).f_dauer > 1)) {
			if ((a_aktive(v_i, g_akt_spieler).f_dauer != 9999)) {
				a_aktive(v_i, g_akt_spieler).f_dauer = (a_aktive(v_i, g_akt_spieler).f_dauer - 1);
			}
		} else {
			if ((a_aktive(v_i, g_akt_spieler).f_dauer == 1)) {
				a_aktive(v_i, g_akt_spieler).f_dauer = 0;
				a_aktive(v_i, g_akt_spieler).f_nr = 0;
				a_aktive(v_i, g_akt_spieler).f_staerke = 0;
			}
		}
	}
	if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 13)) {
		if ((a_spieler(g_akt_spieler).f_mana > 0)) {
			a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana - 1);
		}
	}
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_benutzt == 1) && (a_inventory(v_i, g_akt_spieler).f_name == 46))) {
			a_inventory(v_i, g_akt_spieler).f_attri1 = (a_inventory(v_i, g_akt_spieler).f_attri1 - 1);
			if ((a_inventory(v_i, g_akt_spieler).f_attri1 < 1)) {
				if ((a_inventory(v_i, g_akt_spieler).f_anzahl > 0)) {
					a_inventory(v_i, g_akt_spieler).f_anzahl = (a_inventory(v_i, g_akt_spieler).f_anzahl - 1);
					a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri1;
				} else {
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 3);
				}
			}
		}
		if (((a_inventory(v_i, g_akt_spieler).f_benutzt == 1) && (a_inventory(v_i, g_akt_spieler).f_name == 39))) {
			a_inventory(v_i, g_akt_spieler).f_attri1 = (a_inventory(v_i, g_akt_spieler).f_attri1 - 1);
			if ((a_inventory(v_i, g_akt_spieler).f_attri1 < 1)) {
				if ((a_inventory(v_i, g_akt_spieler).f_anzahl > 0)) {
					a_inventory(v_i, g_akt_spieler).f_anzahl = (a_inventory(v_i, g_akt_spieler).f_anzahl - 1);
					a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri1;
				} else {
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					a_spieler(g_akt_spieler).f_light = (a_spieler(g_akt_spieler).f_light - 4);
				}
			}
		}
	}
	if ((a_spieler(g_akt_spieler).f_fluchdauer == 1)) {
		a_spieler(g_akt_spieler).f_fluchdauer = 0;
		a_spieler(g_akt_spieler).f_fluch = 0;
	}
	if ((a_spieler(g_akt_spieler).f_fluchdauer > 1)) {
		a_spieler(g_akt_spieler).f_fluchdauer = (a_spieler(g_akt_spieler).f_fluchdauer - 1);
	}
	if ((a_spieler(g_akt_spieler).f_betrunken > 0)) {
		a_spieler(g_akt_spieler).f_betrunken = (a_spieler(g_akt_spieler).f_betrunken - 1);
	}
	if ((a_spieler(g_akt_spieler).f_krankheit > 0)) {
		if ((p_random(100) > 80)) {
			p_spielerschaden(1, 2, 10);
		}
		if ((p_random(100) > 95)) {
			a_spieler(g_akt_spieler).f_krankheit = (a_spieler(g_akt_spieler).f_krankheit + 1);
		}
		a_spieler(g_akt_spieler).f_krankheitdauer = (a_spieler(g_akt_spieler).f_krankheitdauer - 1);
		if ((a_spieler(g_akt_spieler).f_krankheitdauer == 0)) {
			a_spieler(g_akt_spieler).f_krankheit = 0;
		}
	}
	if ((a_spieler(g_akt_spieler).f_giftdauer == 1)) {
		p_spielerschaden(a_spieler(g_akt_spieler).f_gift, 2, 10);
		a_spieler(g_akt_spieler).f_giftdauer = 0;
		a_spieler(g_akt_spieler).f_gift = 0;
		if ((p_random(100) < 10)) {
			p_nachricht(625, 4);
			a_spieler(g_akt_spieler).f_giftlehre = (a_spieler(g_akt_spieler).f_giftlehre + 1);
		}
	}
	if ((a_spieler(g_akt_spieler).f_giftdauer > 1)) {
		if ((a_spieler(g_akt_spieler).f_fluch != 12)) {
			a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer - 1);
			if ((a_spieler(g_akt_spieler).f_giftdauer > 1)) {
				if ((p_random(100) < (a_spieler(g_akt_spieler).f_giftlehre * 2))) {
					a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer - 1);
				}
			}
			if (((a_skills(84, g_akt_spieler).f_gewaehlt == 1) && (a_spieler(g_akt_spieler).f_giftdauer > 1))) {
				a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer - 1);
			}
		} else {
			p_nachricht(256, 6);
		}
		if ((a_skills(125, g_akt_spieler).f_gewaehlt == 1)) {
			p_spielerschaden((a_spieler(g_akt_spieler).f_gift + 1), 2, 10);
		} else {
			p_spielerschaden(a_spieler(g_akt_spieler).f_gift, 2, 10);
		}
	}
	if ((a_skills(77, g_akt_spieler).f_gewaehlt == 1)) {
		if ((p_random(100) > 50)) {
			a_spieler(g_akt_spieler).f_hinterhalt = (a_spieler(g_akt_spieler).f_hinterhalt + 1);
		}
	} else {
		a_spieler(g_akt_spieler).f_hinterhalt = (a_spieler(g_akt_spieler).f_hinterhalt + 1);
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 17)) {
		a_spieler(g_akt_spieler).f_hinterhalt = (a_spieler(g_akt_spieler).f_hinterhalt + 1);
	}
	if ((a_levelmod(a_spieler(g_akt_spieler).f_level) == 7)) {
		a_spieler(g_akt_spieler).f_hinterhalt = (a_spieler(g_akt_spieler).f_hinterhalt + 2);
	}
	v_akt_hinterhalt = (a_spieler(g_akt_spieler).f_hinterhalt - 20);
	if ((v_akt_hinterhalt < 1)) {
		v_akt_hinterhalt = 0;
	}
	if (((p_random(100) < v_akt_hinterhalt) && (p_habich(37) == 0))) {
		a_spieler(g_akt_spieler).f_hinterhalt = 0;
		v_welches = 1;
		v_zaehler = 1;
		do {
			v_gef = 0;
			v_welches = (p_random(169) + 1);
			if (((a_monster(v_welches).f_minlevel <= a_spieler(g_akt_spieler).f_level) && (p_hat_eigenschaft2(v_welches, 30) == 0))) {
				v_gef = p_hat_eigenschaft2(v_welches, 2);
			}
			v_zaehler = (v_zaehler + 1);
		} while (!((v_gef == 1) || (v_zaehler > 2000)));
		if ((v_zaehler > 2000)) {
			v_welches = 1;
			if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 10)) {
				v_welches = 118;
			}
		}
		p_hinterhalt(v_welches);
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((g_akt_spieler == 1)) {
		if (((g_spinnenkoenigin > 0) && (p_random(100) > 50))) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, 8));
		}
		if (((g_goblinkoenig > 0) && (p_random(100) > 50))) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, 4));
		}
		if (((g_untotenherr > 0) && (p_random(100) > 50))) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, 3));
		}
		for (v_i = 1; v_i <= a_groesse(a_spieler(g_akt_spieler).f_level); v_i += 1) {
			for (v_j = 1; v_j <= a_groesse(a_spieler(g_akt_spieler).f_level); v_j += 1) {
				v_status = 0;
				if ((p_istmonster(v_i, v_j) == 1)) {
					if ((a_laby_monster(v_i, v_j).f_status[a_spieler(g_akt_spieler).f_level] == 4)) {
						a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] - 1);
						if ((a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] == 0)) {
							a_laby_monster(v_i, v_j).f_status[a_spieler(g_akt_spieler).f_level] = 0;
						}
						if (((((v_i >= (a_spieler(g_akt_spieler).f_character_x - 6)) && (v_i <= (a_spieler(g_akt_spieler).f_character_x + 6))) && (v_j >= (a_spieler(g_akt_spieler).f_character_y - 6))) && (v_j <= (a_spieler(g_akt_spieler).f_character_y + 6)))) {
							v_posx = 0;
							v_posy = 0;
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_x + v_ii) == v_i)) {
									v_posx = v_ii;
								}
							}
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_y + v_ii) == v_j)) {
									v_posy = v_ii;
								}
							}
							p_laby_screen2();
							p_clipsprite(38, 0, 224, 32, 32);
							p_displaytransparentsprite(38, (160 + (v_posx * 32)), (160 + (v_posy * 32)));
							v_wohin = p_screenoutput();
							p_startdrawing(v_wohin);
							p_drawingmode(1);
							p_frontcolor(p_rgb(255, 255, 255));
							p_drawtext((172 + (v_posx * 32)), (172 + (v_posy * 32)), p_str(2), -1, 0);
							p_stopdrawing();
							p_sound((p_random(6) + 1));
							p_flipbuffers(1);
							p_delay(g_mydelay);
						}
						a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] - 2);
						if ((a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
							p_setmonster(v_i, v_j, a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
						}
					}
					if ((a_laby_monster(v_i, v_j).f_status[a_spieler(g_akt_spieler).f_level] == 5)) {
						a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] - 1);
						if ((a_laby_monster(v_i, v_j).f_duration[a_spieler(g_akt_spieler).f_level] == 0)) {
							a_laby_monster(v_i, v_j).f_status[a_spieler(g_akt_spieler).f_level] = 0;
						}
					}
					if (((p_hat_eigenschaft(v_i, v_j, 43) == 1) && (p_random(100) > 95))) {
						v_hugo = a_laby_monster(v_i, v_j).f_name[a_spieler(g_akt_spieler).f_level];
						v_weg = 0;
						if ((((a_laby_monster((v_i + 1), v_j).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (p_blockiert((v_i + 1), v_j, a_spieler(g_akt_spieler).f_level) == 0)) && (v_weg == 0))) {
							v_weg = 1;
							p_setmonster((v_i + 1), v_j, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
						}
						if ((((a_laby_monster((v_i - 1), v_j).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (p_blockiert((v_i - 1), v_j, a_spieler(g_akt_spieler).f_level) == 0)) && (v_weg == 0))) {
							v_weg = 1;
							p_setmonster((v_i - 1), v_j, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
						}
						if ((((a_laby_monster(v_i, (v_j + 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (p_blockiert(v_i, (v_j + 1), a_spieler(g_akt_spieler).f_level) == 0)) && (v_weg == 0))) {
							v_weg = 1;
							p_setmonster(v_i, (v_j + 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
						}
						if ((((a_laby_monster(v_i, (v_j - 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (p_blockiert(v_i, (v_j - 1), a_spieler(g_akt_spieler).f_level) == 0)) && (v_weg == 0))) {
							v_weg = 1;
							p_setmonster(v_i, (v_j - 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
						}
					}
					if (((p_hat_eigenschaft(v_i, v_j, 16) == 1) && (a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] < a_monster(a_laby_monster(v_i, v_j).f_name[a_spieler(g_akt_spieler).f_level]).f_lebenspunkte))) {
						if (((((v_i >= (a_spieler(g_akt_spieler).f_character_x - 6)) && (v_i <= (a_spieler(g_akt_spieler).f_character_x + 6))) && (v_j >= (a_spieler(g_akt_spieler).f_character_y - 6))) && (v_j <= (a_spieler(g_akt_spieler).f_character_y + 6)))) {
							p_sound(11);
							v_posx = 0;
							v_posy = 0;
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_x + v_ii) == v_i)) {
									v_posx = v_ii;
								}
							}
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_y + v_ii) == v_j)) {
									v_posy = v_ii;
								}
							}
							for (v_jjj = 1; v_jjj <= 5; v_jjj += 1) {
								for (v_iii = 1; v_iii <= 4; v_iii += 1) {
									p_laby_screen2();
									p_clipsprite(17, ((v_iii * 40) - 40), 1, 39, 39);
									p_displaytransparentsprite(17, (156 + (v_posx * 32)), (156 + (v_posy * 32)));
									p_flipbuffers(1);
									p_delay(70);
								}
							}
						}
						a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] = ((a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] + p_random(6)) + 1);
						if ((a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] > a_monster(a_laby_monster(v_i, v_j).f_name[a_spieler(g_akt_spieler).f_level]).f_lebenspunkte)) {
							a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] = a_monster(a_laby_monster(v_i, v_j).f_name[a_spieler(g_akt_spieler).f_level]).f_lebenspunkte;
						}
					}
					if ((a_laby_monster(v_i, v_j).f_status[a_spieler(g_akt_spieler).f_level] == 6)) {
						if (((((v_i >= (a_spieler(g_akt_spieler).f_character_x - 6)) && (v_i <= (a_spieler(g_akt_spieler).f_character_x + 6))) && (v_j >= (a_spieler(g_akt_spieler).f_character_y - 6))) && (v_j <= (a_spieler(g_akt_spieler).f_character_y + 6)))) {
							p_sound(47);
							v_posx = 0;
							v_posy = 0;
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_x + v_ii) == v_i)) {
									v_posx = v_ii;
								}
							}
							for (v_ii = -6; v_ii <= 6; v_ii += 1) {
								if (((a_spieler(g_akt_spieler).f_character_y + v_ii) == v_j)) {
									v_posy = v_ii;
								}
							}
							for (v_jjj = 1; v_jjj <= 5; v_jjj += 1) {
								for (v_iii = 1; v_iii <= 2; v_iii += 1) {
									p_laby_screen2();
									p_clipsprite(37, ((v_iii * 32) - 32), 448, 32, 32);
									p_displaytransparentsprite(37, (156 + (v_posx * 32)), (156 + (v_posy * 32)));
									p_flipbuffers(1);
									p_delay(100);
								}
							}
							v_schaden = (p_random(6) + 1);
							p_laby_screen2();
							p_clipsprite(38, 0, 224, 32, 32);
							p_displaytransparentsprite(38, (160 + (v_posx * 32)), (160 + (v_posy * 32)));
							v_wohin = p_screenoutput();
							p_startdrawing(v_wohin);
							p_drawingmode(1);
							p_frontcolor(p_rgb(255, 255, 255));
							p_drawtext((172 + (v_posx * 32)), (172 + (v_posy * 32)), p_str(2), -1, 0);
							p_stopdrawing();
							p_sound((p_random(6) + 1));
							p_flipbuffers(1);
							p_delay(g_mydelay);
						}
						a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] = (a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] - v_schaden);
						if ((a_laby_monster(v_i, v_j).f_lifepoints[a_spieler(g_akt_spieler).f_level] < 1)) {
							p_setmonster(v_i, v_j, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0, 0);
						}
					}
				}
			}
		}
	}
	if ((p_random(100) > 50)) {
		if ((v_level > 3)) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, a_sonderlevel(a_spieler(g_akt_spieler).f_level)));
		}
		if ((v_level > 15)) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, a_sonderlevel(a_spieler(g_akt_spieler).f_level)));
		}
		if ((v_level > 30)) {
			p_monster_setzen(a_spieler(g_akt_spieler).f_level, p_monster_random(a_spieler(g_akt_spieler).f_level, a_sonderlevel(a_spieler(g_akt_spieler).f_level)));
		}
	}
	if ((p_habich(151) == 1)) {
		if ((a_spieler(g_akt_spieler).f_lifepoints < p_maxlife())) {
			a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + 1);
			if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
				a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
			}
		}
	}
	if ((p_habich(80) == 1)) {
		if ((a_spieler(g_akt_spieler).f_lifepoints < p_maxlife())) {
			a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + 1);
			if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
				a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
			}
			v_ring = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if (((a_inventory(v_i, g_akt_spieler).f_name == 221) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
					v_ring = v_i;
				}
			}
			if ((v_ring > 0)) {
				a_inventory(v_ring, g_akt_spieler).f_attri1 = (a_inventory(v_ring, g_akt_spieler).f_attri1 - 1);
				if ((a_inventory(v_ring, g_akt_spieler).f_attri1 == 0)) {
					p_leeren(v_ring);
					p_nachricht(257, 1);
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if ((a_aktive(v_i, g_akt_spieler).f_nr == 80)) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							a_aktive(v_i, g_akt_spieler).f_dauer = 0;
						}
					}
				}
			}
		}
	}
	a_spieler(g_akt_spieler).f_speed = p_maxspeed();
	if ((a_spieler(g_akt_spieler).f_creature_typ > 0)) {
		a_spieler(g_akt_spieler).f_creature_speed = p_creature_speed();
	}
}

static int32_t p_nachricht(int16_t v_text, int16_t v_farbe) {
	std::string v_ausgabe;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(17, 380, 330, 32, -1);
	switch (v_farbe) {
	case 1:
		p_frontcolor(p_rgb(255, 255, 255));
		break;
	case 2:
		p_frontcolor(p_rgb(1, 1, 255));
		break;
	case 3:
		p_frontcolor(p_rgb(255, 1, 1));
		break;
	case 4:
		p_frontcolor(p_rgb(1, 255, 1));
		break;
	case 5:
		p_frontcolor(p_rgb(255, 255, 1));
		break;
	case 6:
		p_frontcolor(p_rgb(150, 150, 150));
		break;
	}
	v_ausgabe = a_nachricht_text(v_text, (1 + g_sprache));
	p_drawtext(25, 380, v_ausgabe, -1, 0);
	p_old_message(v_ausgabe, v_farbe);
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(g_mydelay);
}

static int32_t p_nachricht2(int16_t v_text, int16_t v_geg) {
	std::string v_ausgabe;
	int32_t v_fertig = 0;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(17, 380, 330, 32, -1);
	p_frontcolor(p_rgb(255, 255, 1));
	v_fertig = 0;
	if ((v_geg == 998)) {
		v_fertig = 1;
		v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + a_nachricht_text(734, (1 + g_sprache)));
	}
	if (((v_geg == 997) || (v_geg == 38))) {
		v_fertig = 1;
		v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + a_nachricht_text(658, (1 + g_sprache)));
	}
	if ((v_fertig == 0)) {
		if ((a_gegenstand(v_geg).f_art == 4)) {
			v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + a_nachricht_text(734, (1 + g_sprache)));
		} else {
			v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + a_gegenstand(v_geg).f_name[(1 + g_sprache)]);
		}
	}
	p_drawtext(25, 380, v_ausgabe, -1, 0);
	p_old_message(v_ausgabe, 5);
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(g_mydelay);
}

static int32_t p_nachricht3(int16_t v_text1, int16_t v_anz, int16_t v_text2) {
	std::string v_ausgabe;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(17, 380, 330, 32, -1);
	p_frontcolor(p_rgb(255, 255, 1));
	v_ausgabe = ((a_nachricht_text(v_text1, (1 + g_sprache)) + p_str(v_anz)) + a_nachricht_text(v_text2, (1 + g_sprache)));
	p_drawtext(25, 380, v_ausgabe, -1, 0);
	p_old_message(v_ausgabe, 5);
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(g_mydelay);
}

static std::string p_nachricht4(int16_t v_text) {
	std::string v_ausgabe;
	v_ausgabe = a_nachricht_text(v_text, (1 + g_sprache));
	return v_ausgabe;
}

static std::string p_nachricht5(int16_t v_text, int16_t v_mon) {
	std::string v_ausgabe;
	v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + a_monster(v_mon).f_name[(1 + g_sprache)]);
	return v_ausgabe;
}

static std::string p_nachricht6(int16_t v_text, std::string v_text2) {
	std::string v_ausgabe;
	v_ausgabe = (a_nachricht_text(v_text, (1 + g_sprache)) + v_text2);
	return v_ausgabe;
}

static int32_t p_nachricht7(std::string v_text, int16_t v_farbe) {
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(17, 380, 330, 32, -1);
	switch (v_farbe) {
	case 1:
		p_frontcolor(p_rgb(255, 255, 255));
		break;
	case 2:
		p_frontcolor(p_rgb(1, 1, 255));
		break;
	case 3:
		p_frontcolor(p_rgb(255, 1, 1));
		break;
	case 4:
		p_frontcolor(p_rgb(1, 255, 1));
		break;
	case 5:
		p_frontcolor(p_rgb(255, 255, 1));
		break;
	case 6:
		p_frontcolor(p_rgb(150, 150, 150));
		break;
	}
	p_drawtext(25, 380, v_text, -1, 0);
	p_old_message(v_text, v_farbe);
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(g_mydelay);
}

static int32_t p_naechster() {
	int32_t v_aktiv = 0;
	int32_t v_i = 0;
	if ((g_anz_spieler > 1)) {
		v_aktiv = 0;
		for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
			if ((a_spieler(v_i).f_status == 1)) {
				v_aktiv = 1;
			}
		}
		if ((v_aktiv == 1)) {
			do {
				g_akt_spieler = (g_akt_spieler + 1);
				if ((g_akt_spieler > g_anz_spieler)) {
					g_akt_spieler = 1;
				}
			} while (!(a_spieler(g_akt_spieler).f_status == 1));
		}
		g_xmod = 0;
		g_ymod = 0;
		p_laby_screen();
		p_delay(200);
	}
}

static int32_t p_namenlos() {
	int16_t v_jb1 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_xx = 0;
	int32_t v_y = 0;
	int32_t v_yy = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_clipsprite(14, 1, 1, 335, 335);
		p_displaytransparentsprite(14, 16, 16);
		p_frontcolor(p_rgb(0, 0, 0));
		p_box(16, 16, 335, 335, -1);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(255, 0, 0));
		v_x = 110;
		v_y = 130;
		p_drawtext(v_xx, v_yy, p_nachricht4(122), -1, 0);
		v_y = (v_y + 20);
		p_drawtext(v_xx, v_yy, p_nachricht4(123), -1, 0);
		v_y = (v_y + 20);
		p_drawtext(v_xx, v_yy, p_nachricht4(124), -1, 0);
		p_stopdrawing();
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(((p_keyboardpushed(13) || (v_mmouse_rechts == 1)) || (v_mmouse_links == 1)) || (v_jb1 != 0)));
}

static int32_t p_nekro() {
	p_waehlen(36);
	p_waehlen(37);
	p_waehlen(38);
	p_waehlen(39);
	p_waehlen(40);
	p_waehlen(41);
	p_waehlen(46);
	p_waehlen(52);
	p_waehlen(53);
	p_waehlen(55);
	p_waehlen(89);
	p_waehlen(90);
	p_waehlen(91);
	p_waehlen(121);
	p_waehlen(122);
	p_waehlen(123);
	p_waehlen(127);
	p_waehlen(128);
	p_waehlen(131);
	p_waehlen(134);
}

static int32_t p_neuer_level() {
	int16_t v_geg = 0;
	int16_t v_hugo = 0;
	int32_t v_j = 0;
	int16_t v_willi = 0;
	a_spieler(g_akt_spieler).f_level = (a_spieler(g_akt_spieler).f_level + 1);
	if ((a_spieler(g_akt_spieler).f_level > 150)) {
		p_ende();
	}
	if ((a_spieler(g_akt_spieler).f_level > a_spieler(g_akt_spieler).f_maxlevel)) {
		a_spieler(g_akt_spieler).f_maxlevel = a_spieler(g_akt_spieler).f_level;
		a_spieler(g_akt_spieler).f_portal = 1;
		a_spieler(g_akt_spieler).f_teleport = 1;
		a_spieler(g_akt_spieler).f_nexus = 1;
		a_spieler(g_akt_spieler).f_zauberbuch = 1;
		a_spieler(g_akt_spieler).f_kessel = 1;
		a_spieler(g_akt_spieler).f_udjat_ben = 1;
		a_spieler(g_akt_spieler).f_stehlen = 2;
		a_spieler(g_akt_spieler).f_lehrer = 3;
		a_spieler(g_akt_spieler).f_armageddon = 1;
		a_spieler(g_akt_spieler).f_pestilence = 1;
		a_spieler(g_akt_spieler).f_drachenform = 1;
		a_spieler(g_akt_spieler).f_macht = 1;
		a_spieler(g_akt_spieler).f_magic_apple = 2;
		a_spieler(g_akt_spieler).f_refresh = 2;
		a_spieler(g_akt_spieler).f_heal = 3;
		if ((a_skills(36, g_akt_spieler).f_gewaehlt == 1)) {
			for (v_j = 1; v_j <= 15; v_j += 1) {
				if (((a_aktive(v_j, g_akt_spieler).f_dauer > 0) && (a_aktive(v_j, g_akt_spieler).f_dauer != 9999))) {
					a_aktive(v_j, g_akt_spieler).f_nr = 0;
					a_aktive(v_j, g_akt_spieler).f_staerke = 0;
					a_aktive(v_j, g_akt_spieler).f_dauer = 0;
				}
			}
		}
		if ((a_skills(36, g_akt_spieler).f_gewaehlt == 1)) {
			a_spieler(g_akt_spieler).f_mana = p_maxmana();
		}
		if ((a_skills(85, g_akt_spieler).f_gewaehlt == 1)) {
			a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
		}
		if ((a_skills(30, g_akt_spieler).f_gewaehlt == 1)) {
			v_j = 0;
			do {
				v_j = (v_j + 1);
			} while (!((a_inventory(v_j, g_akt_spieler).f_name == 0) || (v_j > 50)));
			if ((v_j <= 50)) {
				a_inventory(v_j, g_akt_spieler).f_name = 20;
				a_inventory(v_j, g_akt_spieler).f_art = a_gegenstand(20).f_art;
				a_inventory(v_j, g_akt_spieler).f_attri1 = 10;
				a_inventory(v_j, g_akt_spieler).f_attri2 = 0;
				a_inventory(v_j, g_akt_spieler).f_attri3 = 1;
				a_inventory(v_j, g_akt_spieler).f_attri4 = 5;
			}
		}
		if ((a_skills(32, g_akt_spieler).f_gewaehlt == 1)) {
			v_j = 0;
			do {
				v_j = (v_j + 1);
			} while (!((a_inventory(v_j, g_akt_spieler).f_name == 0) || (v_j > 50)));
			v_hugo = (p_random(6) + 1);
			switch (v_hugo) {
			case 1:
				v_geg = 147;
				break;
			case 2:
				v_geg = 190;
				break;
			case 3:
				v_geg = 158;
				break;
			case 4:
				v_geg = 170;
				break;
			case 5:
				v_geg = 171;
				break;
			case 6:
				v_geg = 172;
				break;
			case 7:
				v_geg = 173;
				break;
			}
			if ((v_j <= 50)) {
				a_inventory(v_j, g_akt_spieler).f_name = v_geg;
				a_inventory(v_j, g_akt_spieler).f_art = a_gegenstand(v_geg).f_art;
				a_inventory(v_j, g_akt_spieler).f_attri1 = a_gegenstand(v_geg).f_attri1;
				a_inventory(v_j, g_akt_spieler).f_attri2 = a_gegenstand(v_geg).f_attri2;
				a_inventory(v_j, g_akt_spieler).f_attri3 = a_gegenstand(v_geg).f_attri3;
				a_inventory(v_j, g_akt_spieler).f_attri4 = a_gegenstand(v_geg).f_attri4;
			}
		}
		if (((a_skills(94, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) > 80))) {
			v_willi = (p_random(4) + 1);
			switch (v_willi) {
			case 1:
				p_haendler_init1(a_spieler(g_akt_spieler).f_level);
				break;
			case 2:
				p_haendler_init2(a_spieler(g_akt_spieler).f_level);
				break;
			case 3:
				p_haendler_init3(a_spieler(g_akt_spieler).f_level);
				break;
			case 4:
				p_haendler_init4(a_spieler(g_akt_spieler).f_level);
				break;
			case 5:
				p_haendler_init5(a_spieler(g_akt_spieler).f_level);
				break;
			}
			p_haendler();
		}
		if ((a_skills(27, g_akt_spieler).f_gewaehlt == 1)) {
			p_gold_finden2((a_spieler(g_akt_spieler).f_level * 5));
		}
		if (((a_skills(127, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < p_min((20 + a_spieler(g_akt_spieler).f_level), 90)))) {
			p_nachricht(29, 6);
			if ((a_spieler(g_akt_spieler).f_fluch == 0)) {
				a_spieler(g_akt_spieler).f_fluch = (p_random(25) + 1);
				if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
					p_sound(30);
				} else {
					p_sound(25);
				}
				a_spieler(g_akt_spieler).f_fluchdauer = (p_random(6) + 5);
				if ((a_skills(127, g_akt_spieler).f_gewaehlt == 1)) {
					a_spieler(g_akt_spieler).f_fluchdauer = (a_spieler(g_akt_spieler).f_fluchdauer * 2);
				}
			} else {
				a_spieler(g_akt_spieler).f_fluchdauer = ((a_spieler(g_akt_spieler).f_fluchdauer + p_random(6)) + 5);
				if ((a_skills(127, g_akt_spieler).f_gewaehlt == 1)) {
					a_spieler(g_akt_spieler).f_fluchdauer = ((a_spieler(g_akt_spieler).f_fluchdauer + p_random(6)) + 5);
				}
			}
		}
	}
	if ((a_groesse(a_spieler(g_akt_spieler).f_level) == 0)) {
		p_gen_laby(a_spieler(g_akt_spieler).f_level);
	}
	if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) > 0)) {
		p_sonderlevel_text(a_sonderlevel(a_spieler(g_akt_spieler).f_level));
	}
	if ((a_levelmod(a_spieler(g_akt_spieler).f_level) > 0)) {
		p_levelmodtext(a_levelmod(a_spieler(g_akt_spieler).f_level));
	}
	a_spieler(g_akt_spieler).f_character_x = a_eingangx(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_character_y = a_eingangy(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_speed = p_maxspeed();
	a_spieler(g_akt_spieler).f_creature_x = a_eingangx(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_creature_y = a_eingangy(a_spieler(g_akt_spieler).f_level);
}

static int32_t p_new_highscore() {
	int32_t v_akt_spieler = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	if (p_createfile(0, (g_environment + "/highscores.dat"))) {
		for (v_i = 1; v_i <= 30; v_i += 1) {
			p_writestringn(0, a_hscores(v_i).f_version);
			p_writestringn(0, a_hscores(v_i).f_name);
			p_writeword(0, a_hscores(v_i).f_level);
			p_writeword(0, a_hscores(v_i).f_gold);
			p_writeword(0, a_hscores(v_i).f_mks);
			p_writeword(0, a_hscores(v_i).f_punkte);
			p_writeword(0, a_hscores(v_i).f_maennchen);
			p_writestringn(0, a_hscores(v_i).f_anfangszeit);
			p_writestringn(0, a_hscores(v_i).f_endezeit);
			p_writeword(0, a_hscores(v_i).f_maxlifepoints);
			p_writeword(0, a_hscores(v_i).f_maxmana);
			p_writeword(0, a_hscores(v_i).f_attack);
			p_writeword(0, a_hscores(v_i).f_dexterity);
			p_writeword(0, a_hscores(v_i).f_strength);
			p_writeword(0, a_hscores(v_i).f_maxspeed);
			p_writeword(0, a_hscores(v_i).f_perception);
			p_writeword(0, a_hscores(v_i).f_luck_score);
			p_writeword(0, a_hscores(v_i).f_power_score);
			p_writeword(0, a_hscores(v_i).f_circle);
			p_writeword(0, a_hscores(v_i).f_stabteile);
			p_writeword(0, a_hscores(v_i).f_moves);
			for (v_j = 1; v_j <= 3; v_j += 1) {
				p_writestringn(0, a_hscores(v_i).f_sterbegrund[v_j]);
			}
			for (v_j = 1; v_j <= 30; v_j += 1) {
				p_writeword(0, a_hscores(v_i).f_skills[v_j]);
			}
		}
		p_closefile(0);
	}
	if ((a_spieler(v_akt_spieler).f_maxlevel > 3)) {
		p_upload_box();
	}
}

static int32_t p_objekt(int16_t v_x, int16_t v_y) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_okay = 0;
	int16_t v_testfeld = 0;
	int16_t v_unaufmerksam = 0;
	v_unaufmerksam = 0;
	v_i = 0;
	do {
		v_i = (v_i + 1);
	} while (!((v_i > 50) || (a_inventory(v_i, g_akt_spieler).f_name == 0)));
	if ((v_i <= 50)) {
		v_testfeld = a_laby_item(v_x, v_y).f_name[a_spieler(g_akt_spieler).f_level];
		if ((v_testfeld == 150)) {
			p_gold_finden2(a_laby_item(v_x, v_y).f_anzahl[a_spieler(g_akt_spieler).f_level]);
		} else {
			v_okay = 0;
			if ((v_testfeld == 38)) {
				p_sound(9);
				p_nachricht(310, 5);
				v_okay = 1;
			}
			if (((v_testfeld >= 65) && (v_testfeld <= 74))) {
				v_okay = 1;
				if ((a_skills(123, g_akt_spieler).f_gewaehlt == 1)) {
					v_unaufmerksam = 1;
				} else {
					p_sound(9);
					p_nachricht(10, 5);
				}
			}
			if (((((v_testfeld >= 75) && (v_testfeld <= 112)) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (a_skills(43, g_akt_spieler).f_gewaehlt == 0))) {
				p_sound(9);
				p_nachricht(309, 5);
				v_okay = 1;
			}
			if ((v_okay == 0)) {
				p_sound(9);
				p_nachricht2(6, v_testfeld);
			}
			if ((v_unaufmerksam == 0)) {
				v_j = 0;
				do {
					v_j = (v_j + 1);
				} while (!((((((((a_inventory(v_j, g_akt_spieler).f_name == v_testfeld) && (a_inventory(v_j, g_akt_spieler).f_art == a_gegenstand(v_testfeld).f_art)) && (a_inventory(v_j, g_akt_spieler).f_status == a_laby_item(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level])) && (a_inventory(v_j, g_akt_spieler).f_attri1 == a_laby_item(v_x, v_y).f_anzahl[a_spieler(g_akt_spieler).f_level])) && (a_inventory(v_j, g_akt_spieler).f_attri2 == a_gegenstand(v_testfeld).f_attri2)) && (a_inventory(v_j, g_akt_spieler).f_attri3 == a_gegenstand(v_testfeld).f_attri3)) && (a_inventory(v_j, g_akt_spieler).f_attri4 == a_gegenstand(v_testfeld).f_attri4)) || (v_j > 50)));
				if ((v_j > 50)) {
					a_inventory(v_i, g_akt_spieler).f_name = v_testfeld;
					a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_testfeld).f_art;
					a_inventory(v_i, g_akt_spieler).f_benutzt = 0;
					a_inventory(v_i, g_akt_spieler).f_status = a_laby_item(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level];
					a_inventory(v_i, g_akt_spieler).f_attri1 = a_laby_item(v_x, v_y).f_anzahl[a_spieler(g_akt_spieler).f_level];
					a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_testfeld).f_attri2;
					a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_testfeld).f_attri3;
					a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_testfeld).f_attri4;
				} else {
					a_inventory(v_j, g_akt_spieler).f_anzahl = (a_inventory(v_j, g_akt_spieler).f_anzahl + 1);
				}
			}
		}
		if ((v_unaufmerksam == 0)) {
			p_setitem(v_x, v_y, a_spieler(g_akt_spieler).f_level, 0, 0, 0);
			if ((a_skills(99, g_akt_spieler).f_gewaehlt == 0)) {
				g_aktion = 1;
			}
		}
	}
}

static int32_t p_okaybox(int32_t v_feld) {
	int16_t v_back_button = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_raus = 0;
	int32_t v_result = 0;
	std::string v_was;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int16_t v_xx = 0;
	int16_t v_xxx = 0;
	int32_t v_y = 0;
	int16_t v_yy = 0;
	int16_t v_yyy = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_clipsprite(14, 1, 1, 335, 335);
		p_displaytransparentsprite(14, 16, 16);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(60, 300, a_nachricht_text(740, (1 + g_sprache)), -1, 0);
		p_drawtext(60, 315, a_nachricht_text(741, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		v_x = 90;
		v_y = 170;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(0, 0, 0));
		p_drawingmode(1);
		p_drawtext(v_x, v_y, a_nachricht_text(705, (1 + g_sprache)), -1, 0);
		v_y = (v_y + 15);
		v_was = a_gegenstand(a_inventory(v_feld, g_akt_spieler).f_name).f_name[(g_sprache + 1)];
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 38) && (a_skills(47, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_feld, g_akt_spieler).f_status == 0))) {
			v_was = a_nachricht_text(658, (1 + g_sprache));
		}
		if (((((a_inventory(v_feld, g_akt_spieler).f_name >= 75) && (a_inventory(v_feld, g_akt_spieler).f_name <= 112)) && (a_skills(43, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_feld, g_akt_spieler).f_status == 0))) {
			v_was = a_nachricht_text(734, (1 + g_sprache));
		}
		if (((((a_inventory(v_feld, g_akt_spieler).f_name >= 65) && (a_inventory(v_feld, g_akt_spieler).f_name <= 74)) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_feld, g_akt_spieler).f_status == 0))) {
			v_was = a_nachricht_text(585, (1 + g_sprache));
		}
		p_drawtext(v_x, v_y, (((a_nachricht_text(704, (1 + g_sprache)) + " (") + v_was) + ")"), -1, 0);
		p_stopdrawing();
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		p_examinekeyboard();
		v_xx = 90;
		v_yy = 250;
		v_xxx = 190;
		v_yyy = 250;
		if (((p_keyboardpushed(121) || p_keyboardpushed(122)) || (v_jb1 == 1))) {
			v_raus = 1;
		}
		if (((((v_mmouse_x > v_xx) && (v_mmouse_x < (v_xx + 90))) && (v_mmouse_y > v_yy)) && (v_mmouse_y < (v_yy + 28)))) {
			p_clipsprite(3, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
			}
		} else {
			p_clipsprite(3, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(3, v_xx, v_yy);
		if ((p_keyboardpushed(110) || (v_jb2 == 1))) {
			v_raus = 2;
		}
		v_back_button = 0;
		if (((((v_mmouse_x > v_xxx) && (v_mmouse_x < (v_xxx + 90))) && (v_mmouse_y > v_yyy)) && (v_mmouse_y < (v_yyy + 28)))) {
			p_clipsprite(4, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_raus = 2;
			}
		} else {
			p_clipsprite(4, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(4, v_xxx, v_yyy);
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
	} while (!(v_raus > 0));
	if ((v_raus == 1)) {
		return 1;
	} else {
		return 0;
	}
}

static int32_t p_old_message(std::string v_ausgabe, int16_t v_farbe) {
	int32_t v_frei = 0;
	int32_t v_i = 0;
	v_ausgabe = ((p_formatdate("%hh:%ii:%ss", p_date()) + "  ") + v_ausgabe);
	v_i = 1;
	v_frei = 0;
	do {
		if ((a_old_messages(v_i, g_akt_spieler).f_nachricht == " ")) {
			v_frei = v_i;
		}
		v_i = (v_i + 1);
	} while (!((v_frei > 0) || (v_i > 25)));
	if ((v_frei > 0)) {
		a_old_messages(v_frei, g_akt_spieler).f_nachricht = v_ausgabe;
		a_old_messages(v_frei, g_akt_spieler).f_farbe = v_farbe;
	} else {
		for (v_i = 1; v_i <= 24; v_i += 1) {
			a_old_messages(v_i, g_akt_spieler).f_nachricht = a_old_messages((v_i + 1), g_akt_spieler).f_nachricht;
			a_old_messages(v_i, g_akt_spieler).f_farbe = a_old_messages((v_i + 1), g_akt_spieler).f_farbe;
		}
		a_old_messages(25, g_akt_spieler).f_nachricht = v_ausgabe;
		a_old_messages(25, g_akt_spieler).f_farbe = v_farbe;
	}
}

static int32_t p_opfern() {
	int16_t v_okay = 0;
	int16_t v_opfern = 0;
	v_okay = 0;
	v_opfern = p_select_inventory(595);
	if ((a_gegenstand(a_inventory(v_opfern, g_akt_spieler).f_name).f_einkauf > 40)) {
		v_okay = v_opfern;
	} else {
		p_nachricht(596, 5);
	}
	return v_okay;
}

static int32_t p_opfern2() {
	int16_t v_okay = 0;
	int16_t v_opfern = 0;
	v_okay = 0;
	v_opfern = p_select_inventory(604);
	if ((a_gegenstand(a_inventory(v_opfern, g_akt_spieler).f_name).f_art == 16)) {
		v_okay = v_opfern;
	} else {
		p_nachricht(605, 5);
	}
	return v_okay;
}

static int32_t p_opfern3() {
	int16_t v_okay = 0;
	int16_t v_opfern = 0;
	v_okay = 0;
	v_opfern = p_select_inventory(637);
	if ((a_gegenstand(a_inventory(v_opfern, g_akt_spieler).f_name).f_name[2] == "Edelstein Schwarz")) {
		v_okay = v_opfern;
	} else {
		p_nachricht(638, 5);
	}
	return v_okay;
}

static int32_t p_optionen() {
	int32_t v_aktuell = 0;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_joystick_only = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_raushier = 0;
	int32_t v_result = 0;
	int32_t v_y = 0;
	for (v_i = 1; v_i <= 30; v_i += 1) {
		a_optionenliste(v_i) = "";
	}
	if ((g_sprache == 0)) {
		a_optionenliste((g_akt_zauber_offset2 + 1)) = "Abort game";
		a_optionenliste((g_akt_zauber_offset2 + 2)) = "Quit program";
		a_optionenliste((g_akt_zauber_offset2 + 3)) = "Gamespeed";
		a_optionenliste((g_akt_zauber_offset2 + 4)) = "Save Settings";
		a_optionenliste((g_akt_zauber_offset2 + 5)) = "Fullscreen/Windowed";
		a_optionenliste((g_akt_zauber_offset2 + 6)) = "Enable Joystick";
		a_optionenliste((g_akt_zauber_offset2 + 7)) = "Enable No mouse";
		a_optionenliste((g_akt_zauber_offset2 + 8)) = "Disable No mouse";
		a_optionenliste((g_akt_zauber_offset2 + 9)) = "Auto-Toggle : Off";
		a_optionenliste((g_akt_zauber_offset2 + 10)) = "Auto-Toggle : On";
		a_optionenliste((g_akt_zauber_offset2 + 11)) = "Sounds : Off";
		a_optionenliste((g_akt_zauber_offset2 + 12)) = "Sounds : On";
		a_optionenliste((g_akt_zauber_offset2 + 13)) = "Music : Off";
		a_optionenliste((g_akt_zauber_offset2 + 14)) = "Music : On";
		a_optionenliste((g_akt_zauber_offset2 + 15)) = "Klicking : Off";
		a_optionenliste((g_akt_zauber_offset2 + 16)) = "Klicking : On";
		a_optionenliste((g_akt_zauber_offset2 + 17)) = "Bow = Button 5 : Off";
		a_optionenliste((g_akt_zauber_offset2 + 18)) = "Bow = Button 5 : On";
		a_optionenliste((g_akt_zauber_offset2 + 19)) = "Jars : Off";
		a_optionenliste((g_akt_zauber_offset2 + 20)) = "Jars : On";
		a_optionenliste((g_akt_zauber_offset2 + 21)) = "Load";
		a_optionenliste((g_akt_zauber_offset2 + 22)) = "Save";
		a_optionenliste((g_akt_zauber_offset2 + 23)) = "Cancel";
	}
	if ((g_sprache == 1)) {
		a_optionenliste((g_akt_zauber_offset2 + 1)) = "Spiel abbrechen";
		a_optionenliste((g_akt_zauber_offset2 + 2)) = "Programm beenden";
		a_optionenliste((g_akt_zauber_offset2 + 3)) = "Spielgeschwindigkeit";
		a_optionenliste((g_akt_zauber_offset2 + 4)) = "Einstellungen speichern";
		a_optionenliste((g_akt_zauber_offset2 + 5)) = "Vollbild/Fenster";
		a_optionenliste((g_akt_zauber_offset2 + 6)) = "Joystick einschalten";
		a_optionenliste((g_akt_zauber_offset2 + 7)) = "Keine Maus einschalten";
		a_optionenliste((g_akt_zauber_offset2 + 8)) = "Keine Maus ausschalten";
		a_optionenliste((g_akt_zauber_offset2 + 9)) = "Auto-Toggle : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 10)) = "Auto-Toggle : An";
		a_optionenliste((g_akt_zauber_offset2 + 11)) = "Sound : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 12)) = "Sound : An";
		a_optionenliste((g_akt_zauber_offset2 + 13)) = "Musik : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 14)) = "Musik : An";
		a_optionenliste((g_akt_zauber_offset2 + 15)) = "Klicken : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 16)) = "Klicken : An";
		a_optionenliste((g_akt_zauber_offset2 + 17)) = "Bogen = Knopf 5 : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 18)) = "Bogen = Knopf 5 : An";
		a_optionenliste((g_akt_zauber_offset2 + 19)) = "Flaschen : Aus";
		a_optionenliste((g_akt_zauber_offset2 + 20)) = "Flaschen : An";
		a_optionenliste((g_akt_zauber_offset2 + 21)) = "Laden";
		a_optionenliste((g_akt_zauber_offset2 + 22)) = "Speichern";
		a_optionenliste((g_akt_zauber_offset2 + 23)) = "Abbrechen";
	}
	if ((g_sprache == 2)) {
		a_optionenliste((g_akt_zauber_offset2 + 1)) = "Terminar Juego";
		a_optionenliste((g_akt_zauber_offset2 + 2)) = "Salir del Programa";
		a_optionenliste((g_akt_zauber_offset2 + 3)) = "Velocidad del Juego";
		a_optionenliste((g_akt_zauber_offset2 + 4)) = "Guardar Configuracion";
		a_optionenliste((g_akt_zauber_offset2 + 5)) = "Fullscreen/Ventana";
		a_optionenliste((g_akt_zauber_offset2 + 6)) = "Activar Joystick";
		a_optionenliste((g_akt_zauber_offset2 + 7)) = "Activar No raton";
		a_optionenliste((g_akt_zauber_offset2 + 8)) = "Desactivar No raton";
		a_optionenliste((g_akt_zauber_offset2 + 9)) = "Auto-Usar: No";
		a_optionenliste((g_akt_zauber_offset2 + 10)) = "Auto-Usar : Si";
		a_optionenliste((g_akt_zauber_offset2 + 11)) = "Sonidos : No";
		a_optionenliste((g_akt_zauber_offset2 + 12)) = "Sonidos : Si";
		a_optionenliste((g_akt_zauber_offset2 + 13)) = "Musica : No";
		a_optionenliste((g_akt_zauber_offset2 + 14)) = "Musica : Si";
		a_optionenliste((g_akt_zauber_offset2 + 15)) = "Klickear : No";
		a_optionenliste((g_akt_zauber_offset2 + 16)) = "Klickear : Si";
		a_optionenliste((g_akt_zauber_offset2 + 17)) = "Arco = Buton 5 : No";
		a_optionenliste((g_akt_zauber_offset2 + 18)) = "Arco = Buton 5 : Si";
		a_optionenliste((g_akt_zauber_offset2 + 19)) = "Botellas : No";
		a_optionenliste((g_akt_zauber_offset2 + 20)) = "Botellas : Si";
		a_optionenliste((g_akt_zauber_offset2 + 21)) = "Cargar";
		a_optionenliste((g_akt_zauber_offset2 + 22)) = "Guardar";
		a_optionenliste((g_akt_zauber_offset2 + 23)) = "Cancelar";
	}
	g_akt_option = 12;
	do {
		p_fenster(0);
		p_screen2();
		p_optionen_rahmen();
		if ((g_joystick_used == 1)) {
			v_jax = 0;
			v_jay = 0;
			v_jb1 = 0;
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mouse_links = p_mousebutton(1);
			v_mouse_rechts = p_mousebutton(2);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
		a_addelaymax(1) = g_selectdelay;
		if ((p_keyboardpushed(274) || (v_jay > 0))) {
			if (p_autodelay(1, 1, -2)) {
				p_autodelay(1, 2, -2);
				if ((g_akt_option < 22)) {
					g_akt_option = (g_akt_option + 1);
				}
			}
		} else {
			if ((p_keyboardpushed(273) || (v_jay < 0))) {
				if (p_autodelay(1, 1, -2)) {
					p_autodelay(1, 2, -2);
					if ((g_akt_option > 0)) {
						g_akt_option = (g_akt_option - 1);
					}
				}
			} else {
				p_autodelay(1, 3, -2);
			}
		}
		p_examinekeyboard();
		g_mauszauber = 0;
		v_y = 52;
		v_aktuell = 1;
		if (((v_mmouse_x > 365) && (v_mmouse_x < 610))) {
			for (v_i = 1; v_i <= g_anzz; v_i += 1) {
				if (((v_mmouse_y >= v_y) && (v_mmouse_y <= (v_y + g_yplus)))) {
					g_mauszauber = v_aktuell;
				}
				v_y = (v_y + g_yplus);
				v_aktuell = (v_aktuell + 1);
			}
		}
		v_raushier = 0;
		if (((v_mouse_links == 1) && (g_mauszauber > 0))) {
			v_raushier = 1;
		}
	} while (!((((v_raushier == 1) || (v_mouse_rechts == 1)) || p_keyboardpushed(13)) || (v_jb1 == 1)));
	p_autodelay(-1, 5, -2);
	if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Spiel abbrechen") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Abort game")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Terminar Juego"))) {
			throw Lv_again;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Programm beenden") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Quit program")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Salir del Programa"))) {
			exit(0);
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Spielgeschwindigkeit") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Gamespeed")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Velocidad del Juego"))) {
			p_delay(g_mydelay);
			p_gamespeed();
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Einstellungen speichern") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Save Settings")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Guardar Configuracion"))) {
			if (p_save_settings()) {
				p_nachricht(486, 1);
			} else {
				p_nachricht(487, 3);
			}
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Vollbild/Fenster") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Fullscreen/Windowed")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Fullscreen/Ventana"))) {
			p_fullscreen();
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Joystick einschalten") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Enable Joystick")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Activar Joystick"))) {
			g_joystick_used = 1;
			if ((p_initjoystick() == 0)) {
			}
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Keine Maus einschalten") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Enable No mouse")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Activar No raton"))) {
			g_no_mouse = 1;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Keine Maus ausschalten") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Disable No mouse")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Desactivar No raton"))) {
			g_no_mouse = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Toggle : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Toggle : An")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Usar : Si"))) {
			g_autopickup = 1;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Toggle : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Toggle : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Auto-Usar : No"))) {
			g_autopickup = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sounds : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sound : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sonidos : No"))) {
			g_sound = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sounds : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sound : Ein")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Sonidos : Si"))) {
			g_sound = 1;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Music : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Musik : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Musica : No"))) {
			g_music = 0;
			p_stopmodule(-1);
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Music : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Musik : Ein")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Musica : Si"))) {
			g_music = 1;
			p_playmodule(1);
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klicking : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klicken : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klickear : No"))) {
			g_klicking = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klicking : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klicken : Ein")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Klickear : Si"))) {
			g_klicking = 1;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Laden") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Load")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Cargar"))) {
			p_delay(500);
			p_loading_screen();
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Speichern") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Save")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Guardar"))) {
			p_delay(500);
			p_saving_screen();
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Bow = Button 5 : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Bogen = Knopf 5 : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Arco = Buton 5 : No"))) {
			g_knopf5 = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Bow = Button 5 : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Bogen = Knopf 5 : An")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Arco = Buton 5 : Si"))) {
			g_knopf5 = 1;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Jars : Off") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Flaschen : Aus")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Botellas : No"))) {
			g_flaschen = 0;
		}
		if ((((a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Jars : On") || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Flaschen : An")) || (a_optionenliste(((g_akt_option + g_akt_zauber_offset2) + 1)) == "Botellas : Si"))) {
			g_flaschen = 1;
		}
	}
	if ((v_raushier == 1)) {
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Spiel abbrechen") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Abort game")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Terminar Juego"))) {
			throw Lv_again;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Programm beenden") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Quit program")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Salir del Programa"))) {
			p_closescreen();
			exit(0);
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Spielgeschwindigkeit") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Gamespeed")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Velocidad del Juego"))) {
			p_delay(g_mydelay);
			p_gamespeed();
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Einstellungen speichern") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Save Settings")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Guardar Configuracion"))) {
			if (p_save_settings()) {
				p_nachricht(486, 1);
			} else {
				p_nachricht(487, 3);
			}
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Vollbild/Fenster") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Fullscreen/Windowed")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Fullscreen/Ventana"))) {
			p_fullscreen();
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Joystick einschalten") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Enable Joystick")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Activar Joystick"))) {
			g_no_mouse = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Keine Maus einschalten") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Enable No mouse")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Activar No raton"))) {
			g_no_mouse = 1;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Keine Maus ausschalten") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Disable No mouse")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Desactivar No Raton"))) {
			v_joystick_only = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Toggle : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Toggle : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Usar : No"))) {
			g_autopickup = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Toggle : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Toggle : An")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Auto-Usar : Si"))) {
			g_autopickup = 1;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sounds : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sound : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sonidos : No"))) {
			g_sound = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sounds : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sound : Ein")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Sonidos : Si"))) {
			g_sound = 1;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Music : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Musik : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Musica : No"))) {
			g_music = 0;
			p_stopmodule(-1);
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Music : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Musik : Ein")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Musica : Si"))) {
			g_music = 1;
			p_playmodule(1);
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klicking : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klicken : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klickear : No"))) {
			g_klicking = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klicking : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klicken : Ein")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Klickear : Si"))) {
			g_klicking = 1;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Laden") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Load")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Cargar"))) {
			p_delay(500);
			p_loading_screen();
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Speichern") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Save")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Guardar"))) {
			p_delay(500);
			p_saving_screen();
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Bow = Button 5 : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Bogen = Knopf 5 : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Arco = Buton 5 : No"))) {
			g_knopf5 = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Bow = Button 5 : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Bogen = Knopf 5 : An")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Arco = Buton 5 : Si"))) {
			g_knopf5 = 1;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Jars : Off") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Flaschen : Aus")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Botellas : No"))) {
			g_flaschen = 0;
		}
		if ((((a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Jars : On") || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Flaschen : An")) || (a_optionenliste(((((g_akt_option + g_akt_zauber_offset2) + 1) + g_mauszauber) - 14)) == "Botellas : Si"))) {
			g_flaschen = 1;
		}
	}
}

static int32_t p_optionen2() {
	int32_t v_down_delay = 0;
	int32_t v_key_down = 0;
	int32_t v_key_left = 0;
	int32_t v_key_right = 0;
	int32_t v_key_up = 0;
	int32_t v_left_delay = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_linksold = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_rechts_released = 0;
	int32_t v_mouse_rechtsold = 0;
	int32_t v_mouse_released = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_quit = 0;
	int32_t v_result = 0;
	int32_t v_right_delay = 0;
	int32_t v_up_delay = 0;
	p_clearscreen(0);
	do {
		p_flipbuffers(1);
		p_clearscreen(0);
		p_fenster(0);
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mouse_x = p_mousex();
			v_mouse_y = p_mousey();
			v_mouse_linksold = v_mouse_links;
			v_mouse_links = p_mousebutton(1);
			if (((v_mouse_linksold == 1) && (v_mouse_links == 0))) {
				v_mouse_released = 1;
			} else {
				v_mouse_released = 0;
			}
			v_mouse_rechtsold = v_mouse_rechts;
			v_mouse_rechts = p_mousebutton(2);
			if (((v_mouse_rechtsold == 1) && (v_mouse_rechts == 0))) {
				v_mouse_rechts_released = 1;
			} else {
				v_mouse_rechts_released = 0;
			}
		}
		p_examinekeyboard();
		if ((v_left_delay < 1)) {
			v_key_left = p_keyboardpushed(276);
			if ((v_key_left && (v_left_delay == 0))) {
				v_left_delay = 10;
			} else {
				if (v_key_left) {
					v_left_delay = 40;
				} else {
					v_left_delay = -1;
				}
			}
		} else {
			v_left_delay -= 1;
		}
		if ((v_right_delay < 1)) {
			v_key_right = p_keyboardpushed(275);
			if ((v_key_right && (v_right_delay == 0))) {
				v_right_delay = 10;
			} else {
				if (v_key_right) {
					v_right_delay = 40;
				} else {
					v_right_delay = -1;
				}
			}
		} else {
			v_right_delay -= 1;
		}
		if ((v_up_delay < 1)) {
			v_key_up = p_keyboardpushed(273);
			if ((v_key_up && (v_up_delay == 0))) {
				v_up_delay = 10;
			} else {
				if (v_key_up) {
					v_up_delay = 40;
				} else {
					v_up_delay = -1;
				}
			}
		} else {
			v_up_delay -= 1;
		}
		if ((v_down_delay < 1)) {
			v_key_down = p_keyboardpushed(274);
			if ((v_key_down && (v_down_delay == 0))) {
				v_down_delay = 10;
			} else {
				if (v_key_down) {
					v_down_delay = 40;
				} else {
					v_down_delay = -1;
				}
			}
		} else {
			v_down_delay -= 1;
		}
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		p_clipsprite(57, 0, 0, 607, 17);
		p_displaytransparentsprite(57, 17, 400);
		p_startdrawing(p_screenoutput());
		p_drawingmode(1);
		if (v_key_left) {
			p_drawtext(30, 30, "Left", 65535, 0);
		}
		if (v_key_right) {
			p_drawtext(30, 30, "right", 65535, 0);
		}
		if (v_key_up) {
			p_drawtext(30, 30, "up", 65535, 0);
		}
		if (v_key_down) {
			p_drawtext(30, 30, "down", 65535, 0);
		}
		p_stopdrawing();
		if (v_mouse_rechts_released) {
			v_quit = 1;
		} else {
			if (p_keyboardreleased(32)) {
				v_quit = 1;
			}
		}
		v_key_left = 0;
		v_key_right = 0;
		v_key_up = 0;
		v_key_down = 0;
	} while (!v_quit);
}

static int32_t p_optionen_rahmen() {
	int32_t v_i = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(365, 15, 260, 449, -1);
	p_box(15, 365, 335, 51, -1);
	p_stopdrawing();
	p_clipsprite(54, 0, 0, 640, 17);
	p_displaytransparentsprite(54, 0, 0);
	p_clipsprite(56, 0, 0, 17, 480);
	p_displaytransparentsprite(56, 0, 0);
	p_clipsprite(57, 0, 0, 640, 17);
	p_displaytransparentsprite(57, 0, 464);
	p_clipsprite(59, 0, 0, 17, 480);
	p_displaytransparentsprite(59, 624, 0);
	p_clipsprite(63, 0, 0, 640, 17);
	p_displaysprite(63, 0, 350);
	p_clipsprite(60, 0, 0, 17, 480);
	p_displaysprite(60, 350, 0);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	p_drawtext(440, 19, a_nachricht_text(76, (1 + g_sprache)), -1, 0);
	p_frontcolor(p_rgb(150, 150, 150));
	p_box(365, (200 + g_yplus2), 260, g_yplus, -1);
	p_frontcolor(p_rgb(255, 255, 255));
	v_x = 400;
	v_y = 52;
	for (v_i = 1; v_i <= (g_anzz - 3); v_i += 1) {
		p_frontcolor(p_rgb(255, 255, 255));
		if ((v_i == g_mauszauber)) {
			p_frontcolor(p_rgb(1, 1, 255));
		}
		p_drawtext(v_x, v_y, a_optionenliste((v_i + g_akt_option)), -1, 0);
		v_y = (v_y + g_yplus);
	}
	p_stopdrawing();
}

static int32_t p_ork() {
	int32_t v_mon = 0;
	do {
		v_mon = (p_random(176) + 1);
	} while (!p_hat_eigenschaft2(v_mon, 33));
	return v_mon;
}

static int32_t p_pilz_essen(std::string v_welchen) {
	a_spieler(g_akt_spieler).f_hunger = (a_spieler(g_akt_spieler).f_hunger - 10);
	if ((a_spieler(g_akt_spieler).f_hunger < 0)) {
		a_spieler(g_akt_spieler).f_hunger = 0;
	}
	if (v_welchen == "Wirkungslos") {
		p_nachricht(38, 4);
	} else if (v_welchen == "Schwacher Heilpilz") {
		a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + 2);
		if ((a_spieler(g_akt_spieler).f_lifepoints > a_spieler(g_akt_spieler).f_maxlifepoints)) {
			a_spieler(g_akt_spieler).f_lifepoints = a_spieler(g_akt_spieler).f_maxlifepoints;
		}
		p_nachricht(39, 4);
	} else if (v_welchen == "Starker Heilpilz") {
		a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints + 4);
		if ((a_spieler(g_akt_spieler).f_lifepoints > a_spieler(g_akt_spieler).f_maxlifepoints)) {
			a_spieler(g_akt_spieler).f_lifepoints = a_spieler(g_akt_spieler).f_maxlifepoints;
		}
		p_nachricht(39, 4);
	} else if (v_welchen == "Schwach Giftig") {
		a_spieler(g_akt_spieler).f_gift = 1;
		a_spieler(g_akt_spieler).f_giftdauer = (p_random(15) + 1);
		p_nachricht(40, 4);
	} else if (v_welchen == "Stark Giftig") {
		a_spieler(g_akt_spieler).f_gift = 2;
		a_spieler(g_akt_spieler).f_giftdauer = (p_random(15) + 1);
		p_nachricht(40, 4);
	} else if (v_welchen == "St\344rkepilz") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "St\344rkezauber";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Schw\344chepilz") {
		p_nachricht(41, 4);
	} else if (v_welchen == "Paralysepilz") {
		a_spieler(g_akt_spieler).f_fluch = 5;
		a_spieler(g_akt_spieler).f_fluchdauer = (p_random(15) + 1);
		p_nachricht(42, 4);
	} else if (v_welchen == "Schwacher Manapilz") {
		a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + 2);
		if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
			a_spieler(g_akt_spieler).f_mana = p_maxmana();
		}
		p_nachricht(43, 4);
	} else if (v_welchen == "Starker Manapilz") {
		a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana + 4);
		if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
			a_spieler(g_akt_spieler).f_mana = p_maxmana();
		}
		p_nachricht(43, 4);
	} else 	if (1) {
		p_nachricht(38, 4);

	} else {}
}

static int32_t p_power(int16_t v_spell) {
	int16_t v_akt_power = 0;
	int32_t v_i = 0;
	int16_t v_magelord = 0;
	int32_t v_okay = 0;
	v_akt_power = a_spieler(g_akt_spieler).f_power_score;
	if ((v_spell > 0)) {
		if ((a_skills(35, g_akt_spieler).f_gewaehlt == 1)) {
			v_akt_power = (v_akt_power + a_zauber(v_spell, g_akt_spieler).f_level);
		}
	}
	if ((a_skills(46, g_akt_spieler).f_gewaehlt == 1)) {
		v_okay = 0;
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 4)) && (v_okay == 0))) {
			v_akt_power = (v_akt_power * 5);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 3)) && (v_okay == 0))) {
			v_akt_power = (v_akt_power * 4);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 2)) && (v_okay == 0))) {
			v_akt_power = (v_akt_power * 3);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 1.5)) && (v_okay == 0))) {
			v_akt_power = (v_akt_power * 2);
			v_okay = 1;
		}
	}
	if ((p_habich(59) > 0)) {
		v_akt_power = (v_akt_power * 2);
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 3)) {
		v_akt_power = 1;
	}
	if ((g_schriftrolle == 1)) {
		v_akt_power = (p_random(8) + 1);
	}
	v_akt_power = (v_akt_power + a_spieler(g_akt_spieler).f_powergegenstand);
	v_magelord = 0;
	for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
		if ((a_skills(63, v_i).f_gewaehlt == 1)) {
			v_magelord = 2;
		}
	}
	v_akt_power = (v_akt_power + v_magelord);
	if ((v_akt_power > 15)) {
		v_akt_power = 15;
	}
	return v_akt_power;
}

static int32_t p_punkte() {
	int16_t v_punkte = 0;
	int16_t v_x1 = 0;
	int16_t v_x2 = 0;
	int16_t v_x3 = 0;
	v_x1 = (a_spieler(g_akt_spieler).f_level * 10);
	v_x2 = (p_gold_anzahl() / 10);
	v_x3 = (a_spieler(g_akt_spieler).f_mks / 5);
	if ((v_x2 > v_x1)) {
		v_x2 = v_x1;
	}
	if ((v_x3 > v_x1)) {
		v_x3 = v_x1;
	}
	v_punkte = ((v_x1 + v_x2) + v_x3);
	v_punkte = (v_punkte + (a_spieler(g_akt_spieler).f_stabteile * 100));
	return v_punkte;
}

static int32_t p_radius() {
	int32_t v_levelmod = 0;
	int32_t v_nachtsicht = 0;
	int32_t v_nachtsichtw = 0;
	int32_t v_sicht = 0;
	if ((p_habich(88) > 0)) {
		v_sicht = 4;
	} else {
		if ((p_habich(89) > 0)) {
			v_sicht = 6;
		} else {
			if ((p_habich(87) > 0)) {
				v_sicht = 5;
			} else {
				if ((p_habich(90) > 0)) {
					v_sicht = 4;
				} else {
					v_nachtsichtw = 0;
					if ((a_skills(71, g_akt_spieler).f_gewaehlt == 1)) {
						v_nachtsicht = 2;
					}
					v_sicht = ((((a_spieler(g_akt_spieler).f_light + a_spieler(g_akt_spieler).f_lichtgegenstand) + v_nachtsicht) + p_habich(200)) + p_habich(36));
				}
			}
		}
	}
	if (((((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 10) || (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 9)) || (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 6)) || (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 11))) {
		v_sicht = 8;
	}
	if ((a_skills(129, g_akt_spieler).f_gewaehlt == 1)) {
		v_sicht = (v_sicht / 2);
	}
	if ((v_levelmod == 1)) {
		v_sicht = (v_sicht / 2);
	}
	if (((v_sicht < 1) || (a_spieler(g_akt_spieler).f_fluch == 8))) {
		v_sicht = 1;
	}
	return v_sicht;
}

static int32_t p_radius2() {
	int16_t v_sight = 0;
	v_sight = 0;
	switch (a_spieler(g_akt_spieler).f_creature_typ) {
	case 1:
		v_sight = 4;
		break;
	case 2:
		v_sight = 3;
		break;
	case 3:
		v_sight = 3;
		break;
	case 4:
		v_sight = 6;
		break;
	case 5:
		v_sight = 4;
		break;
	case 6:
		v_sight = 3;
		break;
	case 7:
		v_sight = 4;
		break;
	case 8:
		v_sight = 6;
		break;
	case 9:
		v_sight = 5;
		break;
	case 10:
		v_sight = 5;
		break;
	case 11:
		v_sight = 6;
		break;
	case 12:
		v_sight = 4;
		break;
	case 13:
		v_sight = 4;
		break;
	case 14:
		v_sight = 6;
		break;
	case 15:
		v_sight = 5;
		break;
	case 20:
		v_sight = 5;
		break;
	}
	return v_sight;
}

static int32_t p_raum() {
	int16_t v_akt_falle = 0;
	int32_t v_anhaenger = 0;
	int16_t v_boden = 0;
	int32_t v_falle = 0;
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_koenig = 0;
	int32_t v_level = 0;
	int32_t v_mon = 0;
	int16_t v_was = 0;
	int16_t v_welcher = 0;
	int16_t v_welches = 0;
	int32_t v_zaehler = 0;
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 1)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 64, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 2)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 56, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 57, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 56, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 60, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 61, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 57, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 58, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 59, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 58, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 59, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 3)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 8, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 4)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 7, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 5)) {
		p_sonderlevel_text(19);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 16, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 16, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 15, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 16, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 6)) {
		p_sonderlevel_text(18);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 18, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 18, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 17, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 18, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 7)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 78, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 79, 0, 0, g_anz_spieler);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 8)) {
		p_sonderlevel_text(28);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				v_welches = 1;
				do {
					v_welches = (p_random(169) + 1);
					v_zaehler = (v_zaehler + 1);
				} while (!((a_monster(v_welches).f_minlevel <= a_spieler(g_akt_spieler).f_level) && (p_hat_eigenschaft2(v_welches, 30) == 0)));
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
				p_setmonster((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, 0, 0);
			}
		}
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 5);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 5);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 9)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		v_was = p_finden2();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 67, 0, 0, v_was);
		v_was = p_finden2();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 68, 0, 0, v_was);
		v_was = p_finden2();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 67, 0, 0, v_was);
		for (v_i = 3; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 10)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 1; v_i <= 3; v_i += 1) {
			for (v_j = 1; v_j <= 3; v_j += 1) {
				p_setlaby(((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)) + 3), ((v_j + a_raumy(a_spieler(g_akt_spieler).f_level)) + 3), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
			}
		}
		for (v_i = 3; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 11)) {
		p_sonderlevel_text(12);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 8), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 8), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 8), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 8), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 8), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 8), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 8), (a_raumy(a_spieler(g_akt_spieler).f_level) + 8), a_spieler(g_akt_spieler).f_level, 55, 1, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 12)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 54, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 13)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		v_was = p_finden1();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 6, 0, 0, v_was);
		v_was = p_finden1();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 6, 0, 0, v_was);
		v_was = p_finden1();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 6, 0, 0, v_was);
		for (v_i = 3; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 14)) {
		p_sonderlevel_text(26);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 40, 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 42, 0, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 42, 0, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, 42, 0, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, 42, 0, 0, 0);
		}
		for (v_i = 3; v_i <= 6; v_i += 1) {
			v_hugo = 32;
			p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, v_hugo, 0);
		}
		v_hugo = 56;
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 4);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 6);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 15)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 82, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 16)) {
		v_boden = (113 + p_random(3));
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, v_boden, 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, (122 + p_random(9)), 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 17)) {
		p_sonderlevel_text(13);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 5, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 5, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 5, 0, 0, 0);
		v_was = p_finden2();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 68, 0, 0, v_was);
		v_hugo = 62;
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 4);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 6);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 18)) {
		p_sonderlevel_text(14);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 6; v_i += 1) {
			for (v_j = 2; v_j <= 6; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 110, 0, 0, 0);
			}
		}
		v_was = p_finden2();
		p_setlaby((4 + a_raumx(a_spieler(g_akt_spieler).f_level)), (4 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 68, 0, 0, v_was);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 19)) {
		p_sonderlevel_text(15);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 110, 0, 0, 0);
			}
		}
		p_setlaby((5 + a_raumx(a_spieler(g_akt_spieler).f_level)), (5 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 118, 0, 0, 0);
		p_setlaby((4 + a_raumx(a_spieler(g_akt_spieler).f_level)), (4 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((4 + a_raumx(a_spieler(g_akt_spieler).f_level)), (5 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((5 + a_raumx(a_spieler(g_akt_spieler).f_level)), (4 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 20)) {
		p_sonderlevel_text(16);
		v_boden = (113 + p_random(3));
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, v_boden, 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 123, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 124, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 125, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 126, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 129, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 130, 1, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 65, 1, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 21)) {
		p_sonderlevel_text(17);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 9; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 8), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 8; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 8; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 137, 9, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 138, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 139, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 140, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 141, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 142, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 143, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 144, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 145, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 146, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 147, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 148, 0, 0, 0);
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 4);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 7);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 22)) {
		p_sonderlevel_text(20);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		}
		v_was = p_finden2();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 68, 0, 0, v_was);
		v_was = p_finden1();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 6, 0, 0, v_was);
		v_was = p_finden1();
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 6, 0, 0, v_was);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		v_hugo = 78;
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 23)) {
		p_sonderlevel_text(21);
		v_boden = (113 + p_random(3));
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, v_boden, 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 129, 2, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 8, 1, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 24)) {
		p_sonderlevel_text(22);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				if ((p_random(100) < 90)) {
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 53, 1, 0, 0);
				} else {
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 72, 0, 0, 0);
				}
			}
		}
		for (v_i = 4; v_i <= 4; v_i += 1) {
			for (v_j = 4; v_j <= 5; v_j += 1) {
				v_hugo = p_random(100);
				if (((v_hugo > 40) && (v_hugo < 60))) {
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 160, 0, 0, 0);
				}
				if (((v_hugo >= 60) && (v_hugo < 80))) {
					v_was = p_finden1();
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 161, 0, 0, v_was);
				}
				if (((v_hugo >= 80) && (v_hugo < 90))) {
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 163, 0, 0, 0);
				}
				if ((v_hugo >= 90)) {
					v_was = p_finden2();
					p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, 162, 0, 0, v_was);
				}
			}
		}
		p_setlaby((2 + a_raumx(a_spieler(g_akt_spieler).f_level)), (2 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((2 + a_raumx(a_spieler(g_akt_spieler).f_level)), (7 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((7 + a_raumx(a_spieler(g_akt_spieler).f_level)), (2 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_setlaby((7 + a_raumx(a_spieler(g_akt_spieler).f_level)), (7 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 25)) {
		p_sonderlevel_text(23);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 119, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 164, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 26)) {
		p_sonderlevel_text(24);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				if ((v_level < 10)) {
					v_falle = (p_random(2) + 22);
				}
				if ((v_level > 9)) {
					v_falle = (p_random(8) + 22);
				}
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, v_falle, 0, 0, 0);
			}
		}
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 4);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 4);
		p_laby_screen();
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 27)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 84, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 28)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 86, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 29)) {
		p_sonderlevel_text(25);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 3; v_i <= 7; v_i += 1) {
			for (v_j = 3; v_j <= 7; v_j += 1) {
				p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_j), a_spieler(g_akt_spieler).f_level, 107, 0, 0, 0);
			}
		}
		for (v_i = 3; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 102, 1, 0, 0);
		}
		for (v_i = 3; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 102, 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, 102, 1, 0, 0);
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, 102, 1, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 196, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 195, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 197, 0, 0, 0);
		v_welcher = p_random(2);
		switch (v_welcher) {
		case 0:
			v_koenig = 121;
			v_anhaenger = 125;
			a_spinnenkoenigin(a_spieler(g_akt_spieler).f_level) = 1;
			break;
		case 1:
			v_koenig = 122;
			v_anhaenger = 15;
			a_goblinkoenig(a_spieler(g_akt_spieler).f_level) = 1;
			break;
		case 2:
			v_koenig = 123;
			v_anhaenger = 16;
			a_untotenherr(a_spieler(g_akt_spieler).f_level) = 1;
			break;
		}
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, v_koenig, a_monster(v_koenig).f_nr, a_monster(v_koenig).f_lebenspunkte, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, v_anhaenger, a_monster(v_anhaenger).f_nr, a_monster(v_anhaenger).f_lebenspunkte, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, v_anhaenger, a_monster(v_anhaenger).f_nr, a_monster(v_anhaenger).f_lebenspunkte, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, v_anhaenger, a_monster(v_anhaenger).f_nr, a_monster(v_anhaenger).f_lebenspunkte, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 1, 0, 0);
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, v_anhaenger, a_monster(v_anhaenger).f_nr, a_monster(v_anhaenger).f_lebenspunkte, 0, 0);
		a_spieler(g_akt_spieler).f_character_x = (a_raumx(a_spieler(g_akt_spieler).f_level) + 5);
		a_spieler(g_akt_spieler).f_character_y = (a_raumy(a_spieler(g_akt_spieler).f_level) + 6);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 30)) {
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 87, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 7), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 96, 0, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 31)) {
		p_sonderlevel_text(29);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (2 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((2 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((7 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		for (v_i = 4; v_i <= 7; v_i += 1) {
			p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (7 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((4 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		for (v_i = 3; v_i <= 7; v_i += 1) {
			if ((a_spieler(g_akt_spieler).f_level < 10)) {
				v_akt_falle = (p_random(2) + 22);
			}
			if ((a_spieler(g_akt_spieler).f_level > 9)) {
				v_akt_falle = (p_random(8) + 22);
			}
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_i), a_spieler(g_akt_spieler).f_level, v_akt_falle, 0, 0, 0);
		}
		for (v_i = 4; v_i <= 6; v_i += 1) {
			if ((a_spieler(g_akt_spieler).f_level < 10)) {
				v_akt_falle = (p_random(2) + 22);
			}
			if ((a_spieler(g_akt_spieler).f_level > 9)) {
				v_akt_falle = (p_random(8) + 22);
			}
			p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, v_akt_falle, 0, 0, 0);
		}
		if ((a_spieler(g_akt_spieler).f_level < 10)) {
			v_akt_falle = (p_random(2) + 22);
		}
		if ((a_spieler(g_akt_spieler).f_level > 9)) {
			v_akt_falle = (p_random(8) + 22);
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, v_akt_falle, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 68, 0, 0, p_finden2());
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 32)) {
		p_sonderlevel_text(30);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		for (v_i = 2; v_i <= 7; v_i += 1) {
			p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (2 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		for (v_i = 2; v_i <= 6; v_i += 1) {
			p_setlaby((2 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((2 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((7 + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_i + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		for (v_i = 4; v_i <= 7; v_i += 1) {
			p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (4 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (6 + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_mit_was(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
		}
		v_mon = 139;
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, v_mon, a_monster(v_mon).f_nr, a_monster(v_mon).f_lebenspunkte, 0, 0);
		v_mon = 131;
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, v_mon, a_monster(v_mon).f_nr, a_monster(v_mon).f_lebenspunkte, 0, 0);
		v_mon = 108;
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, v_mon, a_monster(v_mon).f_nr, a_monster(v_mon).f_lebenspunkte, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 70, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 70, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 70, 0, 0, 2);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 6, 0, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 231, 0, 0);
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 33)) {
		p_sonderlevel_text(31);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 65, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 6, 0, 0, 0);
		for (v_i = 2; v_i <= 7; v_i += 1) {
			for (v_j = 2; v_j <= 7; v_j += 1) {
				if ((p_random(100) > 50)) {
					v_mon = p_ork();
					if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumx(a_spieler(g_akt_spieler).f_level) + v_j)).f_feld[a_spieler(g_akt_spieler).f_level] != 65)) {
						p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + v_i), (a_raumy(a_spieler(g_akt_spieler).f_level) + v_j), a_spieler(g_akt_spieler).f_level, v_mon, a_monster(v_mon).f_nr, a_monster(v_mon).f_lebenspunkte, 0, 0);
					}
				}
			}
		}
	}
	if ((a_raeume(a_spieler(g_akt_spieler).f_level) == 34)) {
		p_sonderlevel_text(32);
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_setlaby((v_i + a_raumx(a_spieler(g_akt_spieler).f_level)), (v_j + a_raumy(a_spieler(g_akt_spieler).f_level)), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
		}
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 207, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 136, 0, 0, 0);
		v_mon = 37;
		p_setmonster((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, v_mon, a_monster(v_mon).f_nr, a_monster(v_mon).f_lebenspunkte, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, (65 + p_random(9)), 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 2), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 6), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
		p_setitem((a_raumx(a_spieler(g_akt_spieler).f_level) + 2), (a_raumy(a_spieler(g_akt_spieler).f_level) + 7), a_spieler(g_akt_spieler).f_level, 353, 0, 0);
	}
	p_flipbuffers(1);
}

static int32_t p_read_highscores() {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_load = 0;
	v_load = 0;
	if (p_readfile(0, (g_environment + "/highscores.dat"))) {
		v_load = 1;
	} else {
		if (p_readfile(0, "./highscores.dat")) {
			v_load = 1;
		}
	}
	if ((v_load == 1)) {
		for (v_i = 1; v_i <= 30; v_i += 1) {
			a_hscores(v_i).f_version = p_readstring(0);
			a_hscores(v_i).f_name = p_readstring(0);
			a_hscores(v_i).f_level = p_readword(0);
			a_hscores(v_i).f_gold = p_readword(0);
			a_hscores(v_i).f_mks = p_readword(0);
			a_hscores(v_i).f_punkte = p_readword(0);
			a_hscores(v_i).f_maennchen = p_readword(0);
			a_hscores(v_i).f_anfangszeit = p_readstring(0);
			a_hscores(v_i).f_endezeit = p_readstring(0);
			a_hscores(v_i).f_maxlifepoints = p_readword(0);
			a_hscores(v_i).f_maxmana = p_readword(0);
			a_hscores(v_i).f_attack = p_readword(0);
			a_hscores(v_i).f_dexterity = p_readword(0);
			a_hscores(v_i).f_strength = p_readword(0);
			a_hscores(v_i).f_maxspeed = p_readword(0);
			a_hscores(v_i).f_perception = p_readword(0);
			a_hscores(v_i).f_luck_score = p_readword(0);
			a_hscores(v_i).f_power_score = p_readword(0);
			a_hscores(v_i).f_circle = p_readword(0);
			a_hscores(v_i).f_stabteile = p_readword(0);
			a_hscores(v_i).f_moves = p_readword(0);
			for (v_j = 1; v_j <= 3; v_j += 1) {
				a_hscores(v_i).f_sterbegrund[v_j] = p_readstring(0);
			}
			for (v_j = 1; v_j <= 30; v_j += 1) {
				a_hscores(v_i).f_skills[v_j] = p_readword(0);
			}
		}
		p_closefile(0);
	}
}

static int32_t p_reflexe() {
	int16_t v_akt_reflexe = 0;
	int32_t v_okay = 0;
	v_akt_reflexe = a_spieler(g_akt_spieler).f_dexterity;
	v_akt_reflexe = (v_akt_reflexe + a_spieler(g_akt_spieler).f_dexteritygegenstand);
	v_okay = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 6)) {
		v_akt_reflexe = 1;
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_fluch == 23) && (v_okay == 0))) {
		v_akt_reflexe = 1;
		v_okay = 1;
	}
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_akt_reflexe = 6;
		v_okay = 1;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_akt_reflexe = 6;
		v_okay = 1;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_akt_reflexe = 10;
		v_okay = 1;
	}
	if (((p_habich(87) > 0) && (v_okay == 0))) {
		v_akt_reflexe = 6;
		v_okay = 1;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_akt_reflexe = 1;
	}
	v_akt_reflexe = (v_akt_reflexe + p_habich(175));
	v_akt_reflexe = (v_akt_reflexe - a_spieler(g_akt_spieler).f_krankheit);
	if ((v_akt_reflexe > 15)) {
		v_akt_reflexe = 15;
	}
	return v_akt_reflexe;
}

static int32_t p_reparieren(int16_t v_feld) {
	a_inventory(v_feld, g_akt_spieler).f_status = 0;
	p_sound(38);
	p_delay(g_mydelay);
}

static int32_t p_restaurieren() {
	p_show_sight();
	if ((a_skills(80, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen3(0, 0);
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen4(0, 0);
	}
	if ((a_skills(81, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen7(0, 0);
	}
	p_laby_rahmen();
	p_show_logo();
	p_show_varys();
	p_show_buttons();
}

static int32_t p_restaurieren2() {
	p_show_sight2();
	p_laby_rahmen();
	p_show_logo();
	p_show_varys2();
	p_show_buttons2();
}

static int32_t p_save(std::string v_name) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_k = 0;
	int16_t v_save = 0;
	int32_t v_y = 0;
	v_save = 0;
	if (p_createfile(0, ((g_environment + "/") + v_name))) {
		p_writestringn(0, "10.06.2008");
		g_nr_of_saves = (g_nr_of_saves + 1);
		p_writeword(0, g_nr_of_saves);
		p_writeword(0, g_anz_spieler);
		p_writeword(0, g_sprache);
		p_writestringn(0, g_anfangszeit);
		g_anz_levels = 0;
		for (v_j = 1; v_j <= 150; v_j += 1) {
			if ((a_groesse(v_j) > 0)) {
				g_anz_levels = (g_anz_levels + 1);
			}
		}
		p_writeword(0, g_anz_levels);
		for (v_j = 1; v_j <= 20; v_j += 1) {
			p_writeword(0, a_pilz(v_j).f_nr);
			for (v_k = 1; v_k <= 3; v_k += 1) {
				p_writestringn(0, a_pilz(v_j).f_wirkung[v_k]);
			}
		}
		for (v_j = 0; v_j <= 37; v_j += 1) {
			for (v_k = 1; v_k <= 3; v_k += 1) {
				p_writestringn(0, a_gegenstand((75 + v_j)).f_name[v_k]);
			}
			p_writeword(0, a_gegenstand((75 + v_j)).f_art);
			p_writeword(0, a_gegenstand((75 + v_j)).f_einkauf);
			p_writeword(0, a_gegenstand((75 + v_j)).f_verkauf);
		}
		for (v_j = 0; v_j <= 9; v_j += 1) {
			for (v_k = 1; v_k <= 3; v_k += 1) {
				p_writestringn(0, a_gegenstand((65 + v_j)).f_name[v_k]);
			}
			p_writeword(0, a_gegenstand((65 + v_j)).f_art);
			p_writeword(0, a_gegenstand((65 + v_j)).f_einkauf);
			p_writeword(0, a_gegenstand((65 + v_j)).f_verkauf);
		}
		for (v_j = 1; v_j <= 38; v_j += 1) {
			p_writeword(0, a_mischen(v_j).f_trank1);
			p_writeword(0, a_mischen(v_j).f_trank2);
			p_writeword(0, a_mischen(v_j).f_trank3);
		}
		for (v_j = 1; v_j <= 200; v_j += 1) {
			for (v_k = 1; v_k <= 200; v_k += 1) {
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_labyrinth(v_j, v_k).f_feld[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_labyrinth(v_j, v_k).f_lebenspunkte[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_labyrinth(v_j, v_k).f_objekt[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_labyrinth(v_j, v_k).f_status[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_automap(v_j, v_k).f_feld[v_y]);
				}
			}
		}
		for (v_j = 1; v_j <= 200; v_j += 1) {
			for (v_k = 1; v_k <= 200; v_k += 1) {
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_monster(v_j, v_k).f_name[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_monster(v_j, v_k).f_graphic[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_monster(v_j, v_k).f_lifepoints[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_monster(v_j, v_k).f_status[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_monster(v_j, v_k).f_duration[v_y]);
				}
			}
		}
		for (v_j = 1; v_j <= 200; v_j += 1) {
			for (v_k = 1; v_k <= 200; v_k += 1) {
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_item(v_j, v_k).f_name[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_item(v_j, v_k).f_anzahl[v_y]);
				}
				for (v_y = 1; v_y <= g_anz_levels; v_y += 1) {
					p_writeword(0, a_laby_item(v_j, v_k).f_status[v_y]);
				}
			}
		}
		for (v_j = 1; v_j <= 150; v_j += 1) {
			p_writeword(0, a_raeume(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_raumx(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_raumy(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_ausgangx(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_ausgangy(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_eingangx(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_eingangy(v_j));
		}
		for (v_j = 1; v_j <= 150; v_j += 1) {
			p_writeword(0, a_sonderlevel(v_j));
		}
		for (v_j = 1; v_j <= 150; v_j += 1) {
			p_writeword(0, a_levelmod(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_groesse(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_inhalt(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_mit_was(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_visionen(v_j));
		}
		for (v_j = 1; v_j <= 150; v_j += 1) {
			p_writeword(0, a_fluss(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_spinnenkoenigin(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_goblinkoenig(v_j));
		}
		for (v_j = 1; v_j <= g_anz_levels; v_j += 1) {
			p_writeword(0, a_untotenherr(v_j));
		}
		for (v_j = 1; v_j <= 40; v_j += 1) {
			for (v_k = 1; v_k <= g_anz_levels; v_k += 1) {
				p_writeword(0, a_haendler_objekte(v_j, v_k));
				p_writeword(0, a_haendler_schriftrolle(v_j, v_k));
				p_writeword(0, a_haendler_staerke(v_j, v_k));
			}
		}
		for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
			p_writeword(0, a_spieler(v_i).f_status);
			p_writestringn(0, a_spieler(v_i).f_verifikation);
			p_writeword(0, a_spieler(v_i).f_level);
			p_writeword(0, a_spieler(v_i).f_maxlevel);
			p_writeword(0, a_spieler(v_i).f_maennchen);
			p_writeword(0, a_spieler(v_i).f_lifepoints);
			p_writeword(0, a_spieler(v_i).f_maxlifepoints);
			p_writeword(0, a_spieler(v_i).f_lifegain);
			p_writeword(0, a_spieler(v_i).f_mana);
			p_writeword(0, a_spieler(v_i).f_maxmana);
			p_writeword(0, a_spieler(v_i).f_managain);
			p_writeword(0, a_spieler(v_i).f_attack);
			p_writeword(0, a_spieler(v_i).f_dexterity);
			p_writeword(0, a_spieler(v_i).f_strength);
			p_writeword(0, a_spieler(v_i).f_maxspeed);
			p_writeword(0, a_spieler(v_i).f_speed);
			p_writeword(0, a_spieler(v_i).f_perception);
			p_writeword(0, a_spieler(v_i).f_luck_score);
			p_writeword(0, a_spieler(v_i).f_power_score);
			p_writeword(0, a_spieler(v_i).f_circle);
			p_writeword(0, a_spieler(v_i).f_magieresistenz);
			p_writeword(0, a_spieler(v_i).f_spellweaving);
			p_writeword(0, a_spieler(v_i).f_style);
			p_writeword(0, a_spieler(v_i).f_light);
			p_writeword(0, a_spieler(v_i).f_hunger);
			p_writeword(0, a_spieler(v_i).f_durst);
			p_writeword(0, a_spieler(v_i).f_betrunken);
			p_writeword(0, a_spieler(v_i).f_weisheit);
			p_writeword(0, a_spieler(v_i).f_schleichen);
			p_writeword(0, a_spieler(v_i).f_mks);
			p_writeword(0, a_spieler(v_i).f_fluch);
			p_writeword(0, a_spieler(v_i).f_fluchdauer);
			p_writeword(0, a_spieler(v_i).f_krankheit);
			p_writeword(0, a_spieler(v_i).f_krankheitdauer);
			p_writeword(0, a_spieler(v_i).f_gift);
			p_writeword(0, a_spieler(v_i).f_giftdauer);
			p_writeword(0, a_spieler(v_i).f_verhungern);
			p_writeword(0, a_spieler(v_i).f_verdursten);
			p_writeword(0, a_spieler(v_i).f_lifepointgegenstand);
			p_writeword(0, a_spieler(v_i).f_managegenstand);
			p_writeword(0, a_spieler(v_i).f_staerkegegenstand);
			p_writeword(0, a_spieler(v_i).f_zugweitegegenstand);
			p_writeword(0, a_spieler(v_i).f_dexteritygegenstand);
			p_writeword(0, a_spieler(v_i).f_gluecksgegenstand);
			p_writeword(0, a_spieler(v_i).f_bogentreffergegenstand);
			p_writeword(0, a_spieler(v_i).f_bogenschadengegenstand);
			p_writeword(0, a_spieler(v_i).f_powergegenstand);
			p_writeword(0, a_spieler(v_i).f_perceptiongegenstand);
			p_writeword(0, a_spieler(v_i).f_attackgegenstand);
			p_writeword(0, a_spieler(v_i).f_stealthgegenstand);
			p_writeword(0, a_spieler(v_i).f_damagegegenstand);
			p_writeword(0, a_spieler(v_i).f_lichtgegenstand);
			p_writeword(0, a_spieler(v_i).f_diebstahlgegenstand);
			p_writeword(0, a_spieler(v_i).f_goblinlehre);
			p_writeword(0, a_spieler(v_i).f_spinnenlehre);
			p_writeword(0, a_spieler(v_i).f_untotenlehre);
			p_writeword(0, a_spieler(v_i).f_pflanzenlehre);
			p_writeword(0, a_spieler(v_i).f_tierkunde);
			p_writeword(0, a_spieler(v_i).f_fallenlehre);
			p_writeword(0, a_spieler(v_i).f_giftlehre);
			p_writeword(0, a_spieler(v_i).f_pos_zaubermenue);
			p_writeword(0, a_spieler(v_i).f_dumm);
			p_writeword(0, a_spieler(v_i).f_face);
			p_writeword(0, a_spieler(v_i).f_hinterhalt);
			p_writeword(0, a_spieler(v_i).f_portal);
			p_writeword(0, a_spieler(v_i).f_teleport);
			p_writeword(0, a_spieler(v_i).f_nexus);
			p_writeword(0, a_spieler(v_i).f_stehlen);
			p_writeword(0, a_spieler(v_i).f_schriftrolle);
			p_writeword(0, a_spieler(v_i).f_zauberbuch);
			p_writeword(0, a_spieler(v_i).f_kessel);
			p_writeword(0, a_spieler(v_i).f_armageddon);
			p_writeword(0, a_spieler(v_i).f_pestilence);
			p_writeword(0, a_spieler(v_i).f_drachenform);
			p_writeword(0, a_spieler(v_i).f_macht);
			p_writeword(0, a_spieler(v_i).f_heal);
			p_writeword(0, a_spieler(v_i).f_udjat_ben);
			p_writeword(0, a_spieler(v_i).f_akt_zauber);
			p_writestringn(0, a_spieler(v_i).f_schule);
			p_writeword(0, a_spieler(v_i).f_lehrer);
			p_writeword(0, a_spieler(v_i).f_stabteile);
			p_writeword(0, a_spieler(v_i).f_moves);
			p_writeword(0, a_spieler(v_i).f_anker_x);
			p_writeword(0, a_spieler(v_i).f_anker_y);
			p_writeword(0, a_spieler(v_i).f_anker_level);
			p_writeword(0, a_spieler(v_i).f_old_pos_x);
			p_writeword(0, a_spieler(v_i).f_old_pos_y);
			p_writeword(0, a_spieler(v_i).f_old_lp);
			p_writeword(0, a_spieler(v_i).f_old_max_lp);
			p_writeword(0, a_spieler(v_i).f_old_mp);
			p_writeword(0, a_spieler(v_i).f_old_max_mp);
			for (v_k = 1; v_k <= 3; v_k += 1) {
				p_writestringn(0, a_spieler(v_i).f_sterbegrund[v_k]);
			}
			p_writeword(0, a_spieler(v_i).f_character_x);
			p_writeword(0, a_spieler(v_i).f_character_y);
			p_writeword(0, a_spieler(v_i).f_creature_typ);
			p_writeword(0, a_spieler(v_i).f_creature_lifepoints);
			p_writeword(0, a_spieler(v_i).f_creature_attack);
			p_writeword(0, a_spieler(v_i).f_creature_schaden_min);
			p_writeword(0, a_spieler(v_i).f_creature_schaden_max);
			p_writeword(0, a_spieler(v_i).f_creature_speed);
			p_writeword(0, a_spieler(v_i).f_creature_maxspeed);
			p_writeword(0, a_spieler(v_i).f_creature_x);
			p_writeword(0, a_spieler(v_i).f_creature_y);
			p_writeword(0, a_spieler(v_i).f_creature_heading);
			for (v_j = 1; v_j <= 15; v_j += 1) {
				p_writeword(0, a_aktive(v_j, v_i).f_nr);
				p_writeword(0, a_aktive(v_j, v_i).f_staerke);
				p_writeword(0, a_aktive(v_j, v_i).f_dauer);
				p_writeword(0, a_aktive(v_j, v_i).f_source);
			}
			for (v_j = 1; v_j <= 141; v_j += 1) {
				for (v_k = 1; v_k <= 3; v_k += 1) {
					p_writestringn(0, a_skills(v_j, v_i).f_name[v_k]);
				}
				p_writeword(0, a_skills(v_j, v_i).f_nummer);
				p_writeword(0, a_skills(v_j, v_i).f_kosten);
				p_writeword(0, a_skills(v_j, v_i).f_gruppe);
				for (v_k = 1; v_k <= 3; v_k += 1) {
					p_writestringn(0, a_skills(v_j, v_i).f_beschreibung_1[v_k]);
					p_writestringn(0, a_skills(v_j, v_i).f_beschreibung_2[v_k]);
				}
				p_writeword(0, a_skills(v_j, v_i).f_gewaehlt);
				p_writeword(0, a_skills(v_j, v_i).f_gelocked);
			}
			for (v_j = 1; v_j <= 50; v_j += 1) {
				p_writeword(0, a_inventory(v_j, v_i).f_name);
				p_writeword(0, a_inventory(v_j, v_i).f_art);
				p_writeword(0, a_inventory(v_j, v_i).f_benutzt);
				p_writeword(0, a_inventory(v_j, v_i).f_anzahl);
				p_writeword(0, a_inventory(v_j, v_i).f_status);
				p_writeword(0, a_inventory(v_j, v_i).f_attri1);
				p_writeword(0, a_inventory(v_j, v_i).f_attri2);
				p_writeword(0, a_inventory(v_j, v_i).f_attri3);
				p_writeword(0, a_inventory(v_j, v_i).f_attri4);
				p_writeword(0, a_inventory(v_j, v_i).f_attri5);
			}
			for (v_j = 1; v_j <= 150; v_j += 1) {
				for (v_k = 1; v_k <= 3; v_k += 1) {
					p_writestringn(0, a_zauber(v_j, v_i).f_name[v_k]);
				}
				p_writeword(0, a_zauber(v_j, v_i).f_level);
				p_writeword(0, a_zauber(v_j, v_i).f_kosten);
				p_writeword(0, a_zauber(v_j, v_i).f_dauer);
				p_writeword(0, a_zauber(v_j, v_i).f_chance);
				p_writeword(0, a_zauber(v_j, v_i).f_anhaltend);
				p_writeword(0, a_zauber(v_j, v_i).f_erlernt);
				p_writestringn(0, a_zauber(v_j, v_i).f_art);
				for (v_k = 1; v_k <= 3; v_k += 1) {
					p_writestringn(0, a_zauber(v_j, v_i).f_besch_1[v_k]);
					p_writestringn(0, a_zauber(v_j, v_i).f_besch_2[v_k]);
				}
			}
			for (v_j = 1; v_j <= 10; v_j += 1) {
				p_writestringn(0, a_schnellzauber(v_j, v_i));
			}
			for (v_j = 1; v_j <= 8; v_j += 1) {
				p_writestringn(0, a_schnellzauber2(v_j, v_i));
			}
		}
		p_closefile(0);
	} else {
		p_nachricht(407, 3);
	}
	p_nachricht(298, 1);
}

static int32_t p_save_settings() {
	int32_t v_joystick_only = 0;
	int16_t v_save = 0;
	v_save = 0;
	if (p_createfile(0, (g_environment + "/settings.txt"))) {
		p_writestringn(0, "# Lost Labyrinth Settings File");
		if ((g_sprache == 0)) {
			p_writestringn(0, "language = english   # english, german, spanish");
		}
		if ((g_sprache == 1)) {
			p_writestringn(0, "language = german   # english, german, spanish");
		}
		if ((g_sprache == 2)) {
			p_writestringn(0, "language = spanish   # english, german, spanish");
		}
		p_writestringn(0, (("mydelay  = " + p_rset(p_str(g_mydelay), 5)) + "   # Messages    (5 Digits!)"));
		p_writestringn(0, (("mydelay2 = " + p_rset(p_str(g_mydelay2), 5)) + "   # Scrolling   (5 Digits!)"));
		p_writestringn(0, (("mydelay3 = " + p_rset(p_str(g_mydelay3), 5)) + "   # Mouserefesh (5 Digits!)"));
		p_writestringn(0, (("mydelay4 = " + p_rset(p_str(g_mydelay4), 5)) + "   # Animationen (5 Digits!)"));
		if ((g_joystick_used == 0)) {
			p_writestringn(0, "joystick = no   # yes, no");
		}
		if ((g_joystick_used == 1)) {
			p_writestringn(0, "joystick = yes   # yes, no");
		}
		if ((v_joystick_only == 0)) {
			p_writestringn(0, "no_mouse = no   # yes, no");
		}
		if ((v_joystick_only == 1)) {
			p_writestringn(0, "no_mouse = yes   # yes, no");
		}
		if ((g_win_mode == 1)) {
			p_writestringn(0, "windowed = no   # yes, no");
		}
		if ((g_win_mode == 2)) {
			p_writestringn(0, "windowed = yes    # yes, no");
		}
		if ((g_sound == 1)) {
			p_writestringn(0, "sound = yes   # yes, no");
		}
		if ((g_sound == 0)) {
			p_writestringn(0, "sound = no    # yes, no");
		}
		if ((g_music == 1)) {
			p_writestringn(0, "music = yes   # yes, no");
		}
		if ((g_music == 0)) {
			p_writestringn(0, "music = no    # yes, no");
		}
		if ((g_klicking == 1)) {
			p_writestringn(0, "klicking = yes   # yes, no");
		}
		if ((g_klicking == 0)) {
			p_writestringn(0, "klicking = no    # yes, no");
		}
		if ((g_autopickup == 1)) {
			p_writestringn(0, "auto-toggle = yes   # yes, no");
		}
		if ((g_autopickup == 0)) {
			p_writestringn(0, "auto-toggle = no    # yes, no");
		}
		if ((g_knopf5 == 1)) {
			p_writestringn(0, "button5 = yes   # yes, no");
		}
		if ((g_knopf5 == 0)) {
			p_writestringn(0, "button5 = no    # yes, no");
		}
		if ((g_flaschen == 1)) {
			p_writestringn(0, "jars = yes   # yes, no");
		}
		if ((g_flaschen == 0)) {
			p_writestringn(0, "jars = no    # yes, no");
		}
		if ((g_roomtest == 1)) {
			p_writestringn(0, "roomtest = yes   # yes, no");
		}
		if ((g_roomtest == 0)) {
			p_writestringn(0, "roomtest = no    # yes, no");
		}
		p_closefile(0);
		return 1;
	} else {
		return 0;
	}
}

static int32_t p_saving_screen() {
	std::string v_akt_datum;
	int32_t v_egon = 0;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_x_old = 0;
	int32_t v_mouse_y_old = 0;
	std::string v_myname;
	int16_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_save = 0;
	int32_t v_sel = 0;
	int32_t v_warten = 0;
	int32_t v_willi = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_raus = 0;
	v_save = 0;
	if (p_readfile(0, (g_environment + "/savenames.sav"))) {
		v_save = 1;
	} else {
		if (p_readfile(0, "./savenames.sav")) {
			v_save = 1;
		}
	}
	if ((v_save == 1)) {
		for (v_i = 1; v_i <= 10; v_i += 1) {
			a_savenames(v_i) = p_readstring(0);
			a_savedatum(v_i) = p_readstring(0);
		}
		p_closefile(0);
	}
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_yy = 65;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, v_yy, a_nachricht_text(568, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(190, v_yy, a_nachricht_text(569, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = (v_sel - 1);
			if ((v_sel < 1)) {
				v_sel = 1;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = (v_sel + 1);
			if ((v_sel > 10)) {
				v_sel = 10;
			}
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		for (v_willi = 1; v_willi <= 10; v_willi += 1) {
			if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > (100 + (v_willi * 20)))) && (v_mmouse_y < (120 + (v_willi * 20))))) {
				p_frontcolor(p_rgb(150, 150, 150));
				p_box(40, (100 + (v_willi * 20)), 400, 20, -1);
				if ((v_sel == 1)) {
					p_frontcolor(p_rgb(1, 1, 255));
				} else {
					p_frontcolor(p_rgb(255, 255, 255));
				}
				p_drawtext(40, (100 + (v_willi * 20)), p_str(v_willi), -1, 0);
				if ((v_mmouse_links == 1)) {
					v_raus = 1;
					v_save = v_willi;
				}
			} else {
				if ((v_sel == v_willi)) {
					p_frontcolor(p_rgb(1, 1, 255));
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						v_raus = 1;
						v_save = v_willi;
					}
				} else {
					p_frontcolor(p_rgb(255, 255, 255));
				}
				p_drawtext(40, (100 + (v_willi * 20)), p_str(v_willi), -1, 0);
			}
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(150, (100 + (v_willi * 20)), a_savenames(v_willi), -1, 0);
			if ((a_savedatum(v_willi) != "")) {
				v_akt_datum = p_formatdate("%dd.%mm.%yyyy %hh:%ii", p_parsedate("%yyyy%mm%dd%hh%ii%ss", a_savedatum(v_willi)));
				p_drawtext(450, (100 + (v_willi * 20)), v_akt_datum, -1, 0);
			}
		}
		p_stopdrawing();
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
		p_delay(50);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	if ((v_save > 0)) {
		v_myname = a_savenames(v_save);
		do {
			p_fenster(0);
			p_clearscreen(p_rgb(0, 0, 0));
			v_yy = 65;
			p_clipsprite(54, 0, 0, 640, 17);
			p_displaytransparentsprite(54, 0, 0);
			p_clipsprite(56, 0, 0, 17, 480);
			p_displaytransparentsprite(56, 0, 0);
			p_clipsprite(57, 0, 0, 640, 17);
			p_displaytransparentsprite(57, 0, 463);
			p_clipsprite(59, 0, 0, 17, 480);
			p_displaytransparentsprite(59, 623, 0);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(190, v_yy, a_nachricht_text(568, (1 + g_sprache)), -1, 0);
			v_yy = (v_yy + 15);
			p_drawtext(190, v_yy, a_nachricht_text(569, (1 + g_sprache)), -1, 0);
			p_stopdrawing();
			for (v_willi = 1; v_willi <= 10; v_willi += 1) {
				if ((v_willi == v_save)) {
					p_frontcolor(p_rgb(150, 150, 150));
					p_box(40, (100 + (v_save * 20)), 550, 20, -1);
				}
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(40, (100 + (v_willi * 20)), p_str(v_willi), -1, 0);
				p_stopdrawing();
			}
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(100, (100 + (v_save * 20)), a_nachricht_text(571, (1 + g_sprache)), -1, 0);
			p_drawtext(200, (100 + (v_save * 20)), v_myname, -1, 0);
			p_stopdrawing();
			if ((g_no_mouse == 0)) {
				v_result = p_examinemouse();
				v_mmouse_x = p_mousex();
				v_mmouse_y = p_mousey();
				v_mmouse_links = p_mousebutton(1);
				v_mmouse_rechts = p_mousebutton(2);
				p_clipsprite(8, 192, 288, 32, 32);
				p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
				v_mouse_x_old = v_mmouse_x;
				v_mouse_y_old = v_mmouse_y;
			}
			if ((g_joystick_used == 1)) {
				v_jax = 0;
				v_jay = 0;
				v_jb2 = 0;
				p_examinejoystick();
				v_jax = p_joystickaxisx();
				v_jay = p_joystickaxisy();
				v_jb2 = p_joystickbutton(2);
			}
			v_myname = p_keyboard_string(v_myname, 0);
			if ((p_len(v_myname) > 25)) {
				v_myname = p_mid(v_myname, 1, 25);
			}
			v_warten = (v_warten + 1);
			if ((v_warten < 3)) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_line((200 + p_textwidth(v_myname)), (102 + (v_save * 20)), 0, 15, -1);
				p_line((201 + p_textwidth(v_myname)), (102 + (v_save * 20)), 0, 15, -1);
				p_stopdrawing();
			}
			if ((v_warten > 4)) {
				v_warten = 0;
			}
			p_flipbuffers(1);
			p_delay(1);
		} while (!((((p_keyboardpushed(13) || (v_jb2 == 1)) && (v_myname != "")) || p_keyboardpushed(27)) || (v_mmouse_rechts == 1)));
		if ((v_myname != "")) {
			a_savenames(v_save) = v_myname;
			a_savedatum(v_save) = p_formatdate("%yyyy%mm%dd%hh%ii%ss", p_date());
			if (p_createfile(0, "./savenames.sav")) {
				for (v_egon = 1; v_egon <= 10; v_egon += 1) {
					p_writestringn(0, a_savenames(v_egon));
					p_writestringn(0, a_savedatum(v_egon));
				}
				p_closefile(0);
			}
			p_save((("laby" + p_str(v_save)) + ".sav"));
		}
	}
}

static int32_t p_schaden_critical() {
	int16_t v_bonus = 0;
	int32_t v_i = 0;
	int16_t v_schaden_critical = 0;
	int16_t v_waffe = 0;
	v_schaden_critical = 0;
	v_waffe = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_bonus = 0;
			if ((a_inventory(v_i, g_akt_spieler).f_status == 0)) {
				v_bonus = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri3;
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 1)) {
				v_bonus = (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri3 / 2);
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 2)) {
				v_bonus = 0;
			}
			v_waffe = (v_waffe + v_bonus);
		}
	}
	if ((v_waffe > 0)) {
		v_schaden_critical = v_waffe;
	}
	v_schaden_critical = (v_schaden_critical + (p_reflexe() + p_luck()));
	if ((a_spieler(g_akt_spieler).f_style == 4)) {
		v_schaden_critical = (v_schaden_critical * 2);
	}
	if ((a_skills(76, g_akt_spieler).f_gewaehlt == 1)) {
		v_schaden_critical = (v_schaden_critical * 2);
	}
	if ((p_habich(120) > 0)) {
		v_schaden_critical = (v_schaden_critical + (p_habich(120) * 4));
	}
	if ((a_skills(76, g_akt_spieler).f_gewaehlt == 1)) {
		if ((v_schaden_critical > 45)) {
			v_schaden_critical = 45;
		}
	} else {
		if ((v_schaden_critical > 30)) {
			v_schaden_critical = 30;
		}
	}
	if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 28) == 1)) {
		v_schaden_critical = 0;
	}
	return v_schaden_critical;
}

static int32_t p_schaden_max() {
	int16_t v_akt_str = 0;
	int16_t v_bonus = 0;
	int32_t v_i = 0;
	int32_t v_okay = 0;
	int16_t v_schaden_max = 0;
	int16_t v_waffe = 0;
	v_schaden_max = 0;
	v_waffe = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_bonus = 0;
			if ((a_inventory(v_i, g_akt_spieler).f_status == 0)) {
				v_bonus = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2;
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 1)) {
				v_bonus = (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2 / 2);
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 2)) {
				v_bonus = 0;
			}
			v_waffe = (v_waffe + v_bonus);
		}
	}
	v_akt_str = p_staerke();
	if ((a_skills(4, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_str = (v_akt_str * 2);
	}
	if ((v_waffe > 0)) {
		v_schaden_max = ((2 + v_akt_str) + v_waffe);
	} else {
		v_schaden_max = (2 + v_akt_str);
	}
	v_schaden_max = ((v_schaden_max + p_habich(35)) + p_habich(85));
	if ((a_skills(17, g_akt_spieler).f_gewaehlt == 1)) {
		v_okay = 0;
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 4)) && (v_okay == 0))) {
			v_schaden_max = (v_schaden_max * 5);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 3)) && (v_okay == 0))) {
			v_schaden_max = (v_schaden_max * 4);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 2)) && (v_okay == 0))) {
			v_schaden_max = (v_schaden_max * 3);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 1.5)) && (v_okay == 0))) {
			v_schaden_max = (v_schaden_max * 2);
			v_okay = 1;
		}
	}
	v_schaden_max = (v_schaden_max + a_spieler(g_akt_spieler).f_damagegegenstand);
	if (((a_skills(21, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(1) == 1))) {
		v_schaden_max = (v_schaden_max + 2);
	}
	if (((a_skills(22, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(2) == 1))) {
		v_schaden_max = (v_schaden_max + 2);
	}
	if (((a_skills(23, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(3) == 1))) {
		v_schaden_max = (v_schaden_max + 2);
	}
	if (((a_skills(24, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(4) == 1))) {
		v_schaden_max = (v_schaden_max + 2);
	}
	if (((a_skills(25, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(10) == 0))) {
		v_schaden_max = (v_schaden_max + 3);
	}
	if (((p_ich_trage(10) == 0) && (a_skills(25, g_akt_spieler).f_gewaehlt == 0))) {
		v_schaden_max = (v_schaden_max / 2);
	}
	return v_schaden_max;
}

static int32_t p_schaden_min() {
	int16_t v_akt_str = 0;
	int16_t v_bonus = 0;
	int32_t v_i = 0;
	int32_t v_okay = 0;
	int16_t v_schaden_min = 0;
	int16_t v_waffe = 0;
	v_schaden_min = 0;
	v_waffe = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_bonus = 0;
			if ((a_inventory(v_i, g_akt_spieler).f_status == 0)) {
				v_bonus = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2;
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 1)) {
				v_bonus = (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2 / 2);
			}
			if ((a_inventory(v_i, g_akt_spieler).f_status == 2)) {
				v_bonus = 0;
			}
			v_waffe = (v_waffe + v_bonus);
		}
	}
	v_akt_str = p_staerke();
	if ((a_skills(4, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_str = (v_akt_str * 2);
	}
	if ((v_waffe > 0)) {
		v_schaden_min = ((v_akt_str / 2) + v_waffe);
	} else {
		v_schaden_min = (v_akt_str / 2);
	}
	v_schaden_min = ((v_schaden_min + p_habich(35)) + p_habich(85));
	if ((a_skills(17, g_akt_spieler).f_gewaehlt == 1)) {
		v_okay = 0;
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 4)) && (v_okay == 0))) {
			v_schaden_min = (v_schaden_min * 5);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 3)) && (v_okay == 0))) {
			v_schaden_min = (v_schaden_min * 4);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 2)) && (v_okay == 0))) {
			v_schaden_min = (v_schaden_min * 3);
			v_okay = 1;
		}
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 1.5)) && (v_okay == 0))) {
			v_schaden_min = (v_schaden_min * 2);
			v_okay = 1;
		}
	}
	v_schaden_min = (v_schaden_min + a_spieler(g_akt_spieler).f_damagegegenstand);
	if (((a_skills(21, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(1) == 1))) {
		v_schaden_min = (v_schaden_min + 2);
	}
	if (((a_skills(22, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(2) == 1))) {
		v_schaden_min = (v_schaden_min + 2);
	}
	if (((a_skills(23, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(3) == 1))) {
		v_schaden_min = (v_schaden_min + 2);
	}
	if (((a_skills(24, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(4) == 1))) {
		v_schaden_min = (v_schaden_min + 2);
	}
	if (((a_skills(25, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(10) == 0))) {
		v_schaden_min = (v_schaden_min + 3);
	}
	if (((p_ich_trage(10) == 0) && (a_skills(25, g_akt_spieler).f_gewaehlt == 0))) {
		v_schaden_min = (v_schaden_min / 2);
	}
	return v_schaden_min;
}

static int32_t p_schleichen() {
	int32_t v_akt_schleichen = 0;
	int32_t v_okay = 0;
	if ((a_skills(73, g_akt_spieler).f_gewaehlt == 1)) {
		v_akt_schleichen = ((((p_luck() * 5) + (a_spieler(g_akt_spieler).f_dexterity * 10)) + a_spieler(g_akt_spieler).f_stealthgegenstand) + 25);
	} else {
		v_akt_schleichen = (((p_luck() * 5) + (a_spieler(g_akt_spieler).f_dexterity * 5)) + a_spieler(g_akt_spieler).f_stealthgegenstand);
	}
	v_okay = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
		v_akt_schleichen = 0;
		v_okay = 1;
	}
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_akt_schleichen = 70;
		v_okay = 1;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_akt_schleichen = 70;
		v_okay = 1;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_akt_schleichen = 70;
		v_okay = 1;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_akt_schleichen = 0;
	}
	if ((p_habich(110) > 0)) {
		v_akt_schleichen = (v_akt_schleichen + 40);
	}
	p_schutz();
	v_akt_schleichen = (v_akt_schleichen - (g_behinderung * 10));
	v_akt_schleichen = (v_akt_schleichen - (a_monster(a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_objekt[a_spieler(g_akt_spieler).f_level]).f_minlevel * 2));
	if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 2)) {
		v_akt_schleichen = (v_akt_schleichen + 40);
	}
	if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
		v_akt_schleichen = 0;
	}
	if ((v_akt_schleichen < 1)) {
		v_akt_schleichen = 0;
	}
	if ((v_akt_schleichen > 80)) {
		v_akt_schleichen = 80;
	}
	return v_akt_schleichen;
}

static int32_t p_schnelltasten() {
	int8_t v_xx = 0;
	if ((p_keyboardpushed(49) && (a_schnellzauber(1, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(1, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(50) && (a_schnellzauber(2, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(2, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(51) && (a_schnellzauber(3, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(3, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(52) && (a_schnellzauber(4, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(4, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(53) && (a_schnellzauber(5, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(5, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(54) && (a_schnellzauber(6, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(6, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(55) && (a_schnellzauber(7, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(7, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(56) && (a_schnellzauber(8, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(8, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(57) && (a_schnellzauber(9, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(9, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((p_keyboardpushed(48) && (a_schnellzauber(10, g_akt_spieler) != ""))) {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber(10, g_akt_spieler);
		p_cast_it();
		p_laby_screen();
		throw Lv_nach_zauber;
	}
	if ((g_joystick_used == 1)) {
		for (v_xx = 1; v_xx <= 8; v_xx += 1) {
			if ((p_joystickbutton((v_xx + 4)) && (a_schnellzauber2(v_xx, g_akt_spieler) != ""))) {
				a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = a_schnellzauber2(v_xx, g_akt_spieler);
				p_cast_it();
				p_laby_screen();
				throw Lv_nach_zauber;
			}
		}
	}
}

static int32_t p_schulenicons() {
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_result = 0;
	int16_t v_x = 0;
	int16_t v_y = 0;
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mouse_links = p_mousebutton(1);
		v_mouse_rechts = p_mousebutton(2);
	}
	v_x = 215;
	v_y = 371;
	p_clipsprite(64, 19, 0, 16, 19);
	p_displaysprite(64, v_x, v_y);
	if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
		a_spieler(g_akt_spieler).f_schule = "";
		p_erstelle_liste();
		a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
		g_akt_zauber = 0;
	}
	v_x = (v_x + 19);
	if ((a_skills(133, g_akt_spieler).f_gewaehlt == 0)) {
		p_clipsprite(64, 57, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "basis";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if (((a_skills(64, g_akt_spieler).f_gewaehlt == 1) || (a_skills(65, g_akt_spieler).f_gewaehlt == 1))) {
		p_clipsprite(64, 285, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "frei";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(48, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 190, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "sterne";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(49, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 171, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "illusion";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(50, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 209, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "warlock";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(51, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 247, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "weiss";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(52, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 76, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "schwarz";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if (((a_skills(53, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1))) {
		p_clipsprite(64, 133, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "feuer";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if (((a_skills(54, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1))) {
		p_clipsprite(64, 228, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "wasser";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if (((a_skills(55, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1))) {
		p_clipsprite(64, 114, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "erde";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if (((a_skills(56, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1))) {
		p_clipsprite(64, 0, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "luft";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(57, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 95, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "druide";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(58, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 266, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "hexerei";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(59, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 152, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "hohe";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(60, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 38, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "barde";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
	if ((a_skills(67, g_akt_spieler).f_gewaehlt == 1)) {
		p_clipsprite(64, 304, 0, 16, 19);
		p_displaysprite(64, v_x, v_y);
		if ((((((v_mouse_links == 1) && (v_mmouse_x >= v_x)) && (v_mmouse_x <= (v_x + 16))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 16)))) {
			a_spieler(g_akt_spieler).f_schule = "beschw\357\277\275er";
			p_erstelle_liste();
			a_spieler(g_akt_spieler).f_pos_zaubermenue = 0;
			g_akt_zauber = 0;
		}
		v_x = (v_x + 19);
	}
}

static int32_t p_schutz() {
	int32_t v_i = 0;
	int16_t v_okay = 0;
	g_schutz_min = 0;
	g_schutz_max = 0;
	g_behinderung = 0;
	v_okay = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
		v_okay = 1;
		g_schutz_min = 0;
		g_schutz_max = 1;
	}
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_okay = 1;
		g_schutz_min = 0;
		g_schutz_max = 4;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_okay = 1;
		g_schutz_min = 0;
		g_schutz_max = 5;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_okay = 1;
		g_schutz_min = 1;
		g_schutz_max = 6;
	}
	if (((p_habich(87) > 0) && (v_okay == 0))) {
		v_okay = 1;
		g_schutz_min = 1;
		g_schutz_max = 6;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_okay = 1;
		g_schutz_min = 3;
		g_schutz_max = 12;
	}
	if ((v_okay == 0)) {
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 6) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				g_schutz_min = (g_schutz_min + p_schutz_min(v_i));
				g_schutz_max = (g_schutz_max + p_schutz_max(v_i));
				g_behinderung = (g_behinderung + p_schutz_behinderung(v_i));
			}
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 7) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				g_schutz_min = (g_schutz_min + p_schutz_min(v_i));
				g_schutz_max = (g_schutz_max + p_schutz_max(v_i));
				g_behinderung = (g_behinderung + p_schutz_behinderung(v_i));
			}
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 8) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				g_schutz_min = (g_schutz_min + p_schutz_min(v_i));
				g_schutz_max = (g_schutz_max + p_schutz_max(v_i));
				g_behinderung = (g_behinderung + p_schutz_behinderung(v_i));
			}
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 9) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				g_schutz_min = (g_schutz_min + p_schutz_min(v_i));
				g_schutz_max = (g_schutz_max + p_schutz_max(v_i));
				g_behinderung = (g_behinderung + p_schutz_behinderung(v_i));
			}
		}
		for (v_i = 1; v_i <= 50; v_i += 1) {
			if (((a_inventory(v_i, g_akt_spieler).f_art == 11) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
				g_schutz_min = (g_schutz_min + p_schutz_min(v_i));
				g_schutz_max = (g_schutz_max + p_schutz_max(v_i));
				g_behinderung = (g_behinderung + p_schutz_behinderung(v_i));
			}
		}
	}
}

static int32_t p_schutz_behinderung(int32_t v_i) {
	int16_t v_bonus_behinderung = 0;
	v_bonus_behinderung = 0;
	v_bonus_behinderung = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri1;
	return v_bonus_behinderung;
}

static int32_t p_schutz_max(int32_t v_i) {
	int16_t v_bonus_max = 0;
	v_bonus_max = 0;
	if ((a_inventory(v_i, g_akt_spieler).f_status == 0)) {
		v_bonus_max = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri3;
	}
	if ((a_inventory(v_i, g_akt_spieler).f_status == 1)) {
		v_bonus_max = (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri3 / 2);
	}
	return v_bonus_max;
}

static int32_t p_schutz_min(int32_t v_i) {
	int16_t v_bonus_min = 0;
	v_bonus_min = 0;
	if ((a_inventory(v_i, g_akt_spieler).f_status == 0)) {
		v_bonus_min = a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2;
	}
	if ((a_inventory(v_i, g_akt_spieler).f_status == 1)) {
		v_bonus_min = (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri2 / 2);
	}
	return v_bonus_min;
}

static int32_t p_screen1(int16_t v_i) {
	int16_t v_okay = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_draw_screen(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	v_okay = 0;
	if ((a_skills(80, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen3(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen4(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	if ((a_skills(81, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen7(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	p_show_sight();
	if ((a_skills(80, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen3(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen4(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	if ((a_skills(81, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen7(((g_xmod * v_i) * -1), ((g_ymod * v_i) * -1));
	}
	p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
	p_laby_rahmen();
	p_show_logo();
	p_show_varys();
	p_show_buttons();
	p_show_schnellinventory();
}

static int32_t p_screen2() {
	int16_t v_okay = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	v_okay = 0;
	p_draw_screen(0, 0);
	if ((a_skills(80, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen3(0, 0);
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen4(0, 0);
	}
	if ((a_skills(81, g_akt_spieler).f_gewaehlt == 0)) {
		p_draw_screen7(0, 0);
	}
	p_show_sight();
	if ((a_skills(80, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen3(0, 0);
	}
	if ((a_skills(79, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen4(0, 0);
	}
	if ((a_skills(81, g_akt_spieler).f_gewaehlt == 1)) {
		p_draw_screen7(0, 0);
	}
	p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
	p_laby_rahmen();
	p_show_logo();
	p_show_varys();
	p_show_buttons();
	p_show_schnellinventory();
}

static int32_t p_select_inventory(int16_t v_nachricht) {
	int16_t v_a = 0;
	int16_t v_b = 0;
	int16_t v_bew_geg_x = 0;
	int16_t v_bew_geg_y = 0;
	int16_t v_c = 0;
	int16_t v_d = 0;
	int32_t v_gewaehlt = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int16_t v_mmouse_x = 0;
	int16_t v_mmouse_x_old = 0;
	int16_t v_mmouse_y = 0;
	int16_t v_mmouse_y_old = 0;
	int16_t v_okay = 0;
	int32_t v_pos = 0;
	int32_t v_raus_hier = 0;
	int32_t v_result = 0;
	int16_t v_savepos = 0;
	int32_t v_savepos1 = 0;
	int16_t v_sel_x = 0;
	int16_t v_sel_x_old = 0;
	int16_t v_sel_y = 0;
	int16_t v_sel_y_old = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int32_t v_verkauf = 0;
	int32_t v_verkaufobjekt = 0;
	int16_t v_weg = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_sel_x = 1;
	v_sel_y = 1;
	v_sel_x_old = v_sel_x;
	v_sel_y_old = v_sel_y;
	v_bew_geg_x = 0;
	v_bew_geg_y = 0;
	v_mmouse_x = p_mousex();
	v_mmouse_y = p_mousey();
	v_mmouse_x_old = v_mmouse_x;
	v_mmouse_y_old = v_mmouse_y;
	p_delay(g_mydelay);
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, 25, p_nachricht4(v_nachricht), -1, 0);
		p_stopdrawing();
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			v_sel_x = (v_sel_x + 1);
			if ((v_sel_x > 16)) {
				v_sel_x = 16;
			}
		} else {
			if ((p_keyboardpushed(276) || (v_jax == -1))) {
				v_sel_x = (v_sel_x - 1);
				if ((v_sel_x < 1)) {
					v_sel_x = 1;
				}
			} else {
				if ((p_keyboardpushed(274) || (v_jay == 1))) {
					v_sel_y = (v_sel_y + 1);
					if ((v_sel_y > 5)) {
						v_sel_y = 5;
					}
				} else {
					if ((p_keyboardpushed(273) || (v_jay == -1))) {
						v_sel_y = (v_sel_y - 1);
						if ((v_sel_y < 1)) {
							v_sel_y = 1;
						}
					}
				}
			}
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		v_x = 200;
		v_y = 60;
		for (v_i = 1; v_i <= 8; v_i += 1) {
			for (v_j = 1; v_j <= 5; v_j += 1) {
				v_a = (v_x + ((v_i * 32) - 32));
				v_b = (v_x + (v_i * 32));
				v_c = (v_y + ((v_j * 32) - 32));
				v_d = (v_y + (v_j * 32));
				if (((((v_mmouse_x > v_a) && (v_mmouse_x < v_b)) && (v_mmouse_y > v_c)) && (v_mmouse_y < v_d))) {
					if (((v_sel_x == v_i) && (v_sel_y == v_j))) {
						p_clipsprite(1, 0, 32, 32, 32);
						p_displaytransparentsprite(1, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					} else {
						p_clipsprite(8, 224, 320, 32, 32);
						p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					}
					if (((v_mmouse_x_old != v_mmouse_x) || (v_mmouse_y_old != v_mmouse_y))) {
						v_mmouse_x_old = v_mmouse_x;
						v_mmouse_y_old = v_mmouse_y;
						v_verkaufobjekt = a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_name;
						v_savepos = (v_i + ((8 * v_j) - 8));
					}
					if ((v_mmouse_links == 1)) {
						v_verkauf = 99;
					}
				} else {
					p_clipsprite(8, 480, 64, 32, 32);
					p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
				}
				if ((((v_i == v_sel_x) && (v_j == v_sel_y)) && (v_gewaehlt == 0))) {
					p_clipsprite(1, 0, 32, 32, 32);
					p_displaytransparentsprite(1, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
					v_gewaehlt = 0;
					if (((v_sel_x_old != v_sel_x) || (v_sel_y_old != v_sel_y))) {
						v_sel_x_old = v_sel_x;
						v_sel_y_old = v_sel_y;
						v_verkaufobjekt = a_inventory((v_i + ((8 * v_j) - 8)), g_akt_spieler).f_name;
						v_savepos = (v_i + ((8 * v_j) - 8));
					}
					if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
						v_verkauf = 99;
						v_gewaehlt = 1;
					}
				}
				v_pos = (v_i + ((8 * v_j) - 8));
				if ((v_verkauf == 99)) {
					v_verkauf = v_pos;
				}
				if ((a_inventory(v_pos, g_akt_spieler).f_benutzt == 1)) {
					p_frontcolor(p_rgb(120, 120, 120));
					p_box((v_x + ((v_i * 32) - 31)), (v_y + ((v_j * 32) - 31)), 30, 29, -1);
				}
				v_sprite_x = a_inventory(v_pos, g_akt_spieler).f_name;
				v_sprite_y = 0;
				if ((v_sprite_x > 16)) {
					do {
						v_sprite_y = (v_sprite_y + 1);
						v_sprite_x = (v_sprite_x - 16);
					} while (!(v_sprite_x < 17));
				}
				p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
				p_displaytransparentsprite(8, (v_x + ((v_i * 32) - 32)), (v_y + ((v_j * 32) - 32)));
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		v_weg = p_details(v_verkaufobjekt);
		if ((v_verkaufobjekt == 38)) {
			v_weg = 1;
			if (((a_skills(47, g_akt_spieler).f_gewaehlt == 0) && (a_skills(64, g_akt_spieler).f_gewaehlt == 0))) {
				p_drawtext(200, 315, a_nachricht_text(584, (1 + g_sprache)), -1, 0);
			} else {
				p_drawtext(200, 315, a_zauber(a_inventory(v_savepos, g_akt_spieler).f_attri1, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
			}
		}
		v_okay = 0;
		if (((v_verkaufobjekt >= 75) && (v_verkaufobjekt <= 112))) {
			if ((((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (a_inventory(v_savepos1, g_akt_spieler).f_status == 0))) {
				p_drawtext(200, 315, a_nachricht_text(586, (1 + g_sprache)), -1, 0);
				v_okay = 1;
			}
		}
		if (((v_verkaufobjekt >= 65) && (v_verkaufobjekt <= 74))) {
			if ((a_skills(113, g_akt_spieler).f_gewaehlt == 0)) {
				p_drawtext(200, 315, a_nachricht_text(585, (1 + g_sprache)), -1, 0);
				v_okay = 1;
			}
		}
		if ((v_okay == 0)) {
			p_drawtext(200, 275, a_gegenstand(v_verkaufobjekt).f_name[(1 + g_sprache)], -1, 0);
		}
		if ((v_weg == 0)) {
			if ((a_gegenstand(v_verkaufobjekt).f_qualitaet > 0)) {
				p_drawtext(200, 300, (("+" + p_str(a_haendler_staerke(v_pos, a_spieler(g_akt_spieler).f_level))) + a_gegenstand(v_verkaufobjekt).f_info[(1 + g_sprache)]), -1, 0);
			} else {
				p_drawtext(200, 300, a_gegenstand(v_verkaufobjekt).f_info[(1 + g_sprache)], -1, 0);
			}
		}
		p_stopdrawing();
		if ((((v_verkauf > 0) && (a_inventory(v_verkauf, g_akt_spieler).f_benutzt == 0)) && (a_inventory(v_verkauf, g_akt_spieler).f_name != 0))) {
			v_raus_hier = 1;
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!((((v_mmouse_rechts == 1) || (v_raus_hier > 0)) || (v_jb2 != 0)) || (v_gewaehlt > 0)));
	p_autodelay(1, 5, -2);
	p_delay(g_mydelay);
	return v_verkauf;
}

static int32_t p_select_skills() {
	int16_t v_back_button = 0;
	int16_t v_besch = 0;
	int32_t v_i = 0;
	int32_t v_ignore = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_linksold = 0;
	int32_t v_mouse_over_deleteall = 0;
	int32_t v_mouse_over_skills = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_released = 0;
	int32_t v_mouse_x = 0;
	int16_t v_mouse_x_old = 0;
	int32_t v_mouse_y = 0;
	int16_t v_mouse_y_old = 0;
	int32_t v_mydelay3 = 0;
	int32_t v_ok_button = 0;
	int16_t v_pos_aktuell = 0;
	int16_t v_pressed = 0;
	int32_t v_reloadkeys = 0;
	int32_t v_result = 0;
	int32_t v_tooltip = 0;
	int32_t v_upsidedown_offset = 0;
	int32_t v_warten = 0;
	int16_t v_warten2 = 0;
	int32_t v_wohin = 0;
	int16_t v_zw_skill = 0;
	int16_t v_zw_x = 0;
	int16_t v_zw_y = 0;
	v_mydelay3 = 0;
	v_ok_button = 0;
	v_warten = v_mydelay3;
	v_pos_aktuell = -1;
	v_warten2 = 0;
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		v_mouse_x_old = p_mousex();
		v_mouse_y_old = p_mousey();
	}
	do {
		p_fenster(0);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		p_examinekeyboard();
		if (p_keyboardpushed(27)) {
			if ((g_released == 0)) {
				v_result = p_releasemouse(1);
				g_released = 1;
				p_delay(g_mydelay);
			} else {
				v_result = p_releasemouse(0);
				g_released = 0;
				p_delay(g_mydelay);
			}
		}
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			v_besch = 2;
			if (((v_warten2 <= 0) || (v_reloadkeys == 0))) {
				v_reloadkeys = 1;
				if (((v_pos_aktuell + 27) < (162 + v_upsidedown_offset))) {
					v_pos_aktuell = (v_pos_aktuell + 27);
					v_warten2 = 5;
				}
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			v_besch = 2;
			if (((v_warten2 <= 0) || (v_reloadkeys == 0))) {
				v_reloadkeys = 1;
				if (((v_pos_aktuell - 27) >= 0)) {
					v_pos_aktuell = (v_pos_aktuell - 27);
					v_warten2 = 5;
				}
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_besch = 2;
			if (((v_warten2 <= 0) || (v_reloadkeys == 0))) {
				v_reloadkeys = 1;
				if (((v_pos_aktuell + 1) < (162 + v_upsidedown_offset))) {
					v_pos_aktuell = (v_pos_aktuell + 1);
					v_warten2 = 5;
				}
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_besch = 2;
			if (((v_warten2 <= 0) || (v_reloadkeys == 0))) {
				v_reloadkeys = 1;
				if (((v_pos_aktuell - 1) >= 1)) {
					v_pos_aktuell = (v_pos_aktuell - 1);
					v_warten2 = 5;
				} else {
					v_pos_aktuell = 1;
				}
			}
		}
		if ((v_warten2 > 0)) {
			v_warten2 = (v_warten2 - 1);
		}
		if ((v_pos_aktuell > 140)) {
			v_pos_aktuell = 140;
		}
		if ((v_reloadkeys == 1)) {
			if ((g_currentstyp != 0)) {
				if ((v_pos_aktuell < a_skilltyp_offset(g_currentstyp))) {
					v_pos_aktuell = a_skilltyp_offset(g_currentstyp);
				}
				if ((v_pos_aktuell > (a_skilltyp_offset(g_currentstyp) + a_skilltyp_range(g_currentstyp)))) {
					v_pos_aktuell = (a_skilltyp_offset(g_currentstyp) + a_skilltyp_range(g_currentstyp));
				}
			}
			if ((v_pos_aktuell > ((27 * ((g_skills_menu - 1) + 2)) + v_upsidedown_offset))) {
				g_skills_menu = (g_skills_menu + 1);
			}
			if ((v_pos_aktuell < (27 * (g_skills_menu - 1)))) {
				g_skills_menu = (g_skills_menu - 1);
			}
			if ((g_skills_menu < 1)) {
				g_skills_menu = 1;
			}
			a_skilltyp_offset(2) = (a_skilltyp_offset(1) + a_skilltyp_range(1));
			if ((g_skills_menu > 5)) {
				g_skills_menu = 5;
			}
		}
		if ((((((v_reloadkeys == 1) && (p_keyboardpushed(273) == 0)) && (p_keyboardpushed(274) == 0)) && (p_keyboardpushed(276) == 0)) && (p_keyboardpushed(275) == 0))) {
			v_reloadkeys = 0;
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mouse_x = p_mousex();
			v_mouse_y = p_mousey();
			v_mouse_linksold = v_mouse_links;
			v_mouse_links = p_mousebutton(1);
			if (((v_mouse_linksold == 1) && (v_mouse_links == 0))) {
				v_mouse_released = 1;
			} else {
				v_mouse_released = 0;
			}
			v_mouse_rechts = p_mousebutton(2);
		}
		g_spalte = 0;
		g_zeile = 0;
		if (((v_mouse_x_old != v_mouse_x) || (v_mouse_y_old != v_mouse_y))) {
			v_besch = 1;
			v_mouse_x_old = v_mouse_x;
			v_mouse_y_old = v_mouse_y;
		}
		v_zw_x = v_mouse_x;
		v_zw_y = v_mouse_y;
		v_zw_x = (v_zw_x - 50);
		v_zw_y = (v_zw_y - 50);
		if (((v_zw_x > -20) && (v_zw_x < 160))) {
			g_spalte = 1;
			g_zeile = ((v_zw_y / 14) + 1);
		}
		if (((v_zw_x > 159) && (v_zw_x < 340))) {
			g_spalte = 2;
			g_zeile = ((v_zw_y / 14) + 1);
		}
		if (((v_zw_x > 339) && (v_zw_x < 470))) {
			g_spalte = 3;
			g_zeile = ((v_zw_y / 14) + 1);
		}
		if ((g_zeile > 27)) {
			g_zeile = 27;
		}
		if ((g_zeile < 1)) {
			g_zeile = 1;
		}
		if ((g_spalte > 3)) {
			g_spalte = 3;
		}
		if ((g_spalte < 1)) {
			g_spalte = 1;
		}
		v_pressed = 0;
		if ((p_keyboardreleased(13) || (v_jb1 == 1))) {
			v_pressed = 1;
		}
		if (((((v_mouse_x > 485) && (v_mouse_x < 500)) && (v_mouse_y > 410)) && (v_mouse_y < 425))) {
			if ((v_mouse_released == 1)) {
				p_sound(8);
				for (v_ignore = 1; v_ignore <= 141; v_ignore += 1) {
					if ((a_skills(v_ignore, g_akt_spieler).f_gewaehlt == 1)) {
						a_skills(v_ignore, g_akt_spieler).f_gewaehlt = 0;
						g_punkte = (g_punkte + a_skills(v_ignore, g_akt_spieler).f_kosten);
						p_unlocken(v_ignore);
					}
				}
			} else {
				v_mouse_over_deleteall = 1;
			}
		} else {
			v_mouse_over_deleteall = 0;
		}
		if (((v_mouse_released == 1) || (v_pressed == 1))) {
			if ((v_pressed == 1)) {
				v_zw_skill = v_pos_aktuell;
			} else {
				v_zw_skill = ((((g_zeile + a_skilltyp_offset(g_currentstyp)) + (g_spalte * 27)) - 27) - g_skillrow_offset);
			}
			if (((v_zw_skill < a_skilltyp_offset(g_currentstyp)) && (v_pressed == 0))) {
				v_zw_skill = 0;
				if ((((g_zeile <= 11) && (g_spalte == 1)) && (v_warten == 0))) {
					g_currentstyp = (g_zeile - 2);
					v_warten = 0;
				}
				if ((g_currentstyp > 0)) {
					v_pos_aktuell = a_skilltyp_offset((g_currentstyp - 1));
				}
				if (((g_zeile == 1) && (g_spalte == 1))) {
					g_currentstyp = 0;
				}
			}
			if (((v_zw_skill > (a_skilltyp_offset(g_currentstyp) + a_skilltyp_range(g_currentstyp))) && (v_pressed == 0))) {
				v_zw_skill = 0;
			}
			if (((g_currentstyp == 0) && (v_pressed == 0))) {
				v_zw_skill = (v_zw_skill + (27 * (g_skills_menu - 1)));
			}
			if ((v_warten == 0)) {
				if (((((v_mouse_x > 50) && (v_mouse_y > 50)) && (v_mouse_x < 400)) && (v_mouse_y < 430))) {
					v_mouse_over_skills = 1;
				} else {
					v_mouse_over_skills = 0;
				}
				if (((((v_mouse_x > 50) && (v_mouse_y > 50)) && (v_mouse_x < 570)) && (v_mouse_y < 400))) {
					v_mouse_over_skills = 1;
				}
				if (((v_mouse_x > 550) && (v_mouse_y > 350))) {
					v_mouse_over_skills = 0;
				}
				if (((v_mouse_x < 230) && (v_mouse_y < 176))) {
					v_mouse_over_skills = 0;
				}
				if ((v_mouse_over_skills || (v_pressed == 1))) {
					if ((g_punkte > 0)) {
						g_charsave_now = 0;
						if ((g_klicking == 1)) {
							p_sound(8);
						}
					}
					if ((a_skills(v_zw_skill, g_akt_spieler).f_kosten < 0)) {
						if ((a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt == 0)) {
							if ((a_skills(v_zw_skill, g_akt_spieler).f_gelocked == 0)) {
								if (((((v_mouse_x < 571) && (v_mouse_y < 529)) || ((v_mouse_x < 571) && (v_mouse_y < 350))) || (v_pressed == 1))) {
									a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt = 1;
									g_punkte = (g_punkte - a_skills(v_zw_skill, g_akt_spieler).f_kosten);
									p_locken(v_zw_skill);
									v_warten = 0;
								}
							}
						} else {
							if ((g_punkte > ((0 - a_skills(v_zw_skill, g_akt_spieler).f_kosten) - 1))) {
								if (((((v_mouse_x < 571) && (v_mouse_y < 529)) || ((v_mouse_x < 571) && (v_mouse_y < 350))) || (v_pressed == 1))) {
									a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt = 0;
									g_punkte = (g_punkte + a_skills(v_zw_skill, g_akt_spieler).f_kosten);
									p_unlocken(v_zw_skill);
									v_warten = v_mydelay3;
								}
							}
						}
					} else {
						if ((a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt == 0)) {
							if ((a_skills(v_zw_skill, g_akt_spieler).f_gelocked == 0)) {
								if ((g_punkte > (-1 + a_skills(v_zw_skill, g_akt_spieler).f_kosten))) {
									if (((((v_mouse_x < 571) && (v_mouse_y < 529)) || ((v_mouse_x < 571) && (v_mouse_y < 350))) || (v_pressed == 1))) {
										a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt = 1;
										g_punkte = (g_punkte - a_skills(v_zw_skill, g_akt_spieler).f_kosten);
										p_locken(v_zw_skill);
										v_warten = 0;
									}
								}
							}
						} else {
							if ((a_skills(v_zw_skill, g_akt_spieler).f_gelocked == 0)) {
								if (((((v_mouse_x < 571) && (v_mouse_y < 529)) || ((v_mouse_x < 571) && (v_mouse_y < 350))) || (v_pressed == 1))) {
									a_skills(v_zw_skill, g_akt_spieler).f_gewaehlt = 0;
									g_punkte = (g_punkte + a_skills(v_zw_skill, g_akt_spieler).f_kosten);
									p_unlocken(v_zw_skill);
									v_warten = 0;
								}
							}
						}
					}
				}
			} else {
				p_delay(1);
				v_warten = (v_warten - 1);
			}
		}
		p_draw_skills(g_spalte, g_zeile, v_pos_aktuell, v_besch, g_punkte);
		if ((v_mouse_over_deleteall == 0)) {
			p_clipsprite(36, 32, 32, 14, 14);
			p_displaysprite(36, 485, 410);
		} else {
			p_clipsprite(36, 144, 48, 14, 14);
			p_displaysprite(36, 485, 410);
		}
		for (v_i = 0; v_i <= 140; v_i += 1) {
			if (((a_skills(v_i, g_akt_spieler).f_gelocked == 1) && (a_skills(v_i, g_akt_spieler).f_gewaehlt == 1))) {
				a_skills(v_i, g_akt_spieler).f_gewaehlt = 0;
				g_punkte = (g_punkte + a_skills(v_i, g_akt_spieler).f_kosten);
			}
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(400, 410, ((a_nachricht_text(93, (1 + g_sprache)) + ": ") + p_str(g_punkte)), -1, 0);
		if (v_mouse_over_deleteall) {
			p_drawtext(380, 432, a_nachricht_text(900, (1 + g_sprache)), 16777215, 0);
		}
		p_stopdrawing();
		if (((((v_mouse_x > 529) && (v_mouse_y < 616)) && (v_mouse_y > 389)) && (v_mouse_y < 419))) {
			p_clipsprite(3, 0, 0, 87, 32);
			v_ok_button = 1;
		} else {
			p_clipsprite(3, 0, 31, 87, 32);
			v_ok_button = 0;
		}
		p_displaytransparentsprite(3, 530, 390);
		v_back_button = 0;
		if (((((v_mouse_x > 529) && (v_mouse_y < 616)) && (v_mouse_y > 419)) && (v_mouse_y < 449))) {
			p_clipsprite(4, 0, 0, 87, 32);
			if ((v_mouse_links == 1)) {
				v_back_button = 1;
			}
		} else {
			p_clipsprite(4, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(4, 530, 420);
		if (((((v_mouse_x > 550) && (v_mouse_x < 582)) && (v_mouse_y > 350)) && (v_mouse_y < 382))) {
			p_clipsprite(6, 96, 0, 31, 31);
			if ((v_mouse_released == 1)) {
				g_skills_menu -= 1;
			}
		} else {
			p_clipsprite(6, 32, 0, 31, 31);
		}
		if ((g_skills_menu <= 1)) {
			p_clipsprite(6, 288, 0, 31, 31);
		}
		p_displaytransparentsprite(6, 550, 350);
		if (((((v_mouse_x > 584) && (v_mouse_x < 616)) && (v_mouse_y > 350)) && (v_mouse_y < 382))) {
			p_clipsprite(6, 63, 0, 31, 31);
			if ((v_mouse_released == 1)) {
				g_skills_menu += 1;
			}
		} else {
			p_clipsprite(6, 0, 0, 31, 31);
		}
		if ((g_skills_menu >= 5)) {
			p_clipsprite(6, 256, 0, 31, 31);
		}
		p_displaytransparentsprite(6, 584, 350);
		if ((g_skills_menu < 1)) {
			g_skills_menu = 1;
		}
		if ((g_skills_menu > 5)) {
			g_skills_menu = 5;
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(572, 334, ((p_str(g_skills_menu) + "/") + p_str(5)), -1, 0);
		p_stopdrawing();
		v_tooltip = p_templates(v_mouse_released, v_tooltip);
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		}
		p_flipbuffers(1);
		if ((v_warten > 0)) {
			p_delay(1);
			v_warten = (v_warten - 1);
		}
		p_examinekeyboard();
		if ((((p_keyboardpushed(100) || p_keyboardpushed(120)) || p_keyboardpushed(101)) || p_keyboardpushed(114))) {
			for (v_i = 1; v_i <= 141; v_i += 1) {
				a_skills(v_i, g_akt_spieler).f_gewaehlt = 0;
				a_skills(v_i, g_akt_spieler).f_gelocked = 0;
			}
			g_punkte = 14;
		}
	} while (!(((((v_ok_button == 1) && (v_mouse_released == 1)) || (v_back_button == 1)) || p_keyboardpushed(32)) || (v_jb2 == 1)));
	p_delay(g_mydelay);
	if ((v_back_button == 1)) {
		throw Lv_again;
	}
}

static int32_t p_select_spieler() {
	int16_t v_back_button = 0;
	int32_t v_frame = 0;
	int32_t v_gewaehlt = 0;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_nr = 0;
	int16_t v_pos_aktuell = 0;
	int32_t v_result = 0;
	int16_t v_warten = 0;
	int16_t v_warten2 = 0;
	int32_t v_wohin = 0;
	v_pos_aktuell = 1;
	v_warten = 0;
	v_warten2 = 30;
	v_gewaehlt = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		if ((v_warten2 > 0)) {
			v_warten2 = (v_warten2 - 1);
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(225, 25, p_nachricht4(112), -1, 0);
		p_stopdrawing();
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaysprite(55, 0, 0);
		p_clipsprite(63, 0, 0, 640, 17);
		p_displaysprite(63, 0, 46);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaysprite(58, 0, 464);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaysprite(56, 0, 0);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaysprite(59, 624, 0);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			if ((v_warten > 0)) {
				v_warten = (v_warten - 1);
			} else {
				v_pos_aktuell = (v_pos_aktuell + 1);
				if ((v_pos_aktuell > 4)) {
					v_pos_aktuell = 1;
				}
				v_warten = 20;
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			if ((v_warten > 0)) {
				v_warten = (v_warten - 1);
			} else {
				v_pos_aktuell = (v_pos_aktuell - 1);
				if ((v_pos_aktuell < 1)) {
					v_pos_aktuell = 4;
				}
				v_warten = 20;
			}
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_links = p_mousebutton(1);
			v_mmouse_rechts = p_mousebutton(2);
			if ((v_mmouse_links == 1)) {
				for (v_i = 1; v_i <= 4; v_i += 1) {
					if (((((v_mmouse_x > (40 + ((v_i * 32) * 3))) && (v_mmouse_x < (98 + ((v_i * 32) * 3)))) && (v_mmouse_y > 180)) && (v_mmouse_y < 220))) {
						v_wohin = p_screenoutput();
						p_startdrawing(v_wohin);
						p_frontcolor(p_rgb(120, 120, 120));
						p_box((30 + ((v_i * 32) * 3)), 170, 84, 74, -1);
						p_stopdrawing();
						g_anz_spieler = v_i;
						v_gewaehlt = 1;
					}
				}
			}
		}
		if (((p_keyboardpushed(13) || (v_jb1 == 1)) && (v_warten2 == 0))) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(120, 120, 120));
			p_box((30 + ((v_pos_aktuell * 32) * 3)), 170, 84, 74, -1);
			p_stopdrawing();
			g_anz_spieler = v_pos_aktuell;
			v_gewaehlt = 1;
		}
		v_nr = 1;
		for (v_i = 1; v_i <= 4; v_i += 1) {
			p_clipsprite(68, 32, 0, 32, 32);
			p_displaytransparentsprite(68, (50 + ((32 * v_i) * 3)), 200);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(0, 0, 0));
			p_box(20, 380, 330, 60, -1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext((40 + ((32 * v_i) * 3)), 180, p_str(v_i), -1, 0);
			p_drawtext((55 + ((32 * v_i) * 3)), 180, p_nachricht4(113), -1, 0);
			p_stopdrawing();
			if ((v_i == v_pos_aktuell)) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(150, 150, 150));
				p_line((40 + ((v_i * 32) * 3)), 196, 60, 0, -1);
				p_stopdrawing();
			}
			v_nr = (v_nr + 1);
		}
		v_frame = (v_frame + 1);
		if ((v_frame > 1)) {
			v_frame = 0;
		}
		v_back_button = 0;
		if (((((v_mmouse_x > 529) && (v_mmouse_x < 616)) && (v_mmouse_y > 409)) && (v_mmouse_y < 439))) {
			p_clipsprite(4, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_back_button = 1;
			}
		} else {
			p_clipsprite(4, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(4, 530, 410);
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		}
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!((v_gewaehlt == 1) || (v_back_button == 1)));
	p_delay(g_mydelay);
	if ((v_back_button == 1)) {
		throw Lv_again;
	}
}

static int32_t p_setitem(int16_t v_xx, int16_t v_yy, int16_t v_level, int16_t v_name, int16_t v_anzahl, int16_t v_status) {
	a_laby_item(v_xx, v_yy).f_name[v_level] = v_name;
	a_laby_item(v_xx, v_yy).f_anzahl[v_level] = v_anzahl;
	a_laby_item(v_xx, v_yy).f_status[v_level] = v_status;
}

static int32_t p_setlaby(int16_t v_x_x, int16_t v_y_y, int16_t v_ebene, int16_t v_was, int16_t v_lp, int16_t v_typ, int16_t v_stat) {
	a_labyrinth(v_x_x, v_y_y).f_feld[v_ebene] = v_was;
	a_labyrinth(v_x_x, v_y_y).f_lebenspunkte[v_ebene] = v_lp;
	a_labyrinth(v_x_x, v_y_y).f_objekt[v_ebene] = v_typ;
	a_labyrinth(v_x_x, v_y_y).f_status[v_ebene] = v_stat;
}

static int32_t p_setmonster(int16_t v_xx, int16_t v_yy, int16_t v_level, int16_t v_name, int16_t v_graphic, int16_t v_lifepoints, int16_t v_status, int16_t v_duration) {
	a_laby_monster(v_xx, v_yy).f_name[v_level] = v_name;
	a_laby_monster(v_xx, v_yy).f_graphic[v_level] = v_graphic;
	a_laby_monster(v_xx, v_yy).f_lifepoints[v_level] = v_lifepoints;
	a_laby_monster(v_xx, v_yy).f_status[v_level] = v_status;
	a_laby_monster(v_xx, v_yy).f_duration[v_level] = v_duration;
}

static int32_t p_setzen(int16_t v_x_length, int16_t v_y_length, int16_t v_level) {
	int32_t v_frei = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_x = 0;
	int16_t v_y = 0;
	int16_t v_zaehler = 0;
	v_zaehler = 1;
	do {
		v_frei = 0;
		do {
			v_x = p_random((a_groesse(v_level) - 9));
		} while (!(v_x > 3));
		do {
			v_y = p_random((a_groesse(v_level) - 9));
		} while (!(v_y > 3));
		v_x = (v_x / 2);
		v_y = (v_y / 2);
		v_x = (v_x * 2);
		v_y = (v_y * 2);
		for (v_i = 1; v_i <= v_x_length; v_i += 1) {
			for (v_j = 1; v_j <= v_y_length; v_j += 1) {
				if (((a_labyrinth((v_i + v_x), (v_j + v_y)).f_feld[v_level] == 3) || (a_labyrinth((v_i + v_x), (v_j + v_y)).f_feld[v_level] == 2))) {
					v_frei = 1;
				}
			}
		}
		v_zaehler = (v_zaehler + 1);
	} while (!((((v_x > 0) && (v_y > 0)) && (v_frei == 0)) || (v_zaehler > 500)));
	if ((v_zaehler <= 500)) {
		a_raumx(v_level) = v_x;
		a_raumy(v_level) = v_y;
		for (v_i = 1; v_i <= v_x_length; v_i += 1) {
			for (v_j = 1; v_j <= v_y_length; v_j += 1) {
				p_setlaby((v_i + v_x), (v_j + v_y), v_level, 47, 0, 0, 0);
			}
		}
	}
}

static int32_t p_show_automap() {
	int16_t v_get_out = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_map_level = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int16_t v_offset = 0;
	int32_t v_okay = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int8_t v_x = 0;
	int16_t v_x_akt = 0;
	int32_t v_x_offset = 0;
	int32_t v_xx = 0;
	int8_t v_y = 0;
	int16_t v_y_akt = 0;
	int32_t v_y_offset = 0;
	v_x_akt = 0;
	v_y_akt = 0;
	v_offset = 10;
	g_karten_typ = 2;
	v_map_level = a_spieler(g_akt_spieler).f_level;
	v_get_out = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		for (v_y = -1; v_y <= 20; v_y += 1) {
			for (v_x = -1; v_x <= 20; v_x += 1) {
				if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1) || ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1))) {
					p_draw_small_tile(a_mit_was(v_map_level), v_x, v_y, v_x_offset, v_y_offset);
				} else {
					if ((a_automap((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt), (((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt)).f_feld[v_map_level] == 1)) {
						p_draw_small_tile(a_labyrinth((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt), (((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt)).f_feld[v_map_level], v_x, v_y, v_x_offset, v_y_offset);
						for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
							if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) == a_spieler(v_xx).f_character_x) && ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) == a_spieler(v_xx).f_character_y))) {
								if (((a_spieler(v_xx).f_status == 1) && (a_spieler(v_xx).f_level == v_map_level))) {
									if ((a_spieler(v_xx).f_fluch == 23)) {
										p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 0, 16, 16);
										p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
									} else {
										if (p_hater(86, v_xx)) {
											p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 64, 16, 16);
											p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
										} else {
											if (p_hater(87, v_xx)) {
												p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 32, 16, 16);
												p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
											} else {
												if (p_hater(88, v_xx)) {
													p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 48, 16, 16);
													p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
												} else {
													if (p_hater(89, v_xx)) {
														p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 16, 16, 16);
														p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
													} else {
														if (p_hater(90, v_xx)) {
															p_clipsprite(46, ((a_spieler(v_xx).f_face * 16) * 2), 80, 16, 16);
															p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
														} else {
															p_clipsprite(25, ((a_spieler(v_xx).f_face * 16) * 2), ((a_spieler(v_xx).f_maennchen * 16) - 16), 16, 16);
															p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
														}
													}
												}
											}
										}
									}
								}
							}
						}
						for (v_xx = 1; v_xx <= g_anz_spieler; v_xx += 1) {
							if ((a_spieler(v_xx).f_creature_typ > 0)) {
								if ((((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) == a_spieler(v_xx).f_creature_x) && ((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) == a_spieler(v_xx).f_creature_y))) {
									if (((a_spieler(v_xx).f_level == v_map_level) && (a_spieler(v_xx).f_status == 1))) {
										if ((a_spieler(v_xx).f_creature_typ == 1)) {
											p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 128, 16, 16);
											p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
										} else {
											if ((a_spieler(v_xx).f_creature_typ == 2)) {
												p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 96, 16, 16);
												p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
											} else {
												if ((a_spieler(v_xx).f_creature_typ == 3)) {
													p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 176, 16, 16);
													p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
												} else {
													if ((a_spieler(v_xx).f_creature_typ == 4)) {
														p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 192, 16, 16);
														p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
													} else {
														if ((a_spieler(v_xx).f_creature_typ == 5)) {
															p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 208, 16, 16);
															p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
														} else {
															if ((a_spieler(v_xx).f_creature_typ == 6)) {
																p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 160, 16, 16);
																p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
															} else {
																if ((a_spieler(v_xx).f_creature_typ == 7)) {
																	p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 112, 16, 16);
																	p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																} else {
																	if ((a_spieler(v_xx).f_creature_typ == 8)) {
																		p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 144, 16, 16);
																		p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																	} else {
																		if ((a_spieler(v_xx).f_creature_typ == 9)) {
																			p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 80, 16, 16);
																			p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																		} else {
																			if ((a_spieler(v_xx).f_creature_typ == 10)) {
																				p_clipsprite(25, ((a_spieler(v_xx).f_creature_heading * 16) * 2), ((a_spieler(v_xx).f_maennchen * 16) - 16), 16, 16);
																				p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																			} else {
																				if ((a_spieler(v_xx).f_creature_typ == 11)) {
																					p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 48, 16, 16);
																					p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																				} else {
																					if ((a_spieler(v_xx).f_creature_typ == 12)) {
																						p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 240, 16, 16);
																						p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																					} else {
																						if ((a_spieler(v_xx).f_creature_typ == 13)) {
																							p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 256, 16, 16);
																							p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																						} else {
																							if ((a_spieler(v_xx).f_creature_typ == 13)) {
																								p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 272, 16, 16);
																								p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																							} else {
																								if ((a_spieler(v_xx).f_creature_typ == 13)) {
																									p_clipsprite(46, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 288, 16, 16);
																									p_displaytransparentsprite(46, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																								} else {
																									if ((a_spieler(v_xx).f_creature_typ == 20)) {
																										p_clipsprite(25, ((a_spieler(v_xx).f_creature_heading * 16) * 2), 304, 16, 16);
																										p_displaytransparentsprite(25, ((v_x * 16) + v_x_offset), ((v_y * 16) + v_y_offset));
																										v_okay = 1;
																									}
																								}
																							}
																						}
																					}
																				}
																			}
																		}
																	}
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_examinekeyboard();
		v_jax = 0;
		v_jay = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
		}
		v_get_out = 0;
		if (p_keyboardpushed(27)) {
			v_get_out = 1;
		}
		if ((p_keyboardpushed(275) || (v_jax == 1))) {
			v_x_akt = (v_x_akt + 1);
			if ((v_x_akt > a_groesse(v_map_level))) {
				v_x_akt = a_groesse(v_map_level);
			}
		}
		if ((p_keyboardpushed(276) || (v_jax == -1))) {
			v_x_akt = (v_x_akt - 1);
			if (((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1)) {
				v_x_akt = 0;
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_y_akt = (v_y_akt - 1);
			if (((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1)) {
				v_y_akt = 0;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_y_akt = (v_y_akt + 1);
			if ((v_y_akt > a_groesse(v_map_level))) {
				v_y_akt = a_groesse(v_map_level);
			}
		}
		v_result = p_examinemouse();
		v_mouse_x = p_mousex();
		v_mouse_y = p_mousey();
		v_mouse_links = 0;
		v_mouse_rechts = 0;
		v_mouse_links = p_mousebutton(1);
		v_mouse_rechts = p_mousebutton(2);
		if (((((v_mouse_x >= 437) && (v_mouse_x <= 469)) && (v_mouse_y >= 249)) && (v_mouse_y <= 281))) {
			p_clipsprite(6, 96, 0, 31, 31);
			p_displaytransparentsprite(6, 437, 249);
			if ((v_mouse_links == 1)) {
				v_x_akt = (v_x_akt - 1);
				if (((((a_spieler(g_akt_spieler).f_character_x - v_offset) + v_x) + v_x_akt) < 1)) {
					v_x_akt = 0;
				}
			}
		} else {
			p_clipsprite(6, 32, 0, 31, 31);
			p_displaytransparentsprite(6, 437, 249);
		}
		if (((((v_mouse_x >= 525) && (v_mouse_x <= 557)) && (v_mouse_y >= 249)) && (v_mouse_y <= 281))) {
			p_clipsprite(6, 63, 0, 31, 31);
			p_displaytransparentsprite(6, 525, 249);
			if ((v_mouse_links == 1)) {
				v_x_akt = (v_x_akt + 1);
				if ((v_x_akt > a_groesse(v_map_level))) {
					v_x_akt = a_groesse(v_map_level);
				}
			}
		} else {
			p_clipsprite(6, 0, 0, 31, 31);
			p_displaytransparentsprite(6, 525, 249);
		}
		if (((((v_mouse_x >= 480) && (v_mouse_x <= 512)) && (v_mouse_y >= 211)) && (v_mouse_y <= 243))) {
			p_clipsprite(6, 192, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 211);
			if ((v_mouse_links == 1)) {
				v_y_akt = (v_y_akt - 1);
				if (((((a_spieler(g_akt_spieler).f_character_y - v_offset) + v_y) + v_y_akt) < 1)) {
					v_y_akt = 0;
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 211);
		}
		if (((((v_mouse_x > 480) && (v_mouse_x < 512)) && (v_mouse_y > 295)) && (v_mouse_y < 327))) {
			p_clipsprite(6, 224, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 295);
			if ((v_mouse_links == 1)) {
				v_y_akt = (v_y_akt + 1);
				if ((v_y_akt > a_groesse(v_map_level))) {
					v_y_akt = a_groesse(v_map_level);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 31, 31);
			p_displaytransparentsprite(6, 480, 295);
		}
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(583, 273, ("Lv." + p_str(v_map_level)), -1, 0);
		p_stopdrawing();
		if (((((v_mouse_x >= 593) && (v_mouse_x <= 625)) && (v_mouse_y >= 290)) && (v_mouse_y <= 322))) {
			p_clipsprite(6, 192, 0, 32, 31);
			p_displaytransparentsprite(6, 593, 290);
			if ((v_mouse_links == 1)) {
				if ((v_map_level > 1)) {
					v_map_level = (v_map_level - 1);
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 32, 31);
			p_displaytransparentsprite(6, 593, 290);
		}
		if (((((v_mouse_x > 593) && (v_mouse_x < 625)) && (v_mouse_y > 320)) && (v_mouse_y < 352))) {
			p_clipsprite(6, 224, 0, 32, 31);
			p_displaytransparentsprite(6, 593, 320);
			if ((v_mouse_links == 1)) {
				if ((v_map_level < a_spieler(g_akt_spieler).f_maxlevel)) {
					v_map_level = (v_map_level + 1);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 32, 31);
			p_displaytransparentsprite(6, 593, 320);
		}
		if (((((v_mouse_x > 480) && (v_mouse_x < 512)) && (v_mouse_y > 250)) && (v_mouse_y < 282))) {
			p_clipsprite(6, 32, 32, 29, 32);
			p_displaytransparentsprite(6, 480, 250);
			if ((v_mouse_links == 1)) {
				v_x_akt = 0;
				v_y_akt = 0;
			}
		} else {
			p_clipsprite(6, 0, 32, 29, 32);
			p_displaytransparentsprite(6, 480, 250);
		}
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!((v_mouse_rechts == 1) || (v_get_out == 1)));
}

static int32_t p_show_buttons() {
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int16_t v_jb3 = 0;
	int16_t v_jb4 = 0;
	int16_t v_jb5 = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_ok_button = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_x = 378;
	v_y = 373;
	g_zw_bild = 0;
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		g_mmouse_x = p_mousex();
		g_mmouse_y = p_mousey();
		g_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
	}
	p_examinekeyboard();
	if ((g_joystick_used == 1)) {
		p_examinejoystick();
		v_jb1 = p_joystickbutton(1);
		v_jb2 = p_joystickbutton(2);
		v_jb3 = p_joystickbutton(3);
		v_jb4 = p_joystickbutton(4);
		v_jb5 = p_joystickbutton(5);
	}
	if ((g_flaschen == 1)) {
		if (((((g_mmouse_x > 390) && (g_mmouse_x < 419)) && (g_mmouse_y > 110)) && (g_mmouse_y < 159))) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(247, 36, 61));
			p_drawtext(390, 330, ((p_str(a_spieler(g_akt_spieler).f_lifepoints) + "/") + p_str(p_maxlife())), -1, 0);
			p_stopdrawing();
		}
		if (((((g_mmouse_x > 420) && (g_mmouse_x < 449)) && (g_mmouse_y > 110)) && (g_mmouse_y < 159))) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(130, 125, 250));
			p_drawtext(390, 330, ((p_str(a_spieler(g_akt_spieler).f_mana) + "/") + p_str(p_maxmana())), -1, 0);
			p_stopdrawing();
		}
	}
	p_clipsprite(7, 0, 0, 256, 96);
	p_displaysprite(7, (v_x - 12), (v_y - 5));
	if (p_keyboardpushed(104)) {
		g_zw_bild = 1;
	}
	if (((((g_mmouse_x > (40 + v_x)) && (g_mmouse_x < (81 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(572, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 204, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 38), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 1;
		}
	} else {
		p_clipsprite(2, 204, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 38), (v_y - 2));
		v_ok_button = 0;
	}
	if (p_keyboardpushed(108)) {
		g_zw_bild = 7;
	}
	if (((((g_mmouse_x > (80 + v_x)) && (g_mmouse_x < (121 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(573, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 238, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 78), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 7;
		}
	} else {
		p_clipsprite(2, 238, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 78), (v_y - 2));
	}
	if (p_keyboardpushed(115)) {
		g_zw_bild = 8;
	}
	if (((((g_mmouse_x > (120 + v_x)) && (g_mmouse_x < (161 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(574, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 272, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 118), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 8;
		}
	} else {
		p_clipsprite(2, 272, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 118), (v_y - 2));
	}
	if (p_keyboardpushed(107)) {
		g_zw_bild = 4;
	}
	if (((((g_mmouse_x > (160 + v_x)) && (g_mmouse_x < (201 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(575, (1 + g_sprache)), -1, 0);
		p_clipsprite(2, 306, 1, 34, 42);
		p_stopdrawing();
		p_displaytransparentsprite(2, (v_x + 157), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 4;
		}
	} else {
		p_clipsprite(2, 306, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 157), (v_y - 2));
	}
	if (p_keyboardpushed(103)) {
		if ((a_skills(75, g_akt_spieler).f_gewaehlt == 1)) {
			g_zw_bild = 10;
		}
	}
	if (((((g_mmouse_x > (200 + v_x)) && (g_mmouse_x < (241 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(576, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 340, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			if ((a_skills(75, g_akt_spieler).f_gewaehlt == 1)) {
				g_zw_bild = 10;
			}
		}
	} else {
		p_clipsprite(2, 340, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y - 2));
	}
	if ((((p_keyboardpushed(105) || p_keyboardpushed(114)) || p_keyboardpushed(98)) || (v_jb3 != 0))) {
		g_zw_bild = 2;
	}
	if (((((g_mmouse_x > (40 + v_x)) && (g_mmouse_x < (81 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(577, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 374, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 38), (v_y + 47));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 2;
		}
	} else {
		p_clipsprite(2, 374, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 38), (v_y + 47));
	}
	if (p_keyboardpushed(100)) {
		g_zw_bild = 6;
	}
	if (((((g_mmouse_x > (80 + v_x)) && (g_mmouse_x < (121 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(578, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 476, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 78), (v_y + 46));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 6;
		}
	} else {
		p_clipsprite(2, 476, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 78), (v_y + 46));
	}
	if (((g_knopf5 == 1) && (g_joystick_used == 1))) {
		if ((v_jb5 != 0)) {
			g_zw_bild = 9;
		}
	}
	if (p_keyboardpushed(102)) {
		g_zw_bild = 9;
	}
	if (((((g_mmouse_x > (120 + v_x)) && (g_mmouse_x < (161 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(579, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 442, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 117), (v_y + 46));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 9;
		}
	} else {
		p_clipsprite(2, 442, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 117), (v_y + 46));
	}
	if ((((p_keyboardpushed(122) || p_keyboardpushed(121)) || p_keyboardpushed(99)) || (v_jb4 != 0))) {
		g_zw_bild = 3;
	}
	if (((((g_mmouse_x > (160 + v_x)) && (g_mmouse_x < (201 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(580, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 408, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 157), (v_y + 46));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 3;
		}
	} else {
		p_clipsprite(2, 408, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 157), (v_y + 46));
	}
	if ((p_keyboardpushed(111) || (v_jb2 == 1))) {
		g_zw_bild = 5;
	}
	if (((((g_mmouse_x > (200 + v_x)) && (g_mmouse_x < (241 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(581, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 510, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y + 46));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 5;
		}
	} else {
		p_clipsprite(2, 510, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y + 46));
		v_ok_button = 0;
	}
	if (p_keyboardpushed(120)) {
		g_aktion = 1;
		a_spieler(g_akt_spieler).f_speed = p_maxspeed();
		if ((g_anz_spieler == 1)) {
			p_delay(500);
		}
	}
	if (((((g_mmouse_x > v_x) && (g_mmouse_x < (41 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(582, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 578, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			g_aktion = 1;
			a_spieler(g_akt_spieler).f_speed = p_maxspeed();
			if ((g_anz_spieler == 1)) {
				p_delay(500);
			}
		}
	} else {
		p_clipsprite(2, 578, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y - 2));
		v_ok_button = 0;
	}
	if (p_keyboardpushed(109)) {
		g_zw_bild = 12;
	}
	if (((((g_mmouse_x > v_x) && (g_mmouse_x < (41 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(698, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 544, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y + 47));
		if ((g_mmouse_links == 1)) {
			g_zw_bild = 12;
		}
	} else {
		p_clipsprite(2, 544, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y + 47));
	}
	if (p_keyboardpushed(113)) {
		g_zw_bild = 13;
	}
	if (p_keyboardpushed(97)) {
		g_zw_bild = 11;
	}
}

static int32_t p_show_buttons2() {
	int32_t v_mmouse_rechts = 0;
	int32_t v_ok_button = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_x = 378;
	v_y = 373;
	v_result = p_examinemouse();
	g_mmouse_x = p_mousex();
	g_mmouse_y = p_mousey();
	g_mmouse_links = p_mousebutton(1);
	v_mmouse_rechts = p_mousebutton(2);
	p_examinekeyboard();
	p_clipsprite(7, 0, 0, 256, 96);
	p_displaysprite(7, (v_x - 12), (v_y - 5));
	if (p_keyboardpushed(120)) {
		a_spieler(g_akt_spieler).f_creature_speed = 0;
		p_nachricht(447, 1);
		if ((g_anz_spieler == 1)) {
			p_delay(500);
		}
	}
	if (((((g_mmouse_x > v_x) && (g_mmouse_x < (41 + v_x))) && (g_mmouse_y > v_y)) && (g_mmouse_y < (40 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(582, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 578, 0, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y - 2));
		if ((g_mmouse_links == 1)) {
			a_spieler(g_akt_spieler).f_creature_speed = 0;
			p_nachricht(447, 1);
			if ((g_anz_spieler == 1)) {
				p_delay(500);
			}
		}
	} else {
		p_clipsprite(2, 578, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x - 2), (v_y - 2));
		v_ok_button = 0;
	}
	if (p_keyboardpushed(114)) {
		a_spieler(g_akt_spieler).f_creature_typ = 0;
		a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
		a_spieler(g_akt_spieler).f_creature_speed = 0;
		a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
		p_clipsprite(38, 0, 224, 32, 32);
		p_displaytransparentsprite(38, 160, 160);
		p_sound((p_random(6) + 1));
		p_nachricht(667, 1);
	}
	if (((((g_mmouse_x > (200 + v_x)) && (g_mmouse_x < (241 + v_x))) && (g_mmouse_y > (50 + v_y))) && (g_mmouse_y < (90 + v_y)))) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(170, 170, 170));
		p_drawtext(430, 330, a_nachricht_text(666, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		p_clipsprite(2, 646, 1, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y + 46));
		if (((g_mmouse_links == 1) || p_keyboardpushed(114))) {
			a_spieler(g_akt_spieler).f_creature_typ = 0;
			a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
			a_spieler(g_akt_spieler).f_creature_speed = 0;
			a_spieler(g_akt_spieler).f_creature_maxspeed = 0;
			p_clipsprite(38, 0, 224, 32, 32);
			p_displaytransparentsprite(38, 160, 160);
			p_sound((p_random(6) + 1));
			p_nachricht(667, 1);
		}
	} else {
		p_clipsprite(2, 646, 43, 34, 42);
		p_displaytransparentsprite(2, (v_x + 196), (v_y + 46));
		v_ok_button = 0;
	}
}

static int32_t p_show_credits() {
	int32_t v_a = 0;
	int32_t v_credits = 0;
	int32_t v_elapsedtime = 0;
	int32_t v_farbe = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_result = 0;
	int32_t v_rgb = 0;
	int32_t v_sin = 0;
	int32_t v_starttime = 0;
	int32_t v_warten = 0;
	int32_t v_wohin = 0;
	int32_t v_xx = 0;
	int32_t v_yyy = 0;
	a_credits.dim(28);
	p_credit(1, "Thanx to the most important people for the project:", 400);
	p_credit(2, "Frank Malota - For the original Version of this game", 280);
	p_credit(3, "Frederik Laboreur - For Purebasic", 280);
	p_credit(4, "Roger R\366sch - For helping me with programming", 280);
	p_credit(5, "Rasmus Klette - For improving the skill selection menu", 280);
	p_credit(6, "Peter Eismann - For conversion to new compiler", 280);
	p_credit(7, "David Gervais - For all the nice Graphics", 280);
	p_credit(8, "Patrik Broberg - For all the nice Graphics", 280);
	p_credit(9, "Michael Wieland - For inventing the Labyrinth Algorithm", 280);
	p_credit(10, "Dominik D\366bele - For helping me with the creatures", 280);
	p_credit(11, "Marc Vinals - For the Spanish Translation", 280);
	p_credit(12, "Linus Torvalds - Thanx for the best Operating System", 280);
	p_credit(13, "The whole KDE Team - Thanx for the best Desktop", 280);
	p_credit(14, "", 280);
	p_credit(15, "Greetings to Friends:", 280);
	p_credit(16, "Stephen 'Indiana' Lieber (for endless gametesting)", 280);
	p_credit(17, "Gabriel Szilagy", 130);
	p_credit(18, "Martin Novak", 130);
	p_credit(19, "Michael B\374ttner", 130);
	p_credit(20, "Corinna Popp", 130);
	p_credit(21, "Andreas P\344sler", 130);
	p_credit(22, "Herwig Bosch", 130);
	p_credit(23, "Joachim Hahn", 130);
	p_credit(24, "Tobias Novak", 130);
	p_credit(25, "Christian Lemke", 130);
	p_credit(26, "Fabian Schorcht", 130);
	p_credit(27, "To you all for testing and playing this game", 280);
	v_credits = 27;
	for (v_a = 1; v_a <= v_credits; v_a += 1) {
		if (p_random(1)) {
			a_credits(v_a).f_max = (p_random(40) + 80);
		} else {
			a_credits(v_a).f_max = (-1 * (p_random(40) + 80));
		}
		a_credits(v_a).f_div = (p_random(20) + 60);
		a_credits(v_a).f_sinstart = (60.0 / p_random(200));
	}
	do {
		v_starttime = p_elapsedmilliseconds();
		p_fenster(0);
		v_i += 1;
		p_clearscreen(p_rgb(0, 0, 0));
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		for (v_j = 1; v_j <= v_credits; v_j += 1) {
			if (((a_credits(v_j).f_y < 400) && (a_credits(v_j).f_y > 50))) {
				if ((a_credits(v_j).f_y > 300)) {
					a_credits(v_j).f_fade = (400 - a_credits(v_j).f_y);
				} else {
					if ((a_credits(v_j).f_y < 150)) {
						a_credits(v_j).f_fade = (a_credits(v_j).f_y - 50);
					} else {
						a_credits(v_j).f_fade = 100;
					}
				}
				v_xx = (320 - (p_textwidth(a_credits(v_j).f_text) / 2));
				v_sin = (int32_t)((p_sin((((float) v_i / a_credits(v_j).f_div) + a_credits(v_j).f_sinstart)) * a_credits(v_j).f_max));
				v_yyy = (a_credits(v_j).f_y + (p_textheight("JT") / 2));
				for (v_a = 5; v_a >= 1; v_a -= 1) {
					v_farbe = (((51 * (5 - v_a)) / 100) * a_credits(v_j).f_fade);
					p_circle(((v_xx - 55) + v_sin), v_yyy, v_a, p_rgb(0, 0, v_farbe));
					p_circle(((v_xx - 35) + v_sin), v_yyy, v_a, p_rgb(v_farbe, v_farbe, 0));
					p_circle(((v_xx - 15) + v_sin), v_yyy, v_a, p_rgb(0, v_farbe, 0));
					p_circle((((v_xx + p_textwidth(a_credits(v_j).f_text)) + 10) + v_sin), v_yyy, v_a, p_rgb(0, v_farbe, 0));
					p_circle((((v_xx + p_textwidth(a_credits(v_j).f_text)) + 30) + v_sin), v_yyy, v_a, p_rgb(v_farbe, v_farbe, 0));
					p_circle((((v_xx + p_textwidth(a_credits(v_j).f_text)) + 50) + v_sin), v_yyy, v_a, p_rgb(0, 0, v_farbe));
				}
				p_drawingmode(1);
				p_frontcolor(p_rgb(150, 150, 150));
				v_rgb = (2 * a_credits(v_j).f_fade);
				p_drawtext((v_xx + v_sin), a_credits(v_j).f_y, a_credits(v_j).f_text, p_rgb(v_rgb, v_rgb, v_rgb), 0);
			}
			a_credits(v_j).f_y = (a_credits(v_j).f_y - 1);
		}
		if ((a_credits(v_credits).f_y < 0)) {
			break;
		}
		p_stopdrawing();
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaytransparentsprite(55, 0, 0);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaytransparentsprite(58, 0, 464);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		p_flipbuffers(1);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		v_result = p_examinemouse();
		v_mouse_rechts = p_mousebutton(2);
		p_examinekeyboard();
		if (((((v_mouse_rechts == 1) || (v_jb1 == 1)) || p_keyboardpushed(32)) && (v_warten == 0))) {
			break;
		}
		v_elapsedtime = (p_elapsedmilliseconds() - v_starttime);
		if ((v_elapsedtime < 15)) {
			p_delay((15 - v_elapsedtime));
		}
	} while (!0);
	a_credits.dim(1);
}

static int32_t p_show_detail(int32_t v_akt_eintrag) {
	int32_t v_i = 0;
	int16_t v_j = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_xx = 0;
	int32_t v_ysave = 0;
	int32_t v_yy = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaytransparentsprite(55, 0, 0);
		p_clipsprite(63, 0, 0, 640, 17);
		p_displaysprite(63, 0, 33);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaytransparentsprite(58, 0, 464);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		p_clipsprite(0, 128, ((a_hscores(v_akt_eintrag).f_maennchen * 32) - 32), 32, 32);
		p_displaytransparentsprite(0, 50, 100);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawingmode(1);
		v_xx = 150;
		v_yy = 65;
		p_drawtext(v_xx, v_yy, a_nachricht_text(115, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, a_hscores(v_akt_eintrag).f_name, -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(154, 251, 120));
		p_drawtext(v_xx, v_yy, a_nachricht_text(525, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_level), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(v_xx, v_yy, (a_nachricht_text(156, (1 + g_sprache)) + ":"), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_gold), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(v_xx, v_yy, (a_nachricht_text(155, (1 + g_sprache)) + ":"), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_mks), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, (a_nachricht_text(93, (1 + g_sprache)) + ":"), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_punkte), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(52, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_attack), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(53, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_dexterity), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(54, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_strength), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(247, 36, 61));
		p_drawtext(v_xx, v_yy, a_nachricht_text(55, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_maxlifepoints), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(239, 131, 44));
		p_drawtext(v_xx, v_yy, a_nachricht_text(56, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_maxspeed), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(v_xx, v_yy, a_nachricht_text(57, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_perception), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(58, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_luck_score), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(130, 125, 250));
		p_drawtext(v_xx, v_yy, a_nachricht_text(59, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_maxmana), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(60, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_power_score), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(61, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_circle), -1, 0);
		v_yy = (v_yy + 15);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(v_xx, v_yy, a_nachricht_text(239, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, (p_str(a_hscores(v_akt_eintrag).f_stabteile) + "/9"), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(436, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, p_str(a_hscores(v_akt_eintrag).f_moves), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(v_xx, v_yy, a_nachricht_text(249, (1 + g_sprache)), -1, 0);
		p_drawtext((v_xx + 200), v_yy, a_hscores(v_akt_eintrag).f_sterbegrund[(1 + g_sprache)], -1, 0);
		v_yy = (v_yy + 5);
		v_yy = (v_yy + 15);
		v_ysave = v_yy;
		p_drawtext((v_xx - 100), v_yy, a_nachricht_text(250, (1 + g_sprache)), -1, 0);
		v_j = 1;
		for (v_i = 1; v_i <= 30; v_i += 1) {
			if ((a_hscores(v_akt_eintrag).f_skills[v_i] > 0)) {
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 1)) {
					p_frontcolor(p_rgb(255, 1, 1));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 2)) {
					p_frontcolor(p_rgb(138, 11, 88));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 3)) {
					p_frontcolor(p_rgb(255, 1, 255));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 4)) {
					p_frontcolor(p_rgb(1, 1, 255));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 5)) {
					p_frontcolor(p_rgb(1, 255, 1));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 6)) {
					p_frontcolor(p_rgb(1, 255, 255));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 7)) {
					p_frontcolor(p_rgb(130, 115, 30));
				}
				if ((a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_gruppe == 8)) {
					p_frontcolor(p_rgb(150, 150, 150));
				}
				p_drawtext((v_xx + 50), v_yy, a_skills(a_hscores(v_akt_eintrag).f_skills[v_i], 1).f_name[(1 + g_sprache)], -1, 0);
			}
			v_yy = (v_yy + 15);
			v_j = (v_j + 1);
			if ((v_j == 9)) {
				v_xx = (v_xx + 150);
				v_yy = v_ysave;
				v_j = 1;
			}
		}
		p_stopdrawing();
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(((p_keyboardpushed(27) || p_keyboardpushed(32)) || (v_mmouse_rechts == 1)) || (v_jb2 == 1)));
}

static int32_t p_show_highscore() {
	int32_t v_akt_eintrag = 0;
	int16_t v_akt_pos = 0;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int16_t v_ret = 0;
	int16_t v_spac = 0;
	int32_t v_warten2 = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_akt_pos = 1;
L_wieder_high: ;
	v_akt_eintrag = 0;
	p_clearscreen(p_rgb(0, 0, 0));
	p_clipsprite(55, 0, 0, 640, 17);
	p_displaytransparentsprite(55, 0, 0);
	p_clipsprite(63, 0, 0, 640, 17);
	p_displaysprite(63, 0, 33);
	p_clipsprite(58, 0, 0, 640, 17);
	p_displaytransparentsprite(58, 0, 464);
	p_clipsprite(56, 0, 0, 17, 480);
	p_displaytransparentsprite(56, 0, 0);
	p_clipsprite(59, 0, 0, 17, 480);
	p_displaytransparentsprite(59, 624, 0);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(1, 255, 1));
	p_drawtext(260, 18, "Highscores", -1, 0);
	v_yy = 75;
	p_drawtext(50, v_yy, "Nr", -1, 0);
	p_drawtext(100, v_yy, a_nachricht_text(154, (1 + g_sprache)), -1, 0);
	p_drawtext(400, v_yy, "Level", -1, 0);
	p_drawtext(450, v_yy, "MKS", -1, 0);
	p_drawtext(500, v_yy, a_nachricht_text(156, (1 + g_sprache)), -1, 0);
	p_drawtext(550, v_yy, a_nachricht_text(93, (1 + g_sprache)), -1, 0);
	p_stopdrawing();
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	v_yy = 95;
	for (v_i = 1; v_i <= 30; v_i += 1) {
		p_frontcolor(p_rgb(255, 255, 255));
		if ((v_i == g_letzter_eintrag)) {
			p_frontcolor(p_rgb(255, 1, 1));
		}
		if ((v_i == v_akt_pos)) {
			p_frontcolor(p_rgb(1, 1, 255));
		}
		p_drawtext(50, v_yy, p_str(v_i), -1, 0);
		p_drawtext(100, v_yy, a_hscores(v_i).f_name, -1, 0);
		p_drawtext(400, v_yy, p_str(a_hscores(v_i).f_level), -1, 0);
		p_drawtext(450, v_yy, p_str(a_hscores(v_i).f_mks), -1, 0);
		p_drawtext(500, v_yy, p_str(a_hscores(v_i).f_gold), -1, 0);
		p_drawtext(550, v_yy, p_str(a_hscores(v_i).f_punkte), -1, 0);
		v_yy = (v_yy + 12);
	}
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(500);
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(55, 0, 0, 640, 17);
		p_displaytransparentsprite(55, 0, 0);
		p_clipsprite(63, 0, 0, 640, 17);
		p_displaysprite(63, 0, 33);
		p_clipsprite(58, 0, 0, 640, 17);
		p_displaytransparentsprite(58, 0, 464);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(1, 255, 1));
		p_drawtext(260, 18, "Highscores", -1, 0);
		v_yy = 75;
		p_drawtext(50, v_yy, "Nr", -1, 0);
		p_drawtext(100, v_yy, a_nachricht_text(154, (1 + g_sprache)), -1, 0);
		p_drawtext(400, v_yy, "Level", -1, 0);
		p_drawtext(450, v_yy, "MKS", -1, 0);
		p_drawtext(500, v_yy, a_nachricht_text(156, (1 + g_sprache)), -1, 0);
		p_drawtext(550, v_yy, a_nachricht_text(93, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		v_yy = 95;
		for (v_i = 1; v_i <= 30; v_i += 1) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb(255, 255, 255));
			if ((v_i == g_letzter_eintrag)) {
				p_frontcolor(p_rgb(255, 1, 1));
			}
			if ((v_i == v_akt_pos)) {
				p_frontcolor(p_rgb(1, 1, 255));
			}
			if (((v_mmouse_y > ((v_i * 12) + 85)) && (v_mmouse_y < ((v_i * 12) + 98)))) {
				p_frontcolor(p_rgb(100, 100, 100));
				v_akt_eintrag = v_i;
			}
			p_drawtext(50, v_yy, p_str(v_i), -1, 0);
			p_drawtext(100, v_yy, a_hscores(v_i).f_name, -1, 0);
			p_drawtext(400, v_yy, p_str(a_hscores(v_i).f_level), -1, 0);
			p_drawtext(450, v_yy, p_str(a_hscores(v_i).f_mks), -1, 0);
			p_drawtext(500, v_yy, p_str(a_hscores(v_i).f_gold), -1, 0);
			p_drawtext(550, v_yy, p_str(a_hscores(v_i).f_punkte), -1, 0);
			v_yy = (v_yy + 12);
			p_stopdrawing();
		}
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_akt_pos = (v_akt_pos + 1);
				if ((v_akt_pos > 30)) {
					v_akt_pos = 30;
				}
				v_warten2 = 10;
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			if ((v_warten2 > 0)) {
				v_warten2 = (v_warten2 - 1);
			} else {
				v_akt_pos = (v_akt_pos - 1);
				if ((v_akt_pos < 1)) {
					v_akt_pos = 1;
				}
				v_warten2 = 10;
			}
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		v_ret = 0;
		if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
			v_ret = 1;
		}
		v_spac = 0;
		if ((p_keyboardpushed(32) || (v_jb2 == 1))) {
			v_spac = 1;
		}
	} while (!((((v_mmouse_rechts == 1) || ((v_mmouse_links == 1) && (v_akt_eintrag > 0))) || (v_ret == 1)) || (v_spac == 1)));
	if ((v_mmouse_links == 1)) {
		p_show_detail(v_akt_eintrag);
		goto L_wieder_high;
	}
	if ((v_ret == 1)) {
		p_show_detail(v_akt_pos);
	}
	if ((v_mmouse_rechts == 1)) {
		g_letzter_eintrag = 0;
	}
}

static int32_t p_show_logo() {
	p_clipsprite(12, 1, 1, 200, 58);
	p_displaytransparentsprite(12, 400, 25);
}

static int32_t p_show_old_messages() {
	int32_t v_i = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int16_t v_y = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 464);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 624, 0);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(250, 30, a_nachricht_text(660, (1 + g_sprache)), -1, 0);
		v_y = 60;
		for (v_i = 1; v_i <= 25; v_i += 1) {
			switch (a_old_messages(v_i, g_akt_spieler).f_farbe) {
			case 1:
				p_frontcolor(p_rgb(255, 255, 255));
				break;
			case 2:
				p_frontcolor(p_rgb(1, 1, 255));
				break;
			case 3:
				p_frontcolor(p_rgb(255, 1, 1));
				break;
			case 4:
				p_frontcolor(p_rgb(1, 255, 1));
				break;
			case 5:
				p_frontcolor(p_rgb(255, 255, 1));
				break;
			case 6:
				p_frontcolor(p_rgb(150, 150, 150));
				break;
			}
			p_drawtext(50, v_y, a_old_messages(v_i, g_akt_spieler).f_nachricht, -1, 0);
			v_y = (v_y + 15);
		}
		p_stopdrawing();
		v_result = p_examinemouse();
		v_mouse_x = p_mousex();
		v_mouse_y = p_mousey();
		v_mouse_links = 0;
		v_mouse_rechts = 0;
		v_mouse_links = p_mousebutton(1);
		v_mouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		p_flipbuffers(1);
	} while (!(v_mouse_rechts == 1));
}

static int32_t p_show_schnellinventory() {
	int32_t v_aktuell = 0;
	int32_t v_i = 0;
	int16_t v_menuposx = 0;
	int16_t v_menuposy = 0;
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int32_t v_wohin = 0;
	v_menuposx = 23;
	v_menuposy = 431;
	for (v_i = 1; v_i <= 10; v_i += 1) {
		v_aktuell = 0;
		if ((a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1)) {
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(120, 120, 120));
			p_box((v_menuposx + ((v_i * 32) - 31)), (v_menuposy + 1), 30, 30, -1);
			p_stopdrawing();
		}
		if (((((g_mmouse_x > ((v_menuposx + (v_i * 32)) - 32)) && (g_mmouse_x < (v_menuposx + (v_i * 32)))) && (g_mmouse_y > v_menuposy)) && (g_mmouse_y < (v_menuposy + 32)))) {
			p_beschreiben((v_i + 40), 400, 330);
			p_clipsprite(8, 224, 320, 32, 32);
			p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
			v_aktuell = 1;
			if (((g_mmouse_links == 1) && (g_aktion == 0))) {
				g_aktion = 1;
				g_feld = (v_i + 40);
				if ((a_inventory(g_feld, g_akt_spieler).f_name != 0)) {
					if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
						g_do_it = 1;
						p_itemtest();
						g_do_it = 0;
					} else {
						g_do_it2 = 1;
						p_itemtest();
						g_do_it2 = 0;
					}
					p_laby_screen();
					p_delay(100);
					throw Lv_nach_zauber;
				}
			}
		} else {
			p_clipsprite(8, 480, 64, 32, 32);
			p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
		}
		if ((a_inventory((v_i + 40), g_akt_spieler).f_name != 0)) {
			v_sprite_x = a_inventory((v_i + 40), g_akt_spieler).f_name;
			if (((v_sprite_x == 46) && (a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = 47;
			}
			if (((v_sprite_x == 39) && (a_inventory((v_i + 40), g_akt_spieler).f_benutzt == 1))) {
				v_sprite_x = 40;
			}
			v_sprite_y = 0;
			if ((v_sprite_x > 16)) {
				do {
					v_sprite_y = (v_sprite_y + 1);
					v_sprite_x = (v_sprite_x - 16);
				} while (!(v_sprite_x < 17));
			}
			p_clipsprite(8, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
			p_displaytransparentsprite(8, ((v_menuposx + (v_i * 32)) - 32), v_menuposy);
			if ((a_inventory((v_i + 40), g_akt_spieler).f_anzahl > 0)) {
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawingmode(1);
				p_drawtext(((v_menuposx + ((v_i * 32) - 32)) + 22), (v_menuposy + 18), p_str((a_inventory((v_i + 40), g_akt_spieler).f_anzahl + 1)), -1, 0);
				p_stopdrawing();
			}
		}
	}
}

static int32_t p_show_sight() {
	int16_t v_sicht = 0;
	v_sicht = p_radius();
	switch (v_sicht) {
	case 1:
		p_clipsprite(16, 1, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 2:
		p_clipsprite(16, 335, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 3:
		p_clipsprite(16, 670, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 4:
		p_clipsprite(16, 1, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 5:
		p_clipsprite(16, 335, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 6:
		p_clipsprite(16, 670, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 7:
		p_clipsprite(16, 1, 670, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	default:

		break;
	}
}

static int32_t p_show_sight2() {
	int16_t v_sight = 0;
	v_sight = p_radius2();
	if ((g_levelmod == 1)) {
		v_sight = (v_sight - 2);
		if ((v_sight < 2)) {
			v_sight = 1;
		}
	}
	switch (v_sight) {
	case 1:
		p_clipsprite(16, 1, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 2:
		p_clipsprite(16, 335, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 3:
		p_clipsprite(16, 670, 1, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 4:
		p_clipsprite(16, 1, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 5:
		p_clipsprite(16, 335, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 6:
		p_clipsprite(16, 670, 335, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	case 7:
		p_clipsprite(16, 1, 670, 335, 335);
		p_displaytransparentsprite(16, 16, 15);
		break;
	default:

		break;
	}
}

static int32_t p_show_varys() {
	int16_t v_erkl = 0;
	float v_faktor = 0.0;
	int16_t v_gibts = 0;
	int32_t v_i = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int16_t v_pos = 0;
	int16_t v_pos2 = 0;
	int32_t v_result = 0;
	int16_t v_ruestung_kaputt = 0;
	int16_t v_waffe_kaputt = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	int32_t v_zz = 0;
	v_result = p_examinemouse();
	v_mmouse_x = p_mousex();
	v_mmouse_y = p_mousey();
	v_mmouse_rechts = p_mousebutton(2);
	v_x = 400;
	v_y = 104;
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(v_x, v_y, 160, 55, -1);
	if ((a_spieler(g_akt_spieler).f_lifepoints > p_maxlife())) {
		a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
	}
	if ((a_spieler(g_akt_spieler).f_speed > p_maxspeed())) {
		a_spieler(g_akt_spieler).f_speed = p_maxspeed();
	}
	if ((g_flaschen == 1)) {
		v_faktor = (p_maxlife() / 32.0);
		v_pos = (int32_t)(((a_spieler(g_akt_spieler).f_lifepoints / v_faktor) - 1.0));
		if ((p_maxlife() == a_spieler(g_akt_spieler).f_lifepoints)) {
			v_pos2 = 837;
		} else {
			v_pos2 = ((27 * v_pos) - 27);
		}
		p_clipsprite(67, v_pos2, 0, 27, 49);
		p_displaysprite(67, 390, 110);
		v_faktor = (p_maxmana() / 32.0);
		v_pos = (int32_t)(((a_spieler(g_akt_spieler).f_mana / v_faktor) - 1.0));
		if ((p_maxmana() == a_spieler(g_akt_spieler).f_mana)) {
			v_pos2 = 837;
		} else {
			v_pos2 = ((27 * v_pos) - 27);
		}
		p_clipsprite(66, v_pos2, 0, 27, 49);
		p_displaysprite(66, 420, 110);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(239, 131, 44));
		p_drawtext((v_x + 70), (v_y + 15), a_nachricht_text(77, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 155), (v_y + 15), ((p_str(a_spieler(g_akt_spieler).f_speed) + "/") + p_str(p_maxspeed())), -1, 0);
		p_frontcolor(p_rgb(154, 251, 120));
		p_drawtext((v_x + 70), (v_y + 30), a_nachricht_text(525, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 155), (v_y + 30), p_str(a_spieler(g_akt_spieler).f_level), -1, 0);
	} else {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(247, 36, 61));
		p_drawtext(v_x, v_y, a_nachricht_text(55, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 110), v_y, ((p_str(a_spieler(g_akt_spieler).f_lifepoints) + "/") + p_str(p_maxlife())), -1, 0);
		p_frontcolor(p_rgb(130, 125, 250));
		p_drawtext(v_x, (v_y + 15), a_nachricht_text(59, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 115), (v_y + 15), ((p_str(a_spieler(g_akt_spieler).f_mana) + "/") + p_str(p_maxmana())), -1, 0);
		p_frontcolor(p_rgb(239, 131, 44));
		p_drawtext(v_x, (v_y + 30), a_nachricht_text(77, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 115), (v_y + 30), ((p_str(a_spieler(g_akt_spieler).f_speed) + "/") + p_str(p_maxspeed())), -1, 0);
		p_frontcolor(p_rgb(154, 251, 120));
		p_drawtext(v_x, (v_y + 45), a_nachricht_text(525, (g_sprache + 1)), -1, 0);
		p_drawtext((v_x + 115), (v_y + 45), p_str(a_spieler(g_akt_spieler).f_level), -1, 0);
	}
	p_stopdrawing();
	p_clipsprite(0, 128, ((a_spieler(g_akt_spieler).f_maennchen * 32) - 32), 32, 32);
	p_displaytransparentsprite(0, 590, 120);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	v_x = 400;
	v_y = 174;
	p_frontcolor(p_rgb(0, 0, 0));
	if ((a_spieler(g_akt_spieler).f_schleichen > 0)) {
		v_y = (v_y + 10);
		p_frontcolor(p_rgb(150, 150, 150));
		p_drawtext(v_x, v_y, a_nachricht_text(78, (1 + g_sprache)), -1, 0);
	}
	p_stopdrawing();
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if ((a_aktive(v_i, g_akt_spieler).f_nr > 0)) {
			v_gibts = 0;
			for (v_zz = 1; v_zz <= (v_i - 1); v_zz += 1) {
				if ((a_aktive(v_i, g_akt_spieler).f_nr == a_aktive(v_zz, g_akt_spieler).f_nr)) {
					v_gibts = 1;
				}
			}
			if ((v_gibts == 0)) {
				v_y = (v_y + 16);
				if (((((v_mmouse_x >= v_x) && (v_mmouse_x <= (v_x + 120))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 15)))) {
					p_clipsprite(36, 32, 48, 16, 16);
					p_displaytransparentsprite(36, (v_x - 20), v_y);
					if ((v_mmouse_rechts == 1)) {
						if ((a_aktive(v_i, g_akt_spieler).f_dauer != 9999)) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							p_delay(g_mydelay);
						}
					}
				}
				switch (a_aktive(v_i, g_akt_spieler).f_nr) {
				case 200:
					p_clipsprite(36, 0, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 86:
					p_clipsprite(36, 32, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 87:
					p_clipsprite(36, 32, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 88:
					p_clipsprite(36, 32, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 89:
					p_clipsprite(36, 32, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 90:
					p_clipsprite(36, 32, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 82:
					p_clipsprite(36, 144, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 70:
					p_clipsprite(36, 64, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 71:
					p_clipsprite(36, 80, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 61:
					p_clipsprite(36, 96, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 7:
					p_clipsprite(36, 16, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 68:
					p_clipsprite(36, 0, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 59:
					p_clipsprite(36, 144, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 75:
					p_clipsprite(36, 80, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 85:
					p_clipsprite(36, 0, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 18:
					p_clipsprite(36, 48, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 33:
					p_clipsprite(36, 64, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 45:
					p_clipsprite(36, 144, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 46:
					p_clipsprite(36, 112, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 52:
					p_clipsprite(36, 96, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 26:
					p_clipsprite(36, 96, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 40:
					p_clipsprite(36, 128, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 36:
					p_clipsprite(36, 16, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 37:
					p_clipsprite(36, 112, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 38:
					p_clipsprite(36, 16, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 79:
					p_clipsprite(36, 144, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 80:
					p_clipsprite(36, 0, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 48:
					p_clipsprite(36, 16, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 49:
					p_clipsprite(36, 128, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 35:
					p_clipsprite(36, 16, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 102:
					p_clipsprite(36, 128, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 109:
					p_clipsprite(36, 64, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 110:
					p_clipsprite(36, 48, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 118:
					p_clipsprite(36, 112, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 119:
					p_clipsprite(36, 112, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 103:
					p_clipsprite(36, 144, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 120:
					p_clipsprite(36, 96, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 121:
					p_clipsprite(36, 64, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 124:
					p_clipsprite(36, 64, 16, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 130:
					p_clipsprite(36, 48, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 141:
					p_clipsprite(36, 48, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 142:
					p_clipsprite(36, 80, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 143:
					p_clipsprite(36, 64, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 145:
					p_clipsprite(36, 112, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 151:
					p_clipsprite(36, 0, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 154:
					p_clipsprite(36, 112, 48, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 165:
					p_clipsprite(36, 16, 112, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 166:
					p_clipsprite(36, 32, 32, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 175:
					p_clipsprite(36, 32, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				case 176:
					p_clipsprite(36, 16, 0, 16, 16);
					p_displaysprite(36, v_x, v_y);
					break;
				}
				if (((((a_aktive(v_i, g_akt_spieler).f_nr == 168) || (a_aktive(v_i, g_akt_spieler).f_nr == 169)) || (a_aktive(v_i, g_akt_spieler).f_nr == 170)) || (a_aktive(v_i, g_akt_spieler).f_nr == 171))) {
					p_clipsprite(36, 0, 15, 15, 15);
					p_displaysprite(36, v_x, v_y);
				}
				if (((((((a_aktive(v_i, g_akt_spieler).f_nr == 156) || (a_aktive(v_i, g_akt_spieler).f_nr == 157)) || (a_aktive(v_i, g_akt_spieler).f_nr == 158)) || (a_aktive(v_i, g_akt_spieler).f_nr == 159)) || (a_aktive(v_i, g_akt_spieler).f_nr == 160)) || (a_aktive(v_i, g_akt_spieler).f_nr == 161))) {
					p_clipsprite(36, 143, 0, 15, 15);
					p_displaysprite(36, v_x, v_y);
				}
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 1));
				p_drawtext((v_x + 20), v_y, a_zauber(a_aktive(v_i, g_akt_spieler).f_nr, g_akt_spieler).f_name[(1 + g_sprache)], -1, 0);
				p_stopdrawing();
			}
		}
	}
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	v_waffe_kaputt = 0;
	v_ruestung_kaputt = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_benutzt == 1) && ((a_inventory(v_i, g_akt_spieler).f_status == 1) || (a_inventory(v_i, g_akt_spieler).f_status == 2)))) {
			if ((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 1)) {
				v_waffe_kaputt = 1;
			}
			if ((((((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 6) || (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 7)) || (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 8)) || (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 9)) || (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_art == 11))) {
				v_ruestung_kaputt = 1;
			}
		}
	}
	if ((v_waffe_kaputt > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawtext(v_x, v_y, a_nachricht_text(646, (1 + g_sprache)), -1, 0);
	}
	if ((v_ruestung_kaputt > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawtext(v_x, v_y, a_nachricht_text(647, (1 + g_sprache)), -1, 0);
	}
	if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 6)) || (a_spieler(g_akt_spieler).f_lifepoints <= 3))) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawtext(v_x, v_y, a_nachricht_text(662, (1 + g_sprache)), -1, 0);
	} else {
		if (((a_spieler(g_akt_spieler).f_lifepoints <= (p_maxlife() / 4)) || (a_spieler(g_akt_spieler).f_lifepoints <= 5))) {
			v_y = (v_y + 16);
			p_frontcolor(p_rgb(255, 1, 1));
			p_drawtext(v_x, v_y, a_nachricht_text(661, (1 + g_sprache)), -1, 0);
		}
	}
	if ((a_spieler(g_akt_spieler).f_betrunken > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(1, 255, 1));
		p_drawtext(v_x, v_y, a_nachricht_text(699, (1 + g_sprache)), -1, 0);
	}
	if ((p_belastung() > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawtext(v_x, v_y, ((a_nachricht_text(86, (1 + g_sprache)) + " ") + p_str(p_belastung())), -1, 0);
	}
	if ((a_spieler(g_akt_spieler).f_gift > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(1, 255, 1));
		p_drawtext(v_x, v_y, (a_nachricht_text(645, (1 + g_sprache)) + p_str(a_spieler(g_akt_spieler).f_gift)), -1, 0);
	}
	if ((a_spieler(g_akt_spieler).f_verhungern > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(1, 1, 255));
		switch (a_spieler(g_akt_spieler).f_verhungern) {
		case 1:
			p_drawtext(v_x, v_y, a_nachricht_text(97, (g_sprache + 1)), -1, 0);
			break;
		case 2:
			p_drawtext(v_x, v_y, a_nachricht_text(98, (g_sprache + 1)), -1, 0);
			break;
		case 3:
			p_drawtext(v_x, v_y, a_nachricht_text(99, (g_sprache + 1)), -1, 0);
			break;
		}
	}
	if ((a_spieler(g_akt_spieler).f_verdursten > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(1, 1, 255));
		switch (a_spieler(g_akt_spieler).f_verdursten) {
		case 1:
			p_drawtext(v_x, v_y, a_nachricht_text(94, (g_sprache + 1)), -1, 0);
			break;
		case 2:
			p_drawtext(v_x, v_y, a_nachricht_text(95, (g_sprache + 1)), -1, 0);
			break;
		case 3:
			p_drawtext(v_x, v_y, a_nachricht_text(96, (g_sprache + 1)), -1, 0);
			break;
		}
	}
	if ((a_spieler(g_akt_spieler).f_krankheit > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(1, 255, 1));
		p_drawtext(v_x, v_y, ((a_nachricht_text(825, (1 + g_sprache)) + " ") + p_str(a_spieler(g_akt_spieler).f_krankheit)), -1, 0);
	}
	if ((a_spieler(g_akt_spieler).f_fluch > 0)) {
		v_y = (v_y + 16);
		p_frontcolor(p_rgb(150, 150, 150));
		v_erkl = 0;
		if ((a_spieler(g_akt_spieler).f_fluch == 1)) {
			p_drawtext(v_x, v_y, a_nachricht_text(131, (g_sprache + 1)), -1, 0);
			v_erkl = 838;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 2)) {
			p_drawtext(v_x, v_y, a_nachricht_text(132, (g_sprache + 1)), -1, 0);
			v_erkl = 839;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 3)) {
			p_drawtext(v_x, v_y, a_nachricht_text(133, (g_sprache + 1)), -1, 0);
			v_erkl = 840;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 4)) {
			p_drawtext(v_x, v_y, a_nachricht_text(134, (g_sprache + 1)), -1, 0);
			v_erkl = 841;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 5)) {
			p_drawtext(v_x, v_y, a_nachricht_text(135, (g_sprache + 1)), -1, 0);
			v_erkl = 842;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 6)) {
			p_drawtext(v_x, v_y, a_nachricht_text(136, (g_sprache + 1)), -1, 0);
			v_erkl = 843;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 7)) {
			p_drawtext(v_x, v_y, a_nachricht_text(137, (g_sprache + 1)), -1, 0);
			v_erkl = 844;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 8)) {
			p_drawtext(v_x, v_y, a_nachricht_text(138, (g_sprache + 1)), -1, 0);
			v_erkl = 845;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 9)) {
			p_drawtext(v_x, v_y, a_nachricht_text(139, (g_sprache + 1)), -1, 0);
			v_erkl = 846;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 10)) {
			p_drawtext(v_x, v_y, a_nachricht_text(140, (g_sprache + 1)), -1, 0);
			v_erkl = 847;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 11)) {
			p_drawtext(v_x, v_y, a_nachricht_text(141, (g_sprache + 1)), -1, 0);
			v_erkl = 848;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 12)) {
			p_drawtext(v_x, v_y, a_nachricht_text(142, (g_sprache + 1)), -1, 0);
			v_erkl = 849;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 13)) {
			p_drawtext(v_x, v_y, a_nachricht_text(143, (g_sprache + 1)), -1, 0);
			v_erkl = 850;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 14)) {
			p_drawtext(v_x, v_y, a_nachricht_text(144, (g_sprache + 1)), -1, 0);
			v_erkl = 851;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 15)) {
			p_drawtext(v_x, v_y, a_nachricht_text(145, (g_sprache + 1)), -1, 0);
			v_erkl = 852;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 16)) {
			p_drawtext(v_x, v_y, a_nachricht_text(146, (g_sprache + 1)), -1, 0);
			v_erkl = 853;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 17)) {
			p_drawtext(v_x, v_y, a_nachricht_text(147, (g_sprache + 1)), -1, 0);
			v_erkl = 854;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 18)) {
			p_drawtext(v_x, v_y, a_nachricht_text(148, (g_sprache + 1)), -1, 0);
			v_erkl = 855;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
			p_drawtext(v_x, v_y, a_nachricht_text(149, (g_sprache + 1)), -1, 0);
			v_erkl = 856;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 20)) {
			p_drawtext(v_x, v_y, a_nachricht_text(150, (g_sprache + 1)), -1, 0);
			v_erkl = 857;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 21)) {
			p_drawtext(v_x, v_y, a_nachricht_text(151, (g_sprache + 1)), -1, 0);
			v_erkl = 858;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 22)) {
			p_drawtext(v_x, v_y, a_nachricht_text(152, (g_sprache + 1)), -1, 0);
			v_erkl = 859;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
			p_drawtext(v_x, v_y, a_nachricht_text(153, (g_sprache + 1)), -1, 0);
			v_erkl = 860;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 24)) {
			p_drawtext(v_x, v_y, a_nachricht_text(749, (g_sprache + 1)), -1, 0);
			v_erkl = 861;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 25)) {
			p_drawtext(v_x, v_y, a_nachricht_text(750, (g_sprache + 1)), -1, 0);
			v_erkl = 862;
		}
		if ((a_spieler(g_akt_spieler).f_fluch == 26)) {
			p_drawtext(v_x, v_y, a_nachricht_text(751, (g_sprache + 1)), -1, 0);
			v_erkl = 863;
		}
		if ((((((v_mmouse_x >= v_x) && (v_mmouse_x <= (v_x + 120))) && (v_mmouse_y >= v_y)) && (v_mmouse_y <= (v_y + 15))) && (v_erkl != 0))) {
			p_drawtext(25, 400, a_nachricht_text(v_erkl, (1 + g_sprache)), -1, 0);
		}
	}
	p_stopdrawing();
}

static int32_t p_show_varys2() {
	int32_t v_okay = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	v_x = 400;
	v_y = 104;
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(400, 110, 160, 55, -1);
	p_frontcolor(p_rgb(255, 255, 255));
	p_frontcolor(p_rgb(247, 36, 61));
	p_drawtext(v_x, v_y, a_nachricht_text(55, (g_sprache + 1)), -1, 0);
	p_drawtext((v_x + 110), v_y, p_str(a_spieler(g_akt_spieler).f_creature_lifepoints), -1, 0);
	p_frontcolor(p_rgb(239, 131, 44));
	p_drawtext(v_x, (v_y + 30), a_nachricht_text(77, (g_sprache + 1)), -1, 0);
	p_drawtext((v_x + 115), (v_y + 30), ((p_str(a_spieler(g_akt_spieler).f_creature_speed) + "/") + p_str(p_creature_speed())), -1, 0);
	p_frontcolor(p_rgb(154, 251, 120));
	p_drawtext(v_x, (v_y + 45), "Level:", -1, 0);
	p_drawtext((v_x + 115), (v_y + 45), p_str(a_spieler(g_akt_spieler).f_level), -1, 0);
	p_stopdrawing();
	if (((a_spieler(g_akt_spieler).f_creature_typ == 1) && (v_okay == 0))) {
		p_clipsprite(34, 128, 256, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 2) && (v_okay == 0))) {
		p_clipsprite(34, 128, 192, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 3) && (v_okay == 0))) {
		p_clipsprite(34, 128, 352, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 4) && (v_okay == 0))) {
		p_clipsprite(34, 128, 384, 32, 32);
		p_displaytransparentsprite(34, 590, 130);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 5) && (v_okay == 0))) {
		p_clipsprite(34, 128, 416, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 6) && (v_okay == 0))) {
		p_clipsprite(34, 128, 320, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 7) && (v_okay == 0))) {
		p_clipsprite(34, 128, 224, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 8) && (v_okay == 0))) {
		p_clipsprite(34, 128, 288, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 9) && (v_okay == 0))) {
		p_clipsprite(34, 128, 160, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 10) && (v_okay == 0))) {
		p_clipsprite(0, 128, ((a_spieler(g_akt_spieler).f_maennchen * 32) - 32), 32, 32);
		p_displaytransparentsprite(0, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 11) && (v_okay == 0))) {
		p_clipsprite(34, 128, 96, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 12) && (v_okay == 0))) {
		p_clipsprite(34, 128, 480, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 13) && (v_okay == 0))) {
		p_clipsprite(34, 128, 512, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 14) && (v_okay == 0))) {
		p_clipsprite(34, 128, 544, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 15) && (v_okay == 0))) {
		p_clipsprite(34, 128, 576, 32, 32);
		p_displaytransparentsprite(34, 590, 125);
		v_okay = 1;
	}
	if (((a_spieler(g_akt_spieler).f_creature_typ == 20) && (v_okay == 0))) {
		p_clipsprite(0, 128, 608, 32, 32);
		p_displaytransparentsprite(0, 590, 125);
		v_okay = 1;
	}
}

static int32_t p_sog() {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	for (v_j = 1; v_j <= 5; v_j += 1) {
		for (v_i = 1; v_i <= 4; v_i += 1) {
			p_laby_screen2();
			if ((v_i == 1)) {
				p_clipsprite(17, 80, 40, 39, 39);
			}
			if ((v_i == 2)) {
				p_clipsprite(17, 120, 40, 39, 39);
			}
			if ((v_i == 3)) {
				p_clipsprite(17, 1, 80, 39, 39);
			}
			if ((v_i == 4)) {
				p_clipsprite(17, 40, 80, 39, 39);
			}
			p_displaytransparentsprite(17, (156 + (g_spell_x * 32)), (156 + (g_spell_y * 32)));
			p_flipbuffers(1);
			p_delay(90);
		}
	}
	p_stopdrawing();
}

static int32_t p_sonderfeld() {
	int32_t v_egon = 0;
	int16_t v_entdecken = 0;
	int32_t v_gef_rolle = 0;
	int32_t v_hugo = 0;
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_nach_kampf = 0;
	int32_t v_obje = 0;
	int16_t v_stiefel = 0;
	int16_t v_welches = 0;
	int32_t v_xsave = 0;
	int32_t v_ysave = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	if ((g_bewegt == 1)) {
		switch (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level]) {
		case 79:
			if (((((((a_skills(103, g_akt_spieler).f_gewaehlt == 1) || (a_skills(104, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(105, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(106, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(107, g_akt_spieler).f_gewaehlt == 1)) || (a_skills(108, g_akt_spieler).f_gewaehlt == 1))) {
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] > 0)) {
					a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] = (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_status[a_spieler(g_akt_spieler).f_level] - 1);
					p_altar();
					a_spieler(g_akt_spieler).f_character_y = (a_spieler(g_akt_spieler).f_character_y - 1);
					p_laby_screen();
				} else {
					p_nachricht(654, 5);
				}
			} else {
				p_nachricht(655, 5);
			}
			g_aktion = 1;
			break;
		case 93:
			if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 0)) {
				p_nachricht(446, 1);
				a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 1;
			}
			break;
		case 55:
			g_aktion = 1;
			if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1)) {
				a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 0;
				if ((p_random(100) > 70)) {
					v_hugo = p_random(7);
					if ((((v_hugo == 0) || (v_hugo == 1)) || (v_hugo == 2))) {
						v_egon = (p_random(2) + 1);
						if ((v_egon == 1)) {
							v_welches = 4;
						}
						if ((v_egon == 2)) {
							v_welches = 16;
						}
						if ((v_egon == 3)) {
							v_welches = 26;
						}
						p_hinterhalt(v_welches);
					}
					if (((v_hugo == 3) || (v_hugo == 4))) {
						v_hugo = (p_random(((a_spieler(g_akt_spieler).f_level * 5) + a_spieler(g_akt_spieler).f_luck_score)) + 1);
						p_gold_finden(v_hugo);
					}
					if ((v_hugo == 5)) {
						v_obje = p_finden1();
						p_in_rucksack(v_obje, 1);
						if (((((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (v_obje >= 75)) && (v_obje <= 112))) {
							v_obje = 998;
						}
						p_nachricht2(6, v_obje);
					}
					if (((v_hugo == 6) || (v_hugo == 7))) {
						p_in_rucksack(1, 1);
					}
				} else {
					p_nachricht(445, 1);
				}
			}
			break;
		case 18:
			if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] != 1)) {
				if ((a_spieler(g_akt_spieler).f_fluch != 16)) {
					a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 1;
					if (((p_luck() * 10) < p_random(100))) {
						p_sound(9);
						v_obje = (p_random(37) + 75);
						p_in_rucksack(v_obje, 1);
						p_nachricht(309, 5);
					}
				} else {
					p_nachricht(7, 6);
				}
				g_aktion = 1;
			}
			break;
		case 16:
			if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] != 1)) {
				if ((a_spieler(g_akt_spieler).f_fluch != 16)) {
					a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 1;
					if (((p_luck() * 10) < p_random(100))) {
						p_sound(9);
						v_gef_rolle = (v_gef_rolle + 1);
						p_in_rucksack(38, 1);
						p_nachricht(310, 5);
					}
				} else {
					p_nachricht(7, 6);
				}
				g_aktion = 1;
			}
			break;
		case 81:
			if (((a_skills(84, g_akt_spieler).f_gewaehlt == 0) && (p_habich(130) == 0))) {
				if ((a_spieler(g_akt_spieler).f_gift == 0)) {
					a_spieler(g_akt_spieler).f_gift = 1;
					a_spieler(g_akt_spieler).f_giftdauer = 10;
				} else {
					a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer + 5);
				}
			} else {
				p_nachricht(256, 4);
			}
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			g_aktion = 1;
			break;
		case 201:
			if (((a_skills(84, g_akt_spieler).f_gewaehlt == 0) && (p_habich(130) == 0))) {
				if ((a_spieler(g_akt_spieler).f_gift == 0)) {
					a_spieler(g_akt_spieler).f_gift = 1;
					a_spieler(g_akt_spieler).f_giftdauer = 10;
				} else {
					a_spieler(g_akt_spieler).f_giftdauer = (a_spieler(g_akt_spieler).f_giftdauer + 5);
				}
			} else {
				p_nachricht(256, 4);
			}
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			g_aktion = 1;
			break;
		case 40:
			if (((p_habich(7) == 0) && (p_habich(70) == 0))) {
				p_spielerschaden(1, 1, 11);
			}
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			g_aktion = 1;
			break;
		case 41:
			if (((p_habich(7) == 0) && (p_habich(70) == 0))) {
				p_spielerschaden(2, 1, 11);
			}
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			g_aktion = 1;
			break;
		case 110:
			if (((p_habich(7) == 0) && (p_habich(70) == 0))) {
				if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 0)) {
					p_spielerschaden(5, 1, 11);
					g_aktion = 1;
				}
			}
			break;
		case 53:
			p_sound(27);
			a_spieler(g_akt_spieler).f_durst = 0;
			a_spieler(g_akt_spieler).f_verdursten = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
					a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
				}
			}
			if ((((p_habich(48) == 0) && (p_habich(86) == 0)) && (p_habich(88) == 0))) {
				if ((p_habich(49) == 0)) {
					if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
						g_aktion = 1;
						if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1)) {
							a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 0;
							if ((p_random(100) > 80)) {
								v_hugo = (p_random(((a_spieler(g_akt_spieler).f_level * 5) + a_spieler(g_akt_spieler).f_luck_score)) + 1);
								p_gold_finden(v_hugo);
							}
						}
						if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
							p_spielerschaden(2, 3, 12);
						} else {
							p_spielerschaden(1, 3, 12);
						}
					} else {
						if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1)) {
							a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 0;
							if ((p_random(100) > 80)) {
								v_hugo = (p_random(((a_spieler(g_akt_spieler).f_level * 5) + a_spieler(g_akt_spieler).f_luck_score)) + 1);
								p_gold_finden(v_hugo);
							}
							g_aktion = 1;
						}
					}
				}
			}
			break;
		case 160:
			p_sound(27);
			a_spieler(g_akt_spieler).f_durst = 0;
			a_spieler(g_akt_spieler).f_verdursten = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
					a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
				}
			}
			p_gold(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y);
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
					p_spielerschaden(2, 3, 12);
				} else {
					p_spielerschaden(1, 3, 12);
				}
			}
			g_aktion = 1;
			break;
		case 161:
			p_sound(27);
			a_spieler(g_akt_spieler).f_durst = 0;
			a_spieler(g_akt_spieler).f_verdursten = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
					a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
					p_spielerschaden(2, 3, 12);
				} else {
					p_spielerschaden(1, 3, 12);
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				g_aktion = 1;
			}
			break;
		case 163:
			p_sound(27);
			a_spieler(g_akt_spieler).f_durst = 0;
			a_spieler(g_akt_spieler).f_verdursten = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
					a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
					p_spielerschaden(2, 3, 12);
				} else {
					p_spielerschaden(1, 3, 12);
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				g_aktion = 1;
			}
			break;
		case 162:
			p_sound(27);
			a_spieler(g_akt_spieler).f_durst = 0;
			a_spieler(g_akt_spieler).f_verdursten = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((a_inventory(v_i, g_akt_spieler).f_name == 193)) {
					a_inventory(v_i, g_akt_spieler).f_attri1 = 7;
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				if ((a_spieler(g_akt_spieler).f_fluch == 19)) {
					p_spielerschaden(2, 3, 12);
				} else {
					p_spielerschaden(1, 3, 12);
				}
			}
			if ((a_skills(112, g_akt_spieler).f_gewaehlt == 0)) {
				g_aktion = 1;
			}
			break;
		case 74:
			p_sound(9);
			p_sternchen(156, 156, 4);
			v_xsave = a_spieler(g_akt_spieler).f_character_x;
			v_ysave = a_spieler(g_akt_spieler).f_character_y;
			a_spieler(g_akt_spieler).f_character_x = a_labyrinth(v_xsave, v_ysave).f_lebenspunkte[a_spieler(g_akt_spieler).f_level];
			a_spieler(g_akt_spieler).f_character_y = a_labyrinth(v_xsave, v_ysave).f_objekt[a_spieler(g_akt_spieler).f_level];
			p_update_automap();
			p_laby_screen();
			v_nach_kampf = 1;
			break;
		case 209:
			p_sound(38);
			p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 210, 0, 0, 0);
			break;
		case 208:
			v_stiefel = 0;
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if ((((a_inventory(v_i, g_akt_spieler).f_art == 8) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1)) && (a_inventory(v_i, g_akt_spieler).f_status == 0))) {
					v_stiefel = 1;
				}
			}
			if ((p_habich(48) > 0)) {
				p_nachricht(865, 2);
			} else {
				if ((v_stiefel == 0)) {
					p_spielerschaden(1, 1, 16);
					p_nachricht(831, 3);
				} else {
					p_nachricht(832, 3);
				}
			}
			break;
		case 65:
			if ((p_habich(7) == 0)) {
				p_sound(10);
				p_spielerschaden(1, 1, 11);
				p_laby_screen();
				g_aktion = 1;
			}
			break;
		}
		v_entdecken = p_entdecken();
		if ((v_entdecken > 90)) {
			v_entdecken = 90;
		}
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 20)) {
			if ((p_random(100) < v_entdecken)) {
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 21, 0, 0, 0);
				p_sound(17);
				p_laby_screen();
				p_delay(g_mydelay);
				if (((a_skills(107, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < (100 - (a_spieler(g_akt_spieler).f_level * 2))))) {
					a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
					p_nachricht(325, 5);
				}
			}
		}
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 20)) {
			if ((p_random(100) < v_entdecken)) {
				p_setlaby((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 21, 0, 0, 0);
				p_sound(17);
				p_laby_screen();
				p_delay(g_mydelay);
				if (((a_skills(107, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < (100 - (a_spieler(g_akt_spieler).f_level * 2))))) {
					a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
					p_nachricht(325, 5);
				}
			}
		}
		if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 20)) {
			if ((p_random(100) < v_entdecken)) {
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level, 21, 0, 0, 0);
				p_sound(17);
				p_laby_screen();
				p_delay(g_mydelay);
				if (((a_skills(107, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < (100 - (a_spieler(g_akt_spieler).f_level * 2))))) {
					a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
					p_nachricht(325, 5);
				}
			}
		}
		if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 20)) {
			if ((p_random(100) < v_entdecken)) {
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level, 21, 0, 0, 0);
				p_sound(17);
				p_laby_screen();
				p_delay(g_mydelay);
				if (((a_skills(107, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) < (100 - (a_spieler(g_akt_spieler).f_level * 2))))) {
					a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
					p_nachricht(325, 5);
				}
			}
		}
		if ((g_autopickup == 1)) {
			p_autopickup();
		}
	}
}

static int32_t p_sonderlevel_text(int16_t v_nr) {
	int16_t v_jb1 = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_nachricht1 = 0;
	int32_t v_nachricht2 = 0;
	int32_t v_nachricht3 = 0;
	int32_t v_nachricht4 = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_y = 0;
	if (((((v_nr == 26) || (v_nr == 13)) || (v_nr == 25)) || (v_nr == 17))) {
		p_sound(32);
	}
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		if ((v_nr == 1)) {
			p_clipsprite(29, 1, 1, 335, 335);
			p_displaytransparentsprite(29, 16, 16);
			v_nachricht1 = 157;
			v_nachricht2 = 158;
			v_nachricht3 = 159;
			v_nachricht4 = 160;
		}
		if ((v_nr == 2)) {
			p_clipsprite(30, 1, 1, 335, 335);
			p_displaytransparentsprite(30, 16, 16);
			v_nachricht1 = 161;
			v_nachricht2 = 162;
			v_nachricht3 = 163;
			v_nachricht4 = 164;
		}
		if ((v_nr == 3)) {
			p_clipsprite(28, 1, 1, 335, 335);
			p_displaytransparentsprite(28, 16, 16);
			v_nachricht1 = 165;
			v_nachricht2 = 166;
			v_nachricht3 = 167;
			v_nachricht4 = 0;
		}
		if ((v_nr == 4)) {
			p_clipsprite(31, 1, 1, 335, 335);
			p_displaytransparentsprite(31, 16, 16);
			v_nachricht1 = 168;
			v_nachricht2 = 169;
			v_nachricht3 = 170;
			v_nachricht4 = 171;
		}
		if ((v_nr == 5)) {
			p_clipsprite(33, 1, 1, 335, 335);
			p_displaytransparentsprite(33, 16, 16);
			v_nachricht1 = 172;
			v_nachricht2 = 173;
			v_nachricht3 = 174;
			v_nachricht4 = 0;
		}
		if ((v_nr == 6)) {
			p_clipsprite(32, 1, 1, 335, 335);
			p_displaytransparentsprite(32, 16, 16);
			v_nachricht1 = 201;
			v_nachricht2 = 202;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 7)) {
			p_clipsprite(42, 1, 1, 335, 335);
			p_displaytransparentsprite(42, 16, 16);
			v_nachricht1 = 292;
			v_nachricht2 = 293;
			v_nachricht3 = 294;
			v_nachricht4 = 0;
		}
		if ((v_nr == 8)) {
			p_clipsprite(40, 1, 1, 335, 335);
			p_displaytransparentsprite(40, 16, 16);
			v_nachricht1 = 295;
			v_nachricht2 = 296;
			v_nachricht3 = 297;
			v_nachricht4 = 0;
		}
		if ((v_nr == 9)) {
			p_clipsprite(52, 1, 1, 335, 335);
			p_displaytransparentsprite(52, 16, 16);
			v_nachricht1 = 488;
			v_nachricht2 = 489;
			v_nachricht3 = 490;
			v_nachricht4 = 0;
		}
		if ((v_nr == 10)) {
			p_clipsprite(51, 1, 1, 335, 335);
			p_displaytransparentsprite(51, 16, 16);
			v_nachricht1 = 491;
			v_nachricht2 = 492;
			v_nachricht3 = 493;
			v_nachricht4 = 0;
		}
		if ((v_nr == 26)) {
			p_clipsprite(35, 1, 1, 335, 335);
			p_displaytransparentsprite(35, 16, 16);
			v_nachricht1 = 127;
			v_nachricht2 = 128;
			v_nachricht3 = 129;
			v_nachricht4 = 0;
		}
		if ((v_nr == 12)) {
			p_clipsprite(28, 1, 1, 335, 335);
			p_displaytransparentsprite(28, 16, 16);
			v_nachricht1 = 484;
			v_nachricht2 = 485;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 13)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 218;
			v_nachricht2 = 219;
			v_nachricht3 = 220;
			v_nachricht4 = 0;
		}
		if ((v_nr == 14)) {
			p_clipsprite(30, 1, 1, 335, 335);
			p_displaytransparentsprite(30, 16, 16);
			v_nachricht1 = 234;
			v_nachricht2 = 235;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 15)) {
			p_clipsprite(33, 1, 1, 335, 335);
			p_displaytransparentsprite(33, 16, 16);
			v_nachricht1 = 236;
			v_nachricht2 = 237;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 16)) {
			p_clipsprite(39, 1, 1, 335, 335);
			p_displaytransparentsprite(39, 16, 16);
			v_nachricht1 = 270;
			v_nachricht2 = 271;
			v_nachricht3 = 272;
			v_nachricht4 = 0;
		}
		if ((v_nr == 17)) {
			p_clipsprite(41, 1, 1, 335, 335);
			p_displaytransparentsprite(41, 16, 16);
			v_nachricht1 = 282;
			v_nachricht2 = 283;
			v_nachricht3 = 284;
			v_nachricht4 = 285;
		}
		if ((v_nr == 18)) {
			p_clipsprite(43, 1, 1, 335, 335);
			p_displaytransparentsprite(43, 16, 16);
			v_nachricht1 = 301;
			v_nachricht2 = 302;
			v_nachricht3 = 303;
			v_nachricht4 = 304;
		}
		if ((v_nr == 19)) {
			p_clipsprite(43, 1, 1, 335, 335);
			p_displaytransparentsprite(43, 16, 16);
			v_nachricht1 = 305;
			v_nachricht2 = 306;
			v_nachricht3 = 307;
			v_nachricht4 = 308;
		}
		if ((v_nr == 20)) {
			p_clipsprite(33, 1, 1, 335, 335);
			p_displaytransparentsprite(33, 16, 16);
			v_nachricht1 = 331;
			v_nachricht2 = 332;
			v_nachricht3 = 333;
			v_nachricht4 = 0;
		}
		if ((v_nr == 21)) {
			p_clipsprite(43, 1, 1, 335, 335);
			p_displaytransparentsprite(43, 16, 16);
			v_nachricht1 = 335;
			v_nachricht2 = 336;
			v_nachricht3 = 337;
			v_nachricht4 = 0;
		}
		if ((v_nr == 22)) {
			p_clipsprite(44, 1, 1, 335, 335);
			p_displaytransparentsprite(44, 16, 16);
			v_nachricht1 = 345;
			v_nachricht2 = 346;
			v_nachricht3 = 347;
			v_nachricht4 = 0;
		}
		if ((v_nr == 23)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 410;
			v_nachricht2 = 411;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 24)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 426;
			v_nachricht2 = 0;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 25)) {
			p_clipsprite(48, 1, 1, 335, 335);
			p_displaytransparentsprite(48, 16, 16);
			v_nachricht1 = 500;
			v_nachricht2 = 501;
			v_nachricht3 = 502;
			v_nachricht4 = 0;
		}
		if ((v_nr == 11)) {
			p_clipsprite(50, 1, 1, 335, 335);
			p_displaytransparentsprite(50, 16, 16);
			v_nachricht1 = 504;
			v_nachricht2 = 505;
			v_nachricht3 = 506;
			v_nachricht4 = 0;
		}
		if ((v_nr == 27)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 125;
			v_nachricht2 = 123;
			v_nachricht3 = 124;
			v_nachricht4 = 0;
		}
		if ((v_nr == 28)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 640;
			v_nachricht2 = 641;
			v_nachricht3 = 642;
			v_nachricht4 = 643;
		}
		if ((v_nr == 29)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 722;
			v_nachricht2 = 723;
			v_nachricht3 = 724;
			v_nachricht4 = 0;
		}
		if ((v_nr == 30)) {
			p_clipsprite(65, 1, 1, 335, 335);
			p_displaytransparentsprite(65, 16, 16);
			v_nachricht1 = 725;
			v_nachricht2 = 726;
			v_nachricht3 = 727;
			v_nachricht4 = 0;
		}
		if ((v_nr == 31)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 742;
			v_nachricht2 = 743;
			v_nachricht3 = 744;
			v_nachricht4 = 745;
		}
		if ((v_nr == 32)) {
			p_clipsprite(14, 1, 1, 335, 335);
			p_displaytransparentsprite(14, 16, 16);
			v_nachricht1 = 746;
			v_nachricht2 = 747;
			v_nachricht3 = 0;
			v_nachricht4 = 0;
		}
		if ((v_nr == 33)) {
			p_clipsprite(53, 1, 1, 335, 335);
			p_displaytransparentsprite(53, 16, 16);
			v_nachricht1 = 867;
			v_nachricht2 = 868;
			v_nachricht3 = 869;
			v_nachricht4 = 870;
		}
		v_x = 45;
		v_y = 35;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(255, 1, 1));
		p_drawingmode(1);
		if ((v_nachricht1 != 0)) {
			p_drawtext(v_x, v_y, p_nachricht4(v_nachricht1), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
		}
		if ((v_nachricht2 != 0)) {
			p_drawtext(v_x, v_y, p_nachricht4(v_nachricht2), -1, 0);
			v_y = (v_y + g_yplus);
		}
		if ((v_nachricht3 != 0)) {
			p_drawtext(v_x, v_y, p_nachricht4(v_nachricht3), -1, 0);
			v_y = (v_y + g_yplus);
		}
		if ((v_nachricht4 != 0)) {
			p_drawtext(v_x, v_y, p_nachricht4(v_nachricht4), -1, 0);
			v_y = (v_y + g_yplus);
		}
		p_stopdrawing();
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_rechts = p_mousebutton(2);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!((p_keyboardpushed(13) || (v_mmouse_rechts == 1)) || (v_jb1 != 0)));
	p_delay(g_mydelay);
}

static int32_t p_sound(int16_t v_welchen) {
	if ((g_sound == 1)) {
		p_playsound(v_welchen);
	}
}

static int32_t p_special_success(int16_t v_spell) {
	int16_t v_akt_power = 0;
	v_akt_power = p_power(v_spell);
	if ((p_random(1000) <= 5)) {
		v_akt_power = (v_akt_power * 2);
		p_nachricht(737, 2);
	}
	return v_akt_power;
}

static int32_t p_spellweaving() {
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_result = 0;
	int32_t v_wohin = 0;
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
	}
	if (((((v_mmouse_x > 50) && (v_mmouse_x < 82)) && (v_mmouse_y > 365)) && (v_mmouse_y < 397))) {
		p_clipsprite(6, 96, 0, 31, 31);
		if ((v_mmouse_links == 1)) {
			a_spieler(g_akt_spieler).f_spellweaving = (a_spieler(g_akt_spieler).f_spellweaving - 1);
			if ((a_spieler(g_akt_spieler).f_spellweaving < 1)) {
				a_spieler(g_akt_spieler).f_spellweaving = 1;
			}
		}
	} else {
		p_clipsprite(6, 32, 0, 31, 31);
	}
	p_displaytransparentsprite(6, 50, 365);
	if (((((v_mmouse_x > 94) && (v_mmouse_x < 126)) && (v_mmouse_y > 365)) && (v_mmouse_y < 397))) {
		p_clipsprite(6, 63, 0, 31, 31);
		if ((v_mmouse_links == 1)) {
			a_spieler(g_akt_spieler).f_spellweaving = (a_spieler(g_akt_spieler).f_spellweaving + 1);
			if ((a_spieler(g_akt_spieler).f_spellweaving > 9)) {
				a_spieler(g_akt_spieler).f_spellweaving = 9;
			}
		}
	} else {
		p_clipsprite(6, 0, 0, 31, 31);
	}
	p_displaytransparentsprite(6, 94, 365);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	p_drawtext(84, 372, p_str(a_spieler(g_akt_spieler).f_spellweaving), -1, 0);
	p_stopdrawing();
	p_delay(40);
}

static int32_t p_spieler_angriffswert() {
	int16_t v_angriff = 0;
	v_angriff = (((20 + (p_angriff() * 10)) + (p_waffe_attack() * 10)) + (p_habich(35) * 10));
	if ((a_skills(7, g_akt_spieler).f_gewaehlt == 0)) {
		v_angriff = (v_angriff - (g_behinderung * 10));
	}
	if ((a_spieler(g_akt_spieler).f_fluch == 4)) {
		v_angriff = 10;
	}
	return v_angriff;
}

static int32_t p_spielerschaden(int16_t v_schaden, int16_t v_farbe, int16_t v_sterbegrund) {
	int32_t v_i = 0;
	int16_t v_inhalt_x = 0;
	int16_t v_inhalt_y = 0;
	int32_t v_wohin = 0;
	v_inhalt_x = a_inhalt(a_spieler(g_akt_spieler).f_level);
	v_inhalt_y = 0;
	if ((v_inhalt_x > 10)) {
		do {
			v_inhalt_y = (v_inhalt_y + 1);
			v_inhalt_x = (v_inhalt_x - 10);
		} while (!(v_inhalt_x < 11));
	}
	if ((v_inhalt_x == 10)) {
		v_inhalt_x = 0;
		v_inhalt_y = (v_inhalt_y + 1);
	}
	a_spieler(g_akt_spieler).f_lifepoints = (a_spieler(g_akt_spieler).f_lifepoints - v_schaden);
	p_laby_screen2();
	if ((v_farbe == 1)) {
		p_clipsprite(38, 0, 224, 32, 32);
	}
	if ((v_farbe == 2)) {
		p_clipsprite(38, 32, 224, 32, 32);
	}
	if ((v_farbe == 3)) {
		p_clipsprite(38, 64, 224, 32, 32);
	}
	p_displaytransparentsprite(38, 160, 160);
	p_sound((p_random(6) + 1));
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_schaden < 10)) {
		p_drawtext(172, 168, p_str(v_schaden), -1, 0);
	}
	if ((v_schaden >= 10)) {
		p_drawtext(166, 168, p_str(v_schaden), -1, 0);
	}
	if ((v_schaden >= 100)) {
		p_drawtext(163, 168, p_str(v_schaden), -1, 0);
	}
	p_stopdrawing();
	p_flipbuffers(1);
	p_delay(150);
	if (((v_sterbegrund == 4) && (a_spieler(g_akt_spieler).f_lifepoints < 1))) {
		a_spieler(g_akt_spieler).f_lifepoints = 1;
	}
	if ((a_spieler(g_akt_spieler).f_lifepoints < 1)) {
		switch (v_sterbegrund) {
		case 1:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(680, (1 + g_sprache));
			}
			break;
		case 2:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(681, (1 + g_sprache));
			}
			break;
		case 3:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(682, (1 + g_sprache));
			}
			break;
		case 4:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(683, (1 + g_sprache));
			}
			break;
		case 5:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(684, (1 + g_sprache));
			}
			break;
		case 6:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(685, (1 + g_sprache));
			}
			break;
		case 7:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(686, (1 + g_sprache));
			}
			break;
		case 8:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(687, (1 + g_sprache));
			}
			break;
		case 9:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(688, (1 + g_sprache));
			}
			break;
		case 10:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(689, (1 + g_sprache));
			}
			break;
		case 11:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(690, (1 + g_sprache));
			}
			break;
		case 12:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(691, (1 + g_sprache));
			}
			break;
		case 13:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(692, (1 + g_sprache));
			}
			break;
		case 14:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(707, (1 + g_sprache));
			}
			break;
		case 15:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(739, (1 + g_sprache));
			}
			break;
		case 16:
			for (v_i = 1; v_i <= 3; v_i += 1) {
				a_spieler(g_akt_spieler).f_sterbegrund[v_i] = a_nachricht_text(830, (1 + g_sprache));
			}
			break;
		}
		p_tot();
	}
}

static int32_t p_spraygrafik(int32_t v_radius, int32_t v_dauer) {
	int32_t v_b = 0;
	int32_t v_g = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_r = 0;
	int32_t v_wohin = 0;
	int32_t v_z = 0;
	v_z = 177;
	for (v_i = 1; v_i <= v_dauer; v_i += 1) {
		p_laby_screen2();
		for (v_j = 0; v_j <= 360; v_j += 10) {
			v_r = p_random(1);
			v_g = p_random(1);
			v_b = p_random(1);
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_frontcolor(p_rgb((v_r * 255), (v_g * 255), (v_b * 255)));
			p_line(v_z, v_z, (int32_t)((v_z + (p_sin(v_j) * v_radius))), (int32_t)((v_z + (p_cos(v_j) * v_radius))), -1);
			p_stopdrawing();
		}
		p_flipbuffers(1);
		p_delay(100);
	}
}

static int32_t p_staerke() {
	int16_t v_akt_strength = 0;
	int16_t v_dragon = 0;
	int32_t v_okay = 0;
	v_dragon = 0;
	v_akt_strength = a_spieler(g_akt_spieler).f_strength;
	v_okay = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 23)) {
		v_akt_strength = 1;
		v_okay = 1;
	}
	if (((p_habich(86) > 0) && (v_okay == 0))) {
		v_akt_strength = 1;
		v_okay = 1;
	}
	if (((p_habich(88) > 0) && (v_okay == 0))) {
		v_akt_strength = 1;
		v_okay = 1;
	}
	if (((p_habich(89) > 0) && (v_okay == 0))) {
		v_akt_strength = 1;
		v_okay = 1;
	}
	if (((p_habich(87) > 0) && (v_okay == 0))) {
		v_akt_strength = 5;
		v_okay = 1;
	}
	if (((p_habich(90) > 0) && (v_okay == 0))) {
		v_akt_strength = 30;
		v_dragon = 1;
	}
	v_akt_strength = (v_akt_strength + a_spieler(g_akt_spieler).f_staerkegegenstand);
	v_akt_strength = (v_akt_strength - a_spieler(g_akt_spieler).f_krankheit);
	if (((v_akt_strength > 15) && (v_dragon == 0))) {
		v_akt_strength = 15;
	}
	if ((v_akt_strength < 1)) {
		v_akt_strength = 1;
	}
	return v_akt_strength;
}

static int32_t p_stehlen() {
	int32_t v_blocked = 0;
	int32_t v_hugo = 0;
	int32_t v_obje = 0;
	int16_t v_okay = 0;
	int16_t v_stehl = 0;
	g_spell_x = 0;
	g_spell_y = 0;
	p_feld_waehlen();
	v_blocked = 0;
	p_los();
	if ((a_spieler(g_akt_spieler).f_stehlen > 0)) {
		if ((v_blocked == 0)) {
			g_aktion = 1;
			if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 4) == 1)) {
				if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
					p_nachricht(522, 3);
				} else {
					a_spieler(g_akt_spieler).f_stehlen = (a_spieler(g_akt_spieler).f_stehlen - 1);
					v_stehl = ((p_reflexe() * 8) + (p_luck() * 6));
					if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] == 2)) {
						v_stehl = (v_stehl + 30);
					}
					if ((v_stehl > 90)) {
						v_stehl = 90;
					}
					if ((p_random(100) < v_stehl)) {
						v_hugo = p_random(100);
						if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 27) == 0)) {
							v_hugo = 1;
						}
						if ((v_hugo < 80)) {
							v_obje = p_finden1();
						} else {
							v_obje = p_finden2();
						}
						p_in_rucksack(v_obje, 1);
						v_okay = 0;
						if (((((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0)) && (v_obje >= 75)) && (v_obje <= 112))) {
							p_nachricht(199, 3);
							v_okay = 1;
						}
						if ((v_obje == 38)) {
							p_nachricht(443, 1);
							v_okay = 1;
						}
						if ((v_okay == 0)) {
							p_nachricht2(44, v_obje);
						}
					} else {
						p_nachricht(261, 1);
						a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 1;
					}
				}
			} else {
				p_nachricht(197, 1);
			}
		} else {
			p_nachricht(196, 1);
		}
	} else {
		p_nachricht(45, 1);
	}
}

static int32_t p_sternchen(int16_t v_x, int16_t v_y, int16_t v_stern) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	for (v_i = 1; v_i <= 20; v_i += 1) {
		a_xsprites(v_i) = 0;
		a_ysprites(v_i) = 0;
		a_fsprites(v_i) = ((0 - v_i) - 1);
		a_rsprites(v_i) = 1;
	}
	for (v_j = 1; v_j <= 30; v_j += 1) {
		p_laby_screen2();
		for (v_i = 1; v_i <= 20; v_i += 1) {
			a_fsprites(v_i) = (a_fsprites(v_i) + a_rsprites(v_i));
			if ((a_fsprites(v_i) >= 4)) {
				a_rsprites(v_i) = -1;
			}
			if ((a_fsprites(v_i) == -1)) {
				a_xsprites(v_i) = p_random(32);
				a_ysprites(v_i) = p_random(32);
				a_rsprites(v_i) = 1;
			}
			if ((a_fsprites(v_i) >= 0)) {
				p_clipsprite(20, (a_fsprites(v_i) + (v_stern * 5)), ((v_stern * 9) - 9), 9, 9);
				p_displaytransparentsprite(20, ((v_x + a_xsprites(v_i)) - 5), ((v_y + a_ysprites(v_i)) - 5));
			}
		}
		p_flipbuffers(1);
		p_delay(50);
	}
}

static int32_t p_sternchen2(int16_t v_x, int16_t v_y, int16_t v_stern) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	for (v_i = 1; v_i <= 20; v_i += 1) {
		a_xsprites(v_i) = 0;
		a_ysprites(v_i) = 0;
		a_fsprites(v_i) = ((0 - v_i) - 1);
		a_rsprites(v_i) = 1;
	}
	for (v_j = 1; v_j <= 30; v_j += 1) {
		p_laby_screen3();
		for (v_i = 1; v_i <= 20; v_i += 1) {
			a_fsprites(v_i) = (a_fsprites(v_i) + a_rsprites(v_i));
			if ((a_fsprites(v_i) >= 4)) {
				a_rsprites(v_i) = -1;
			}
			if ((a_fsprites(v_i) == -1)) {
				a_xsprites(v_i) = p_random(32);
				a_ysprites(v_i) = p_random(32);
				a_rsprites(v_i) = 1;
			}
			if ((a_fsprites(v_i) >= 0)) {
				p_clipsprite(20, (a_fsprites(v_i) + (v_stern * 5)), ((v_stern * 9) - 9), 9, 9);
				p_displaytransparentsprite(20, ((v_x + a_xsprites(v_i)) - 5), ((v_y + a_ysprites(v_i)) - 5));
			}
		}
		p_flipbuffers(1);
		p_delay(50);
	}
}

static int32_t p_teacher(int16_t v_which) {
	int32_t v_akt_spieler = 0;
	int32_t v_aktion = 0;
	if (((a_skills(131, v_akt_spieler).f_gewaehlt == 1) || (a_spieler(v_akt_spieler).f_fluch == 26))) {
		p_nachricht(327, 6);
		p_setlaby(a_spieler(v_akt_spieler).f_character_x, a_spieler(v_akt_spieler).f_character_y, a_spieler(v_akt_spieler).f_level, a_inhalt(a_spieler(v_akt_spieler).f_level), 0, 0, 0);
	} else {
		if ((a_labyrinth(a_spieler(v_akt_spieler).f_character_x, a_spieler(v_akt_spieler).f_character_y).f_lebenspunkte[a_spieler(v_akt_spieler).f_level] == 1)) {
			p_gefaehrte(1);
		} else {
			p_lehrer(v_which);
		}
	}
	p_laby_screen();
	v_aktion = 1;
}

static int32_t p_templates(int32_t v_mouse_released, int32_t v_tooltip) {
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_jb2 = 0;
	int16_t v_jb3 = 0;
	int16_t v_jb4 = 0;
	int16_t v_jb5 = 0;
	int16_t v_jb6 = 0;
	int32_t v_jjj = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_mydelay3 = 0;
	int32_t v_nnn = 0;
	int32_t v_result = 0;
	int32_t v_save_button = 0;
	std::string v_savename;
	int16_t v_taste = 0;
	int32_t v_warten = 0;
	int32_t v_wohin = 0;
	int16_t v_x = 0;
	int16_t v_y = 0;
	v_x = 570;
	v_y = 60;
	v_jb2 = 0;
	v_jb3 = 0;
	v_jb4 = 0;
	v_jb5 = 0;
	v_jb6 = 0;
	if ((g_joystick_used == 1)) {
		p_examinejoystick();
		v_jb2 = p_joystickbutton(2);
		v_jb3 = p_joystickbutton(3);
		v_jb4 = p_joystickbutton(4);
		v_jb5 = p_joystickbutton(5);
		v_jb6 = p_joystickbutton(6);
	}
	p_examinekeyboard();
	v_taste = 0;
	if ((p_keyboardpushed(49) || (v_jb2 > 0))) {
		v_taste = 1;
	}
	if ((p_keyboardpushed(50) || (v_jb3 > 0))) {
		v_taste = 2;
	}
	if ((p_keyboardpushed(51) || (v_jb4 > 0))) {
		v_taste = 3;
	}
	if ((p_keyboardpushed(52) || (v_jb5 > 0))) {
		v_taste = 4;
	}
	if ((p_keyboardpushed(53) || (v_jb6 > 0))) {
		v_taste = 5;
	}
	if ((g_no_mouse == 0)) {
		v_result = p_examinemouse();
		v_mouse_x = p_mousex();
		v_mouse_y = p_mousey();
		v_mouse_rechts = p_mousebutton(2);
	}
	v_savename = "skillsv.";
	if ((g_charsave_now == 1)) {
		p_clipsprite(5, 0, 62, 47, 32);
		v_save_button = 0;
	} else {
		if (((((v_mouse_x > 571) && (v_mouse_x < 616)) && (v_mouse_y > 299)) && (v_mouse_y < 329))) {
			p_clipsprite(5, 0, 0, 47, 32);
			v_save_button = 1;
			if ((v_mouse_released == 1)) {
				if ((g_punkte == 0)) {
					g_charsave_now = 1;
				} else {
					v_tooltip = 1;
				}
			}
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_drawingmode(1);
			p_drawtext(30, 430, a_nachricht_text((901 + v_tooltip), (1 + g_sprache)), 16777215, 0);
			p_stopdrawing();
		} else {
			p_clipsprite(5, 0, 31, 47, 32);
			v_save_button = 0;
			v_tooltip = 0;
		}
	}
	p_displaytransparentsprite(5, 571, 300);
	if ((v_taste > 0)) {
		for (v_j = 0; v_j <= 140; v_j += 1) {
			a_skills(v_j, g_akt_spieler).f_gewaehlt = 0;
			a_skills(v_j, g_akt_spieler).f_gelocked = 0;
		}
		g_punkte = 0;
		if ((v_taste == 1)) {
			p_kaempfer();
		}
		if ((v_taste == 2)) {
			p_dieb();
		}
		if ((v_taste == 3)) {
			p_weiss();
		}
		if ((v_taste == 4)) {
			p_bogenschuetze();
		}
		if ((v_taste == 5)) {
			p_nekro();
		}
	}
	for (v_i = 1; v_i <= 5; v_i += 1) {
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		if (((((v_mouse_x >= v_x) && (v_mouse_x <= (v_x + 48))) && (v_mouse_y >= ((v_y + (v_i * 48)) - 48))) && (v_mouse_y <= (v_y + (v_i * 48))))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box((v_x - 2), ((v_y + (v_i * 48)) - 50), 52, 49, -1);
			p_frontcolor(p_rgb(255, 255, 255));
			p_drawtext(30, 430, a_nachricht_text((587 + v_i), (1 + g_sprache)), -1, 0);
			if (((v_mouse_released == 1) && (g_charsave_now == 1))) {
				v_warten = v_mydelay3;
				if (p_createfile(0, (("./" + v_savename) + p_str(v_i)))) {
					p_writeword(0, g_punkte);
					v_nnn = 0;
					for (v_jjj = 0; v_jjj <= 140; v_jjj += 1) {
						if ((a_skills(v_jjj, g_akt_spieler).f_gewaehlt == 1)) {
							v_nnn += 1;
						}
					}
					p_writeword(0, v_nnn);
					for (v_jjj = 0; v_jjj <= 140; v_jjj += 1) {
						if ((a_skills(v_jjj, g_akt_spieler).f_gewaehlt == 1)) {
							p_writeword(0, v_jjj);
						}
					}
					g_charsave_now = 0;
					p_closefile(0);
				}
			}
			if (((v_mouse_released == 1) && (g_charsave_now == 0))) {
				for (v_jjj = 0; v_jjj <= 140; v_jjj += 1) {
					a_skills(v_jjj, g_akt_spieler).f_gewaehlt = 0;
					a_skills(v_jjj, g_akt_spieler).f_gelocked = 0;
				}
				if (p_readfile(0, (("./" + v_savename) + p_str(v_i)))) {
					g_punkte = p_readword(0);
					v_nnn = p_readword(0);
					for (v_jjj = 1; v_jjj <= v_nnn; v_jjj += 1) {
						p_waehlen(p_readword(0));
					}
					p_closefile(0);
				} else {
					if (((v_mouse_released == 1) && (g_charsave_now == 0))) {
						for (v_j = 0; v_j <= 140; v_j += 1) {
							a_skills(v_j, g_akt_spieler).f_gewaehlt = 0;
							a_skills(v_j, g_akt_spieler).f_gelocked = 0;
						}
						g_punkte = 0;
						if ((v_i == 1)) {
							p_kaempfer();
						}
						if ((v_i == 2)) {
							p_dieb();
						}
						if ((v_i == 3)) {
							p_weiss();
						}
						if ((v_i == 4)) {
							p_bogenschuetze();
						}
						if ((v_i == 5)) {
							p_nekro();
						}
					}
				}
			}
		}
		p_stopdrawing();
		p_clipsprite(24, ((48 * v_i) - 48), 0, 48, 45);
		p_displaysprite(24, v_x, (((v_i * 48) - 48) + v_y));
	}
	return v_tooltip;
}

static int32_t p_terminate(int16_t v_welchen, int16_t v_source) {
	int32_t v_i = 0;
	for (v_i = 1; v_i <= 15; v_i += 1) {
		if (((a_aktive(v_i, g_akt_spieler).f_nr == v_welchen) && (a_aktive(v_i, g_akt_spieler).f_source == v_source))) {
			a_aktive(v_i, g_akt_spieler).f_nr = 0;
			a_aktive(v_i, g_akt_spieler).f_staerke = 0;
			a_aktive(v_i, g_akt_spieler).f_dauer = 0;
		}
	}
}

static int32_t p_title() {
	int32_t v_a = 0;
	int32_t v_elapsedtime = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_linksold = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_released = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_ok_button = 0;
	int16_t v_pos_aktuell = 0;
	int32_t v_result = 0;
	int32_t v_sprachen_zeigen = 0;
	int16_t v_start = 0;
	int32_t v_starttime = 0;
	std::string v_t;
	int16_t v_warten = 0;
	int8_t v_x_moddy = 0;
	int16_t v_xxx = 0;
	int32_t v_ytemp = 0;
	v_pos_aktuell = 0;
	v_warten = 30;
	v_x_moddy = 2;
	v_ok_button = 0;
	v_start = 0;
	do {
		v_starttime = p_elapsedmilliseconds();
		p_fenster(0);
		v_xxx = (v_xxx + v_x_moddy);
		if ((v_xxx > 1123)) {
			v_x_moddy = -2;
		}
		if ((v_xxx < 1)) {
			v_x_moddy = 2;
		}
		p_clearscreen(0);
		p_clipsprite(18, v_xxx, 0, 640, 480);
		p_displaysprite(18, 0, 0);
		p_clipsprite(26, 0, 0, 640, 174);
		p_displaytransparentsprite(26, 0, 40);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jax = p_joystickaxisx();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((g_no_mouse == 0)) {
			if (p_keyboardpushed(27)) {
				if ((g_released == 0)) {
					v_result = p_releasemouse(1);
					g_released = 1;
					p_delay(g_mydelay);
				} else {
					v_result = p_releasemouse(0);
					g_released = 0;
					p_delay(g_mydelay);
				}
			}
		}
		if ((p_keyboardreleased(275) || (v_jax == 1))) {
			v_pos_aktuell = (v_pos_aktuell + 1);
			if ((v_pos_aktuell > 8)) {
				v_pos_aktuell = 1;
			}
		}
		if ((p_keyboardreleased(276) || (v_jax == -1))) {
			v_pos_aktuell = (v_pos_aktuell - 1);
			if ((v_pos_aktuell < 1)) {
				v_pos_aktuell = 8;
			}
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mouse_x = p_mousex();
			v_mouse_y = p_mousey();
			v_mouse_linksold = v_mouse_links;
			v_mouse_links = p_mousebutton(1);
			if (((v_mouse_linksold == 1) && (v_mouse_links == 0))) {
				v_mouse_released = 1;
			} else {
				v_mouse_released = 0;
			}
			v_mouse_rechts = p_mousebutton(2);
		}
		if ((v_mouse_rechts && v_sprachen_zeigen)) {
			v_sprachen_zeigen = 0;
		}
		v_ok_button = 0;
		p_startdrawing(p_screenoutput());
		p_drawingmode(1);
		p_frontcolor(16711680);
		v_t = "Version: 3.0.0  (10.06.2008)";
		p_drawtext((330 - (p_textwidth(v_t) / 2)), 240, v_t, -1, 0);
		v_t = "www.lostlabyrinth.com";
		p_drawtext((330 - (p_textwidth(v_t) / 2)), 260, v_t, -1, 0);
		v_t = "Authors:";
		p_drawtext((330 - (p_textwidth(v_t) / 2)), 290, v_t, -1, 0);
		v_t = "Markus D\366bele (Programming)";
		p_drawtext((330 - (p_textwidth(v_t) / 2)), 310, v_t, -1, 0);
		v_t = "Massimiliano De Ruvo (Graphics)";
		p_drawtext((330 - (p_textwidth(v_t) / 2)), 330, v_t, -1, 0);
		p_frontcolor(16777215);
		p_drawtext((70 - (p_textwidth(a_nachricht_text(106, (g_sprache + 1))) / 2)), 440, a_nachricht_text(106, (g_sprache + 1)), -1, 0);
		p_drawtext((170 - (p_textwidth(a_nachricht_text((907 + g_sprache), (g_sprache + 1))) / 2)), 440, a_nachricht_text((907 + g_sprache), g_sprache), -1, 0);
		if ((v_sprachen_zeigen == 0)) {
			p_drawtext(164, 380, "^", -1, 0);
		} else {
			for (v_a = 0; v_a <= 2; v_a += 1) {
				if ((v_a != g_sprache)) {
					p_drawtext((170 - (p_textwidth(a_nachricht_text((907 + v_a), g_sprache)) / 2)), (550 - (60 * v_ytemp)), a_nachricht_text((907 + v_a), g_sprache), -1, 0);
					v_ytemp += 1;
				}
			}
		}
		p_drawtext((350 - (p_textwidth(a_nachricht_text(109, (g_sprache + 1))) / 2)), 440, a_nachricht_text(109, (g_sprache + 1)), -1, 0);
		p_drawtext((450 - (p_textwidth(a_nachricht_text(110, (g_sprache + 1))) / 2)), 440, a_nachricht_text(110, (g_sprache + 1)), -1, 0);
		p_drawtext((258 - (p_textwidth(a_nachricht_text(67, (g_sprache + 1))) / 2)), 440, a_nachricht_text(67, (g_sprache + 1)), -1, 0);
		p_drawtext((520 - (p_textwidth(a_nachricht_text(405, (g_sprache + 1))) / 2)), 440, a_nachricht_text(405, (g_sprache + 1)), -1, 0);
		p_drawtext((590 - (p_textwidth(a_nachricht_text(111, (g_sprache + 1))) / 2)), 440, a_nachricht_text(111, (g_sprache + 1)), -1, 0);
		p_stopdrawing();
		if ((v_pos_aktuell == 1)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				v_ok_button = 1;
				v_start = 1;
			}
		}
		if (((((v_mouse_x >= 50) && (v_mouse_x <= 91)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 0, 1, 34, 42);
			p_displaytransparentsprite(2, 50, 390);
			v_ok_button = 1;
		} else {
			p_clipsprite(2, 0, 43, 34, 42);
			p_displaytransparentsprite(2, 50, 390);
			v_ok_button = 0;
		}
		if ((v_pos_aktuell == 2)) {
			if (p_keyboardreleased(273)) {
				g_sprache = (g_sprache + 1);
				if ((g_sprache > 2)) {
					g_sprache = 0;
				}
			}
			if (p_keyboardreleased(274)) {
				g_sprache = (g_sprache - 1);
				if ((g_sprache < 0)) {
					g_sprache = 2;
				}
			}
			if ((p_keyboardreleased(13) || (v_jb1 == 1))) {
				if ((v_sprachen_zeigen == 1)) {
					v_sprachen_zeigen = 0;
				} else {
					v_sprachen_zeigen = 1;
				}
			}
		}
		if (v_sprachen_zeigen) {
			v_ytemp = 1;
			for (v_a = 0; v_a <= 2; v_a += 1) {
				if ((v_a != g_sprache)) {
					if (((((v_mouse_x >= 150) && (v_mouse_x <= 191)) && (v_mouse_y >= (390 - (60 * v_ytemp)))) && (v_mouse_y <= (431 - (60 * v_ytemp))))) {
						p_clipsprite(2, a_sprache(v_a).f_buttonpos, 1, 34, 42);
						if (v_mouse_released) {
							v_sprachen_zeigen = 0;
							g_sprache = v_a;
						}
					} else {
						p_clipsprite(2, a_sprache(v_a).f_buttonpos, 43, 34, 42);
					}
					p_displaytransparentsprite(2, 150, (390 - (v_ytemp * 60)));
					v_ytemp += 1;
				}
			}
		}
		if (((((v_mouse_x >= 150) && (v_mouse_x <= 191)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, a_sprache(g_sprache).f_buttonpos, 1, 34, 42);
			p_displaytransparentsprite(2, 150, 390);
			if ((v_mouse_released == 1)) {
				if ((v_sprachen_zeigen == 1)) {
					v_sprachen_zeigen = 0;
				} else {
					v_sprachen_zeigen = 1;
				}
			}
		} else {
			p_clipsprite(2, a_sprache(g_sprache).f_buttonpos, 43, 34, 42);
			p_displaytransparentsprite(2, 150, 390);
		}
		if ((v_pos_aktuell == 3)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				g_gb_callfromtitlescreen = 1;
				p_hilfe();
				g_gb_callfromtitlescreen = 0;
			}
		}
		if (((((v_mouse_x >= 238) && (v_mouse_x <= 279)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 204, 1, 34, 42);
			p_displaytransparentsprite(2, 238, 390);
			if ((v_mouse_released == 1)) {
				g_gb_callfromtitlescreen = 1;
				p_hilfe();
				g_gb_callfromtitlescreen = 0;
			}
		} else {
			p_clipsprite(2, 204, 43, 34, 42);
			p_displaytransparentsprite(2, 238, 390);
		}
		if ((v_pos_aktuell == 5)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				p_init_skills();
				p_show_highscore();
			}
		}
		if (((((v_mouse_x >= 330) && (v_mouse_x <= 371)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 136, 1, 34, 42);
			p_displaytransparentsprite(2, 330, 390);
			if ((v_mouse_released == 1)) {
				p_init_skills();
				p_show_highscore();
			}
		} else {
			p_clipsprite(2, 136, 43, 34, 42);
			p_displaytransparentsprite(2, 330, 390);
		}
		if ((v_pos_aktuell == 6)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				p_show_credits();
			}
		}
		if (((((v_mouse_x >= 430) && (v_mouse_x <= 471)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 102, 1, 34, 42);
			p_displaytransparentsprite(2, 430, 390);
			if ((v_mouse_released == 1)) {
				p_show_credits();
			}
		} else {
			p_clipsprite(2, 102, 43, 34, 42);
			p_displaytransparentsprite(2, 430, 390);
		}
		if ((v_pos_aktuell == 7)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				p_loading_screen();
			}
		}
		if (((((v_mouse_x >= 500) && (v_mouse_x <= 541)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 578, 1, 34, 42);
			p_displaytransparentsprite(2, 500, 390);
			if ((v_mouse_released == 1)) {
				p_loading_screen();
			}
		} else {
			p_clipsprite(2, 578, 43, 34, 42);
			p_displaytransparentsprite(2, 500, 390);
		}
		if ((v_pos_aktuell == 8)) {
			if ((p_keyboardpushed(13) || (v_jb1 == 1))) {
				p_closescreen();
				exit(0);
			}
		}
		if (((((v_mouse_x >= 570) && (v_mouse_x <= 611)) && (v_mouse_y >= 390)) && (v_mouse_y <= 431))) {
			p_clipsprite(2, 170, 1, 34, 42);
			p_displaytransparentsprite(2, 570, 390);
			if ((v_mouse_released == 1)) {
				p_closescreen();
				exit(0);
			}
		} else {
			p_clipsprite(2, 170, 43, 34, 42);
			p_displaytransparentsprite(2, 570, 390);
		}
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		}
		v_elapsedtime = (p_elapsedmilliseconds() - v_starttime);
		if ((v_elapsedtime < 20)) {
			p_delay((20 - v_elapsedtime));
		}
		p_flipbuffers(1);
	} while (!(((v_ok_button == 1) && (v_mouse_released == 1)) || (v_start == 1)));
}

static int32_t p_todesblick() {
	int32_t v_akt_zeile = 0;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(0, 0, 0));
	for (v_akt_zeile = 32; v_akt_zeile >= 1; v_akt_zeile -= 1) {
		p_line((160 + (g_spell_x * 32)), ((160 + v_akt_zeile) + (g_spell_y * 32)), 32, 0, -1);
		p_flipbuffers(1);
		p_delay(20);
	}
	p_stopdrawing();
}

static int32_t p_tot() {
	int32_t v_aktiv = 0;
	int8_t v_eintrag = 0;
	std::string v_endezeit;
	int32_t v_herz = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int32_t v_jb1 = 0;
	int32_t v_k = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_mouse_x_old = 0;
	int32_t v_mouse_y_old = 0;
	int16_t v_punkte = 0;
	int32_t v_result = 0;
	int32_t v_tot = 0;
	int16_t v_warten = 0;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int16_t v_xx = 0;
	int32_t v_y = 0;
	int16_t v_yy = 0;
	int32_t v_zaehler = 0;
	v_herz = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if ((a_inventory(v_i, g_akt_spieler).f_name == 146)) {
			v_herz = v_i;
		}
	}
	if ((v_herz == 0)) {
		g_myname = "";
		p_sound(24);
		a_spieler(g_akt_spieler).f_status = 3;
		a_spieler(g_akt_spieler).f_creature_typ = 0;
		a_spieler(g_akt_spieler).f_creature_lifepoints = 0;
		v_punkte = p_punkte();
		v_eintrag = 0;
		v_i = 1;
		do {
			if ((v_punkte > a_hscores(v_i).f_punkte)) {
				v_eintrag = v_i;
			}
			v_i = (v_i + 1);
		} while (!((v_i > 30) || (v_eintrag > 0)));
		if ((v_eintrag > 0)) {
			v_warten = 0;
			v_xx = 100;
			v_yy = 70;
			do {
				p_fenster(0);
				p_clearscreen(p_rgb(0, 0, 0));
				p_laby_rahmen();
				p_show_logo();
				p_show_varys();
				p_clipsprite(19, 1, 1, 335, 335);
				p_displaytransparentsprite(19, 16, 16);
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(0, 0, 0));
				p_box(v_xx, v_yy, 150, 17, -1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(130, 20, a_nachricht_text(83, (1 + g_sprache)), -1, 0);
				p_drawtext(40, 35, a_nachricht_text(79, (1 + g_sprache)), -1, 0);
				p_drawtext(80, 50, a_nachricht_text(80, (1 + g_sprache)), -1, 0);
				p_drawtext(v_xx, v_yy, g_myname, -1, 0);
				p_stopdrawing();
				v_result = p_examinemouse();
				v_mmouse_x = p_mousex();
				v_mmouse_y = p_mousey();
				v_mmouse_links = p_mousebutton(1);
				p_clipsprite(8, 192, 288, 32, 32);
				p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
				v_mouse_x_old = v_mmouse_x;
				v_mouse_y_old = v_mmouse_y;
				p_examinekeyboard();
				g_myname = p_keyboard_string(g_myname, 0);
				if ((p_len(g_myname) > 25)) {
					g_myname = p_mid(g_myname, 1, 25);
				}
				v_warten = (v_warten + 1);
				if ((v_warten < 3)) {
					v_wohin = p_screenoutput();
					p_startdrawing(v_wohin);
					p_drawingmode(1);
					p_frontcolor(p_rgb(255, 255, 255));
					p_line((v_xx + p_textwidth(g_myname)), v_yy, 0, 15, -1);
					p_line(((v_xx + 1) + p_textwidth(g_myname)), v_yy, 0, 15, -1);
					p_stopdrawing();
				}
				if ((v_warten > 4)) {
					v_warten = 0;
				}
				p_flipbuffers(1);
				p_delay(1);
			} while (!((p_keyboardpushed(13) || (v_jb1 == 1)) && (g_myname != "")));
			v_j = 30;
			while ((v_j > v_eintrag)) {
				a_hscores(v_j).f_version = a_hscores((v_j - 1)).f_version;
				a_hscores(v_j).f_name = a_hscores((v_j - 1)).f_name;
				a_hscores(v_j).f_level = a_hscores((v_j - 1)).f_level;
				a_hscores(v_j).f_gold = a_hscores((v_j - 1)).f_gold;
				a_hscores(v_j).f_mks = a_hscores((v_j - 1)).f_mks;
				a_hscores(v_j).f_punkte = a_hscores((v_j - 1)).f_punkte;
				a_hscores(v_j).f_maennchen = a_hscores((v_j - 1)).f_maennchen;
				a_hscores(v_j).f_anfangszeit = a_hscores((v_j - 1)).f_anfangszeit;
				a_hscores(v_j).f_endezeit = a_hscores((v_j - 1)).f_endezeit;
				a_hscores(v_j).f_maxlifepoints = a_hscores((v_j - 1)).f_maxlifepoints;
				a_hscores(v_j).f_maxmana = a_hscores((v_j - 1)).f_maxmana;
				a_hscores(v_j).f_attack = a_hscores((v_j - 1)).f_attack;
				a_hscores(v_j).f_dexterity = a_hscores((v_j - 1)).f_dexterity;
				a_hscores(v_j).f_strength = a_hscores((v_j - 1)).f_strength;
				a_hscores(v_j).f_maxspeed = a_hscores((v_j - 1)).f_maxspeed;
				a_hscores(v_j).f_perception = a_hscores((v_j - 1)).f_perception;
				a_hscores(v_j).f_luck_score = a_hscores((v_j - 1)).f_luck_score;
				a_hscores(v_j).f_power_score = a_hscores((v_j - 1)).f_power_score;
				a_hscores(v_j).f_circle = a_hscores((v_j - 1)).f_circle;
				a_hscores(v_j).f_stabteile = a_hscores((v_j - 1)).f_stabteile;
				a_hscores(v_j).f_moves = a_hscores((v_j - 1)).f_moves;
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_hscores(v_j).f_sterbegrund[v_k] = a_hscores((v_j - 1)).f_sterbegrund[v_k];
				}
				for (v_k = 1; v_k <= 30; v_k += 1) {
					a_hscores(v_j).f_skills[v_k] = a_hscores((v_j - 1)).f_skills[v_k];
				}
				v_j = (v_j - 1);
			}
			g_letzter_eintrag = v_eintrag;
			if ((v_eintrag > 0)) {
				v_endezeit = p_formatdate("%yyyy%mm%dd%hh%ii%ss", p_date());
				a_hscores(v_eintrag).f_version = "3.0.0";
				a_hscores(v_eintrag).f_name = g_myname;
				a_hscores(v_eintrag).f_level = a_spieler(g_akt_spieler).f_maxlevel;
				a_hscores(v_eintrag).f_gold = p_gold_anzahl();
				a_hscores(v_eintrag).f_mks = a_spieler(g_akt_spieler).f_mks;
				a_hscores(v_eintrag).f_punkte = v_punkte;
				a_hscores(v_eintrag).f_maennchen = a_spieler(g_akt_spieler).f_maennchen;
				a_hscores(v_eintrag).f_anfangszeit = g_anfangszeit;
				a_hscores(v_eintrag).f_endezeit = v_endezeit;
				a_hscores(v_eintrag).f_maxlifepoints = a_spieler(g_akt_spieler).f_maxlifepoints;
				a_hscores(v_eintrag).f_maxmana = a_spieler(g_akt_spieler).f_maxmana;
				a_hscores(v_eintrag).f_attack = a_spieler(g_akt_spieler).f_attack;
				a_hscores(v_eintrag).f_dexterity = a_spieler(g_akt_spieler).f_dexterity;
				a_hscores(v_eintrag).f_strength = a_spieler(g_akt_spieler).f_strength;
				a_hscores(v_eintrag).f_maxspeed = a_spieler(g_akt_spieler).f_maxspeed;
				a_hscores(v_eintrag).f_perception = a_spieler(g_akt_spieler).f_perception;
				a_hscores(v_eintrag).f_luck_score = a_spieler(g_akt_spieler).f_luck_score;
				a_hscores(v_eintrag).f_power_score = a_spieler(g_akt_spieler).f_power_score;
				a_hscores(v_eintrag).f_circle = a_spieler(g_akt_spieler).f_circle;
				a_hscores(v_eintrag).f_stabteile = a_spieler(g_akt_spieler).f_stabteile;
				a_hscores(v_eintrag).f_moves = a_spieler(g_akt_spieler).f_moves;
				for (v_k = 1; v_k <= 3; v_k += 1) {
					a_hscores(v_eintrag).f_sterbegrund[v_k] = a_spieler(g_akt_spieler).f_sterbegrund[v_k];
				}
				a_high_skill.dim(31);
				for (v_i = 1; v_i <= 30; v_i += 1) {
					a_high_skill(v_i) = 0;
				}
				v_zaehler = 1;
				for (v_i = 2; v_i <= 141; v_i += 1) {
					if ((a_skills(v_i, g_akt_spieler).f_gewaehlt == 1)) {
						a_high_skill(v_zaehler) = a_skills(v_i, g_akt_spieler).f_nummer;
						v_zaehler = (v_zaehler + 1);
					}
				}
				for (v_k = 1; v_k <= 30; v_k += 1) {
					a_hscores(v_eintrag).f_skills[v_k] = a_high_skill(v_k);
				}
				p_new_highscore();
				p_show_highscore();
			}
		} else {
			do {
				p_fenster(0);
				p_clearscreen(p_rgb(0, 0, 0));
				p_laby_rahmen();
				p_show_logo();
				p_show_varys();
				p_clipsprite(19, 1, 1, 335, 335);
				p_displaytransparentsprite(19, 16, 16);
				v_wohin = p_screenoutput();
				p_startdrawing(v_wohin);
				p_drawingmode(1);
				p_frontcolor(p_rgb(255, 255, 255));
				p_drawtext(130, 25, p_nachricht4(83), -1, 0);
				p_stopdrawing();
				v_result = p_examinemouse();
				v_mmouse_x = p_mousex();
				v_mmouse_y = p_mousey();
				v_mmouse_links = p_mousebutton(1);
				p_clipsprite(8, 192, 288, 32, 32);
				p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
				v_mouse_x_old = v_mmouse_x;
				v_mouse_y_old = v_mmouse_y;
				p_examinekeyboard();
				p_flipbuffers(1);
			} while (!(((v_mmouse_links == 1) || p_keyboardpushed(13)) || (v_jb1 == 1)));
		}
		v_aktiv = 0;
		for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
			if ((a_spieler(v_i).f_status == 1)) {
				v_aktiv = 1;
			}
		}
		if ((v_aktiv == 1)) {
			p_naechster();
		} else {
			v_tot = 1;
			for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
				if ((a_spieler(v_i).f_status < 3)) {
					v_tot = 0;
				}
			}
			if ((v_tot == 1)) {
				throw Lv_again;
			}
		}
	} else {
		p_leeren(v_herz);
		do {
			p_fenster(0);
			p_clearscreen(p_rgb(0, 0, 0));
			p_laby_rahmen();
			p_show_logo();
			p_show_varys();
			p_show_buttons();
			p_clipsprite(27, 1, 1, 335, 335);
			p_displaytransparentsprite(27, 16, 16);
			v_x = 160;
			v_y = 35;
			v_wohin = p_screenoutput();
			p_startdrawing(v_wohin);
			p_frontcolor(p_rgb(255, 1, 1));
			p_drawingmode(1);
			p_drawtext(v_x, v_y, p_nachricht4(176), -1, 0);
			v_y = ((v_y + g_yplus) + 5);
			p_drawtext(v_x, v_y, p_nachricht4(177), -1, 0);
			p_stopdrawing();
			p_examinekeyboard();
			v_result = p_examinemouse();
			v_mmouse_x = p_mousex();
			v_mmouse_y = p_mousey();
			v_mmouse_rechts = p_mousebutton(2);
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
			p_flipbuffers(1);
		} while (!((p_keyboardpushed(13) || (v_mmouse_rechts == 1)) || (v_jb1 == 1)));
		a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
		p_naechster();
	}
}

static int32_t p_trinken(std::string v_welchen) {
	int32_t v_i = 0;
	a_spieler(g_akt_spieler).f_durst = 0;
	if (v_welchen == "Wirkungslos") {
		p_nachricht(38, 4);
	} else if (v_welchen == "Schwacher Heiltrank") {
		a_spieler(g_akt_spieler).f_lifepoints = ((a_spieler(g_akt_spieler).f_lifepoints + p_random(10)) + 3);
		if ((a_spieler(g_akt_spieler).f_lifepoints > a_spieler(g_akt_spieler).f_maxlifepoints)) {
			a_spieler(g_akt_spieler).f_lifepoints = a_spieler(g_akt_spieler).f_maxlifepoints;
		}
		p_nachricht(46, 4);
	} else if (v_welchen == "Starker Heiltrank") {
		a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
		p_nachricht(47, 4);
	} else if (v_welchen == "Schwaches Gift") {
		if ((p_habich(130) > 0)) {
			p_nachricht(256, 4);
		} else {
			a_spieler(g_akt_spieler).f_gift = 1;
			a_spieler(g_akt_spieler).f_giftdauer = (p_random(10) + 1);
			p_nachricht(40, 4);
		}
	} else if (v_welchen == "Starkes Gift") {
		if ((p_habich(130) > 0)) {
			p_nachricht(256, 4);
		} else {
			a_spieler(g_akt_spieler).f_gift = 2;
			a_spieler(g_akt_spieler).f_giftdauer = (p_random(15) + 1);
			p_nachricht(40, 4);
		}
	} else if (v_welchen == "Trank der Helden") {
		p_aufsteigen(2);
	} else if (v_welchen == "Trank der G\366tter") {
		for (v_i = 1; v_i <= 3; v_i += 1) {
			p_aufsteigen(2);
		}
	} else if (v_welchen == "St\344rketrank") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "St\344rkezauber";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Schw\344chetrank") {
		p_nachricht(41, 4);
	} else if (v_welchen == "Paralysetrank") {
		a_spieler(g_akt_spieler).f_fluch = 5;
		a_spieler(g_akt_spieler).f_fluchdauer = (p_random(15) + 1);
		p_nachricht(42, 4);
	} else if (v_welchen == "Trank des Fiegens") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Fliegen";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Trank des Schutzes") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Schutzzauber";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Schwacher Manatrank") {
		a_spieler(g_akt_spieler).f_mana = ((a_spieler(g_akt_spieler).f_mana + p_random(10)) + 3);
		if ((a_spieler(g_akt_spieler).f_mana > p_maxmana())) {
			a_spieler(g_akt_spieler).f_mana = p_maxmana();
		}
		p_nachricht(43, 4);
	} else if (v_welchen == "Starker Manatrank") {
		a_spieler(g_akt_spieler).f_mana = p_maxmana();
		p_nachricht(43, 4);
	} else if (v_welchen == "Gegengift") {
		a_spieler(g_akt_spieler).f_gift = 0;
		a_spieler(g_akt_spieler).f_giftdauer = 0;
		p_nachricht(222, 4);
	} else if (v_welchen == "K\344lteschutz") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Eisschild";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Hitzeschutz") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Feuerschild";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Magieleere") {
		a_spieler(g_akt_spieler).f_mana = 0;
		p_nachricht(222, 4);
	} else if (v_welchen == "Unsichtbarkeit") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Unsichtbarkeit";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Macht") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Macht";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Fallen sp\374hren") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Fallen sp\374hren";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Winteratem") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Winteratem";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Flammenaura") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Flammenaura";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Fledermausgestalt") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Fledermausgestalt";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Wolfsgestalt") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Wolfsgestalt";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Vogelgestalt") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Vogelgestalt";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Katzengestalt") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Katzengestalt";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Drachengestalt") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Drachengestalt";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "\334bers Wasser gehen") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "\334bers Wasser gehen";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Schutz vor Geschossen") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Schutz vor Geschossen";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Unsichtbares sehen") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Unsichtbares sehen";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Magieschutz") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Magieschutz";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Hexensicht") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Hexensicht";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Unverwundbarkeit") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Unverwundbarkeit";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Giftschutz") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Giftschutz";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Selbsthypnose") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Selbsthypnose";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Regeneration") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Regeneration";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else if (v_welchen == "Lebensbund") {
		a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] = "Lebensbund";
		g_schriftrolle = 1;
		p_cast_it();
		g_schriftrolle = 0;
	} else 	if (1) {
		p_nachricht(38, 4);

	} else {}
}

static int32_t p_truhe(int16_t v_x, int16_t v_y) {
	int32_t v_i = 0;
	int32_t v_obje = 0;
	if ((a_spieler(g_akt_spieler).f_fluch == 18)) {
		p_nachricht(179, 6);
	} else {
		v_obje = a_labyrinth(v_x, v_y).f_status[a_spieler(g_akt_spieler).f_level];
		if ((v_obje == 0)) {
			v_obje = p_finden1();
		}
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
		if ((v_i <= 50)) {
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 6)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 192)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 94, 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 161)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 53, 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 68)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 63)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 194)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 94, 0, 0, 0);
			}
			if ((a_labyrinth(v_x, v_y).f_feld[a_spieler(g_akt_spieler).f_level] == 162)) {
				p_setlaby(v_x, v_y, a_spieler(g_akt_spieler).f_level, 53, 0, 0, 0);
			}
			p_sound(9);
			p_in_rucksack(v_obje, 1);
			if ((a_gegenstand(v_obje).f_art == 4)) {
				if (((a_skills(43, g_akt_spieler).f_gewaehlt == 0) && (a_skills(113, g_akt_spieler).f_gewaehlt == 0))) {
					v_obje = 998;
				}
			}
			if ((v_obje == 38)) {
				if (((a_skills(47, g_akt_spieler).f_gewaehlt == 0) && (a_skills(64, g_akt_spieler).f_gewaehlt == 0))) {
					v_obje = 997;
				}
			}
			p_nachricht2(6, v_obje);
		} else {
			p_nachricht(428, 3);
		}
	}
}

static int32_t p_umwandeln(int16_t v_feld) {
	int16_t v_geg = 0;
	int16_t v_gewa = 0;
	int32_t v_welche = 0;
	v_geg = 0;
	v_welche = p_select_inventory(565);
	v_gewa = 0;
	if ((a_gegenstand(a_inventory(v_welche, g_akt_spieler).f_name).f_art == 13)) {
		v_gewa = 1;
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 218) || (a_inventory(v_feld, g_akt_spieler).f_name == 209)) || (a_inventory(v_feld, g_akt_spieler).f_name == 210))) {
			v_geg = 190;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 199) || (a_inventory(v_feld, g_akt_spieler).f_name == 217)) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 172;
		}
		if (((a_inventory(v_feld, g_akt_spieler).f_name == 198) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 173;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 211) || (a_inventory(v_feld, g_akt_spieler).f_name == 197)) || (a_inventory(v_feld, g_akt_spieler).f_name == 215))) {
			v_geg = 171;
		}
		if (((a_inventory(v_feld, g_akt_spieler).f_name == 216) || (a_inventory(v_feld, g_akt_spieler).f_name == 214))) {
			v_geg = 158;
		}
	}
	if ((a_gegenstand(a_inventory(v_welche, g_akt_spieler).f_name).f_klasse == 1)) {
		v_gewa = 1;
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 218) || (a_inventory(v_feld, g_akt_spieler).f_name == 209)) || (a_inventory(v_feld, g_akt_spieler).f_name == 210))) {
			v_geg = 142;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 199) || (a_inventory(v_feld, g_akt_spieler).f_name == 217)) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 143;
		}
		if (((a_inventory(v_feld, g_akt_spieler).f_name == 198) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 237;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 211) || (a_inventory(v_feld, g_akt_spieler).f_name == 197)) || (a_inventory(v_feld, g_akt_spieler).f_name == 215))) {
			v_geg = 144;
		}
		if ((a_inventory(v_feld, g_akt_spieler).f_name == 216)) {
			v_geg = 162;
		}
		if ((a_inventory(v_feld, g_akt_spieler).f_name == 214)) {
			v_geg = 162;
		}
	}
	if ((a_gegenstand(a_inventory(v_welche, g_akt_spieler).f_name).f_klasse == 2)) {
		v_gewa = 1;
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 218) || (a_inventory(v_feld, g_akt_spieler).f_name == 209)) || (a_inventory(v_feld, g_akt_spieler).f_name == 210))) {
			v_geg = 376;
		}
		if (((((a_inventory(v_feld, g_akt_spieler).f_name == 199) || (a_inventory(v_feld, g_akt_spieler).f_name == 217)) || (a_inventory(v_feld, g_akt_spieler).f_name == 216)) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 378;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 211) || (a_inventory(v_feld, g_akt_spieler).f_name == 197)) || (a_inventory(v_feld, g_akt_spieler).f_name == 215))) {
			v_geg = 381;
		}
	}
	if ((a_gegenstand(a_inventory(v_welche, g_akt_spieler).f_name).f_klasse == 3)) {
		v_gewa = 1;
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 218) || (a_inventory(v_feld, g_akt_spieler).f_name == 209)) || (a_inventory(v_feld, g_akt_spieler).f_name == 210))) {
			v_geg = 377;
		}
		if (((((a_inventory(v_feld, g_akt_spieler).f_name == 199) || (a_inventory(v_feld, g_akt_spieler).f_name == 217)) || (a_inventory(v_feld, g_akt_spieler).f_name == 216)) || (a_inventory(v_feld, g_akt_spieler).f_name == 213))) {
			v_geg = 379;
		}
		if ((((a_inventory(v_feld, g_akt_spieler).f_name == 211) || (a_inventory(v_feld, g_akt_spieler).f_name == 197)) || (a_inventory(v_feld, g_akt_spieler).f_name == 215))) {
			v_geg = 382;
		}
	}
	if ((v_gewa == 0)) {
		p_nachricht(566, 1);
	} else {
		if ((v_geg > 0)) {
			p_leeren(v_feld);
			p_leeren(v_welche);
			p_in_rucksack(v_geg, 1);
			p_nachricht(567, 1);
		}
	}
}

static int32_t p_unlocken(int16_t v_welche) {
	int16_t v_i = 0;
	int16_t v_j = 0;
	for (v_i = 1; v_i <= 216; v_i += 1) {
		if ((a_unmoeglich(v_i).f_name == a_skills(v_welche, g_akt_spieler).f_nummer)) {
			for (v_j = 0; v_j <= 140; v_j += 1) {
				if ((a_unmoeglich(v_i).f_locked == a_skills(v_j, g_akt_spieler).f_nummer)) {
					a_skills(v_j, g_akt_spieler).f_gelocked -= 1;
				}
			}
		}
	}
}

static int32_t p_update_automap() {
	a_automap(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	a_automap((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	if ((a_spieler(g_akt_spieler).f_character_x > 1)) {
		a_automap((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		if ((a_spieler(g_akt_spieler).f_character_y > 1)) {
			a_automap((a_spieler(g_akt_spieler).f_character_x - 1), (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		}
		a_automap((a_spieler(g_akt_spieler).f_character_x - 1), (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	}
	a_automap(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	a_automap((a_spieler(g_akt_spieler).f_character_x + 1), (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	if ((a_spieler(g_akt_spieler).f_character_y > 1)) {
		a_automap(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		a_automap((a_spieler(g_akt_spieler).f_character_x + 1), (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	}
}

static int32_t p_update_automap2() {
	a_automap(a_spieler(g_akt_spieler).f_creature_x, a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	a_automap((a_spieler(g_akt_spieler).f_creature_x + 1), a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	if ((a_spieler(g_akt_spieler).f_creature_x > 1)) {
		a_automap((a_spieler(g_akt_spieler).f_creature_x - 1), a_spieler(g_akt_spieler).f_creature_y).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		if ((a_spieler(g_akt_spieler).f_creature_y > 1)) {
			a_automap((a_spieler(g_akt_spieler).f_creature_x - 1), (a_spieler(g_akt_spieler).f_creature_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		}
		a_automap((a_spieler(g_akt_spieler).f_creature_x - 1), (a_spieler(g_akt_spieler).f_creature_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	}
	a_automap(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	a_automap((a_spieler(g_akt_spieler).f_creature_x + 1), (a_spieler(g_akt_spieler).f_creature_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	if ((a_spieler(g_akt_spieler).f_creature_y > 1)) {
		a_automap(a_spieler(g_akt_spieler).f_creature_x, (a_spieler(g_akt_spieler).f_creature_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
		a_automap((a_spieler(g_akt_spieler).f_creature_x + 1), (a_spieler(g_akt_spieler).f_creature_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] = 1;
	}
}

static int32_t p_upload_box() {
	int16_t v_back_button = 0;
	int16_t v_jb1 = 0;
	int16_t v_jb2 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int32_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_xx = 0;
	int16_t v_xxx = 0;
	int16_t v_yy = 0;
	int16_t v_yyy = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_laby_rahmen();
		p_show_logo();
		p_show_varys();
		p_show_buttons();
		p_clipsprite(14, 1, 1, 335, 335);
		p_displaytransparentsprite(14, 16, 16);
		p_startdrawing(p_screenoutput());
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(60, 300, a_nachricht_text(740, (1 + g_sprache)), -1, 0);
		p_drawtext(60, 315, a_nachricht_text(741, (1 + g_sprache)), -1, 0);
		p_frontcolor(p_rgb(0, 0, 0));
		p_drawtext(90, 170, a_nachricht_text(748, (1 + g_sprache)), -1, 0);
		p_stopdrawing();
		v_jb1 = 0;
		v_jb2 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jb1 = p_joystickbutton(1);
			v_jb2 = p_joystickbutton(2);
		}
		p_examinekeyboard();
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		v_xx = 90;
		v_yy = 250;
		v_xxx = 190;
		v_yyy = 250;
		if (((p_keyboardpushed(121) || p_keyboardpushed(122)) || (v_jb1 == 1))) {
			v_raus = 1;
		}
		if (((((v_mmouse_x > v_xx) && (v_mmouse_x < (v_xx + 90))) && (v_mmouse_y > v_yy)) && (v_mmouse_y < (v_yy + 28)))) {
			p_clipsprite(3, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
			}
		} else {
			p_clipsprite(3, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(3, v_xx, v_yy);
		if ((p_keyboardpushed(110) || (v_jb2 == 1))) {
			v_raus = 2;
		}
		v_back_button = 0;
		if (((((v_mmouse_x > v_xxx) && (v_mmouse_x < (v_xxx + 90))) && (v_mmouse_y > v_yyy)) && (v_mmouse_y < (v_yyy + 28)))) {
			p_clipsprite(4, 0, 0, 87, 32);
			if ((v_mmouse_links == 1)) {
				v_raus = 2;
			}
		} else {
			p_clipsprite(4, 0, 31, 87, 32);
		}
		p_displaytransparentsprite(4, v_xxx, v_yyy);
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
	} while (!(v_raus > 0));
	if ((v_raus == 1)) {
		p_highscore_upload();
	}
}

static int32_t p_vergiften() {
	int16_t v_verkauf = 0;
	v_verkauf = p_select_inventory(452);
	if ((v_verkauf != 0)) {
		if (((a_gegenstand(a_inventory(v_verkauf, g_akt_spieler).f_name).f_art == 1) || (a_gegenstand(a_inventory(v_verkauf, g_akt_spieler).f_name).f_art == 13))) {
			if (((a_inventory(v_verkauf, g_akt_spieler).f_status == 0) || (a_inventory(v_verkauf, g_akt_spieler).f_status == 1))) {
				a_inventory(v_verkauf, g_akt_spieler).f_status = 4;
				p_sound(9);
				p_nachricht(453, 4);
			} else {
				p_nachricht(455, 3);
			}
		} else {
			p_nachricht(454, 3);
		}
	}
}

static int32_t p_vergolden() {
	int32_t v_hugo = 0;
	int16_t v_verkauf = 0;
	int32_t v_wohin = 0;
	v_verkauf = p_select_inventory(104);
	if ((a_inventory(v_verkauf, g_akt_spieler).f_name == 150)) {
		v_verkauf = 0;
	}
	if ((v_verkauf != 0)) {
		v_hugo = p_random((a_spieler(g_akt_spieler).f_level * 5));
		p_gold_finden(v_hugo);
		p_leeren(v_verkauf);
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 1));
		p_drawtext(200, 400, p_nachricht6(105, p_str(p_gold_anzahl())), -1, 0);
		p_stopdrawing();
	}
}

static int32_t p_versteinern() {
	int32_t v_akt_zeile = 0;
	int32_t v_wohin = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	for (v_akt_zeile = 32; v_akt_zeile >= 1; v_akt_zeile -= 1) {
		p_line((160 + (g_spell_x * 32)), ((160 + v_akt_zeile) + (g_spell_y * 32)), 32, 0, -1);
		p_flipbuffers(1);
		p_delay(20);
	}
	p_stopdrawing();
}

static int32_t p_vertikal(int16_t v_akt_level) {
	int16_t v_gef = 0;
	int32_t v_i = 0;
	int32_t v_j = 0;
	int16_t v_save_anzahl = 0;
	int16_t v_save_duration = 0;
	int16_t v_save_feld = 0;
	int16_t v_save_graphic = 0;
	int16_t v_save_lebenspunkte = 0;
	int16_t v_save_lifepoints = 0;
	int16_t v_save_name = 0;
	int16_t v_save_name2 = 0;
	int16_t v_save_objekt = 0;
	int16_t v_save_status = 0;
	int16_t v_save_status2 = 0;
	int16_t v_xxx = 0;
	int16_t v_yyy = 0;
	for (v_i = 1; v_i <= (a_groesse(v_akt_level) / 2); v_i += 1) {
		for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
			v_save_feld = a_labyrinth(v_i, v_j).f_feld[v_akt_level];
			v_save_lebenspunkte = a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level];
			v_save_objekt = a_labyrinth(v_i, v_j).f_objekt[v_akt_level];
			v_save_status = a_labyrinth(v_i, v_j).f_status[v_akt_level];
			v_save_name = a_laby_monster(v_i, v_j).f_name[v_akt_level];
			v_save_graphic = a_laby_monster(v_i, v_j).f_graphic[v_akt_level];
			v_save_lifepoints = a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level];
			v_save_status = a_laby_monster(v_i, v_j).f_status[v_akt_level];
			v_save_duration = a_laby_monster(v_i, v_j).f_duration[v_akt_level];
			v_save_name2 = a_laby_item(v_i, v_j).f_name[v_akt_level];
			v_save_anzahl = a_laby_item(v_i, v_j).f_anzahl[v_akt_level];
			v_save_status2 = a_laby_item(v_i, v_j).f_status[v_akt_level];
			a_labyrinth(v_i, v_j).f_feld[v_akt_level] = a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_feld[v_akt_level];
			a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level] = a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_lebenspunkte[v_akt_level];
			a_labyrinth(v_i, v_j).f_objekt[v_akt_level] = a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_objekt[v_akt_level];
			a_labyrinth(v_i, v_j).f_status[v_akt_level] = a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_name[v_akt_level] = a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_name[v_akt_level];
			a_laby_monster(v_i, v_j).f_graphic[v_akt_level] = a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_graphic[v_akt_level];
			a_laby_monster(v_i, v_j).f_lifepoints[v_akt_level] = a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_lifepoints[v_akt_level];
			a_laby_monster(v_i, v_j).f_status[v_akt_level] = a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level];
			a_laby_monster(v_i, v_j).f_duration[v_akt_level] = a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_duration[v_akt_level];
			a_laby_item(v_i, v_j).f_name[v_akt_level] = a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_name[v_akt_level];
			a_laby_item(v_i, v_j).f_anzahl[v_akt_level] = a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_anzahl[v_akt_level];
			a_laby_item(v_i, v_j).f_status[v_akt_level] = a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level];
			a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_feld[v_akt_level] = v_save_feld;
			a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_lebenspunkte[v_akt_level] = v_save_lebenspunkte;
			a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_objekt[v_akt_level] = v_save_objekt;
			a_labyrinth(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level] = v_save_status;
			a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_name[v_akt_level] = v_save_name;
			a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_graphic[v_akt_level] = v_save_graphic;
			a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_lifepoints[v_akt_level] = v_save_lifepoints;
			a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level] = v_save_status;
			a_laby_monster(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_duration[v_akt_level] = v_save_duration;
			a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_name[v_akt_level] = v_save_name2;
			a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_anzahl[v_akt_level] = v_save_anzahl;
			a_laby_item(((a_groesse(v_akt_level) + 1) - v_i), v_j).f_status[v_akt_level] = v_save_status2;
		}
	}
	for (v_i = 1; v_i <= a_groesse(v_akt_level); v_i += 1) {
		for (v_j = 1; v_j <= a_groesse(v_akt_level); v_j += 1) {
			if ((a_labyrinth(v_i, v_j).f_feld[v_akt_level] == 74)) {
				a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level] = ((a_groesse(v_akt_level) + 1) - a_labyrinth(v_i, v_j).f_lebenspunkte[v_akt_level]);
			}
		}
	}
	v_yyy = 1;
	v_gef = 0;
	do {
		v_xxx = 0;
		do {
			if ((a_labyrinth(v_xxx, v_yyy).f_feld[v_akt_level] == 47)) {
				v_gef = 1;
			}
			v_xxx = (v_xxx + 1);
		} while (!((v_gef == 1) || (v_xxx > a_groesse(v_akt_level))));
		v_yyy = (v_yyy + 1);
	} while (!((v_gef == 1) || (v_yyy > a_groesse(v_akt_level))));
	a_raumx(v_akt_level) = (v_xxx - 2);
	a_eingangx(v_akt_level) = a_groesse(v_akt_level);
	a_ausgangx(v_akt_level) = ((a_groesse(v_akt_level) + 1) - a_ausgangx(v_akt_level));
}

static int32_t p_vor_bewegung() {
	int32_t v_akt_schleichen = 0;
	int16_t v_angriff = 0;
	int32_t v_ausweichen = 0;
	int32_t v_counter = 0;
	int32_t v_critical_chance = 0;
	int16_t v_egon = 0;
	int16_t v_entdecken = 0;
	int32_t v_frame = 0;
	int16_t v_frei = 0;
	int8_t v_gesetzt = 0;
	int16_t v_hugo = 0;
	int32_t v_i = 0;
	int32_t v_inhalt_x = 0;
	int32_t v_inhalt_y = 0;
	int32_t v_k = 0;
	int32_t v_maxi = 0;
	int32_t v_mini = 0;
	int32_t v_neue_koepfe = 0;
	int16_t v_richtung = 0;
	int32_t v_schaden = 0;
	int32_t v_sprite_x = 0;
	int32_t v_sprite_y = 0;
	int16_t v_testfeld = 0;
	int16_t v_treffer = 0;
	int32_t v_unsichtbar = 0;
	int32_t v_vorbei = 0;
	int16_t v_xmod2 = 0;
	int32_t v_xmod_save = 0;
	int16_t v_ymod2 = 0;
	int32_t v_ymod_save = 0;
	int16_t v_zaehl = 0;
	int16_t v_zaehler = 0;
	int32_t v_zw = 0;
	if ((a_spieler(g_akt_spieler).f_betrunken > 0)) {
		v_zaehler = 1;
		v_frei = 0;
		do {
			v_richtung = (p_random(3) + 1);
			switch (v_richtung) {
			case 1:
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
					g_xmod = 1;
					g_ymod = 0;
					v_frei = 1;
				}
				break;
			case 2:
				if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
					g_xmod = -1;
					g_ymod = 0;
					v_frei = 1;
				}
				break;
			case 3:
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
					g_xmod = 0;
					g_ymod = 1;
					v_frei = 1;
				}
				break;
			case 4:
				if ((a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
					g_xmod = 0;
					g_ymod = -1;
					v_frei = 1;
				}
				break;
			}
			v_zaehler = (v_zaehler + 1);
		} while (!((v_frei == 1) || (v_zaehler > 500)));
	}
	if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 210) && (p_habich(86) == 0))) {
		if ((p_random(100) <= (p_staerke() * 3))) {
			p_nachricht(829, 1);
			p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 209, 0, 0, 0);
		} else {
			p_nachricht(827, 1);
		}
		g_xmod = 0;
		g_ymod = 0;
		a_spieler(g_akt_spieler).f_speed = 0;
		g_aktion = 1;
	}
	if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] >= 137) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] <= 148))) {
		v_vorbei = 0;
		if ((a_spieler(g_akt_spieler).f_schleichen > 0)) {
			v_akt_schleichen = p_schleichen();
			if ((p_random(100) < v_akt_schleichen)) {
				p_nachricht(1, 2);
				v_vorbei = 1;
			} else {
				p_nachricht(2, 3);
				g_xmod = 0;
				g_ymod = 0;
				p_laby_screen();
				a_spieler(g_akt_spieler).f_speed = 0;
				g_aktion = 1;
			}
		} else {
			v_angriff = p_spieler_angriffswert();
			v_mini = p_schaden_min();
			v_maxi = p_schaden_max();
			v_critical_chance = p_schaden_critical();
			v_treffer = (p_random(99) + 1);
			if ((v_treffer < v_angriff)) {
				p_clipsprite(38, 0, 224, 32, 32);
				p_displaysprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
				if ((v_treffer < v_critical_chance)) {
					p_clipsprite(38, 96, 224, 32, 32);
					p_displaysprite(38, (160 + (g_xmod * 32)), (160 + (g_ymod * 32)));
					a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
					p_nachricht(287, 3);
					p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
					if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
					}
				} else {
					v_counter = 1;
					do {
						v_schaden = (p_random((v_maxi - 1)) + 1);
						v_counter = (v_counter + 1);
					} while (!((v_schaden >= v_mini) || (v_counter > 500)));
					if ((v_counter > 500)) {
						v_schaden = 1;
					}
					if ((v_schaden > p_min(p_max(((a_spieler(g_akt_spieler).f_level / 2) + 1), 6), 15))) {
						a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] - 1);
						p_nachricht(287, 3);
						p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
						if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] < 1)) {
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 9, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 4), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 4), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 5), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
							p_setlaby((a_raumx(a_spieler(g_akt_spieler).f_level) + 6), (a_raumy(a_spieler(g_akt_spieler).f_level) + 5), a_spieler(g_akt_spieler).f_level, 89, 0, 0, 0);
						}
					} else {
						v_neue_koepfe = (p_random(1) + 1);
						a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = (a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] + v_neue_koepfe);
						if ((a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] > 9)) {
							a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] = 9;
						}
						p_nachricht3(289, a_labyrinth((a_raumx(a_spieler(g_akt_spieler).f_level) + 3), (a_raumy(a_spieler(g_akt_spieler).f_level) + 3)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level], 290);
					}
				}
			} else {
				p_nachricht(286, 3);
			}
			a_spieler(g_akt_spieler).f_speed = 0;
			g_aktion = 1;
			g_xmod = 0;
			g_ymod = 0;
		}
		if ((v_vorbei == 0)) {
			v_ausweichen = 0;
			if (((a_skills(6, g_akt_spieler).f_gewaehlt == 1) && (p_random(100) > 50))) {
				v_ausweichen = 1;
			}
			if ((v_ausweichen == 0)) {
				v_angriff = 80;
				v_angriff = (v_angriff - (p_reflexe() * 10));
				if ((v_angriff < 10)) {
					v_angriff = 10;
				}
				if ((a_spieler(g_akt_spieler).f_fluch == 21)) {
					v_angriff = 90;
				}
				if (((p_random(99) + 1) < v_angriff)) {
					v_schaden = (p_random(15) + 1);
					if ((a_spieler(g_akt_spieler).f_lifepoints < 1)) {
						for (v_k = 1; v_k <= 3; v_k += 1) {
							a_spieler(g_akt_spieler).f_sterbegrund[v_k] = a_nachricht_text(631, v_k);
						}
						p_tot();
					} else {
						p_clipsprite(1, (v_inhalt_x * 32), (v_inhalt_y * 32), 32, 32);
						p_displaysprite(1, 160, 160);
						p_draw_character(a_spieler(g_akt_spieler).f_face, v_frame, 0);
						p_flipbuffers(1);
					}
				} else {
					p_nachricht(291, 3);
				}
			} else {
				p_nachricht(178, 3);
			}
		}
	}
	if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
		if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] != 3)) {
			if (((a_spieler(g_akt_spieler).f_schleichen > 0) || (p_habich(110) > 0))) {
				v_akt_schleichen = p_schleichen();
				if ((p_random(100) < v_akt_schleichen)) {
					p_nachricht(1, 2);
				} else {
					p_nachricht(2, 3);
					if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 0)) {
						a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 1;
					}
					if ((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 2)) {
						a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] = 0;
					}
					g_xmod = 0;
					g_ymod = 0;
					p_laby_screen();
					a_spieler(g_akt_spieler).f_speed = 0;
					g_aktion = 1;
					for (v_i = 1; v_i <= 15; v_i += 1) {
						if ((a_aktive(v_i, g_akt_spieler).f_nr == 110)) {
							a_aktive(v_i, g_akt_spieler).f_nr = 0;
							a_aktive(v_i, g_akt_spieler).f_staerke = 0;
							a_aktive(v_i, g_akt_spieler).f_dauer = 0;
						}
					}
				}
			} else {
				v_unsichtbar = 0;
				if (((p_hat_eigenschaft2(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level], 19) == 1) && (p_habich(109) == 0))) {
					v_unsichtbar = 1;
				}
				if ((((v_unsichtbar == 1) && (p_random(100) > 80)) || (v_unsichtbar == 0))) {
					v_zw = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_graphic[a_spieler(g_akt_spieler).f_level];
					v_sprite_x = v_zw;
					v_sprite_y = 0;
					if ((v_sprite_x > 10)) {
						do {
							v_sprite_y = (v_sprite_y + 1);
							v_sprite_x = (v_sprite_x - 10);
						} while (!(v_sprite_x < 11));
					}
					if (((a_skills(18, g_akt_spieler).f_gewaehlt == 1) || (a_spieler(g_akt_spieler).f_style == 9))) {
						v_xmod_save = g_xmod;
						v_ymod_save = g_ymod;
						g_xmod = 1;
						g_ymod = 0;
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
							p_kampf();
						}
						g_xmod = 0;
						g_ymod = 1;
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
							p_kampf();
						}
						g_xmod = 0;
						g_ymod = -1;
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
							p_kampf();
						}
						g_xmod = -1;
						g_ymod = 0;
						if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
							p_kampf();
						}
						g_xmod = v_xmod_save;
						g_ymod = v_ymod_save;
					} else {
						p_kampf();
					}
					if (((((a_skills(20, g_akt_spieler).f_gewaehlt == 1) || (a_spieler(g_akt_spieler).f_style == 7)) && (p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_lifepoints[a_spieler(g_akt_spieler).f_level] > 0))) {
						p_kampf();
					}
					if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 1)) {
						v_gesetzt = 0;
						v_xmod_save = g_xmod;
						v_ymod_save = g_ymod;
						if (((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 6) == 1) && (p_random(10) > 4))) {
							v_hugo = a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_name[a_spieler(g_akt_spieler).f_level];
							if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), 30) == 1)) {
								if (((a_laby_monster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 53))) {
									v_gesetzt = 1;
									g_xmod = 1;
									g_ymod = 0;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((a_laby_monster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 53))) {
									v_gesetzt = 1;
									g_xmod = -1;
									g_ymod = 0;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 53))) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = 1;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_feld[a_spieler(g_akt_spieler).f_level] == 53))) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = -1;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
							} else {
								if (((p_blockiert2((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0))) {
									v_gesetzt = 1;
									g_xmod = 1;
									g_ymod = 0;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_character_x + 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((p_blockiert2((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] == 0))) {
									v_gesetzt = 1;
									g_xmod = -1;
									g_ymod = 0;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster((a_spieler(g_akt_spieler).f_character_x - 1), a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((p_blockiert2(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0))) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = 1;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y + 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
								if (((p_blockiert2(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level) == 0) && (a_laby_monster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0))) {
									v_gesetzt = 1;
									g_xmod = 0;
									g_ymod = -1;
									p_aufstehen(a_monster(v_hugo).f_nr);
									p_setmonster(a_spieler(g_akt_spieler).f_character_x, (a_spieler(g_akt_spieler).f_character_y - 1), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
								}
							}
						}
						g_xmod = v_xmod_save;
						g_ymod = v_ymod_save;
						if ((v_gesetzt == 1)) {
							p_laby_screen2();
							p_nachricht(36, 3);
						}
					}
					if (((a_skills(19, g_akt_spieler).f_gewaehlt == 1) && (p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)) == 0))) {
						a_spieler(g_akt_spieler).f_speed = (a_spieler(g_akt_spieler).f_speed - 1);
					} else {
						a_spieler(g_akt_spieler).f_speed = 0;
						g_aktion = 1;
					}
				} else {
					p_nachricht(441, 2);
					a_spieler(g_akt_spieler).f_speed = 0;
					g_aktion = 1;
				}
				g_xmod = 0;
				g_ymod = 0;
			}
		} else {
			p_nachricht(457, 5);
		}
	}
	if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 97)) {
		v_hugo = 70;
		p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0);
		p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, v_hugo, a_monster(v_hugo).f_nr, a_monster(v_hugo).f_lebenspunkte, 0, 0);
		a_spieler(g_akt_spieler).f_speed = 0;
		g_aktion = 1;
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 80)) {
		v_angriff = (p_spieler_angriffswert() / 2);
		if ((p_random(100) < v_angriff)) {
			p_sound(23);
			p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, a_inhalt(a_spieler(g_akt_spieler).f_level), 0, 0, 0);
			p_delay(g_mydelay);
			p_laby_screen();
		} else {
			p_nachricht(3, 2);
			if ((p_habich(68) == 0)) {
				p_sound(10);
				p_spielerschaden(1, 3, 13);
			} else {
				p_nachricht(315, 2);
			}
			p_delay(g_mydelay);
		}
		a_spieler(g_akt_spieler).f_speed = 0;
		g_aktion = 1;
		g_xmod = 0;
		g_ymod = 0;
	}
	if ((a_skills(123, g_akt_spieler).f_gewaehlt == 0)) {
		if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] >= 22) && (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] <= 30))) {
			v_entdecken = (p_entdecken() + (p_habich(61) * 10));
			if ((a_skills(77, g_akt_spieler).f_gewaehlt == 1)) {
				v_entdecken = (v_entdecken + 70);
			}
			if ((a_skills(95, g_akt_spieler).f_gewaehlt == 1)) {
				v_entdecken = (v_entdecken + 30);
			}
			if ((v_entdecken > 90)) {
				v_entdecken = 90;
			}
			if ((p_habich(26) > 0)) {
				v_entdecken = 90;
			}
			if ((p_random(100) < v_entdecken)) {
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] + 9), 0, 0, 0);
				g_xmod = 0;
				g_ymod = 0;
				p_sound(17);
				p_laby_screen();
				p_flipbuffers(1);
				p_delay(g_mydelay);
			}
		}
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 75)) {
			v_entdecken = (p_wahrnehmung() * 10);
			if ((a_skills(95, g_akt_spieler).f_gewaehlt == 1)) {
				v_entdecken = (v_entdecken + 30);
			}
			if ((v_entdecken > 90)) {
				v_entdecken = 90;
			}
			if (((p_random(100) < v_entdecken) || (a_skills(79, g_akt_spieler).f_gewaehlt == 1))) {
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 69, 0, 0, 0);
				g_xmod = 0;
				g_ymod = 0;
				p_sound(17);
				p_laby_screen();
				p_delay(g_mydelay);
			}
		}
	}
	if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 47)) {
		if (((a_skills(95, g_akt_spieler).f_gewaehlt == 1) && (a_visionen(a_spieler(g_akt_spieler).f_level) == 1))) {
			a_visionen(a_spieler(g_akt_spieler).f_level) = 0;
			switch (a_raeume(a_spieler(g_akt_spieler).f_level)) {
			case 0:
				p_nachricht(458, 2);
				break;
			case 1:
				p_nachricht(458, 2);
				break;
			case 2:
				p_nachricht(459, 2);
				break;
			case 3:
				p_nachricht(460, 2);
				break;
			case 4:
				p_nachricht(461, 2);
				break;
			case 5:
				p_nachricht(462, 2);
				break;
			case 6:
				p_nachricht(463, 2);
				break;
			case 7:
				p_nachricht(464, 2);
				break;
			case 8:
				p_nachricht(465, 2);
				break;
			case 9:
				p_nachricht(466, 2);
				break;
			case 10:
				p_nachricht(467, 2);
				break;
			case 11:
				p_nachricht(468, 2);
				break;
			case 12:
				p_nachricht(469, 2);
				break;
			case 13:
				p_nachricht(470, 2);
				break;
			case 14:
				p_nachricht(471, 2);
				break;
			case 15:
				p_nachricht(458, 2);
				break;
			case 16:
				p_nachricht(472, 2);
				break;
			case 17:
				p_nachricht(473, 2);
				break;
			case 18:
				p_nachricht(470, 2);
				break;
			case 19:
				p_nachricht(470, 2);
				break;
			case 20:
				p_nachricht(474, 2);
				break;
			case 21:
				p_nachricht(475, 2);
				break;
			case 22:
				p_nachricht(470, 2);
				break;
			case 23:
				p_nachricht(476, 2);
				break;
			case 24:
				p_nachricht(477, 2);
				break;
			case 25:
				p_nachricht(478, 2);
				break;
			case 26:
				p_nachricht(479, 2);
				break;
			case 27:
				p_nachricht(458, 2);
				break;
			case 28:
				p_nachricht(458, 2);
				break;
			case 29:
				p_nachricht(507, 2);
				break;
			}
			g_xmod = 0;
			g_ymod = 0;
		} else {
			p_raum();
		}
	}
	if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 3)) {
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] == 55)) {
			g_xmod = 0;
			g_ymod = 0;
		}
	}
	switch (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level]) {
	case 1:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 101:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 102:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 103:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 104:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 42:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 56:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 57:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 15:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 17:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 78:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 20:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 136:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 112:
		v_xmod2 = (g_xmod * 2);
		v_ymod2 = (g_ymod * 2);
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + v_xmod2), (a_spieler(g_akt_spieler).f_character_y + v_ymod2)).f_feld[a_spieler(g_akt_spieler).f_level] == a_inhalt(a_spieler(g_akt_spieler).f_level))) {
			if ((p_random(100) <= p_staerke())) {
				p_sound(31);
				p_nachricht(828, 1);
				a_labyrinth((a_spieler(g_akt_spieler).f_character_x + v_xmod2), (a_spieler(g_akt_spieler).f_character_y + v_ymod2)).f_feld[a_spieler(g_akt_spieler).f_level] = 112;
				a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level] = a_inhalt(a_spieler(g_akt_spieler).f_level);
			} else {
				p_sound(10);
				p_nachricht(827, 1);
				g_xmod = 0;
				g_ymod = 0;
			}
		} else {
			p_sound(10);
			p_nachricht(826, 1);
			g_xmod = 0;
			g_ymod = 0;
		}
		break;
	case 45:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 88:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 178:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 199:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 164:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 165:
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 70:
		if (((a_skills(74, g_akt_spieler).f_gewaehlt == 1) || (a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 2))) {
			if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
				p_nachricht(524, 1);
			} else {
				p_sound(19);
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 71, 0, 0, 0);
				p_laby_screen();
				p_delay(g_mydelay);
			}
		} else {
			p_sound(10);
			p_nachricht(185, 1);
		}
		g_xmod = 0;
		g_ymod = 0;
		break;
	case 72:
		v_zaehl = 1;
		do {
			v_egon = (p_random(169) + 1);
			v_zaehl = (v_zaehl + 1);
		} while (!((p_hat_eigenschaft2(v_egon, 30) == 1) || (v_zaehl > 500)));
		if ((v_zaehl > 500)) {
			v_egon = 1;
		}
		p_aufstehen2(a_monster(v_egon).f_nr);
		p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 53, 0, 0, 0);
		p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, v_egon, a_monster(v_egon).f_nr, a_monster(v_egon).f_lebenspunkte, 0, 0);
		g_xmod = 0;
		g_ymod = 0;
		p_laby_screen();
		p_sound(27);
		break;
	}
	v_testfeld = a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_feld[a_spieler(g_akt_spieler).f_level];
	if ((v_testfeld == 53)) {
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
			g_xmod = 0;
			g_ymod = 0;
			p_sound(27);
		}
	}
	if ((v_testfeld == 198)) {
		if ((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_status[a_spieler(g_akt_spieler).f_level] == 1)) {
			g_xmod = 0;
			g_ymod = 0;
		}
	}
	if ((((((((((v_testfeld == 5) || (v_testfeld == 150)) || (v_testfeld == 151)) || (v_testfeld == 152)) || (v_testfeld == 153)) || (v_testfeld == 154)) || (v_testfeld == 155)) || (v_testfeld == 156)) || (v_testfeld == 157))) {
		if ((p_habich(38) == 0)) {
			if (((a_labyrinth((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod)).f_lebenspunkte[a_spieler(g_akt_spieler).f_level] == 1) || (a_spieler(g_akt_spieler).f_fluch == 10))) {
				p_sound(16);
				p_aufstehen(23);
				p_setlaby((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0);
				p_setmonster((a_spieler(g_akt_spieler).f_character_x + g_xmod), (a_spieler(g_akt_spieler).f_character_y + g_ymod), a_spieler(g_akt_spieler).f_level, 4, a_monster(4).f_nr, a_monster(4).f_lebenspunkte, 0, 0);
				g_xmod = 0;
				g_ymod = 0;
				a_spieler(g_akt_spieler).f_speed = 0;
				g_aktion = 1;
				p_laby_screen();
			}
		}
	}
	if ((((a_spieler(g_akt_spieler).f_character_x + g_xmod) < 1) || ((a_spieler(g_akt_spieler).f_character_y + g_ymod) < 1))) {
		g_xmod = 0;
		g_ymod = 0;
	}
}

static int32_t p_vorheriger_level() {
	a_spieler(g_akt_spieler).f_level = (a_spieler(g_akt_spieler).f_level - 1);
	a_spieler(g_akt_spieler).f_character_x = a_ausgangx(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_character_y = a_ausgangy(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_speed = p_maxspeed();
	a_spieler(g_akt_spieler).f_creature_x = a_ausgangx(a_spieler(g_akt_spieler).f_level);
	a_spieler(g_akt_spieler).f_creature_y = a_ausgangy(a_spieler(g_akt_spieler).f_level);
	if ((a_sonderlevel(a_spieler(g_akt_spieler).f_level) > 0)) {
		p_sonderlevel_text(a_sonderlevel(a_spieler(g_akt_spieler).f_level));
	}
	if ((a_levelmod(a_spieler(g_akt_spieler).f_level) > 0)) {
		p_levelmodtext(a_levelmod(a_spieler(g_akt_spieler).f_level));
	}
}

static int32_t p_waehlen(int16_t v_welche) {
	int16_t v_iii = 0;
	int16_t v_jjj = 0;
	a_skills(v_welche, g_akt_spieler).f_gewaehlt = 1;
	for (v_iii = 1; v_iii <= 216; v_iii += 1) {
		if ((a_unmoeglich(v_iii).f_name == a_skills(v_welche, g_akt_spieler).f_nummer)) {
			for (v_jjj = 0; v_jjj <= 140; v_jjj += 1) {
				if ((a_unmoeglich(v_iii).f_locked == a_skills(v_jjj, g_akt_spieler).f_nummer)) {
					a_skills(v_jjj, g_akt_spieler).f_gelocked = 1;
				}
			}
		}
	}
}

static int32_t p_waffe_attack() {
	int32_t v_i = 0;
	int16_t v_waffe = 0;
	int16_t v_waffe_attack = 0;
	v_waffe_attack = 0;
	v_waffe = 0;
	for (v_i = 1; v_i <= 50; v_i += 1) {
		if (((a_inventory(v_i, g_akt_spieler).f_art == 1) && (a_inventory(v_i, g_akt_spieler).f_benutzt == 1))) {
			v_waffe = (v_waffe + a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_attri1);
		}
	}
	if ((v_waffe > 0)) {
		v_waffe_attack = v_waffe;
	}
	if (((a_skills(21, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(1) == 1))) {
		v_waffe_attack = (v_waffe_attack + 2);
	}
	if (((a_skills(22, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(2) == 1))) {
		v_waffe_attack = (v_waffe_attack + 2);
	}
	if (((a_skills(23, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(3) == 1))) {
		v_waffe_attack = (v_waffe_attack + 2);
	}
	if (((a_skills(24, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(4) == 1))) {
		v_waffe_attack = (v_waffe_attack + 2);
	}
	if (((a_skills(25, g_akt_spieler).f_gewaehlt == 1) && (p_ich_trage(10) == 0))) {
		v_waffe_attack = (v_waffe_attack + 3);
	}
	if (((p_ich_trage(10) == 0) && (a_skills(25, g_akt_spieler).f_gewaehlt == 0))) {
		v_waffe_attack = (v_waffe_attack / 2);
	}
	return v_waffe_attack;
}

static int32_t p_wahrnehmung() {
	int16_t v_akt_wahrnehmung = 0;
	v_akt_wahrnehmung = a_spieler(g_akt_spieler).f_perception;
	v_akt_wahrnehmung = (v_akt_wahrnehmung + (p_habich(52) * 10));
	v_akt_wahrnehmung = (v_akt_wahrnehmung + a_spieler(g_akt_spieler).f_perceptiongegenstand);
	if ((v_akt_wahrnehmung > 15)) {
		v_akt_wahrnehmung = 15;
	}
	return v_akt_wahrnehmung;
}

static int32_t p_wassermonster_setzen(int32_t v_level, int32_t v_welches) {
	int32_t v_hugo = 0;
	int16_t v_monstat = 0;
	int16_t v_x = 0;
	int16_t v_y = 0;
	int16_t v_zaehler = 0;
	v_x = 0;
	v_y = 0;
	v_zaehler = 1;
	do {
		v_x = (p_random((a_groesse(v_level) - 3)) + 2);
		v_y = (p_random((a_groesse(v_level) - 3)) + 2);
		v_zaehler = (v_zaehler + 1);
	} while (!((a_labyrinth(v_x, v_y).f_feld[v_level] == 53) || (v_zaehler > 500)));
	if ((v_zaehler <= 500)) {
		v_monstat = 0;
		if (((p_random(100) > 90) || (a_levelmod(v_level) == 11))) {
			if (((p_random(100) > 50) && (a_levelmod(v_level) != 11))) {
				if ((p_hat_eigenschaft2(v_hugo, 29) == 1)) {
					v_monstat = 2;
				} else {
					v_monstat = 1;
				}
			} else {
				v_monstat = 1;
			}
		}
		p_setmonster(v_x, v_y, v_level, v_welches, a_monster(v_welches).f_nr, a_monster(v_welches).f_lebenspunkte, v_monstat, 0);
	}
}

static int32_t p_weiss() {
	p_waehlen(36);
	p_waehlen(37);
	p_waehlen(38);
	p_waehlen(39);
	p_waehlen(40);
	p_waehlen(51);
	p_waehlen(53);
	p_waehlen(54);
	p_waehlen(57);
	p_waehlen(64);
	p_waehlen(89);
	p_waehlen(121);
	p_waehlen(122);
	p_waehlen(131);
	p_waehlen(133);
}

static int32_t p_werfen() {
	int32_t v_angriff = 0;
	int16_t v_maxschaden = 0;
	int32_t v_okay = 0;
	int16_t v_schaden = 0;
	if ((a_inventory(g_feld, g_akt_spieler).f_benutzt == 0)) {
		g_spell_x = 0;
		g_spell_y = 0;
		p_feld_waehlen();
		g_blocked = 0;
		p_los();
		if ((g_blocked == 0)) {
			if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)) == 1)) {
				g_aktion = 1;
				p_sound(26);
				if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_klasse == 5)) {
					p_attack_spell(7);
				}
				if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_klasse == 2)) {
					p_attack_spell(8);
				}
				if ((a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_klasse == 3)) {
					p_attack_spell(9);
				}
				v_angriff = 60;
				if ((a_skills(110, g_akt_spieler).f_gewaehlt == 1)) {
					v_angriff = (v_angriff + 50);
				}
				if ((v_angriff > 90)) {
					v_angriff = 90;
				}
				if ((v_angriff < 10)) {
					v_angriff = 10;
				}
				if ((p_random(100) < v_angriff)) {
					v_maxschaden = (a_gegenstand(a_inventory(g_feld, g_akt_spieler).f_name).f_attri2 + a_spieler(g_akt_spieler).f_strength);
					if ((a_skills(110, g_akt_spieler).f_gewaehlt == 1)) {
						v_maxschaden = (v_maxschaden + 2);
					}
					v_schaden = p_random(v_maxschaden);
					p_monsterschaden(v_schaden);
					if ((a_inventory(g_feld, g_akt_spieler).f_status == 4)) {
						a_inventory(g_feld, g_akt_spieler).f_status = 0;
						if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), 3) == 0)) {
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_status[a_spieler(g_akt_spieler).f_level] = 4;
							a_laby_monster((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_duration[a_spieler(g_akt_spieler).f_level] = (p_random(20) + 5);
						} else {
							p_nachricht(456, 4);
						}
					}
				} else {
					p_nachricht(16, 3);
				}
				v_okay = 0;
				if (((a_laby_item((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (v_okay == 0))) {
					p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
					v_okay = 1;
				}
				if (((a_laby_item(((a_spieler(g_akt_spieler).f_character_x + g_spell_x) + 1), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (v_okay == 0))) {
					p_setitem(((a_spieler(g_akt_spieler).f_character_x + g_spell_x) + 1), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
					v_okay = 1;
				}
				if (((a_laby_item(((a_spieler(g_akt_spieler).f_character_x + g_spell_x) - 1), (a_spieler(g_akt_spieler).f_character_y + g_spell_y)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (v_okay == 0))) {
					p_setitem(((a_spieler(g_akt_spieler).f_character_x + g_spell_x) - 1), (a_spieler(g_akt_spieler).f_character_y + g_spell_y), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
					v_okay = 1;
				}
				if (((a_laby_item((a_spieler(g_akt_spieler).f_character_x + g_spell_x), ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) + 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (v_okay == 0))) {
					p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) + 1), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
					v_okay = 1;
				}
				if (((a_laby_item((a_spieler(g_akt_spieler).f_character_x + g_spell_x), ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) - 1)).f_name[a_spieler(g_akt_spieler).f_level] == 0) && (v_okay == 0))) {
					p_setitem((a_spieler(g_akt_spieler).f_character_x + g_spell_x), ((a_spieler(g_akt_spieler).f_character_y + g_spell_y) - 1), a_spieler(g_akt_spieler).f_level, a_inventory(g_feld, g_akt_spieler).f_name, a_inventory(g_feld, g_akt_spieler).f_attri1, a_inventory(g_feld, g_akt_spieler).f_status);
					v_okay = 1;
				}
				p_leeren(g_feld);
				p_laby_screen();
				p_delay(g_mydelay);
			} else {
				p_nachricht(246, 3);
			}
		} else {
			p_nachricht(233, 3);
		}
	}
}

static int32_t p_wounded_hero() {
	int16_t v_heilen = 0;
	int32_t v_heilen2 = 0;
	int32_t v_i = 0;
	int16_t v_jax = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_mmouse_links = 0;
	int32_t v_mmouse_rechts = 0;
	int32_t v_mmouse_x = 0;
	int32_t v_mmouse_y = 0;
	int8_t v_raus = 0;
	int32_t v_result = 0;
	int16_t v_sel = 0;
	int16_t v_trank = 0;
	int16_t v_trank2 = 0;
	int16_t v_was = 0;
	int32_t v_wohin = 0;
	int32_t v_yy = 0;
	v_sel = 1;
	v_trank2 = 0;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_clipsprite(54, 0, 0, 640, 17);
		p_displaytransparentsprite(54, 0, 0);
		p_clipsprite(56, 0, 0, 17, 480);
		p_displaytransparentsprite(56, 0, 0);
		p_clipsprite(57, 0, 0, 640, 17);
		p_displaytransparentsprite(57, 0, 463);
		p_clipsprite(59, 0, 0, 17, 480);
		p_displaytransparentsprite(59, 623, 0);
		v_raus = 0;
		v_trank = 0;
		v_heilen = 0;
		v_yy = 65;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_drawingmode(1);
		p_frontcolor(p_rgb(255, 255, 255));
		p_drawtext(190, v_yy, a_nachricht_text(508, (1 + g_sprache)), -1, 0);
		v_yy = (v_yy + 15);
		p_drawtext(190, v_yy, a_nachricht_text(509, (1 + g_sprache)), -1, 0);
		p_clipsprite(1, 192, 640, 32, 32);
		p_displaysprite(1, 50, 70);
		v_jax = 0;
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		p_examinekeyboard();
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			v_sel = (v_sel - 1);
			if ((v_sel < 1)) {
				v_sel = 1;
			}
		}
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			v_sel = (v_sel + 1);
			if ((v_sel > 3)) {
				v_sel = 3;
			}
		}
		v_result = p_examinemouse();
		v_mmouse_x = p_mousex();
		v_mmouse_y = p_mousey();
		v_mmouse_links = p_mousebutton(1);
		v_mmouse_rechts = p_mousebutton(2);
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 120)) && (v_mmouse_y < 140))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 120, 550, 20, -1);
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 120, a_nachricht_text(510, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_trank = 1;
			}
		} else {
			if ((v_sel == 1)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_trank = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 120, a_nachricht_text(510, (1 + g_sprache)), -1, 0);
		}
		if ((v_trank == 1)) {
			for (v_i = 1; v_i <= 50; v_i += 1) {
				if (((a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_name[2] == "Schwacher Heiltrank") || (a_gegenstand(a_inventory(v_i, g_akt_spieler).f_name).f_name[2] == "Starker Heiltrank"))) {
					v_trank2 = v_i;
				}
			}
			if ((v_trank2 > 0)) {
				p_nachricht(514, 1);
				p_nachricht(515, 1);
				p_leeren(v_trank2);
				p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 203, 0, 0, 0);
				g_aktion = 1;
			} else {
				p_nachricht(517, 1);
			}
		}
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 140)) && (v_mmouse_y < 160))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 140, 550, 20, -1);
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 140, a_nachricht_text(511, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
				v_heilen = 1;
			}
		} else {
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
					v_heilen = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 140, a_nachricht_text(511, (1 + g_sprache)), -1, 0);
		}
		v_heilen2 = 0;
		if ((v_heilen == 1)) {
			if (((a_skills(51, g_akt_spieler).f_gewaehlt == 1) && (a_spieler(g_akt_spieler).f_circle >= 7))) {
				v_heilen2 = 1;
			}
			if ((a_zauber(100, g_akt_spieler).f_erlernt == 1)) {
				v_heilen2 = 1;
			}
			if ((v_heilen2 == 1)) {
				if ((a_spieler(g_akt_spieler).f_mana >= 2)) {
					a_spieler(g_akt_spieler).f_mana = (a_spieler(g_akt_spieler).f_mana - 2);
					p_sound(11);
					p_nachricht(514, 1);
					p_nachricht(515, 1);
					p_setlaby(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y, a_spieler(g_akt_spieler).f_level, 203, 0, 0, 0);
					v_trank2 = 1;
					g_aktion = 1;
				} else {
					p_nachricht(194, 1);
				}
			} else {
				p_nachricht(516, 1);
			}
		}
		if (((((v_mmouse_x > 40) && (v_mmouse_x < 600)) && (v_mmouse_y > 160)) && (v_mmouse_y < 180))) {
			p_frontcolor(p_rgb(150, 150, 150));
			p_box(40, 160, 550, 20, -1);
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 160, a_nachricht_text(512, (1 + g_sprache)), -1, 0);
			if ((v_mmouse_links == 1)) {
				v_raus = 1;
			}
		} else {
			if ((v_sel == 2)) {
				p_frontcolor(p_rgb(1, 1, 255));
				if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
					v_raus = 1;
				}
			} else {
				p_frontcolor(p_rgb(255, 255, 255));
			}
			p_drawtext(40, 160, a_nachricht_text(512, (1 + g_sprache)), -1, 0);
		}
		p_stopdrawing();
		p_clipsprite(8, 192, 288, 32, 32);
		p_displaytransparentsprite(8, v_mmouse_x, v_mmouse_y);
		p_flipbuffers(1);
		p_delay(g_mydelay3);
	} while (!(((v_mmouse_rechts == 1) || (v_raus == 1)) || p_keyboardpushed(27)));
	if ((v_trank2 > 0)) {
		v_i = 0;
		do {
			v_i = (v_i + 1);
		} while (!((a_inventory(v_i, g_akt_spieler).f_name == 0) || (v_i > 50)));
		if ((v_i <= 50)) {
			v_was = 0;
			switch (p_random(7)) {
			case 0:
				v_was = 220;
				break;
			case 1:
				v_was = 263;
				break;
			case 2:
				v_was = 148;
				break;
			case 3:
				v_was = 253;
				break;
			case 4:
				v_was = 230;
				break;
			case 5:
				v_was = 241;
				break;
			case 6:
				v_was = 155;
				break;
			case 7:
				v_was = 280;
				break;
			}
			a_inventory(v_i, g_akt_spieler).f_name = v_was;
			a_inventory(v_i, g_akt_spieler).f_art = a_gegenstand(v_was).f_art;
			a_inventory(v_i, g_akt_spieler).f_attri1 = a_gegenstand(v_was).f_attri1;
			a_inventory(v_i, g_akt_spieler).f_attri2 = a_gegenstand(v_was).f_attri2;
			a_inventory(v_i, g_akt_spieler).f_attri3 = a_gegenstand(v_was).f_attri3;
			a_inventory(v_i, g_akt_spieler).f_attri4 = a_gegenstand(v_was).f_attri4;
			p_sound(9);
		}
	}
}

static int32_t p_wr_txt(int32_t v_what, int32_t v_nr1, int32_t v_nr2, int32_t v_x, int32_t v_y) {
	if (((v_nr1 == 0) && (v_nr2 == 0))) {
		p_drawtext(v_x, v_y, a_zauberliste(v_what).f_name[(1 + g_sprache)], -1, 0);
	}
	if (((v_nr1 > 0) && (v_nr2 == 0))) {
		p_drawtext(v_x, v_y, (((a_zauberliste(v_what).f_name[(1 + g_sprache)] + " (") + p_str(v_nr1)) + ")"), -1, 0);
	}
	if (((v_nr1 == 0) && (v_nr2 > 0))) {
		p_drawtext(v_x, v_y, (((a_zauberliste(v_what).f_name[(1 + g_sprache)] + " (B") + p_str(v_nr2)) + ")"), -1, 0);
	}
	if (((v_nr1 > 0) && (v_nr2 > 0))) {
		p_drawtext(v_x, v_y, ((((((a_zauberliste(v_what).f_name[(1 + g_sprache)] + " (") + p_str(v_nr1)) + ")") + " (B") + p_str(v_nr2)) + ")"), -1, 0);
	}
}

static int32_t p_zauber_nehmen(int16_t v_i) {
	int16_t v_nehmen = 0;
	v_nehmen = 0;
	if ((a_zauber(v_i, g_akt_spieler).f_level <= a_spieler(g_akt_spieler).f_circle)) {
		if ((((a_summoning(v_i) == 1) || (a_zauber(v_i, g_akt_spieler).f_art == "beschw\357\277\275er")) && (a_skills(67, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "basis") && (a_skills(133, g_akt_spieler).f_gewaehlt == 0))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "erde") && ((a_skills(55, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1)))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "feuer") && ((a_skills(53, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1)))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "schwarz") && (a_skills(52, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "druide") && (a_skills(57, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "wasser") && ((a_skills(54, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1)))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "sterne") && (a_skills(48, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "luft") && ((a_skills(56, g_akt_spieler).f_gewaehlt == 1) || (a_skills(62, g_akt_spieler).f_gewaehlt == 1)))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "weiss") && (a_skills(51, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "barde") && (a_skills(60, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "illusion") && (a_skills(49, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "hohe") && (a_skills(59, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "hexerei") && (a_skills(58, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
		if (((a_zauber(v_i, g_akt_spieler).f_art == "warlock") && (a_skills(50, g_akt_spieler).f_gewaehlt == 1))) {
			v_nehmen = 1;
		}
	}
	return v_nehmen;
}

static int32_t p_zauber_rahmen() {
	int32_t v_besch = 0;
	int32_t v_hamwer = 0;
	int32_t v_i = 0;
	int32_t v_merker = 0;
	int32_t v_merker2 = 0;
	std::string v_mzauber;
	int32_t v_wohin = 0;
	int32_t v_x = 0;
	int32_t v_xadd = 0;
	int32_t v_y = 0;
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_frontcolor(p_rgb(0, 0, 0));
	p_box(365, 15, 260, 449, -1);
	p_box(15, 365, 335, 51, -1);
	p_stopdrawing();
	p_clipsprite(54, 0, 0, 640, 17);
	p_displaytransparentsprite(54, 0, 0);
	p_clipsprite(56, 0, 0, 17, 480);
	p_displaytransparentsprite(56, 0, 0);
	p_clipsprite(57, 0, 0, 640, 17);
	p_displaytransparentsprite(57, 0, 464);
	p_clipsprite(59, 0, 0, 17, 480);
	p_displaytransparentsprite(59, 624, 0);
	p_clipsprite(63, 0, 0, 365, 17);
	p_displaysprite(63, 0, 350);
	p_clipsprite(61, 0, 0, 274, 16);
	p_displaysprite(61, 350, 35);
	p_clipsprite(62, 0, 0, 274, 16);
	p_displaysprite(62, 350, 375);
	p_clipsprite(60, 0, 0, 17, 480);
	p_displaysprite(60, 350, 0);
	v_wohin = p_screenoutput();
	p_startdrawing(v_wohin);
	p_drawingmode(1);
	p_frontcolor(p_rgb(255, 255, 255));
	p_drawtext(440, 18, p_nachricht4(100), -1, 0);
	p_frontcolor(p_rgb(150, 150, 150));
	p_box(365, (200 + g_yplus2), 260, g_yplus, -1);
	v_x = 400;
	v_y = 52;
	v_besch = 0;
	v_mzauber = "";
	for (v_i = 1; v_i <= g_anzz; v_i += 1) {
		p_frontcolor(p_rgb(255, 255, 255));
		if ((v_i == g_mauszauber)) {
			p_frontcolor(p_rgb(1, 1, 255));
			v_mzauber = a_zauberliste((v_i + g_akt_zauber)).f_name[2];
		}
		v_hamwer = 0;
		v_merker = 0;
		v_merker2 = 0;
		if ((a_zauberliste((v_i + g_akt_zauber)).f_name[2] != "")) {
			if ((a_schnellzauber(1, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 1;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(2, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 2;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(3, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 3;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(4, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 4;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(5, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 5;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(6, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 6;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(7, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 7;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(8, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 8;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(9, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 9;
				v_hamwer = 1;
			}
			if ((a_schnellzauber(10, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker = 10;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(1, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 1;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(2, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 2;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(3, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 3;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(4, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 4;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(5, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 5;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(6, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 6;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(7, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 7;
				v_hamwer = 1;
			}
			if ((a_schnellzauber2(8, g_akt_spieler) == a_zauberliste((v_i + g_akt_zauber)).f_name[2])) {
				v_merker2 = 8;
				v_hamwer = 1;
			}
			if ((v_hamwer == 1)) {
				p_wr_txt((v_i + g_akt_zauber), v_merker, v_merker2, v_x, v_y);
			} else {
				p_wr_txt((v_i + g_akt_zauber), 0, 0, v_x, v_y);
			}
		}
		v_y = (v_y + g_yplus);
	}
	p_frontcolor(p_rgb(255, 255, 255));
	if ((v_mzauber == "")) {
		for (v_i = 1; v_i <= 177; v_i += 1) {
			if ((a_zauber(v_i, g_akt_spieler).f_name[2] == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
				v_besch = v_i;
			}
		}
	} else {
		for (v_i = 1; v_i <= 177; v_i += 1) {
			if ((a_zauber(v_i, g_akt_spieler).f_name[2] == v_mzauber)) {
				v_besch = v_i;
			}
		}
	}
	if ((v_besch > 0)) {
		v_x = 415;
		v_y = 390;
		v_xadd = 150;
		p_drawtext(v_x, v_y, p_nachricht4(61), -1, 0);
		p_drawtext((v_x + v_xadd), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_level), -1, 0);
		v_y = (v_y + g_yplus);
		p_drawtext(v_x, v_y, p_nachricht4(101), -1, 0);
		p_drawtext((v_x + v_xadd), v_y, p_str((a_zauber(v_besch, g_akt_spieler).f_kosten + (a_spieler(g_akt_spieler).f_spellweaving - 1))), -1, 0);
		v_y = (v_y + g_yplus);
		p_drawtext(v_x, v_y, p_nachricht4(91), -1, 0);
		p_drawtext((v_x + v_xadd), v_y, p_str(p_power(v_besch)), -1, 0);
		v_y = (v_y + g_yplus);
		p_drawtext(v_x, v_y, p_nachricht4(102), -1, 0);
		p_drawtext((v_x + v_xadd), v_y, p_str(a_zauber(v_besch, g_akt_spieler).f_dauer), -1, 0);
		v_y = (v_y + g_yplus);
		p_drawtext(v_x, v_y, p_nachricht4(103), -1, 0);
		p_drawtext((v_x + v_xadd), v_y, p_str(p_zauberchance(v_besch)), -1, 0);
		p_drawtext(25, 400, a_zauber(v_besch, g_akt_spieler).f_besch_1[(1 + g_sprache)], -1, 0);
		p_drawtext(25, 420, a_zauber(v_besch, g_akt_spieler).f_besch_2[(1 + g_sprache)], -1, 0);
	}
	p_stopdrawing();
	p_schulenicons();
	if ((a_skills(66, g_akt_spieler).f_gewaehlt == 1)) {
		p_spellweaving();
	}
}

static int32_t p_zauberchance(int16_t v_spell) {
	int16_t v_chance = 0;
	v_chance = a_zauber(v_spell, g_akt_spieler).f_chance;
	if ((p_aus_schule(v_spell) == 1)) {
		if ((a_skills(40, g_akt_spieler).f_gewaehlt == 1)) {
			v_chance = 99;
		}
	}
	if ((a_skills(45, g_akt_spieler).f_gewaehlt == 0)) {
		p_schutz();
		v_chance = (v_chance - (g_behinderung * 10));
	}
	return v_chance;
}

static int32_t p_zauberkosten(int16_t v_spell) {
	int16_t v_kosten = 0;
	v_kosten = (a_zauber(v_spell, g_akt_spieler).f_kosten + (a_spieler(g_akt_spieler).f_spellweaving - 1));
	return v_kosten;
}

static int32_t p_zaubern() {
	int32_t v_aktuell = 0;
	int32_t v_i = 0;
	int16_t v_jay = 0;
	int16_t v_jb1 = 0;
	int32_t v_k = 0;
	int32_t v_mouse_links = 0;
	int32_t v_mouse_rechts = 0;
	int32_t v_mouse_x = 0;
	int32_t v_mouse_y = 0;
	int32_t v_raushier = 0;
	int32_t v_result = 0;
	int32_t v_y = 0;
	p_erstelle_liste();
	g_akt_zauber = a_spieler(g_akt_spieler).f_pos_zaubermenue;
	do {
		p_fenster(0);
		p_clearscreen(p_rgb(0, 0, 0));
		p_draw_screen(0, 0);
		p_draw_screen3(0, 0);
		p_draw_screen4(0, 0);
		p_draw_screen7(0, 0);
		p_draw_character(a_spieler(g_akt_spieler).f_face, g_frame, 0);
		p_show_sight();
		p_zauber_rahmen();
		p_examinekeyboard();
		v_jay = 0;
		v_jb1 = 0;
		if ((g_joystick_used == 1)) {
			p_examinejoystick();
			v_jay = p_joystickaxisy();
			v_jb1 = p_joystickbutton(1);
		}
		if ((g_no_mouse == 0)) {
			v_result = p_examinemouse();
			v_mouse_x = p_mousex();
			v_mouse_y = p_mousey();
			v_mouse_links = p_mousebutton(1);
			v_mouse_rechts = p_mousebutton(2);
		}
		if (((((v_mouse_x >= 590) && (v_mouse_x <= 622)) && (v_mouse_y >= 310)) && (v_mouse_y <= 342))) {
			p_clipsprite(6, 192, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 310);
			if ((v_mouse_links == 1)) {
				if ((g_akt_zauber > 0)) {
					g_akt_zauber = (g_akt_zauber - 1);
					p_delay(50);
				}
			}
		} else {
			p_clipsprite(6, 128, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 310);
		}
		if (((((v_mouse_x > 590) && (v_mouse_x < 622)) && (v_mouse_y > 340)) && (v_mouse_y < 372))) {
			p_clipsprite(6, 224, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 340);
			if ((v_mouse_links == 1)) {
				if ((g_akt_zauber < (g_anz_zauber - 1))) {
					g_akt_zauber = (g_akt_zauber + 1);
					p_delay(50);
				}
			}
		} else {
			p_clipsprite(6, 160, 0, 31, 31);
			p_displaytransparentsprite(6, 590, 340);
		}
		if ((g_no_mouse == 0)) {
			p_clipsprite(8, 192, 288, 32, 32);
			p_displaytransparentsprite(8, v_mouse_x, v_mouse_y);
		}
		p_flipbuffers(1);
		if ((p_keyboardpushed(274) || (v_jay == 1))) {
			if ((g_akt_zauber < (g_anz_zauber - 1))) {
				g_akt_zauber = (g_akt_zauber + 1);
				p_delay(50);
			}
		}
		if ((p_keyboardpushed(273) || (v_jay == -1))) {
			if ((g_akt_zauber > 0)) {
				g_akt_zauber = (g_akt_zauber - 1);
				p_delay(50);
			}
		}
		g_mauszauber = 0;
		v_y = 52;
		v_aktuell = 1;
		if (((v_mouse_x > 365) && (v_mouse_x < 574))) {
			for (v_i = 1; v_i <= g_anzz; v_i += 1) {
				if (((v_mouse_y >= v_y) && (v_mouse_y <= (v_y + g_yplus)))) {
					g_mauszauber = v_aktuell;
				}
				v_y = (v_y + g_yplus);
				v_aktuell = (v_aktuell + 1);
			}
		}
		v_raushier = 0;
		if (((v_mouse_links == 1) && (g_mauszauber > 0))) {
			v_raushier = 1;
		}
		if ((a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2] != "Abbrechen")) {
			if (p_keyboardpushed(49)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(1, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(50)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(2, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(51)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(3, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(52)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(4, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(53)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(5, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(54)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(6, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(55)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(7, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(56)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(8, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(57)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(9, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_keyboardpushed(48)) {
				for (v_i = 1; v_i <= 10; v_i += 1) {
					if ((a_schnellzauber(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber(10, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
		}
		if ((g_joystick_used == 1)) {
			if (p_joystickbutton(5)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(1, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(6)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(2, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(7)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(3, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(8)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(4, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(9)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(5, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(10)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(6, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(11)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(7, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
			if (p_joystickbutton(12)) {
				for (v_i = 1; v_i <= 8; v_i += 1) {
					if ((a_schnellzauber2(v_i, g_akt_spieler) == a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2])) {
						a_schnellzauber2(v_i, g_akt_spieler) = " ";
					}
				}
				a_schnellzauber2(8, g_akt_spieler) = a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[2];
			}
		}
	} while (!(((((v_raushier == 1) || (v_mouse_rechts == 1)) || p_keyboardpushed(13)) || p_keyboardpushed(27)) || (v_jb1 != 0)));
	if ((p_keyboardpushed(13) || (v_jb1 != 0))) {
		g_schriftrolle = 0;
		p_cast_it();
	}
	if ((v_raushier == 1)) {
		for (v_k = 1; v_k <= 3; v_k += 1) {
			a_zauberliste((g_akt_zauber + g_akt_zauber_offset)).f_name[v_k] = a_zauberliste((((g_akt_zauber + g_akt_zauber_offset) + g_mauszauber) - 14)).f_name[v_k];
		}
		g_schriftrolle = 0;
		p_cast_it();
	}
	a_spieler(g_akt_spieler).f_pos_zaubermenue = g_akt_zauber;
}

static int32_t p_zeige_unsichtbare(int16_t v_x_r, int16_t v_y_r) {
	int16_t v_sprite_x = 0;
	int16_t v_sprite_y = 0;
	int16_t v_xx = 0;
	int16_t v_yy = 0;
	int32_t v_zw = 0;
	v_xx = 0;
	v_yy = 0;
	if ((p_hat_eigenschaft(v_x_r, v_y_r, 19) == 1)) {
		if ((v_x_r > a_spieler(g_akt_spieler).f_character_x)) {
			v_xx = 1;
		}
		if ((v_x_r < a_spieler(g_akt_spieler).f_character_x)) {
			v_xx = -1;
		}
		if ((v_y_r > a_spieler(g_akt_spieler).f_character_y)) {
			v_yy = 1;
		}
		if ((v_y_r < a_spieler(g_akt_spieler).f_character_y)) {
			v_yy = -1;
		}
		v_zw = a_laby_monster(v_x_r, v_y_r).f_graphic[a_spieler(g_akt_spieler).f_level];
		v_sprite_x = v_zw;
		v_sprite_y = 0;
		if ((v_sprite_x > 10)) {
			do {
				v_sprite_y = (v_sprite_y + 1);
				v_sprite_x = (v_sprite_x - 10);
			} while (!(v_sprite_x < 11));
		}
		p_clipsprite(9, ((v_sprite_x * 32) - 32), (v_sprite_y * 32), 32, 32);
		p_displaytransparentsprite(9, (160 + (v_xx * 32)), (160 + (v_yy * 32)));
	}
}

static int32_t p_zerstoeren(int32_t v_feld) {
	if ((p_okaybox(v_feld) == 1)) {
		if ((a_inventory(v_feld, g_akt_spieler).f_benutzt == 0)) {
			p_leeren(v_feld);
		} else {
			p_nachricht(719, 1);
		}
	}
}

static int32_t p_zerstoert(int16_t v_x, int16_t v_y) {
	int16_t v_explo = 0;
	int32_t v_inhalt_x = 0;
	int32_t v_inhalt_y = 0;
	std::string v_willi;
	if ((p_istmonster((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y)) == 1)) {
		v_explo = 0;
		if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y), 42) > 0)) {
			v_explo = 1;
		}
		a_spieler(g_akt_spieler).f_mks = (a_spieler(g_akt_spieler).f_mks + 1);
		v_willi = " ";
		v_willi = (a_monster(a_laby_monster((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y)).f_name[a_spieler(g_akt_spieler).f_level]).f_name[(1 + g_sprache)] + a_nachricht_text(627, (g_sprache + 1)));
		p_lernen((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y));
		if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y), 30) > 0)) {
			p_setmonster((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y), a_spieler(g_akt_spieler).f_level, 0, 0, 0, 0, 0);
		} else {
			p_hinterlassen((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y));
		}
		if ((p_hat_eigenschaft((a_spieler(g_akt_spieler).f_character_x + v_x), (a_spieler(g_akt_spieler).f_character_y + v_y), 30) > 0)) {
			p_clipsprite(1, 64, 224, 32, 32);
			p_displaysprite(1, (160 + (v_x * 32)), (160 + (v_y * 32)));
		} else {
			p_clipsprite(1, (v_inhalt_x * 32), (v_inhalt_y * 32), 32, 32);
			p_displaysprite(1, (160 + (v_x * 32)), (160 + (v_y * 32)));
		}
		p_laby_screen2();
		p_nachricht7(v_willi, 3);
		if ((a_skills(103, g_akt_spieler).f_gewaehlt == 1)) {
			if ((p_random(100) < (200 / a_spieler(g_akt_spieler).f_maxlifepoints))) {
				a_spieler(g_akt_spieler).f_maxlifepoints = (a_spieler(g_akt_spieler).f_maxlifepoints + 1);
				p_nachricht(321, 5);
			}
		}
		if ((a_skills(104, g_akt_spieler).f_gewaehlt == 1)) {
			if ((p_random(100) < (200 / a_spieler(g_akt_spieler).f_maxmana))) {
				a_spieler(g_akt_spieler).f_maxmana = (a_spieler(g_akt_spieler).f_maxmana + 1);
				p_nachricht(322, 5);
			}
		}
		if ((v_explo == 1)) {
			g_spell_x = v_x;
			g_spell_y = v_y;
			p_explodiert();
		}
	}
}

static int32_t p_zug_verlieren() {
	int32_t v_i = 0;
	if ((p_habich(158) == 0)) {
		g_aktion = 1;
	} else {
		for (v_i = 1; v_i <= 15; v_i += 1) {
			if ((a_aktive(v_i, g_akt_spieler).f_dauer == 9998)) {
				a_aktive(v_i, g_akt_spieler).f_dauer = 0;
				a_aktive(v_i, g_akt_spieler).f_nr = 0;
				a_aktive(v_i, g_akt_spieler).f_staerke = 0;
			}
		}
	}
}

static int32_t p_zwischenbild() {
	int32_t v_wohin = 0;
	if ((g_zw_bild != 0)) {
		g_schongemalt = 1;
		v_wohin = p_screenoutput();
		p_startdrawing(v_wohin);
		p_frontcolor(p_rgb(0, 0, 0));
		p_box(400, 110, 150, 50, -1);
		p_stopdrawing();
		p_laby_rahmen();
		p_show_logo();
		switch (g_zw_bild) {
		case 1:
			p_hilfe();
			break;
		case 2:
			p_inv();
			p_laby_screen();
			if ((g_aktion == 1)) {
				throw Lv_nach_zauber;
			}
			break;
		case 3:
			p_zaubern();
			p_laby_screen();
			if ((g_aktion == 1)) {
				throw Lv_nach_zauber;
			}
			break;
		case 4:
			if (((a_skills(111, g_akt_spieler).f_gewaehlt == 1) && (a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level] == 73))) {
				p_nachricht(5, 2);
				if (((a_spieler(g_akt_spieler).f_level + 1) > a_spieler(g_akt_spieler).f_maxlevel)) {
					p_aufsteigen(1);
				}
				p_neuer_level();
				p_naechster();
			}
			break;
		case 5:
			p_optionen();
			p_laby_screen();
			break;
		case 6:
			p_character_info();
			p_laby_screen();
			break;
		case 7:
			p_monsterkunde();
			p_laby_screen();
			break;
		case 8:
			if ((a_spieler(g_akt_spieler).f_schleichen == 0)) {
				a_spieler(g_akt_spieler).f_schleichen = 1;
				if ((a_spieler(g_akt_spieler).f_speed > p_maxspeed())) {
					a_spieler(g_akt_spieler).f_speed = p_maxspeed();
				}
			} else {
				a_spieler(g_akt_spieler).f_schleichen = 0;
			}
			p_laby_screen();
			p_flipbuffers(1);
			p_delay(g_mydelay);
			break;
		case 9:
			p_bogen();
			p_laby_screen();
			if ((g_aktion == 1)) {
				throw Lv_nach_zauber;
			}
			break;
		case 10:
			p_stehlen();
			p_laby_screen();
			if ((g_aktion == 1)) {
				throw Lv_nach_zauber;
			}
			break;
		case 11:
			if ((a_skills(92, g_akt_spieler).f_gewaehlt == 1)) {
				p_mystisch();
				p_laby_screen();
				if ((g_aktion == 1)) {
					throw Lv_nach_zauber;
				}
			}
			break;
		case 12:
			p_show_automap();
			break;
		case 13:
			p_show_old_messages();
			break;
		}
		g_zw_bild = 0;
	}
}

int main() {
	enum label gotolabel = NOLABEL;
	init_random();
	init_text();
	DISPATCH: try {
		switch (gotolabel) {
		case NOLABEL: break;
		case Lv_again: goto L_again;
		case Lv_geladen: goto L_geladen;
		case Lv_nach_zauber: goto L_nach_zauber;
		}
		a_labyrinth.dim(202, 202);
		a_labyrinth2.dim(2, 2);
		a_laby_monster.dim(202, 202);
		a_laby_monster2.dim(2, 2);
		a_laby_item.dim(202, 202);
		a_laby_item2.dim(2, 2);
		a_raeume.dim(152);
		a_raumx.dim(152);
		a_raumy.dim(152);
		a_eingangx.dim(152);
		a_eingangy.dim(152);
		a_ausgangx.dim(152);
		a_ausgangy.dim(152);
		a_sonderlevel.dim(152);
		a_levelmod.dim(152);
		a_groesse.dim(152);
		a_inhalt.dim(152);
		a_mit_was.dim(152);
		a_visionen.dim(152);
		a_fluss.dim(152);
		a_spinnenkoenigin.dim(152);
		a_goblinkoenig.dim(152);
		a_untotenherr.dim(152);
		a_automap.dim(202, 202);
		a_aktive.dim(17, 5);
		a_skills.dim(143, 5);
		a_unmoeglich.dim(218);
		a_hscores.dim(32);
		a_inventory.dim(52, 5);
		a_new_item.dim(2);
		a_gegenstand.dim(408);
		a_zauber.dim(201, 5);
		a_mischen.dim(39);
		a_monster.dim(179);
		a_pilz.dim(22);
		a_zauberliste.dim(501);
		a_old_messages.dim(26, 5);
		a_creature.dim(16);
		a_sprache.dim(3);
		a_sprache(0).f_buttonpos = 34;
		a_sprache(1).f_buttonpos = 68;
		a_sprache(2).f_buttonpos = 612;
		g_gb_callfromtitlescreen = 0;
		g_test = 0;
		g_win_mode = 1;
		g_nr_of_saves = 0;
		g_flaschen = 1;
		g_released = 1;
		g_roomtest = 0;
		g_itemmenue_aktiv = 0;
		g_joystick_used = 0;
		g_no_mouse = 0;
		g_knopf5 = 0;
		g_mit_was_normal = 1;
		g_inhalt_normal = 4;
		g_bewegen = 0;
		g_aktuell = 0;
		g_akt_spieler = 1;
		g_anz_levels = 0;
		g_frame = 0;
		v_framestep = 0;
		g_xmod = 0;
		g_ymod = 0;
		v_messages = "";
		g_sprache = 0;
		g_zw_bild = 0;
		v_angreifen = 1;
		v_nach_kampf = 0;
		g_punkte = 0;
		g_bewegt = 0;
		g_anz_spieler = 1;
		g_von_ferne = 0;
		g_mydelay = 600;
		g_mydelay2 = 0;
		g_mydelay3 = 30;
		g_mydelay4 = 0;
		g_autopickup = 1;
		g_keydelay = 15;
		g_keydelay2 = 3;
		g_selectdelay = 150;
		g_schutz_min = 0;
		g_schutz_max = 0;
		g_behinderung = 0;
		g_anfangszeit = " ";
		g_skills_menu = 1;
		g_maennchen_menu = 1;
		g_cinfo_menu = 1;
		g_letzter_eintrag = 0;
		g_anz_zauber = 0;
		g_akt_option = 1;
		g_do_it = 0;
		g_do_it2 = 0;
		g_do_it3 = 0;
		g_do_it4 = 0;
		g_sound = 1;
		g_music = 1;
		g_klicking = 1;
		g_punkte = 7;
		g_adcount = 1;
		g_admax = 10;
		g_abbrechen = 0;
		v_room_cursprite_nr = -1;
		v_room_curtext_nr = -1;
		v_room_curtext = "";
		g_no_room_intro = 0;
		g_monsterauge = 0;
		g_over_item = 0;
		g_warten = 0;
		a_haendler_objekte.dim(41, 151);
		a_haendler_schriftrolle.dim(41, 151);
		a_haendler_staerke.dim(41, 151);
		a_spieler.dim(5);
		a_nachricht_text.dim(1001, 4);
		a_xsprites.dim(21);
		a_ysprites.dim(21);
		a_fsprites.dim(21);
		a_rsprites.dim(21);
		a_optionenliste.dim(131);
		a_schnellzauber.dim(11, 5);
		a_schnellzauber2.dim(9, 5);
		a_savenames.dim(11);
		a_savedatum.dim(11);
		a_addelay.dim(((g_admax + 10) + 1));
		a_addelaymax.dim(((g_admax + 10) + 1));
		a_matrix.dim(13, 13);
		a_matrix2.dim(13, 13);
		a_summoning.dim(178);
		a_nachricht_text(1, 1) = "You sneak by!";
		a_nachricht_text(1, 2) = "Du schleichst vorbei!";
		a_nachricht_text(1, 3) = "Has pasado!";
		a_nachricht_text(2, 1) = "You were spotted!";
		a_nachricht_text(2, 2) = "Du wurdest bemerkt!";
		a_nachricht_text(2, 3) = "Has sido descubierto!";
		a_nachricht_text(3, 1) = "The Iceblock is too strong!";
		a_nachricht_text(3, 2) = "Der Eisblock ist zu hart!";
		a_nachricht_text(3, 3) = "El bloque de hielo es demasiado fuerte!";
		a_nachricht_text(4, 1) = "An ambush!";
		a_nachricht_text(4, 2) = "Ein Hinterhalt!";
		a_nachricht_text(4, 3) = "Una emboscada!";
		a_nachricht_text(5, 1) = "You climb down!";
		a_nachricht_text(5, 2) = "Du kletterst hinab!";
		a_nachricht_text(5, 3) = "Desciendes!";
		a_nachricht_text(6, 1) = "You found: ";
		a_nachricht_text(6, 2) = "Du findest: ";
		a_nachricht_text(6, 3) = "Has encontrado: ";
		a_nachricht_text(7, 1) = "Curse of leprechaun!";
		a_nachricht_text(7, 2) = "Fluch des Leprechaun!";
		a_nachricht_text(7, 3) = "Maldicion de Leprechaun!";
		a_nachricht_text(8, 1) = " gold";
		a_nachricht_text(8, 2) = " Goldst\374cke";
		a_nachricht_text(8, 3) = " oro";
		a_nachricht_text(9, 1) = "Curse of Seth!";
		a_nachricht_text(9, 2) = "Fluch des Seth!";
		a_nachricht_text(9, 3) = "Maldicion de Seth!";
		a_nachricht_text(10, 1) = "You found a mushroom!";
		a_nachricht_text(10, 2) = "Du findest einen Pilz!";
		a_nachricht_text(10, 3) = "Encuentras una seta!";
		a_nachricht_text(11, 1) = "You refill your water!";
		a_nachricht_text(11, 2) = "Du f\374llst dein Wasser auf!";
		a_nachricht_text(11, 3) = "Llenas tu agua";
		a_nachricht_text(12, 1) = "Your offering has been accepted!!!";
		a_nachricht_text(12, 2) = "Deine Gabe wurde erh\366rt!!!";
		a_nachricht_text(12, 3) = "Tu oferta ha sido aceptada!!!";
		a_nachricht_text(13, 1) = "Your offering was rejected!";
		a_nachricht_text(13, 2) = "Deine Gabe wurde nicht erh\366rt!";
		a_nachricht_text(13, 3) = "Tu oferta ha sido rechazada!";
		a_nachricht_text(14, 1) = "No Bow/Sling/Arrows/Stones!";
		a_nachricht_text(14, 2) = "Kein Bogen/Schleuder/Pfeile/Steine!";
		a_nachricht_text(14, 3) = "Sin Arco/Honda/Flechas/Piedras!";
		a_nachricht_text(16, 1) = "You missed!";
		a_nachricht_text(16, 2) = "Du verfehlst!";
		a_nachricht_text(16, 3) = "Pierdes";
		a_nachricht_text(17, 1) = "A Speartrap hits you!";
		a_nachricht_text(17, 2) = "Eine Speerfalle trifft dich!";
		a_nachricht_text(17, 3) = "Una Lanza te alcanza!";
		a_nachricht_text(18, 1) = "An Axetrap hits you!";
		a_nachricht_text(18, 2) = "Eine Axtfalle trifft dich!";
		a_nachricht_text(18, 3) = "Un Hacha te alcanza!";
		a_nachricht_text(19, 1) = "A Dart hits you!";
		a_nachricht_text(19, 2) = "Eine Pfeilfalle trifft dich!";
		a_nachricht_text(19, 3) = "Un Dardo te alcanza!";
		a_nachricht_text(20, 1) = "A Rune Trap Hits you!";
		a_nachricht_text(20, 2) = "Eine Runenfalle trifft dich!";
		a_nachricht_text(20, 3) = "Una Runa te alcanza!";
		a_nachricht_text(21, 1) = "You are protected against Runetraps!";
		a_nachricht_text(21, 2) = "Du bist gegen Runenfallen gesch\374tzt!";
		a_nachricht_text(21, 3) = "Estas protegido contra Runas!";
		a_nachricht_text(22, 1) = "You fall into a Trapdoor!";
		a_nachricht_text(22, 2) = "Du st\374rzt in eine Fallgrube!";
		a_nachricht_text(22, 3) = "Caes en una trampilla!";
		a_nachricht_text(23, 1) = "A Rune steals your mana!";
		a_nachricht_text(23, 2) = "Eine Rune stiehlt dein Mana!";
		a_nachricht_text(23, 3) = "Una Runa te ha robado el Mana!";
		a_nachricht_text(24, 1) = "An arrow gets fired at you!";
		a_nachricht_text(24, 2) = "Ein Pfeil wird auf dich abgefeuert!";
		a_nachricht_text(24, 3) = "Se lanza una Flecha a ti!";
		a_nachricht_text(25, 1) = "You are protected against arrows!";
		a_nachricht_text(25, 2) = "Du bist vor Geschossen gesch\374tzt!";
		a_nachricht_text(25, 3) = "Estas protegido contra flechas!";
		a_nachricht_text(26, 1) = "You evaded a hostile spell!";
		a_nachricht_text(26, 2) = "Du hast einen fremden Zauber abgewehrt!";
		a_nachricht_text(26, 3) = "Has evadido un hechizo enemigo!";
		a_nachricht_text(27, 1) = "A fireball gets fired at you!";
		a_nachricht_text(27, 2) = "Ein Feuerball wird auf dich geworfen!";
		a_nachricht_text(27, 3) = "Se lanza una bola de Fuego a ti!";
		a_nachricht_text(28, 1) = "You are protected against fire!";
		a_nachricht_text(28, 2) = "Du bist gegen Feuer gesch\374tzt!";
		a_nachricht_text(28, 3) = "Estas protegido contra el fuego!";
		a_nachricht_text(29, 1) = "You get cursed!";
		a_nachricht_text(29, 2) = "Ein Fluch trifft dich!";
		a_nachricht_text(29, 3) = "Has sido maldito!";
		a_nachricht_text(30, 1) = "A spell steals an item from you!";
		a_nachricht_text(30, 2) = "Ein Zauber raubt dir einen Gegenstand!";
		a_nachricht_text(30, 3) = "Un hechizo te roba un objeto!";
		a_nachricht_text(31, 1) = "A spell steals your mana!";
		a_nachricht_text(31, 2) = "Ein Zauber raubt dir Mana!";
		a_nachricht_text(31, 3) = "Un hechizo te roba tu Mana!";
		a_nachricht_text(32, 1) = "A spell steals your LPs!";
		a_nachricht_text(32, 2) = "Ein Zauber raubt dir LPs!";
		a_nachricht_text(32, 3) = "Un hechizo te roba tus PVs!";
		a_nachricht_text(33, 1) = "The Head explodes!";
		a_nachricht_text(33, 2) = "Der Kopf zerspringt!";
		a_nachricht_text(33, 3) = "La Cabeza explota!";
		a_nachricht_text(34, 1) = "The Staff explodes!";
		a_nachricht_text(34, 2) = "Der Zauberstab zerspringt!";
		a_nachricht_text(34, 3) = "El Baston explota!";
		a_nachricht_text(35, 1) = "Only once per level!";
		a_nachricht_text(35, 2) = "Nur einmal pro Ebene!";
		a_nachricht_text(35, 3) = "Solo una vez por nivel!";
		a_nachricht_text(36, 1) = "The monster calls for backup!";
		a_nachricht_text(36, 2) = "Das Monster holt Verst\344rkung!";
		a_nachricht_text(36, 3) = "El Monstruo pide ayuda!";
		a_nachricht_text(37, 1) = "Nothing could be robbed!";
		a_nachricht_text(37, 2) = "Nichts konnte gestohlen werden!";
		a_nachricht_text(37, 3) = "No se pudo robarte!";
		a_nachricht_text(38, 1) = "It tastes awful!";
		a_nachricht_text(38, 2) = "Schmeckt wiederlich!";
		a_nachricht_text(38, 3) = "Su sabor es asqueroso!";
		a_nachricht_text(39, 1) = "You feel better!";
		a_nachricht_text(39, 2) = "Du f\374hlst dich besser!";
		a_nachricht_text(39, 3) = "Te encuentras mejor!";
		a_nachricht_text(40, 1) = "You are poisoned!";
		a_nachricht_text(40, 2) = "Du hast dich vergiftet!";
		a_nachricht_text(40, 3) = "Estas envenenado!";
		a_nachricht_text(41, 1) = "You lose your strength!";
		a_nachricht_text(41, 2) = "Du verlierst deine Kraft!";
		a_nachricht_text(41, 3) = "Pierdes la fuerza!";
		a_nachricht_text(42, 1) = "You are paralysed!";
		a_nachricht_text(42, 2) = "Du bist paralysiert!";
		a_nachricht_text(42, 3) = "Estas paralizado!";
		a_nachricht_text(43, 1) = "Your Mana is coming back!";
		a_nachricht_text(43, 2) = "Dein Mana kehrt zur\374ck!";
		a_nachricht_text(43, 3) = "Estas recuperando el Mana!";
		a_nachricht_text(44, 1) = "You steal ";
		a_nachricht_text(44, 2) = "Du stiehlst ";
		a_nachricht_text(44, 3) = "Robas ";
		a_nachricht_text(45, 1) = "Only twice per level!";
		a_nachricht_text(45, 2) = "Nur 2 mal pro Ebene!";
		a_nachricht_text(45, 3) = "Solo dos veces por nivel!";
		a_nachricht_text(46, 1) = "You get healed!";
		a_nachricht_text(46, 2) = "Du wirst geheilt!";
		a_nachricht_text(46, 3) = "Te curas!";
		a_nachricht_text(47, 1) = "You get completely healed!";
		a_nachricht_text(47, 2) = "Du wirst vollst\344ndig geheilt!";
		a_nachricht_text(47, 3) = "Te curas totalmente!";
		a_nachricht_text(48, 1) = "The spell did not work!";
		a_nachricht_text(48, 2) = "Der Zauber ist dir misslungen!";
		a_nachricht_text(48, 3) = "El hechizo no ha funcionado!";
		a_nachricht_text(49, 1) = "Only once per level!";
		a_nachricht_text(49, 2) = "Nur einmal pro ebene!";
		a_nachricht_text(49, 3) = "Solo una vez por nivel!";
		a_nachricht_text(50, 1) = "You gain Experience!";
		a_nachricht_text(50, 2) = "Du gewinnst Erfahrung!";
		a_nachricht_text(50, 3) = "Ganas experiencia!";
		a_nachricht_text(51, 1) = "Choose what to advance:";
		a_nachricht_text(51, 2) = "W\344hle Verbesserung:";
		a_nachricht_text(51, 3) = "Escoje la mejora:";
		a_nachricht_text(52, 1) = "Attack:";
		a_nachricht_text(52, 2) = "Angriff:";
		a_nachricht_text(52, 3) = "Ataque:";
		a_nachricht_text(53, 1) = "Dexterity:";
		a_nachricht_text(53, 2) = "Geschick:";
		a_nachricht_text(53, 3) = "Destreza:";
		a_nachricht_text(54, 1) = "Strength:";
		a_nachricht_text(54, 2) = "St\344rke:";
		a_nachricht_text(54, 3) = "Fuerza:";
		a_nachricht_text(55, 1) = "Life Points:";
		a_nachricht_text(55, 2) = "Lebenspunkte:";
		a_nachricht_text(55, 3) = "Puntos de Vida:";
		a_nachricht_text(56, 1) = "Speed:";
		a_nachricht_text(56, 2) = "Geschwindigkeit:";
		a_nachricht_text(56, 3) = "Velocidad:";
		a_nachricht_text(57, 1) = "Perception:";
		a_nachricht_text(57, 2) = "Wahrnehmung:";
		a_nachricht_text(57, 3) = "Percepcion:";
		a_nachricht_text(58, 1) = "Luck:";
		a_nachricht_text(58, 2) = "Gl\374ck:";
		a_nachricht_text(58, 3) = "Suerte:";
		a_nachricht_text(59, 1) = "Mana:";
		a_nachricht_text(59, 2) = "Mana:";
		a_nachricht_text(59, 3) = "Mana:";
		a_nachricht_text(60, 1) = "Spell Power:";
		a_nachricht_text(60, 2) = "Zauberkraft:";
		a_nachricht_text(60, 3) = "Poder de Hechizos:";
		a_nachricht_text(61, 1) = "Spell Circle:";
		a_nachricht_text(61, 2) = "Zirkel:";
		a_nachricht_text(61, 3) = "Circulo de Hechizos:";
		a_nachricht_text(62, 1) = "Your Udjat Eye";
		a_nachricht_text(62, 2) = "Dein Udjat Auge";
		a_nachricht_text(62, 3) = "Tu ojo Udjat";
		a_nachricht_text(63, 1) = "grants you another";
		a_nachricht_text(63, 2) = "garantiert dir eine";
		a_nachricht_text(63, 3) = "te concede otro";
		a_nachricht_text(64, 1) = "Advancement";
		a_nachricht_text(64, 2) = "weitere Verbesserung";
		a_nachricht_text(64, 3) = "Avance";
		a_nachricht_text(65, 1) = "Your deep wisdom";
		a_nachricht_text(65, 2) = "Deine tiefe Weisheit";
		a_nachricht_text(65, 3) = "Tu Sabiduria profunda";
		a_nachricht_text(66, 1) = "A Merchant offers you his goods:";
		a_nachricht_text(66, 2) = "Ein H\344ndler bietet dir seine Waren an:";
		a_nachricht_text(66, 3) = "Un comerciante te ofrece sus bienes:";
		a_nachricht_text(67, 1) = "Help";
		a_nachricht_text(67, 2) = "Hilfe";
		a_nachricht_text(67, 3) = "Ayuda";
		a_nachricht_text(68, 1) = "I: Inventory";
		a_nachricht_text(68, 2) = "I: Inventar";
		a_nachricht_text(68, 3) = "I: Inventario";
		a_nachricht_text(69, 1) = "C: Cast spell";
		a_nachricht_text(69, 2) = "C: Zaubern";
		a_nachricht_text(69, 3) = "C: Lanzar hechizo";
		a_nachricht_text(70, 1) = "D: Character data";
		a_nachricht_text(70, 2) = "D: Charakterdaten";
		a_nachricht_text(70, 3) = "D: Datos del personaje";
		a_nachricht_text(71, 1) = "S: Sneak";
		a_nachricht_text(71, 2) = "S: Schleichen";
		a_nachricht_text(71, 3) = "S: Escaparse";
		a_nachricht_text(72, 1) = "K: Climb";
		a_nachricht_text(72, 2) = "K: Klettern";
		a_nachricht_text(72, 3) = "K: Escalar";
		a_nachricht_text(73, 1) = "P: Pick pocket";
		a_nachricht_text(73, 2) = "P: Stehlen";
		a_nachricht_text(73, 3) = "P: Robar";
		a_nachricht_text(74, 1) = "A: Mystic Attack";
		a_nachricht_text(74, 2) = "A: Mystische Attacke";
		a_nachricht_text(74, 3) = "A:  Ataque Mistico";
		a_nachricht_text(75, 1) = "Continue: Return or Right Mousebutton";
		a_nachricht_text(75, 2) = "Weiter: Return oder rechte Maustaste";
		a_nachricht_text(75, 3) = "Continuar: Intro o Boton derecho";
		a_nachricht_text(76, 1) = "Options";
		a_nachricht_text(76, 2) = "Optionen";
		a_nachricht_text(76, 3) = "Opciones";
		a_nachricht_text(77, 1) = "Moves:";
		a_nachricht_text(77, 2) = "Zugweite:";
		a_nachricht_text(77, 3) = "Movimientos:";
		a_nachricht_text(78, 1) = "Stealth";
		a_nachricht_text(78, 2) = "Schleichen";
		a_nachricht_text(78, 3) = "Cautela";
		a_nachricht_text(79, 1) = "You got a new Highscore!";
		a_nachricht_text(79, 2) = "Du hast es in den Highscore geschafft!";
		a_nachricht_text(79, 3) = "Has conseguido una puntuacion alta!";
		a_nachricht_text(80, 1) = "Please insert your name:";
		a_nachricht_text(80, 2) = "Bitte gib deinen Namen ein:";
		a_nachricht_text(80, 3) = "Por favor, entra tu nombre:";
		a_nachricht_text(81, 1) = "You got a new Highscore!";
		a_nachricht_text(81, 2) = "Ihr habt es in den Highscore geschafft!";
		a_nachricht_text(81, 3) = "Conseguieron una puntuacion alta!";
		a_nachricht_text(82, 1) = "Please insert your names:";
		a_nachricht_text(82, 2) = "Gebt eure Namen ein:";
		a_nachricht_text(82, 3) = "Por favor, entrad vuestros nombres:";
		a_nachricht_text(83, 1) = "You are dead!";
		a_nachricht_text(83, 2) = "Du bist tot!";
		a_nachricht_text(83, 3) = "Estas muerto!";
		a_nachricht_text(84, 1) = "Killed Monsters:";
		a_nachricht_text(84, 2) = "Get\366tete Monster:";
		a_nachricht_text(84, 3) = "Monstruos matados:";
		a_nachricht_text(85, 1) = "Gold:";
		a_nachricht_text(85, 2) = "Goldst\374cke:";
		a_nachricht_text(85, 3) = "Oro:";
		a_nachricht_text(86, 1) = "Encumbrance:";
		a_nachricht_text(86, 2) = "Behinderung:";
		a_nachricht_text(86, 3) = "Estorbos:";
		a_nachricht_text(87, 1) = "Armor:";
		a_nachricht_text(87, 2) = "R\374stung:";
		a_nachricht_text(87, 3) = "Armadura:";
		a_nachricht_text(88, 1) = "Damage:";
		a_nachricht_text(88, 2) = "Schaden:";
		a_nachricht_text(88, 3) = "Dano:";
		a_nachricht_text(89, 1) = "Thirst:";
		a_nachricht_text(89, 2) = "Durst:";
		a_nachricht_text(89, 3) = "Sed:";
		a_nachricht_text(90, 1) = "Hunger:";
		a_nachricht_text(90, 2) = "Hunger:";
		a_nachricht_text(90, 3) = "Hambre:";
		a_nachricht_text(91, 1) = "Power:";
		a_nachricht_text(91, 2) = "Macht:";
		a_nachricht_text(91, 3) = "Poder:";
		a_nachricht_text(92, 1) = "Your character data:";
		a_nachricht_text(92, 2) = "Deine Characterdaten:";
		a_nachricht_text(92, 3) = "Datos de tu personaje:";
		a_nachricht_text(93, 1) = "Points";
		a_nachricht_text(93, 2) = "Punkte";
		a_nachricht_text(93, 3) = "Puntos";
		a_nachricht_text(94, 1) = "Thirsty";
		a_nachricht_text(94, 2) = "Durstig";
		a_nachricht_text(94, 3) = "Sediento";
		a_nachricht_text(95, 1) = "Very Thirsty";
		a_nachricht_text(95, 2) = "Sehr Durstig";
		a_nachricht_text(95, 3) = "Muy Sediento";
		a_nachricht_text(96, 1) = "Dehydrated";
		a_nachricht_text(96, 2) = "Am verdursten";
		a_nachricht_text(96, 3) = "Estas muriendo de sed";
		a_nachricht_text(97, 1) = "Hungry";
		a_nachricht_text(97, 2) = "Hungrig";
		a_nachricht_text(97, 3) = "Hambriento";
		a_nachricht_text(98, 1) = "Very Hungry";
		a_nachricht_text(98, 2) = "Sehr Hungrig";
		a_nachricht_text(98, 3) = "Muy Hambriento";
		a_nachricht_text(99, 1) = "Starving";
		a_nachricht_text(99, 2) = "Am verhungern";
		a_nachricht_text(99, 3) = "Estas muriendo de Hambre";
		a_nachricht_text(100, 1) = "Choose Spell";
		a_nachricht_text(100, 2) = "W\344hle Zauber";
		a_nachricht_text(100, 3) = "Escoje el Hechizo";
		a_nachricht_text(101, 1) = "Cost:";
		a_nachricht_text(101, 2) = "Kosten:";
		a_nachricht_text(101, 3) = "Coste:";
		a_nachricht_text(102, 1) = "Duration:";
		a_nachricht_text(102, 2) = "Dauer:";
		a_nachricht_text(102, 3) = "Duracion:";
		a_nachricht_text(103, 1) = "Chance:";
		a_nachricht_text(103, 2) = "Chance:";
		a_nachricht_text(103, 3) = "Oportunidades:";
		a_nachricht_text(104, 1) = "    Choose an item to turn to gold:";
		a_nachricht_text(104, 2) = "W\344hle einen Gegenstand zum verwandeln:";
		a_nachricht_text(104, 3) = "Escoje un Objeto para cambiarlo en oro:";
		a_nachricht_text(105, 1) = "Your Gold: ";
		a_nachricht_text(105, 2) = "Dein Gold: ";
		a_nachricht_text(105, 3) = "Tu Oro:";
		a_nachricht_text(106, 1) = "Start game";
		a_nachricht_text(106, 2) = "Spiel starten";
		a_nachricht_text(106, 3) = "Comenzar";
		a_nachricht_text(107, 1) = "German";
		a_nachricht_text(107, 2) = "Deutsch";
		a_nachricht_text(107, 3) = "Aleman";
		a_nachricht_text(108, 1) = "English";
		a_nachricht_text(108, 2) = "Englisch";
		a_nachricht_text(108, 3) = "Ingles";
		a_nachricht_text(109, 1) = "Highscores";
		a_nachricht_text(109, 2) = "Highscores";
		a_nachricht_text(109, 3) = "Highscores";
		a_nachricht_text(110, 1) = "Credits";
		a_nachricht_text(110, 2) = "Credits";
		a_nachricht_text(110, 3) = "Creditos";
		a_nachricht_text(111, 1) = "Quit";
		a_nachricht_text(111, 2) = "Beenden";
		a_nachricht_text(111, 3) = "Salir";
		a_nachricht_text(112, 1) = "Choose number of players";
		a_nachricht_text(112, 2) = "W\344hle Anzahl Spieler";
		a_nachricht_text(112, 3) = "Escoje numero de jugadores";
		a_nachricht_text(113, 1) = "Player";
		a_nachricht_text(113, 2) = "Spieler";
		a_nachricht_text(113, 3) = "Jugador";
		a_nachricht_text(114, 1) = "            Choose your skills (Player ";
		a_nachricht_text(114, 2) = "Suche deine Eigenschaften aus (Spieler ";
		a_nachricht_text(114, 3) = "       Escoje tus habilidades (Jugador ";
		a_nachricht_text(115, 1) = "Name: ";
		a_nachricht_text(115, 2) = "Name: ";
		a_nachricht_text(115, 3) = "Nombre: ";
		a_nachricht_text(116, 1) = "Type: ";
		a_nachricht_text(116, 2) = "Art: ";
		a_nachricht_text(116, 3) = "Tipo: ";
		a_nachricht_text(117, 1) = "Attack/Defence: ";
		a_nachricht_text(117, 2) = "Angriff/Abwehr: ";
		a_nachricht_text(117, 3) = "Ataque/Defensa: ";
		a_nachricht_text(118, 1) = "Animal";
		a_nachricht_text(118, 2) = "Tier";
		a_nachricht_text(118, 3) = "Animal";
		a_nachricht_text(119, 1) = "Human";
		a_nachricht_text(119, 2) = "Mensch";
		a_nachricht_text(119, 3) = "Humano";
		a_nachricht_text(120, 1) = "Undead";
		a_nachricht_text(120, 2) = "Untoter";
		a_nachricht_text(120, 3) = "No-muerto";
		a_nachricht_text(121, 1) = "Plant";
		a_nachricht_text(121, 2) = "Pflanze";
		a_nachricht_text(121, 3) = "Planta";
		a_nachricht_text(122, 1) = "The nameless Curse";
		a_nachricht_text(122, 2) = "Der Namenlose Fluch";
		a_nachricht_text(122, 3) = "La maldicion sin nombre";
		a_nachricht_text(123, 1) = "prevents you";
		a_nachricht_text(123, 2) = "verhindert deinen";
		a_nachricht_text(123, 3) = "te evita";
		a_nachricht_text(124, 1) = "from gaining experience!";
		a_nachricht_text(124, 2) = "Erfahrungsgewinn!";
		a_nachricht_text(124, 3) = "ganar experiencia!";
		a_nachricht_text(125, 1) = "Your stupidity";
		a_nachricht_text(125, 2) = "Deine Dummheit";
		a_nachricht_text(125, 3) = "Tu estupidez";
		a_nachricht_text(126, 1) = "This is your end!";
		a_nachricht_text(126, 2) = "Das ist dein Ende!";
		a_nachricht_text(126, 3) = "Este es tu fin!";
		a_nachricht_text(127, 1) = "A mighty Firedemon";
		a_nachricht_text(127, 2) = "Ein m\344chtiger Feuerd\344mon";
		a_nachricht_text(127, 3) = "Un poderoso Diablo de Fuego";
		a_nachricht_text(128, 1) = "materializes and wants to";
		a_nachricht_text(128, 2) = "steigt empor und will dir";
		a_nachricht_text(128, 3) = "se materializa y quiere";
		a_nachricht_text(129, 1) = "take your life!";
		a_nachricht_text(129, 2) = "dein Leben nehmen!";
		a_nachricht_text(129, 3) = "llevarse tu vida!";
		a_nachricht_text(130, 1) = "Spanish";
		a_nachricht_text(130, 2) = "Spanisch";
		a_nachricht_text(130, 3) = "Espanol";
		a_nachricht_text(131, 1) = "nameless curse";
		a_nachricht_text(131, 2) = "Der namelose Fluch";
		a_nachricht_text(131, 3) = "Maldicion sin nombre";
		a_nachricht_text(132, 1) = "curse of tiamat";
		a_nachricht_text(132, 2) = "Fluch der Tiamat";
		a_nachricht_text(132, 3) = "Maldicion del Tiamat";
		a_nachricht_text(133, 1) = "curse of hekate";
		a_nachricht_text(133, 2) = "Fluch der Hekate";
		a_nachricht_text(133, 3) = "Maldicion del Hekate";
		a_nachricht_text(134, 1) = "curse of ares";
		a_nachricht_text(134, 2) = "Fluch des Ares";
		a_nachricht_text(134, 3) = "Maldicion del Ares";
		a_nachricht_text(135, 1) = "curse paralyse";
		a_nachricht_text(135, 2) = "Fluch Paralyse";
		a_nachricht_text(135, 3) = "Paralisis";
		a_nachricht_text(136, 1) = "curse of artemis";
		a_nachricht_text(136, 2) = "Fluch der Artemis";
		a_nachricht_text(136, 3) = "Maldicion de Artemis";
		a_nachricht_text(137, 1) = "curse of achilles";
		a_nachricht_text(137, 2) = "Fluch des Achilles";
		a_nachricht_text(137, 3) = "Maldicion de Achilles";
		a_nachricht_text(138, 1) = "curse blindness";
		a_nachricht_text(138, 2) = "Fluch Blindheit";
		a_nachricht_text(138, 3) = "Ciego";
		a_nachricht_text(139, 1) = "curse of hephaistos";
		a_nachricht_text(139, 2) = "Fluch des Hephaistos";
		a_nachricht_text(139, 3) = "Maldicion del Hephaistos";
		a_nachricht_text(140, 1) = "curse of hades";
		a_nachricht_text(140, 2) = "Fluch des Hades";
		a_nachricht_text(140, 3) = "Maldicion del Hades";
		a_nachricht_text(141, 1) = "curse of seth";
		a_nachricht_text(141, 2) = "Fluch des Seth";
		a_nachricht_text(141, 3) = "Maldicion del Seth";
		a_nachricht_text(142, 1) = "curse of apophis";
		a_nachricht_text(142, 2) = "Fluch des Apophis";
		a_nachricht_text(142, 3) = "Maldicion del Apophis";
		a_nachricht_text(143, 1) = "curse of dagda";
		a_nachricht_text(143, 2) = "Fluch des Dagda";
		a_nachricht_text(143, 3) = "Maldicion del Dagda";
		a_nachricht_text(144, 1) = "curse of naiaden";
		a_nachricht_text(144, 2) = "Fluch der Naiaden";
		a_nachricht_text(144, 3) = "Maldicion del Naiaden";
		a_nachricht_text(145, 1) = "curse of osiris";
		a_nachricht_text(145, 2) = "Fluch des Osiris";
		a_nachricht_text(145, 3) = "Maldicion del Osiris";
		a_nachricht_text(146, 1) = "curse of leprechaun";
		a_nachricht_text(146, 2) = "Fluch des Leprechaun";
		a_nachricht_text(146, 3) = "Maldicion del Leprechaun";
		a_nachricht_text(147, 1) = "curse of marduk";
		a_nachricht_text(147, 2) = "Fluch des Marduk";
		a_nachricht_text(147, 3) = "Maldicion del Marduk";
		a_nachricht_text(148, 1) = "curse of astarte";
		a_nachricht_text(148, 2) = "Fluch der Astarte";
		a_nachricht_text(148, 3) = "Maldicion del Astarte";
		a_nachricht_text(149, 1) = "curse of poseidon";
		a_nachricht_text(149, 2) = "Fluch des Poseidon";
		a_nachricht_text(149, 3) = "Maldicion del Poseidon";
		a_nachricht_text(150, 1) = "curse of tanis";
		a_nachricht_text(150, 2) = "Fluch der Tanis";
		a_nachricht_text(150, 3) = "Maldicion del Tanis";
		a_nachricht_text(151, 1) = "curse of athene";
		a_nachricht_text(151, 2) = "Fluch der Athene";
		a_nachricht_text(151, 3) = "Maldicion del Athene";
		a_nachricht_text(152, 1) = "curse of morrigu";
		a_nachricht_text(152, 2) = "Fluch der Morrigu";
		a_nachricht_text(152, 3) = "Maldicion del Morrigu";
		a_nachricht_text(153, 1) = "Chickencurse";
		a_nachricht_text(153, 2) = "H\374hnerfluch";
		a_nachricht_text(153, 3) = "Maldicion del Pollo";
		a_nachricht_text(154, 1) = "Name";
		a_nachricht_text(154, 2) = "Name";
		a_nachricht_text(154, 3) = "Nombre";
		a_nachricht_text(155, 1) = "Killed Monsters";
		a_nachricht_text(155, 2) = "Get\366tete Monster";
		a_nachricht_text(155, 3) = "Monstruos Matados";
		a_nachricht_text(156, 1) = "Gold";
		a_nachricht_text(156, 2) = "Gold";
		a_nachricht_text(156, 3) = "Oro";
		a_nachricht_text(157, 1) = "You enter a Cavern made of Ice.";
		a_nachricht_text(157, 2) = "Du betrittst eine Eiskaverne.";
		a_nachricht_text(157, 3) = "Entras una Cueva de Hielo.";
		a_nachricht_text(158, 1) = "You shiver immediately.";
		a_nachricht_text(158, 2) = "Dir wird sofort bitterkalt.";
		a_nachricht_text(158, 3) = "Empiezas a sentir mucho frio.";
		a_nachricht_text(159, 1) = "Will you find a frosty death";
		a_nachricht_text(159, 2) = "Wirst du hier einen frostigen";
		a_nachricht_text(159, 3) = "Vas a morir de congelado aqui?";
		a_nachricht_text(160, 1) = "here?";
		a_nachricht_text(160, 2) = "Tod finden?";
		a_nachricht_text(160, 3) = "";
		a_nachricht_text(161, 1) = "You enter a Cavern made of Fire.";
		a_nachricht_text(161, 2) = "Du betrittst eine Feuerkaverne.";
		a_nachricht_text(161, 3) = "Entras una Cueva de Fuego.";
		a_nachricht_text(162, 1) = "You immediately start to sweat.";
		a_nachricht_text(162, 2) = "Du beginst sofort zu schwitzen.";
		a_nachricht_text(162, 3) = "Empiezas a sentir mucho calor.";
		a_nachricht_text(163, 1) = "Will you find a hot death";
		a_nachricht_text(163, 2) = "Wirst du hier einen feurigen";
		a_nachricht_text(163, 3) = "Vas a morir de quemado aqui?";
		a_nachricht_text(164, 1) = "here?";
		a_nachricht_text(164, 2) = "Tod finden?";
		a_nachricht_text(164, 3) = "";
		a_nachricht_text(165, 1) = "You enter a gigantic Graveyard.";
		a_nachricht_text(165, 2) = "Du betrittst einen riesigen Friedhof.";
		a_nachricht_text(165, 3) = "Entras en un enorme cementerio.";
		a_nachricht_text(166, 1) = "You can smell the Death here.";
		a_nachricht_text(166, 2) = "Du kannst den Tod hier riechen.";
		a_nachricht_text(166, 3) = "Puedes oler la muerte en este sitio.";
		a_nachricht_text(167, 1) = "Will you join the Dead here?";
		a_nachricht_text(167, 2) = "Wirst du ihr Schicksal teilen?";
		a_nachricht_text(167, 3) = "Te uniras a los muertes aqui?";
		a_nachricht_text(168, 1) = "You enter the Lair of Goblins.";
		a_nachricht_text(168, 2) = "Du betrittst einen Goblinbau.";
		a_nachricht_text(168, 3) = "Entras en una cueva de Goblins.";
		a_nachricht_text(169, 1) = "There are a lot of";
		a_nachricht_text(169, 2) = "Hier wimmelt es nur so von diesen";
		a_nachricht_text(169, 3) = "Hay muchisimas de estes";
		a_nachricht_text(170, 1) = "ugly creatures here.";
		a_nachricht_text(170, 2) = "abscheulichen Kreaturen.";
		a_nachricht_text(170, 3) = "horribles monstruos.";
		a_nachricht_text(171, 1) = "Take care!";
		a_nachricht_text(171, 2) = "Sei vorsichtig!";
		a_nachricht_text(171, 3) = "Vigila!";
		a_nachricht_text(172, 1) = "You have found the Den of Thieves.";
		a_nachricht_text(172, 2) = "Du hast den Unterschlupf einer";
		a_nachricht_text(172, 3) = "Encontraste lel campemento de una banda de";
		a_nachricht_text(173, 1) = "Take care that they don't steal";
		a_nachricht_text(173, 2) = "Diebesbande gefunden. Sei vorsichtig";
		a_nachricht_text(173, 3) = "ladrones. Vigila para que no te";
		a_nachricht_text(174, 1) = "all your belongings!";
		a_nachricht_text(174, 2) = "das dir nicht alles geklaut wird!";
		a_nachricht_text(174, 3) = "roben tus cosas!";
		a_nachricht_text(175, 1) = "You break the Lock Picks!";
		a_nachricht_text(175, 2) = "Die Dietriche brechen ab!";
		a_nachricht_text(175, 3) = "Rompiste las Ganzuas!";
		a_nachricht_text(176, 1) = "Your Heart of Stone saves";
		a_nachricht_text(176, 2) = "Dein steinernes Herz";
		a_nachricht_text(176, 3) = "Tu corazon de Piedra te";
		a_nachricht_text(177, 1) = "your life!";
		a_nachricht_text(177, 2) = "rettet dir das Leben!";
		a_nachricht_text(177, 3) = "salva la Vida!";
		a_nachricht_text(178, 1) = "You evaded the attack!";
		a_nachricht_text(178, 2) = "Du bist ausgewichen!";
		a_nachricht_text(178, 3) = "Esquivaste el ataque!";
		a_nachricht_text(179, 1) = "The curse of astarte prevents you from finding something!";
		a_nachricht_text(179, 2) = "Der Fluch der Astarte verhindert das du etwas findest!";
		a_nachricht_text(179, 3) = "La maldicion de astarte te impide encontrar algo!";
		a_nachricht_text(180, 1) = "You dodged the trap!";
		a_nachricht_text(180, 2) = "Du bist der Falle ausgewichen!";
		a_nachricht_text(180, 3) = "Evadiste la trampa!";
		a_nachricht_text(181, 1) = "You fly over the trapdoor!";
		a_nachricht_text(181, 2) = "Du fliegt \374ber die Fallt\374re!";
		a_nachricht_text(181, 3) = "Volas sobre la trampa!";
		a_nachricht_text(182, 1) = "Works on bones only!";
		a_nachricht_text(182, 2) = "Funktioniert nur auf Knochen!";
		a_nachricht_text(182, 3) = "Funciona solamente en Huesos!";
		a_nachricht_text(183, 1) = "Works on Nexus only!";
		a_nachricht_text(183, 2) = "Funktioniert nur auf Nexus!";
		a_nachricht_text(183, 3) = "Funciona solamente en Nexus!";
		a_nachricht_text(184, 1) = "Works on Sanktum only!";
		a_nachricht_text(184, 2) = "Funktioniert nur auf Sanktum!";
		a_nachricht_text(184, 3) = "Funciona solamente en Sanktum!";
		a_nachricht_text(185, 1) = "The door is locked!";
		a_nachricht_text(185, 2) = "Die T\374r ist verschlossen!";
		a_nachricht_text(185, 3) = "La puerta esta cerrada con llave!";
		a_nachricht_text(186, 1) = "Press Space!";
		a_nachricht_text(186, 2) = "Mit Space gehts weiter!";
		a_nachricht_text(186, 3) = "Pulsa Espacio para continuar!";
		a_nachricht_text(187, 1) = "You are protected against magic!";
		a_nachricht_text(187, 2) = "Du bist gegen magie gesch\374tzt!";
		a_nachricht_text(187, 3) = "Estas protegido contra magia!";
		a_nachricht_text(188, 1) = "Your creature destroyed a trap!";
		a_nachricht_text(188, 2) = "Deine Kreatur hat eine Falle zerst\366rt!";
		a_nachricht_text(188, 3) = "Tu criatura ha destruido una trampa!";
		a_nachricht_text(189, 1) = "Is not an animal!";
		a_nachricht_text(189, 2) = "Das ist kein Tier!";
		a_nachricht_text(189, 3) = "No es un animal!";
		a_nachricht_text(190, 1) = "Is not undead!";
		a_nachricht_text(190, 2) = "Das ist kein Untoter!";
		a_nachricht_text(190, 3) = "No es un no-muerto!";
		a_nachricht_text(191, 1) = "Your creature is destroyed!";
		a_nachricht_text(191, 2) = "Deine Kreatur ist vernichtet!";
		a_nachricht_text(191, 3) = "Tu criatura es destruida!";
		a_nachricht_text(192, 1) = "Next Player!";
		a_nachricht_text(192, 2) = "N\344chster Spieler!";
		a_nachricht_text(192, 3) = "Proximo jugador!";
		a_nachricht_text(193, 1) = "You reached a new level!";
		a_nachricht_text(193, 2) = "Du erreichst einen neuen Level!";
		a_nachricht_text(193, 3) = "Entras en un nuevo nivel!";
		a_nachricht_text(194, 1) = "You do not have enough mana!";
		a_nachricht_text(194, 2) = "Du hast nicht genug Mana!";
		a_nachricht_text(194, 3) = "No tienes suficiente mana!";
		a_nachricht_text(195, 1) = "Your Creature falls into a pittrap!";
		a_nachricht_text(195, 2) = "Deine Kreatur f\303\244llt in eine Grube!";
		a_nachricht_text(195, 3) = "Tu criatura cae en una trampa!";
		a_nachricht_text(196, 1) = "You have to see the monster!";
		a_nachricht_text(196, 2) = "Du musst das Monster sehen k\366nnen!";
		a_nachricht_text(196, 3) = "Tienes que ver el monstruo!";
		a_nachricht_text(197, 1) = "This Monster can't be robbed!";
		a_nachricht_text(197, 2) = "Dieses Monster kann nicht bestohelen werden!";
		a_nachricht_text(197, 3) = "No puedes robar a este monstruo!";
		a_nachricht_text(198, 1) = "You robbed a Jewel!";
		a_nachricht_text(198, 2) = "Du hast einen Edelstein geklaut!";
		a_nachricht_text(198, 3) = "Robaste una piedra preciosa!";
		a_nachricht_text(199, 1) = "You robbed a Potion!";
		a_nachricht_text(199, 2) = "Du hast einen Trank geklaut!";
		a_nachricht_text(199, 3) = "Robaste un pocion!";
		a_nachricht_text(200, 1) = "Immune against bewiching!";
		a_nachricht_text(200, 2) = "Immun gegen verhexen!";
		a_nachricht_text(200, 3) = "Inmune contra brujeria!";
		a_nachricht_text(201, 1) = "You enter an underground forest";
		a_nachricht_text(201, 2) = "Du betrittst einen unterirdischen Wald";
		a_nachricht_text(201, 3) = "Entras en un bosque en una cueva";
		a_nachricht_text(202, 1) = "Who will be living here?";
		a_nachricht_text(202, 2) = "Wer wird hier wohl leben?";
		a_nachricht_text(202, 3) = "Quien estara viviendo aqui?";
		a_nachricht_text(203, 1) = "This nun can increase your luck";
		a_nachricht_text(203, 2) = "Diese Nonne kann dein Gl\374ck steigern";
		a_nachricht_text(203, 3) = "Esta Monja puede aumentar tu suerte";
		a_nachricht_text(204, 1) = "This Warrior can teach you to attack";
		a_nachricht_text(204, 2) = "Dieser Krieger kann deinen Angriff verbessern";
		a_nachricht_text(204, 3) = "Este luchador puede aumentar tu ataque";
		a_nachricht_text(205, 1) = "Trainer of Dexterity";
		a_nachricht_text(205, 2) = "Geschick-Lehrer";
		a_nachricht_text(205, 3) = "Entrenador de Destreza";
		a_nachricht_text(206, 1) = "Trainer of Strength";
		a_nachricht_text(206, 2) = "St\344rke-Lehrer";
		a_nachricht_text(206, 3) = "Entrenador de Fuerza";
		a_nachricht_text(207, 1) = "Trainer of Lifepoints";
		a_nachricht_text(207, 2) = "Lebenspunkte-Lehrer";
		a_nachricht_text(207, 3) = "Entrenador de Puntos de Vida";
		a_nachricht_text(208, 1) = "Trainer of Speed";
		a_nachricht_text(208, 2) = "Geschwindigkeits-Lehrer";
		a_nachricht_text(208, 3) = "Entrenador de Velocidad";
		a_nachricht_text(209, 1) = "This little Faerie can increase your Perception";
		a_nachricht_text(209, 2) = "Diese kleine Fee kann deine Wahrnehmung steigern";
		a_nachricht_text(209, 3) = "Este hada puede aumentar tu percepcion";
		a_nachricht_text(210, 1) = "Trainer of Mana";
		a_nachricht_text(210, 2) = "Mana-Lehrer";
		a_nachricht_text(210, 3) = "Entrenador de Mana";
		a_nachricht_text(211, 1) = "This witch can increase your Spell Power Score";
		a_nachricht_text(211, 2) = "Diese Hexe kann deine Zauberkraft verbessern";
		a_nachricht_text(211, 3) = "Esta Bruja puede aumentar tu Poder de Hechizos";
		a_nachricht_text(212, 1) = "This Archmage can teach you Spell Circles";
		a_nachricht_text(212, 2) = "Dieser Erzmagier kann dir Zirkel beibringen";
		a_nachricht_text(212, 3) = "Este Archmago puede entrenarte Circulos";
		a_nachricht_text(213, 1) = "The Training costs you: ";
		a_nachricht_text(213, 2) = "Das Training kostet: ";
		a_nachricht_text(213, 3) = "El entrenamiento cuesta: ";
		a_nachricht_text(214, 1) = "Train";
		a_nachricht_text(214, 2) = "Trainieren";
		a_nachricht_text(214, 3) = "Entrenar";
		a_nachricht_text(215, 1) = "You do not have enough gold!";
		a_nachricht_text(215, 2) = "Du hast nicht genug Gold!";
		a_nachricht_text(215, 3) = "No tienes suficiente oro!";
		a_nachricht_text(216, 1) = "Your actual rating:";
		a_nachricht_text(216, 2) = "Dein aktueller Wert:";
		a_nachricht_text(216, 3) = "Ahora tienes:";
		a_nachricht_text(217, 1) = "You have been trained";
		a_nachricht_text(217, 2) = "Du wurdest trainiert";
		a_nachricht_text(217, 3) = "Has sido entrenado";
		a_nachricht_text(218, 1) = "This is your end!";
		a_nachricht_text(218, 2) = "Das ist dein Ende!";
		a_nachricht_text(218, 3) = "Este es tu Fin!";
		a_nachricht_text(219, 1) = "You have fallen into the lair";
		a_nachricht_text(219, 2) = "Du ist in den Bau eines";
		a_nachricht_text(219, 3) = "Caiste en la guarida de un";
		a_nachricht_text(220, 1) = "of a horrible dragon!";
		a_nachricht_text(220, 2) = "schrecklichen Drachen gefallen!";
		a_nachricht_text(220, 3) = "dragon horrible!";
		a_nachricht_text(221, 1) = "You are unobservant!";
		a_nachricht_text(221, 2) = "Du bist unaufmerksam!";
		a_nachricht_text(221, 3) = "Eres despistado!";
		a_nachricht_text(222, 1) = "You have been cured from poison!";
		a_nachricht_text(222, 2) = "Du bist entgiftet worden!";
		a_nachricht_text(222, 3) = "Estas curado de veneno!";
		a_nachricht_text(223, 1) = "You lose all your Mana!";
		a_nachricht_text(223, 2) = "Du verlierst all dein Mana!";
		a_nachricht_text(223, 3) = "Pierdes todo tu Mana!";
		a_nachricht_text(224, 1) = "You already carry a weapon!";
		a_nachricht_text(224, 2) = "Du tr\344gst schon eine Waffe!";
		a_nachricht_text(224, 3) = "Ya llevas equipada una arma!";
		a_nachricht_text(225, 1) = "You already wear boots!";
		a_nachricht_text(225, 2) = "Du tr\344gst schon Stiefel!";
		a_nachricht_text(225, 3) = "Ya llevas puestas unas botas!";
		a_nachricht_text(226, 1) = "You already wear a helmet!";
		a_nachricht_text(226, 2) = "Du tr\344gst schon einen Helm!";
		a_nachricht_text(226, 3) = "Ya llevas puesto casco!";
		a_nachricht_text(227, 1) = "You already wear gloves!";
		a_nachricht_text(227, 2) = "Du tr\344gst schon Handschuhe!";
		a_nachricht_text(227, 3) = "Ya llevas puestos unos guantes!";
		a_nachricht_text(228, 1) = "You already wear armor!";
		a_nachricht_text(228, 2) = "Du tr\344gst schon eine R\374stung!";
		a_nachricht_text(228, 3) = "Ya llevas una armadura!";
		a_nachricht_text(229, 1) = "You already carry a shield!";
		a_nachricht_text(229, 2) = "Du tr\344gst schon ein Schild!";
		a_nachricht_text(229, 3) = "Ya llevas equipado un escudo!";
		a_nachricht_text(230, 1) = "You need both hands!";
		a_nachricht_text(230, 2) = "Du ben\366tigst beide H\344nde!";
		a_nachricht_text(230, 3) = "Necesitas ambas manos!";
		a_nachricht_text(231, 1) = "You carry a two handed weapon!";
		a_nachricht_text(231, 2) = "Du tr\344gst eine Zweihandwaffe!";
		a_nachricht_text(231, 3) = "Tienes equipada una arma a dos manos!";
		a_nachricht_text(232, 1) = "You can't train anymore!";
		a_nachricht_text(232, 2) = "Du kannt nicht mehr trainieren!";
		a_nachricht_text(232, 3) = "No puedes entrenar mas!";
		a_nachricht_text(233, 1) = "You can't see the destination!";
		a_nachricht_text(233, 2) = "Du kannt das Ziel nicht sehen!";
		a_nachricht_text(233, 3) = "No puedes ver el destino!";
		a_nachricht_text(234, 1) = "You enter a room with a lake of";
		a_nachricht_text(234, 2) = "Du betrittst einen Raum mit einem";
		a_nachricht_text(234, 3) = "Entras en una cueva con un lago";
		a_nachricht_text(235, 1) = "lava, and treasure!";
		a_nachricht_text(235, 2) = "Lavasee und einem Schatz!";
		a_nachricht_text(235, 3) = "de lava y un tesoro!";
		a_nachricht_text(236, 1) = "A piece of the staff of";
		a_nachricht_text(236, 2) = "Ein Teil des Stabes des";
		a_nachricht_text(236, 3) = "Una parte del baston del";
		a_nachricht_text(237, 1) = "the last covenant!";
		a_nachricht_text(237, 2) = "letzten B\374ndnisses!";
		a_nachricht_text(237, 3) = "utlimo convenio!";
		a_nachricht_text(238, 1) = "You found one pice of the staff!";
		a_nachricht_text(238, 2) = "Du hast einen Teil des Stabes gefunden!";
		a_nachricht_text(238, 3) = "Encontraste una parte del baston!";
		a_nachricht_text(239, 1) = "Staff Pieces: ";
		a_nachricht_text(239, 2) = "Stabteile: ";
		a_nachricht_text(239, 3) = "Partes del baston: ";
		a_nachricht_text(240, 1) = "You made it!";
		a_nachricht_text(240, 2) = "Du hast es geschafft!";
		a_nachricht_text(240, 3) = "Lo conseguiste!";
		a_nachricht_text(241, 1) = "You will see the daylight again!";
		a_nachricht_text(241, 2) = "Du wirst das Tageslicht wiedersehen!";
		a_nachricht_text(241, 3) = "Volveras a ver el sol!";
		a_nachricht_text(242, 1) = "You can enter your Name into";
		a_nachricht_text(242, 2) = "Du kannst dich in die Liste";
		a_nachricht_text(242, 3) = "Puedes escribir tu nombre en";
		a_nachricht_text(243, 1) = "the List of Survivors";
		a_nachricht_text(243, 2) = "der \334berlebenden eintragen";
		a_nachricht_text(243, 3) = "la lista de los sobrevivientes";
		a_nachricht_text(244, 1) = "We hope you liked Lost Labyrinth!";
		a_nachricht_text(244, 2) = "Wir hoffen Lost Labyrinth hat dir gefallen!";
		a_nachricht_text(244, 3) = "Esperamos que disfrutaste Lost Labyrinth!";
		a_nachricht_text(245, 1) = "Enter your Name:";
		a_nachricht_text(245, 2) = "Gib deinen Namen ein:";
		a_nachricht_text(245, 3) = "Ingresa tu nombre:";
		a_nachricht_text(246, 1) = "There is nobody there!";
		a_nachricht_text(246, 2) = "Da ist niemand!";
		a_nachricht_text(246, 3) = "No hay nadie!";
		a_nachricht_text(247, 1) = "You remove the rock!";
		a_nachricht_text(247, 2) = "Du entfernst den Stein!";
		a_nachricht_text(247, 3) = "Remueves la piedra!";
		a_nachricht_text(248, 1) = "You found a treasure!";
		a_nachricht_text(248, 2) = "Du hast einen Schatz gefunden!";
		a_nachricht_text(248, 3) = "Encontraste un tesoro!";
		a_nachricht_text(249, 1) = "Reason of Death: ";
		a_nachricht_text(249, 2) = "Todesgrund: ";
		a_nachricht_text(249, 3) = "Tipo de Muerto: ";
		a_nachricht_text(250, 1) = "Skills: ";
		a_nachricht_text(250, 2) = "F\344higkeiten: ";
		a_nachricht_text(250, 3) = "Habilidades: ";
		a_nachricht_text(251, 1) = "The Map dissolves!";
		a_nachricht_text(251, 2) = "Die Karte zerf\344llt!";
		a_nachricht_text(251, 3) = "El mapa desaparece!";
		a_nachricht_text(252, 1) = "The shovel breaks!";
		a_nachricht_text(252, 2) = "Die Schaufel zerbricht!";
		a_nachricht_text(252, 3) = "La pala se rompe!";
		a_nachricht_text(253, 1) = "The pick axe breaks!";
		a_nachricht_text(253, 2) = "Die Spitzhacke zerbricht!";
		a_nachricht_text(253, 3) = "La piqueta se rompe!";
		a_nachricht_text(254, 1) = "The lockpicks break!";
		a_nachricht_text(254, 2) = "Die Dietriche zerbrechen!";
		a_nachricht_text(254, 3) = "Las Ganzuas se rompe!";
		a_nachricht_text(255, 1) = "You cannot open this!";
		a_nachricht_text(255, 2) = "Das kannst du nicht \366ffnen!";
		a_nachricht_text(255, 3) = "No puedes abrir eso!";
		a_nachricht_text(256, 1) = "You are immune to poison!";
		a_nachricht_text(256, 2) = "Du bist immun gegen Gift!";
		a_nachricht_text(256, 3) = "Eres inmune contra el veneno!";
		a_nachricht_text(257, 1) = "The ring disappears!";
		a_nachricht_text(257, 2) = "Der Ring verschwindet!";
		a_nachricht_text(257, 3) = "El anillo desaparece!";
		a_nachricht_text(258, 1) = "The nexus disappears!";
		a_nachricht_text(258, 2) = "Der Nexus verschwindet!";
		a_nachricht_text(258, 3) = "El nexo desaparece!";
		a_nachricht_text(259, 1) = "The sanctum disappears!";
		a_nachricht_text(259, 2) = "Das Sanktum verschwindet!";
		a_nachricht_text(259, 3) = "El santuario desaparece!";
		a_nachricht_text(260, 1) = "You already wear a ring!";
		a_nachricht_text(260, 2) = "Du tr\344gst schon einen Ring!";
		a_nachricht_text(260, 3) = "Ya llevas puesto un anillo!";
		a_nachricht_text(261, 1) = "You have been spotted!";
		a_nachricht_text(261, 2) = "Du wurdest bemerkt!";
		a_nachricht_text(261, 3) = "Te han descubierto!";
		a_nachricht_text(262, 1) = "No charges left!";
		a_nachricht_text(262, 2) = "Keine Ladungen mehr!";
		a_nachricht_text(262, 3) = "No quedan mas cargas!";
		a_nachricht_text(263, 1) = "This was the last arrow!";
		a_nachricht_text(263, 2) = "Das war der letzte Pfeil!";
		a_nachricht_text(263, 3) = "Esa fue la ultima flecha!";
		a_nachricht_text(264, 1) = "Works on walls only!";
		a_nachricht_text(264, 2) = "Funktioniert nur auf W\344nde!";
		a_nachricht_text(264, 3) = "Funciona solamente con Pareds!";
		a_nachricht_text(265, 1) = "Immune against fire!";
		a_nachricht_text(265, 2) = "Immun gegen Feuer!";
		a_nachricht_text(265, 3) = "Inmune al fuego!";
		a_nachricht_text(266, 1) = "Immune against turn to stone!";
		a_nachricht_text(266, 2) = "Immun gegen Versteinern!";
		a_nachricht_text(266, 3) = "Imune a la transforma en piedra!";
		a_nachricht_text(267, 1) = "Immune against ice!";
		a_nachricht_text(267, 2) = "Immun gegen Eis!";
		a_nachricht_text(267, 3) = "Imune al hielo!";
		a_nachricht_text(268, 1) = "Immune against dehydration!";
		a_nachricht_text(268, 2) = "Immun gegen Dehydration!";
		a_nachricht_text(268, 3) = "Inmune a la Deshidratacion!";
		a_nachricht_text(269, 1) = "Has no fear!";
		a_nachricht_text(269, 2) = "Hat keine Angst!";
		a_nachricht_text(269, 3) = "No tiene miedo!";
		a_nachricht_text(270, 1) = "You enter a Tavern";
		a_nachricht_text(270, 2) = "Du betrittst eine Taverne";
		a_nachricht_text(270, 3) = "Entras en una taverna";
		a_nachricht_text(271, 1) = "filled with courageous";
		a_nachricht_text(271, 2) = "gef\374llt mit wagemutigen";
		a_nachricht_text(271, 3) = "llena de aventureros";
		a_nachricht_text(272, 1) = "Adventurers.";
		a_nachricht_text(272, 2) = "Abenteurern.";
		a_nachricht_text(272, 3) = "sin miedo.";
		a_nachricht_text(273, 1) = "This fighter would work";
		a_nachricht_text(273, 2) = "Dieser K\344mpfer w\374rde sich ";
		a_nachricht_text(273, 3) = "Este luchador trabajaria";
		a_nachricht_text(274, 1) = "for you!";
		a_nachricht_text(274, 2) = "dir anschliessen!";
		a_nachricht_text(274, 3) = "por ti!";
		a_nachricht_text(275, 1) = "He wants: ";
		a_nachricht_text(275, 2) = "Er will: ";
		a_nachricht_text(275, 3) = "El quiere: ";
		a_nachricht_text(276, 1) = "His scores: ";
		a_nachricht_text(276, 2) = "Seine Werte: ";
		a_nachricht_text(276, 3) = "Sus atributos: ";
		a_nachricht_text(277, 1) = "Yes";
		a_nachricht_text(277, 2) = "Ja";
		a_nachricht_text(277, 3) = "Si";
		a_nachricht_text(278, 1) = "No";
		a_nachricht_text(278, 2) = "Nein";
		a_nachricht_text(278, 3) = "No";
		a_nachricht_text(279, 1) = "Do you accept?";
		a_nachricht_text(279, 2) = "Akzeptierst du?";
		a_nachricht_text(279, 3) = "Aceptas?";
		a_nachricht_text(280, 1) = "You got a bodyguard!";
		a_nachricht_text(280, 2) = "Du hast nun einen Leibw\344chter!";
		a_nachricht_text(280, 3) = "Ahora tienes guardaespaldas!";
		a_nachricht_text(281, 1) = "Cannot be dropped!";
		a_nachricht_text(281, 2) = "Kann nicht abgelegt werden!";
		a_nachricht_text(281, 3) = "No puedes tirarlo!";
		a_nachricht_text(282, 1) = "You entered the Lair of the";
		a_nachricht_text(282, 2) = "Du hast den Bau des gr\366ssten";
		a_nachricht_text(282, 3) = "Entraste en la guarida del Monstro";
		a_nachricht_text(283, 1) = "biggest Monster in the Labyrinth!";
		a_nachricht_text(283, 2) = "Monsters des Labyrinths betreten!";
		a_nachricht_text(283, 3) = "mas grande del Laberinto!";
		a_nachricht_text(284, 1) = "Here lives the ancient Hydra!!!";
		a_nachricht_text(284, 2) = "Hier lebt die uralte Hydra!!!";
		a_nachricht_text(284, 3) = "Aqui vive una Hydra anciana!!!";
		a_nachricht_text(285, 1) = "Will you serve as food here?";
		a_nachricht_text(285, 2) = "Wirst du hier als Futter enden?";
		a_nachricht_text(285, 3) = "Vas a ser tu su proxima comida?";
		a_nachricht_text(286, 1) = "You missed!";
		a_nachricht_text(286, 2) = "Du schl\344gst vorbei!";
		a_nachricht_text(286, 3) = "No alcanzaste!";
		a_nachricht_text(287, 1) = "You destroyed one head!";
		a_nachricht_text(287, 2) = "Du hast einen Kopf abgeschlagen!";
		a_nachricht_text(287, 3) = "Le cortaste una cabeza!";
		a_nachricht_text(288, 1) = "You destroyed the Hydra!";
		a_nachricht_text(288, 2) = "Du hast die Hydra vernichtet!";
		a_nachricht_text(288, 3) = "Mastaste la hydra!";
		a_nachricht_text(289, 1) = "The Hydra has ";
		a_nachricht_text(289, 2) = "Du Hydra hat nun ";
		a_nachricht_text(289, 3) = "La Hydra ahora tiene ";
		a_nachricht_text(290, 1) = " Heads!";
		a_nachricht_text(290, 2) = " K\366pfe!";
		a_nachricht_text(290, 3) = " Cabezas!";
		a_nachricht_text(291, 1) = "The monster missed!";
		a_nachricht_text(291, 2) = "Das monster verfehlt dich!";
		a_nachricht_text(291, 3) = "El monstruo no alcanza!";
		a_nachricht_text(292, 1) = "You enter the Hall of";
		a_nachricht_text(292, 2) = "Du betrittst die Halle der";
		a_nachricht_text(292, 3) = "Entras en la Sala de";
		a_nachricht_text(293, 1) = "Illusions!";
		a_nachricht_text(293, 2) = "Illusionen!";
		a_nachricht_text(293, 3) = "Ilusiones!";
		a_nachricht_text(294, 1) = "Will you be able to find the exit here";
		a_nachricht_text(294, 2) = "Wirst du hier den Ausgang finden?";
		a_nachricht_text(294, 3) = "Vas a encontrar la salida aqui?";
		a_nachricht_text(295, 1) = "Itzy bitzy Spiders!";
		a_nachricht_text(295, 2) = "Spinnen, Spinnen ,Spinnen!";
		a_nachricht_text(295, 3) = "Aranas, Aranas, Aranas!";
		a_nachricht_text(296, 1) = "This is a big lair full of them.";
		a_nachricht_text(296, 2) = "Das ist wohl ein riesiger Bau.";
		a_nachricht_text(296, 3) = "Eso es una guarida de allas.";
		a_nachricht_text(297, 1) = "Take care that they don't bite you!";
		a_nachricht_text(297, 2) = "Pass auf das sie dich nicht beissen!";
		a_nachricht_text(297, 3) = "Cuidate que no te piquen!";
		a_nachricht_text(298, 1) = "Game saved!";
		a_nachricht_text(298, 2) = "Spiel gesichert!";
		a_nachricht_text(298, 3) = "Juego guardado!";
		a_nachricht_text(299, 1) = "Game loaded!";
		a_nachricht_text(299, 2) = "Spiel geladen!";
		a_nachricht_text(299, 3) = "Juego cargado!";
		a_nachricht_text(300, 1) = "Your creature missed!";
		a_nachricht_text(300, 2) = "Deine Kreatur verfehlt!";
		a_nachricht_text(300, 3) = "Tu criatura no alcanza!";
		a_nachricht_text(301, 1) = "You found the secret laboratory";
		a_nachricht_text(301, 2) = "Du hast das geheime Labor";
		a_nachricht_text(301, 3) = "Encontraste el laboratorio secreto";
		a_nachricht_text(302, 1) = "of an alchemist!";
		a_nachricht_text(302, 2) = "eines Alchimisten gefunden!";
		a_nachricht_text(302, 3) = "de un alquimista!";
		a_nachricht_text(303, 1) = "Maybe you can find some";
		a_nachricht_text(303, 2) = "Vielleicht findest du hier den";
		a_nachricht_text(303, 3) = "Tal vez puedes encontrar";
		a_nachricht_text(304, 1) = "potions here.";
		a_nachricht_text(304, 2) = "einen oder anderen Trank.";
		a_nachricht_text(304, 3) = "algunos pociones.";
		a_nachricht_text(305, 1) = "You found a secret library";
		a_nachricht_text(305, 2) = "Du hast eine geheime Bibliothek";
		a_nachricht_text(305, 3) = "Encontraste una libreria";
		a_nachricht_text(306, 1) = "";
		a_nachricht_text(306, 2) = "gefunden.";
		a_nachricht_text(306, 3) = "secreta.";
		a_nachricht_text(307, 1) = "Maybe you can find some scrolls";
		a_nachricht_text(307, 2) = "Vielleicht kannst du ein paar";
		a_nachricht_text(307, 3) = "Tal vez puedes encontrar algunos";
		a_nachricht_text(308, 1) = "here.";
		a_nachricht_text(308, 2) = "Schriftrollen finden.";
		a_nachricht_text(308, 3) = "hechizos.";
		a_nachricht_text(309, 1) = "You found a Potion!";
		a_nachricht_text(309, 2) = "Du findest einen Trank!";
		a_nachricht_text(309, 3) = "Encontraste una pocion!";
		a_nachricht_text(310, 1) = "You found a Scroll!";
		a_nachricht_text(310, 2) = "Du findest eine Schriftrolle!";
		a_nachricht_text(310, 3) = "Encontraste un pergamino!";
		a_nachricht_text(311, 1) = "You found an Apple!";
		a_nachricht_text(311, 2) = "Du findest einen Apfel!";
		a_nachricht_text(311, 3) = "Encontraste una manzanana!";
		a_nachricht_text(312, 1) = "The Monster dispelled your spell!";
		a_nachricht_text(312, 2) = "Das Monster hat deinen Zauber dispelled!";
		a_nachricht_text(312, 3) = "El monstruo ha cancelado tu hechizo!";
		a_nachricht_text(313, 1) = "The Monster breathes fire!";
		a_nachricht_text(313, 2) = "Das Monster spuckt Feuer!";
		a_nachricht_text(313, 3) = "El monstruo lanza fuego!";
		a_nachricht_text(314, 1) = "The Monster breathes ice!";
		a_nachricht_text(314, 2) = "Das Monster spuckt Eis!";
		a_nachricht_text(314, 3) = "El monstruo lanza hielo!";
		a_nachricht_text(315, 1) = "You are protected against cold!";
		a_nachricht_text(315, 2) = "Du bist gegen K\344lte geschutzt!";
		a_nachricht_text(315, 3) = "Estas protegido contra el frio!";
		a_nachricht_text(316, 1) = "The Monster breathes venom!";
		a_nachricht_text(316, 2) = "Das Monster spuckt Gift!";
		a_nachricht_text(316, 3) = "El monstruo lanza veneno!";
		a_nachricht_text(317, 1) = "The Monster throws lightning!";
		a_nachricht_text(317, 2) = "Das Monster wirft Blitze!";
		a_nachricht_text(317, 3) = "El monstruo lanza rayos!";
		a_nachricht_text(318, 1) = "The Monster turns you to stone!";
		a_nachricht_text(318, 2) = "Das Monster versteinert dich!";
		a_nachricht_text(318, 3) = "El monstruo te transforma en piedra!";
		a_nachricht_text(319, 1) = "The Monster kills you with his gaze!";
		a_nachricht_text(319, 2) = "Das Monster t\366tet dich mit einem Blick!";
		a_nachricht_text(319, 3) = "El monstruo te mata con una vista!";
		a_nachricht_text(320, 1) = "Wrong Program Version!";
		a_nachricht_text(320, 2) = "Falsche Programmversion!";
		a_nachricht_text(320, 3) = "Verciona de programa erronea!";
		a_nachricht_text(321, 1) = "Your God of War grants you a Lifepoint!";
		a_nachricht_text(321, 2) = "Dein Kriegsgott schenkt dir einen Lebenspunkt!";
		a_nachricht_text(321, 3) = "Tu dios de la guerra te ortoga un punto de vida!";
		a_nachricht_text(322, 1) = "Your God of Death grants you a Manapoint!";
		a_nachricht_text(322, 2) = "Dein Todesgott schenkt dir einen Manapunkt!";
		a_nachricht_text(322, 3) = "Su dios del muerto te ortoga un punto de mana!";
		a_nachricht_text(323, 1) = "Your Goddess of Healing grants you a Lifepoint!";
		a_nachricht_text(323, 2) = "Deine G\366ttin der Heilung schenkt dir einen Lebenspunkt!";
		a_nachricht_text(323, 3) = "Su diosa de la curacion te ortoga un punto de vida!";
		a_nachricht_text(324, 1) = "Your Goddess of Wisdom grants you a Manapoint!";
		a_nachricht_text(324, 2) = "Deine G\366ttin der Weisheit schenkt dir einen Manapunkt!";
		a_nachricht_text(324, 3) = "Su diosa de la sabiduria te ortoga un punto de mana!";
		a_nachricht_text(325, 1) = "Your God of Secrets grants you a Lifepoint!";
		a_nachricht_text(325, 2) = "Dein Gott der Geheimnisse schenkt dir einen Lebenspunkt!";
		a_nachricht_text(325, 3) = "Su dios de los secretos te ortoga un punto de vida!";
		a_nachricht_text(326, 1) = "Your God of Wealth grants you a Lifepoint!";
		a_nachricht_text(326, 2) = "Dein Gott des Reichtums schenkt dir einen Lebenspunkt!";
		a_nachricht_text(326, 3) = "Su dios de la riqueza te ortoga un punto de vida!";
		a_nachricht_text(327, 1) = "Nobody wants to talk to you!";
		a_nachricht_text(327, 2) = "Niemand will mit dir reden!";
		a_nachricht_text(327, 3) = "Nadie quiere hablar contigo!";
		a_nachricht_text(328, 1) = "You do not have thaumaturgy!";
		a_nachricht_text(328, 2) = "Du hast keine Thaumaturgie!";
		a_nachricht_text(328, 3) = "No tienes Taumaturgia!";
		a_nachricht_text(329, 1) = "Immune against lightning!";
		a_nachricht_text(329, 2) = "Immun gegen Blitze!";
		a_nachricht_text(329, 3) = "Inmune a los relampagos!";
		a_nachricht_text(330, 1) = "Highscore saved on the Internet!";
		a_nachricht_text(330, 2) = "Highscore im Internet gespeichert!";
		a_nachricht_text(330, 3) = "Puntuacion alta anadida a internet!";
		a_nachricht_text(331, 1) = "You enter a room with a";
		a_nachricht_text(331, 2) = "Du betrittst einen Raum mit";
		a_nachricht_text(331, 3) = "Entras en una habitacion con";
		a_nachricht_text(332, 1) = "treasure!";
		a_nachricht_text(332, 2) = "einem Schatz!";
		a_nachricht_text(332, 3) = "un tesoro!";
		a_nachricht_text(333, 1) = "But it's protected!";
		a_nachricht_text(333, 2) = "Leider ist er bewacht!";
		a_nachricht_text(333, 3) = "Pero esta protegido!";
		a_nachricht_text(334, 1) = "Reinforced stone!";
		a_nachricht_text(334, 2) = "Zu harter Stein!";
		a_nachricht_text(334, 3) = "El muro es demasiado fuerte!";
		a_nachricht_text(335, 1) = "This is the room of an old";
		a_nachricht_text(335, 2) = "Dies ist der Raum eines";
		a_nachricht_text(335, 3) = "Esta es la habitacion de un";
		a_nachricht_text(336, 1) = "Wizard!";
		a_nachricht_text(336, 2) = "alten Zaubereres!";
		a_nachricht_text(336, 3) = "mago viejo!";
		a_nachricht_text(337, 1) = "Maybe he could be of help?";
		a_nachricht_text(337, 2) = "Vielleicht kann er dir helfen?";
		a_nachricht_text(337, 3) = "Tal vez el puede ayudarte?";
		a_nachricht_text(338, 1) = "Hello my Friend!";
		a_nachricht_text(338, 2) = "Hallo mein Freund!";
		a_nachricht_text(338, 3) = "Hola Amigo!";
		a_nachricht_text(339, 1) = "Shall I do something for you?";
		a_nachricht_text(339, 2) = "Soll ich etwas f\303\274r dich tun?";
		a_nachricht_text(339, 3) = "Puedo hacer algo por ti?";
		a_nachricht_text(340, 1) = "Kill all monsters in this level?";
		a_nachricht_text(340, 2) = "Alle monster dieses Levels t\366ten?";
		a_nachricht_text(340, 3) = "Matar todos los montruos de este nivel?";
		a_nachricht_text(341, 1) = "Destroy all the traps?";
		a_nachricht_text(341, 2) = "Alle Fallen zerst\366ren?";
		a_nachricht_text(341, 3) = "Destruir todas las trampas?";
		a_nachricht_text(342, 1) = "Open all doors?";
		a_nachricht_text(342, 2) = "Alle T\374ren \366ffnen?";
		a_nachricht_text(342, 3) = "Abrir todas las puertas?";
		a_nachricht_text(343, 1) = "Heal you completely?";
		a_nachricht_text(343, 2) = "Dich vollst\344ndig heilen?";
		a_nachricht_text(343, 3) = "Curarte totalmente?";
		a_nachricht_text(344, 1) = "The wizard disappears!";
		a_nachricht_text(344, 2) = "Der Zauberer verschwindet!";
		a_nachricht_text(344, 3) = "El mago desaparece!";
		a_nachricht_text(345, 1) = "You found an uderground pond!";
		a_nachricht_text(345, 2) = "Du hast einen unterirdischen Teich gefunden!";
		a_nachricht_text(345, 3) = "Encontraste un lago subterraneo!";
		a_nachricht_text(346, 1) = "Maybe you can dive and";
		a_nachricht_text(346, 2) = "Vielleicht kannst du hier tauchen";
		a_nachricht_text(346, 3) = "Tal vez puedes bucear y encontrar";
		a_nachricht_text(347, 1) = "find some treasures?";
		a_nachricht_text(347, 2) = "und Sch\344tze finden?";
		a_nachricht_text(347, 3) = "tesoros?";
		a_nachricht_text(348, 1) = "Some potions broke!";
		a_nachricht_text(348, 2) = "Einige Tr\344nke zerbrachen!";
		a_nachricht_text(348, 3) = "Algunos pociones se rompieron!";
		a_nachricht_text(349, 1) = "Flying";
		a_nachricht_text(349, 2) = "Fliegen";
		a_nachricht_text(349, 3) = "Volar";
		a_nachricht_text(350, 1) = "Sets Ambushes";
		a_nachricht_text(350, 2) = "Legt Hinterhalte";
		a_nachricht_text(350, 3) = "Hace Emboscadas";
		a_nachricht_text(351, 1) = "Poisonous";
		a_nachricht_text(351, 2) = "Giftig";
		a_nachricht_text(351, 3) = "Venesoso";
		a_nachricht_text(352, 1) = "Can be robbed";
		a_nachricht_text(352, 2) = "Ist bestehlbar";
		a_nachricht_text(352, 3) = "Puede ser robado";
		a_nachricht_text(353, 1) = "Ranged Combat";
		a_nachricht_text(353, 2) = "Fernkampf";
		a_nachricht_text(353, 3) = "Arco";
		a_nachricht_text(354, 1) = "Calls for Backup";
		a_nachricht_text(354, 2) = "Holt Verst\344rkung";
		a_nachricht_text(354, 3) = "Pide ayuda";
		a_nachricht_text(355, 1) = "Dry";
		a_nachricht_text(355, 2) = "Trocken";
		a_nachricht_text(355, 3) = "Seco";
		a_nachricht_text(356, 1) = "Afraid";
		a_nachricht_text(356, 2) = "Hat Angst";
		a_nachricht_text(356, 3) = "Tiene Miedo";
		a_nachricht_text(357, 1) = "Can be charmed";
		a_nachricht_text(357, 2) = "Befreundbar";
		a_nachricht_text(357, 3) = "Puede ser encantado";
		a_nachricht_text(358, 1) = "Robs";
		a_nachricht_text(358, 2) = "Stiehlt";
		a_nachricht_text(358, 3) = "Roba";
		a_nachricht_text(359, 1) = "Burns";
		a_nachricht_text(359, 2) = "Brennt";
		a_nachricht_text(359, 3) = "Quema";
		a_nachricht_text(360, 1) = "Fire Resistant";
		a_nachricht_text(360, 2) = "Feuerfest";
		a_nachricht_text(360, 3) = "Inmune al Fuego";
		a_nachricht_text(361, 1) = "Stoneproof";
		a_nachricht_text(361, 2) = "Steinfest";
		a_nachricht_text(361, 3) = "Inmune a la Piedra";
		a_nachricht_text(362, 1) = "Throws Lightning";
		a_nachricht_text(362, 2) = "Wirft Blitze";
		a_nachricht_text(362, 3) = "Tira rayos";
		a_nachricht_text(363, 1) = "Dispel";
		a_nachricht_text(363, 2) = "Dispel";
		a_nachricht_text(363, 3) = "Contrarresta";
		a_nachricht_text(364, 1) = "Regenerates";
		a_nachricht_text(364, 2) = "Regeneriert";
		a_nachricht_text(364, 3) = "Regeneracion";
		a_nachricht_text(365, 1) = "Resists Damage";
		a_nachricht_text(365, 2) = "Unverwundbar";
		a_nachricht_text(365, 3) = "Inmune al Dano";
		a_nachricht_text(366, 1) = "Iceproof";
		a_nachricht_text(366, 2) = "Eisfest";
		a_nachricht_text(366, 3) = "Inmune al Hielo";
		a_nachricht_text(367, 1) = "Invisible";
		a_nachricht_text(367, 2) = "Unsichtbar";
		a_nachricht_text(367, 3) = "Transparente";
		a_nachricht_text(368, 1) = "Firebreath";
		a_nachricht_text(368, 2) = "Feueratem";
		a_nachricht_text(368, 3) = "Escupe Fuego";
		a_nachricht_text(369, 1) = "Poisonbreath";
		a_nachricht_text(369, 2) = "Giftatem";
		a_nachricht_text(369, 3) = "Escupe veneno";
		a_nachricht_text(370, 1) = "Turns to Stone";
		a_nachricht_text(370, 2) = "Versteinert";
		a_nachricht_text(370, 3) = "Transforma en Piedra";
		a_nachricht_text(371, 1) = "Frostbreath";
		a_nachricht_text(371, 2) = "Frostatem";
		a_nachricht_text(371, 3) = "Escupe hielo";
		a_nachricht_text(372, 1) = "View of Death";
		a_nachricht_text(372, 2) = "Todesblick";
		a_nachricht_text(372, 3) = "Mirada de la Muerte";
		a_nachricht_text(373, 1) = "Lightningproof";
		a_nachricht_text(373, 2) = "Blitzfest";
		a_nachricht_text(373, 3) = "Inmune a rayos";
		a_nachricht_text(374, 1) = "Has treasure";
		a_nachricht_text(374, 2) = "Hat Schatz";
		a_nachricht_text(374, 3) = "Tiene un tesoro";
		a_nachricht_text(375, 1) = "Has magical teasure";
		a_nachricht_text(375, 2) = "Hat magischen Schatz";
		a_nachricht_text(375, 3) = "Tiene un tesoro magico";
		a_nachricht_text(376, 1) = "Resits Critical Hits";
		a_nachricht_text(376, 2) = "Wiedersteht kritischen Treffern";
		a_nachricht_text(376, 3) = "Inmune a golpes criticales";
		a_nachricht_text(377, 1) = "Magical Darkness";
		a_nachricht_text(377, 2) = "Magische Dunkelheit";
		a_nachricht_text(377, 3) = "Oscuridad Magica";
		a_nachricht_text(378, 1) = "It's very dark in here...";
		a_nachricht_text(378, 2) = "Es ist sehr dunkel hier...";
		a_nachricht_text(378, 3) = "Esta muy oscuro aqui...";
		a_nachricht_text(379, 1) = "You can't see your own hands!";
		a_nachricht_text(379, 2) = "Du kannst deine eigenen H\344nde nicht sehen!";
		a_nachricht_text(379, 3) = "No puedes ver tus propias manos!";
		a_nachricht_text(380, 1) = "Fierce Traps";
		a_nachricht_text(380, 2) = "Gef\344hrliche Fallen";
		a_nachricht_text(380, 3) = "Trampas peligrosas";
		a_nachricht_text(381, 1) = "Watch out the traps here could";
		a_nachricht_text(381, 2) = "Sei vorsichtig die Fallen hier";
		a_nachricht_text(381, 3) = "Cuidate. Las trampas aqui podrian";
		a_nachricht_text(382, 1) = "be deadly!";
		a_nachricht_text(382, 2) = "k\366nnten t\366dlich sein!";
		a_nachricht_text(382, 3) = "matarte rapidamente!";
		a_nachricht_text(383, 1) = "Monsters!";
		a_nachricht_text(383, 2) = "Monster!";
		a_nachricht_text(383, 3) = "Monstruos!";
		a_nachricht_text(384, 1) = "There are a lot of monsters in";
		a_nachricht_text(384, 2) = "In diesem Level sind unglaublich";
		a_nachricht_text(384, 3) = "En este nivel hay muchisimos";
		a_nachricht_text(385, 1) = "this level!";
		a_nachricht_text(385, 2) = "viele Monster!";
		a_nachricht_text(385, 3) = "monstruos!";
		a_nachricht_text(386, 1) = "Blocked Exit!";
		a_nachricht_text(386, 2) = "Verschlossener Ausgang!";
		a_nachricht_text(386, 3) = "Salida bloqueada!";
		a_nachricht_text(387, 1) = "You have to find the switch";
		a_nachricht_text(387, 2) = "Du musst den Schalter finden";
		a_nachricht_text(387, 3) = "Tienes que encontrar el interruptor";
		a_nachricht_text(388, 1) = "to get out!";
		a_nachricht_text(388, 2) = "um zu entkommen!";
		a_nachricht_text(388, 3) = "para escapar!";
		a_nachricht_text(389, 1) = "You pressed the button!";
		a_nachricht_text(389, 2) = "Du hast den Knopf gedr\374ckt!";
		a_nachricht_text(389, 3) = "Accionaste el interuptor!";
		a_nachricht_text(390, 1) = "No Nexus!";
		a_nachricht_text(390, 2) = "Kein Nexus!";
		a_nachricht_text(390, 3) = "No Nexos!";
		a_nachricht_text(391, 1) = "This level has no Nexus!";
		a_nachricht_text(391, 2) = "Dieser Level hat keinen Nexus!";
		a_nachricht_text(391, 3) = "En este nivel no hay nexos!";
		a_nachricht_text(392, 1) = "No Sanktum!";
		a_nachricht_text(392, 2) = "Kein Sanktum!";
		a_nachricht_text(392, 3) = "No Santuarios!";
		a_nachricht_text(393, 1) = "This level has no Sanktum!";
		a_nachricht_text(393, 2) = "Dieser Level hat kein Sanktum!";
		a_nachricht_text(393, 3) = "En este nivel no hay santuarios!";
		a_nachricht_text(394, 1) = "Ambushes!";
		a_nachricht_text(394, 2) = "Hinteralte!";
		a_nachricht_text(394, 3) = "Emboscadas!";
		a_nachricht_text(395, 1) = "The chances to get trapped here";
		a_nachricht_text(395, 2) = "Die Wahrscheinlichkeit hier in einen";
		a_nachricht_text(395, 3) = "La posibilidad de encontrar un emboscada";
		a_nachricht_text(396, 1) = "are very high!";
		a_nachricht_text(396, 2) = "Hinterhalt zu geraten ist hoch!";
		a_nachricht_text(396, 3) = "aqui es enorme!";
		a_nachricht_text(397, 1) = "Poisonous fog!";
		a_nachricht_text(397, 2) = "Giftiger Nebel!";
		a_nachricht_text(397, 3) = "Niebla venenosa!";
		a_nachricht_text(398, 1) = "The whole level is filled with fog!";
		a_nachricht_text(398, 2) = "Der ganze Level ist mit Nebel gef\374llt!";
		a_nachricht_text(398, 3) = "Todo el nivel es lleno de niebla!";
		a_nachricht_text(399, 1) = "And it's poisoneous!";
		a_nachricht_text(399, 2) = "Und dieser ist giftig!";
		a_nachricht_text(399, 3) = "Y lo esta venenoso!";
		a_nachricht_text(400, 1) = "Angel";
		a_nachricht_text(400, 2) = "Engel";
		a_nachricht_text(400, 3) = "Angel";
		a_nachricht_text(401, 1) = "Demon";
		a_nachricht_text(401, 2) = "D\344mon";
		a_nachricht_text(401, 3) = "Demonio";
		a_nachricht_text(402, 1) = "Dragon";
		a_nachricht_text(402, 2) = "Drache";
		a_nachricht_text(402, 3) = "Dragon";
		a_nachricht_text(403, 1) = "Construct";
		a_nachricht_text(403, 2) = "Konstrukt";
		a_nachricht_text(403, 3) = "Constructo";
		a_nachricht_text(404, 1) = "Wraith";
		a_nachricht_text(404, 2) = "Geist";
		a_nachricht_text(404, 3) = "Fantasma";
		a_nachricht_text(405, 1) = "Load";
		a_nachricht_text(405, 2) = "Laden";
		a_nachricht_text(405, 3) = "Cargar";
		a_nachricht_text(406, 1) = "No Savegame!";
		a_nachricht_text(406, 2) = "Kein Savegame!";
		a_nachricht_text(406, 3) = "No hay ningun juego guardado!";
		a_nachricht_text(407, 1) = "Could not be saved!";
		a_nachricht_text(407, 2) = "Konnte nicht speichern!";
		a_nachricht_text(407, 3) = "No se pudo guardar!";
		a_nachricht_text(408, 1) = "X: Skip Turn";
		a_nachricht_text(408, 2) = "X: Zug beenden";
		a_nachricht_text(408, 3) = "X: Terminar Turno";
		a_nachricht_text(409, 1) = "Not enough Lifepoints!";
		a_nachricht_text(409, 2) = "Nicht genug Lebenspunkte!";
		a_nachricht_text(409, 3) = "No tienes suficientes Puntos de Vida!";
		a_nachricht_text(410, 1) = "You found a forgotten Forge!";
		a_nachricht_text(410, 2) = "Du hast eine vergessene Schmiede gefunden!";
		a_nachricht_text(410, 3) = "Enconstraste una forja olvidada!";
		a_nachricht_text(411, 1) = "Maybe you can make a weapon?";
		a_nachricht_text(411, 2) = "Vielleicht kannst du eine Waffe schmieden?";
		a_nachricht_text(411, 3) = "Tal vez puedes forjar una arma?";
		a_nachricht_text(412, 1) = "You repaird all your weapons and armor!";
		a_nachricht_text(412, 2) = "Du hast alle deine Waffen und R\374stungen repariert!";
		a_nachricht_text(412, 3) = "Arreglaste todas sus armas y armaduras!";
		a_nachricht_text(413, 1) = "The forge is destroyed!";
		a_nachricht_text(413, 2) = "Die Schmiede ist zerst\366rt!";
		a_nachricht_text(413, 3) = "La forja se rompe!";
		a_nachricht_text(414, 1) = "You couldn't forge anything!";
		a_nachricht_text(414, 2) = "Du konntest nicht schmieden!";
		a_nachricht_text(414, 3) = "No pudiste forjar nada!";
		a_nachricht_text(415, 1) = "ESC: Release/Lock Mouse";
		a_nachricht_text(415, 2) = "ESC: Maus freigeben/benutzen";
		a_nachricht_text(415, 3) = "ESC: Soltar/Bloquear el raton";
		a_nachricht_text(416, 1) = "Do not Train";
		a_nachricht_text(416, 2) = "Nicht Trainieren";
		a_nachricht_text(416, 3) = "No Entrenar";
		a_nachricht_text(417, 1) = "You already wear a belt!";
		a_nachricht_text(417, 2) = "Du tr\344gst schon einen Guertel!";
		a_nachricht_text(417, 3) = "Ya llevas equipado un cinturon!";
		a_nachricht_text(418, 1) = "You already wear a medallion!";
		a_nachricht_text(418, 2) = "Du tr\344gst schon ein Amulett!";
		a_nachricht_text(418, 3) = "Ya llevas equipado un medallion!";
		a_nachricht_text(419, 1) = "You already wear a mask!";
		a_nachricht_text(419, 2) = "Du tr\344gst schon eine Maske!";
		a_nachricht_text(419, 3) = "Ya llevas equipada una mascara!";
		a_nachricht_text(420, 1) = "Extremely Hot!";
		a_nachricht_text(420, 2) = "T\366dliche Hitze!";
		a_nachricht_text(420, 3) = "Muy Caliente!";
		a_nachricht_text(421, 1) = "The tempreture in this level is extremely hot!";
		a_nachricht_text(421, 2) = "Dieser Level ist unglaublich heiss!";
		a_nachricht_text(421, 3) = "La temperatura de este nivel es muy alta!";
		a_nachricht_text(422, 1) = "Don't get burned here!";
		a_nachricht_text(422, 2) = "Verbrenne dich nicht!";
		a_nachricht_text(422, 3) = "No te quemes aqui!";
		a_nachricht_text(423, 1) = "Extremely Cold!";
		a_nachricht_text(423, 2) = "T\366dliche K\344lte!";
		a_nachricht_text(423, 3) = "Muy Frio!";
		a_nachricht_text(424, 1) = "The tempreture in this level is extremely cold!";
		a_nachricht_text(424, 2) = "Dieser Level ist unglaublich kalt!";
		a_nachricht_text(424, 3) = "La temperatura de este nivel es muy baja!";
		a_nachricht_text(425, 1) = "Take care not to freeze to death!";
		a_nachricht_text(425, 2) = "Pass auf das du nicht erfrierst!";
		a_nachricht_text(425, 3) = "Ten Cuidad para no te morirte congelado!";
		a_nachricht_text(426, 1) = "This room seems to be empty!";
		a_nachricht_text(426, 2) = "Dieser Raum scheint leer zu sein!";
		a_nachricht_text(426, 3) = "Esta habitacion parece estar vacia!";
		a_nachricht_text(427, 1) = "You are protected agaist lightning!";
		a_nachricht_text(427, 2) = "Du bist gegen Blitze gesch\374tzt!";
		a_nachricht_text(427, 3) = "Estas protegido contra rayos!";
		a_nachricht_text(428, 1) = "Your Backpack is full!";
		a_nachricht_text(428, 2) = "Dein Rucksack ist voll!";
		a_nachricht_text(428, 3) = "Tu mochila esta llena!";
		a_nachricht_text(429, 1) = "You evaded being turned to stone!";
		a_nachricht_text(429, 2) = "Du konntest verhindern versteinert zu werden!";
		a_nachricht_text(429, 3) = "Evitaste ser convertido en piedra!";
		a_nachricht_text(430, 1) = "You evaded being killed by Deathvision!";
		a_nachricht_text(430, 2) = "Du konntest einen Todesblick verhindern!";
		a_nachricht_text(430, 3) = "Pudiste evitar la mirada de la muerte!";
		a_nachricht_text(431, 1) = "You are invulnerable!";
		a_nachricht_text(431, 2) = "Du bist unverwundbar!";
		a_nachricht_text(431, 3) = "Eres invulnerable!";
		a_nachricht_text(432, 1) = "This was the last stone!";
		a_nachricht_text(432, 2) = "Das war der letzte Stein!";
		a_nachricht_text(432, 3) = "Esa fue tu ultima piedra!";
		a_nachricht_text(433, 1) = "You already carry a ranged weapon!";
		a_nachricht_text(433, 2) = "Du tr\344gst schon eine Fernkampf Waffe!";
		a_nachricht_text(433, 3) = "Ya llevas equipada una arma de largo alcance!";
		a_nachricht_text(434, 1) = "You already carry a 2H weapon!";
		a_nachricht_text(434, 2) = "Du tr\344gst schon eine Zweihandwaffe!";
		a_nachricht_text(434, 3) = "Ya llevas equipada una arma a dos manos!";
		a_nachricht_text(435, 1) = "You already carry 2 weapons!";
		a_nachricht_text(435, 2) = "Du tr\344gst schon 2 Waffen!";
		a_nachricht_text(435, 3) = "Ya llevas equipada dos armas!";
		a_nachricht_text(436, 1) = "Number of Rounds";
		a_nachricht_text(436, 2) = "Anzahl Runden";
		a_nachricht_text(436, 3) = "Cantidad de turnos";
		a_nachricht_text(437, 1) = "You bought: ";
		a_nachricht_text(437, 2) = "Du hast gekauft: ";
		a_nachricht_text(437, 3) = "Compraste: ";
		a_nachricht_text(438, 1) = "You sold: ";
		a_nachricht_text(438, 2) = "Du hast vergekauft: ";
		a_nachricht_text(438, 3) = "Vendiste: ";
		a_nachricht_text(439, 1) = "You go one level up!";
		a_nachricht_text(439, 2) = "Du gehst einen Level nach oben!";
		a_nachricht_text(439, 3) = "Entras en el proximo nivel!";
		a_nachricht_text(440, 1) = "This is the first level!";
		a_nachricht_text(440, 2) = "Das ist der erste Level!";
		a_nachricht_text(440, 3) = "Esto es el primer nivel!";
		a_nachricht_text(441, 1) = "Invisible Opponent!";
		a_nachricht_text(441, 2) = "Unsichtbarer Gegner!";
		a_nachricht_text(441, 3) = "Oponente invisible!";
		a_nachricht_text(442, 1) = "This was the last stone!";
		a_nachricht_text(442, 2) = "Das war der letzte Stein!";
		a_nachricht_text(442, 3) = "Esa fue la ultima piedra!";
		a_nachricht_text(443, 1) = "You stole a scroll!";
		a_nachricht_text(443, 2) = "Du stiehlst eine Schriftrolle!";
		a_nachricht_text(443, 3) = "Robaste un pergamino!";
		a_nachricht_text(444, 1) = "You are invisible!";
		a_nachricht_text(444, 2) = "Du bist unsichtbar!";
		a_nachricht_text(444, 3) = "Eres invisible!";
		a_nachricht_text(445, 1) = "You found nothing!";
		a_nachricht_text(445, 2) = "Du findest nichts!";
		a_nachricht_text(445, 3) = "No encontraste nada!";
		a_nachricht_text(446, 1) = "Maybe something is buried here?";
		a_nachricht_text(446, 2) = "Vielleicht ist hier etwas vergraben?";
		a_nachricht_text(446, 3) = "Tal vez hay algo escondido aqui?";
		a_nachricht_text(447, 1) = "Now move the Character!";
		a_nachricht_text(447, 2) = "Jetzt der Character!";
		a_nachricht_text(447, 3) = "Mueve ahora el personaje!";
		a_nachricht_text(448, 1) = "Your Weapon has been damaged!";
		a_nachricht_text(448, 2) = "Deine Waffe wurde besch\344digt!";
		a_nachricht_text(448, 3) = "Tu arma fue danada!";
		a_nachricht_text(449, 1) = "Your weapon broke!";
		a_nachricht_text(449, 2) = "Deine Waffe zerbrach!";
		a_nachricht_text(449, 3) = "Tu arma se rompe!";
		a_nachricht_text(450, 1) = "Your armor has been damaged!";
		a_nachricht_text(450, 2) = "Deine R\374stung wurde besch\344digt!";
		a_nachricht_text(450, 3) = "Tu armadura fue danada!";
		a_nachricht_text(451, 1) = "Your armor broke!";
		a_nachricht_text(451, 2) = "Deine R\374stung zerbrach!";
		a_nachricht_text(451, 3) = "Tu armadura se rompe!";
		a_nachricht_text(452, 1) = "    Choose an Item to poison:";
		a_nachricht_text(452, 2) = "W\344hle einen Gegenstand zum vergiften:";
		a_nachricht_text(452, 3) = "   Escoje un Objeto para envenenar:";
		a_nachricht_text(453, 1) = "The weapon is poisoneous now!";
		a_nachricht_text(453, 2) = "Die Waffe ist nun giftig!";
		a_nachricht_text(453, 3) = "La arma ya esta envenenada!";
		a_nachricht_text(454, 1) = "Only weapons!";
		a_nachricht_text(454, 2) = "Nur Waffen!";
		a_nachricht_text(454, 3) = "Solo armas!";
		a_nachricht_text(455, 1) = "This weapon is broken!";
		a_nachricht_text(455, 2) = "Diese Waffe ist kaputt!";
		a_nachricht_text(455, 3) = "Esta arma esta rota!";
		a_nachricht_text(456, 1) = "Cannot be poisoned!";
		a_nachricht_text(456, 2) = "Kann nicht vergiftet werden!";
		a_nachricht_text(456, 3) = "No lo puedes envenenar!";
		a_nachricht_text(457, 1) = "You move by!";
		a_nachricht_text(457, 2) = "Du l\344ufst vorbei!";
		a_nachricht_text(457, 3) = "Pasas!";
		a_nachricht_text(458, 1) = "Merchant!!!";
		a_nachricht_text(458, 2) = "H\344ndler!!!";
		a_nachricht_text(458, 3) = "Comerciante!!!";
		a_nachricht_text(459, 1) = "Forest!!!";
		a_nachricht_text(459, 2) = "Wald!!!";
		a_nachricht_text(459, 3) = "Bosque!!!";
		a_nachricht_text(460, 1) = "Pentagram!!!";
		a_nachricht_text(460, 2) = "Pentagram!!!";
		a_nachricht_text(460, 3) = "Pentagrama!!!";
		a_nachricht_text(461, 1) = "Sanctum!!!";
		a_nachricht_text(461, 2) = "Sanktum!!!";
		a_nachricht_text(461, 3) = "Santuario!!!";
		a_nachricht_text(462, 1) = "Library!!!";
		a_nachricht_text(462, 2) = "Bibliothek!!!";
		a_nachricht_text(462, 3) = "Libreria!!!";
		a_nachricht_text(463, 1) = "Laboratory!!!";
		a_nachricht_text(463, 2) = "Labor!!!";
		a_nachricht_text(463, 3) = "Laboratorio!!!";
		a_nachricht_text(464, 1) = "Statue!!!";
		a_nachricht_text(464, 2) = "Statue!!!";
		a_nachricht_text(464, 3) = "Estatua!!!";
		a_nachricht_text(465, 1) = "Monstertrap!!!";
		a_nachricht_text(465, 2) = "Monsterfalle!!!";
		a_nachricht_text(465, 3) = "Trampa de Monstruos!!!";
		a_nachricht_text(466, 1) = "Chests!!!";
		a_nachricht_text(466, 2) = "Truhen!!!";
		a_nachricht_text(466, 3) = "Cajas!!!";
		a_nachricht_text(467, 1) = "Gold!!!";
		a_nachricht_text(467, 2) = "Gold!!!";
		a_nachricht_text(467, 3) = "Oro!!!";
		a_nachricht_text(468, 1) = "Cemetary!!!";
		a_nachricht_text(468, 2) = "Friedhof!!!";
		a_nachricht_text(468, 3) = "Cementerio!!!";
		a_nachricht_text(469, 1) = "Pond!!!";
		a_nachricht_text(469, 2) = "Brunnen!!!";
		a_nachricht_text(469, 3) = "Pozo!!!";
		a_nachricht_text(470, 1) = "Treasure!!!";
		a_nachricht_text(470, 2) = "Schatz!!!";
		a_nachricht_text(470, 3) = "Tesoro!!!";
		a_nachricht_text(471, 1) = "Firedemon!!!";
		a_nachricht_text(471, 2) = "Feuerd\344mon!!!";
		a_nachricht_text(471, 3) = "Demonio de Fuego!!!";
		a_nachricht_text(472, 1) = "Teacher!!!";
		a_nachricht_text(472, 2) = "Lehrer!!!";
		a_nachricht_text(472, 3) = "Maestro!!!";
		a_nachricht_text(473, 1) = "Dragon!!!";
		a_nachricht_text(473, 2) = "Drache!!!";
		a_nachricht_text(473, 3) = "Dragon!!!";
		a_nachricht_text(474, 1) = "Tavern!!!";
		a_nachricht_text(474, 2) = "Taverne!!!";
		a_nachricht_text(474, 3) = "Taverna!!!";
		a_nachricht_text(475, 1) = "Hydra!!!";
		a_nachricht_text(475, 2) = "Hydra!!!";
		a_nachricht_text(475, 3) = "Hydra!!!";
		a_nachricht_text(476, 1) = "Mage!!!";
		a_nachricht_text(476, 2) = "Magier!!!";
		a_nachricht_text(476, 3) = "Mago!!!";
		a_nachricht_text(477, 1) = "Lake!!!";
		a_nachricht_text(477, 2) = "See!!!";
		a_nachricht_text(477, 3) = "Lago!!!";
		a_nachricht_text(478, 1) = "Forge!!!";
		a_nachricht_text(478, 2) = "Schmiede!!!";
		a_nachricht_text(478, 3) = "Forja!!!";
		a_nachricht_text(479, 1) = "Traps!!!";
		a_nachricht_text(479, 2) = "Fallen!!!";
		a_nachricht_text(479, 3) = "Trampas!!!";
		a_nachricht_text(480, 1) = "Monster does not sleep!";
		a_nachricht_text(480, 2) = "Monster schl\344ft nicht!";
		a_nachricht_text(480, 3) = "Montruo no se duerme!";
		a_nachricht_text(481, 1) = "Sleeps";
		a_nachricht_text(481, 2) = "Schl\344ft";
		a_nachricht_text(481, 3) = "Duerme";
		a_nachricht_text(482, 1) = "You couldn't learn the spell!";
		a_nachricht_text(482, 2) = "Du konntest den Spruch nicht lernen!";
		a_nachricht_text(482, 3) = "No pudiste aprender el hechizo!";
		a_nachricht_text(483, 1) = "You know a new Spell!";
		a_nachricht_text(483, 2) = "Du kannst einen neuen Spruch!";
		a_nachricht_text(483, 3) = "Conoces un nuevo hechizo!";
		a_nachricht_text(484, 1) = "You enter an old cemetary!";
		a_nachricht_text(484, 2) = "Du betrittst einen alten Friedhof!";
		a_nachricht_text(484, 3) = "Entras en un antiguo cementerio!";
		a_nachricht_text(485, 1) = "It smells like rotting here!";
		a_nachricht_text(485, 2) = "Es riecht nach Verwesung hier!";
		a_nachricht_text(485, 3) = "Huele a muerto aqui!";
		a_nachricht_text(486, 1) = "Configuration saved!";
		a_nachricht_text(486, 2) = "Einstellungen gesichert!";
		a_nachricht_text(486, 3) = "Configuracion guardada!";
		a_nachricht_text(487, 1) = "Configuration could not be saved!";
		a_nachricht_text(487, 2) = "Einstellungen konnten nicht gesichert werden!";
		a_nachricht_text(487, 3) = "No pude guardar la configuracion!";
		a_nachricht_text(488, 1) = "The desert of forgetfulness!";
		a_nachricht_text(488, 2) = "Die W\374ste des Vergessens!";
		a_nachricht_text(488, 3) = "El desierto del olvido!";
		a_nachricht_text(489, 1) = "Its really hot and dry here!";
		a_nachricht_text(489, 2) = "Es ist unglaublich heiss und trocken hier!";
		a_nachricht_text(489, 3) = "Esta todo seco y hace mucho calor!";
		a_nachricht_text(490, 1) = "Don't run out of water!";
		a_nachricht_text(490, 2) = "Pass auf das du nicht verdurstest!";
		a_nachricht_text(490, 3) = "No te quedes sin aqua!";
		a_nachricht_text(491, 1) = "The archipelago of the ancients!";
		a_nachricht_text(491, 2) = "Der Archipel der Alten!";
		a_nachricht_text(491, 3) = "El Archipelago de los ancianos!";
		a_nachricht_text(492, 1) = "A great ocean with small islands...";
		a_nachricht_text(492, 2) = "Ein grosses Meer mit kleinen Inseln...";
		a_nachricht_text(492, 3) = "Un mar grande con muchas islas pequenas...";
		a_nachricht_text(493, 1) = "Maybe we can find some treasure here...";
		a_nachricht_text(493, 2) = "Vielleicht k\366nnen wir hier Sch\344tze finden...";
		a_nachricht_text(493, 3) = "Tal vez podemos encontrar tesoros aqui...";
		a_nachricht_text(494, 1) = "This spot has been fished already!";
		a_nachricht_text(494, 2) = "Hier wurde schon gefischt!";
		a_nachricht_text(494, 3) = "Ya pescaste aqui!";
		a_nachricht_text(495, 1) = "You coulnd't catch anything!";
		a_nachricht_text(495, 2) = "Du konntest nichts fangen!";
		a_nachricht_text(495, 3) = "No pudiste pescar algo!";
		a_nachricht_text(496, 1) = "You caught something!";
		a_nachricht_text(496, 2) = "Du hast etwas gefangen!";
		a_nachricht_text(496, 3) = "Pescaste algo!";
		a_nachricht_text(497, 1) = "Only in Water!";
		a_nachricht_text(497, 2) = "Nur in Wasser!";
		a_nachricht_text(497, 3) = "Solamente en el aqua!";
		a_nachricht_text(498, 1) = "The rune explodes and destroys your creature!";
		a_nachricht_text(498, 2) = "Die Rune explodiert und zerst\366rt deine Kreatur!";
		a_nachricht_text(498, 3) = "La runa explota y destruye a tu criatura!";
		a_nachricht_text(499, 1) = "The rune explodes and damages your creature!";
		a_nachricht_text(499, 2) = "Die Rune explodiert und verletzt deine Kreatur!";
		a_nachricht_text(499, 3) = "La runa explota y dana a tu criatura!";
		a_nachricht_text(500, 1) = "You enter a wonderful Throneroom!";
		a_nachricht_text(500, 2) = "Du betrittst einen prunkvollen Thronsaal!";
		a_nachricht_text(500, 3) = "Entras en el aposento de un rey!";
		a_nachricht_text(501, 1) = "The king looks at you and smiles!";
		a_nachricht_text(501, 2) = "Der K\366nig schaut dich grinsend an!";
		a_nachricht_text(501, 3) = "El rey te mira sonriendo!";
		a_nachricht_text(502, 1) = "It seems he doesn't want to let you go!";
		a_nachricht_text(502, 2) = "Er scheint dich nicht gehen lassen zu wollen!";
		a_nachricht_text(502, 3) = "Parece que no va a dejarte ir!";
		a_nachricht_text(503, 1) = "Does not need air!";
		a_nachricht_text(503, 2) = "Braucht keine Luft!";
		a_nachricht_text(503, 3) = "No necesita aire!";
		a_nachricht_text(504, 1) = "The swamp of loneliness!";
		a_nachricht_text(504, 2) = "Der Sumpf der Einsamkeit!";
		a_nachricht_text(504, 3) = "El pantano de la soledad!";
		a_nachricht_text(505, 1) = "The air here is very bad!";
		a_nachricht_text(505, 2) = "Die luft hier ist sehr schlecht!";
		a_nachricht_text(505, 3) = "El aire aqui es muy malo!";
		a_nachricht_text(506, 1) = "Don't get lost!";
		a_nachricht_text(506, 2) = "Verlaufe dich nicht!";
		a_nachricht_text(506, 3) = "No te pierdas!";
		a_nachricht_text(507, 1) = "Throneroom!!!";
		a_nachricht_text(507, 2) = "Thronsaal!!!";
		a_nachricht_text(507, 3) = "Aposento!!!";
		a_nachricht_text(508, 1) = "The wounded Hero";
		a_nachricht_text(508, 2) = "Der verwundete Krieger";
		a_nachricht_text(508, 3) = "El luchador herido";
		a_nachricht_text(509, 1) = "Please my friend. Help me if you can!";
		a_nachricht_text(509, 2) = "Bitte mein Freund hilf mir wenn du kannst!";
		a_nachricht_text(509, 3) = "Por favor, ayudame amigo si puedes!";
		a_nachricht_text(510, 1) = "Use healing potion";
		a_nachricht_text(510, 2) = "Benutze Heiltrank";
		a_nachricht_text(510, 3) = "Usas pocion de curacion";
		a_nachricht_text(511, 1) = "Cast heal others";
		a_nachricht_text(511, 2) = "Zaubere Andere heilen";
		a_nachricht_text(511, 3) = "Lanzas curar a otros sobre el";
		a_nachricht_text(512, 1) = "I cannot help you";
		a_nachricht_text(512, 2) = "Ich kann dir nicht helfen";
		a_nachricht_text(512, 3) = "No puedo ayudarte";
		a_nachricht_text(513, 1) = "Hello my Friend!";
		a_nachricht_text(513, 2) = "Hallo mein Freund!";
		a_nachricht_text(513, 3) = "Hola mi amigo!";
		a_nachricht_text(514, 1) = "Thanks my Friend!";
		a_nachricht_text(514, 2) = "Danke mein Freund!";
		a_nachricht_text(514, 3) = "Gracias amigo!";
		a_nachricht_text(515, 1) = "You saved my life!";
		a_nachricht_text(515, 2) = "Du hast mein Leben gerettet!";
		a_nachricht_text(515, 3) = "Me salvaste la vida!";
		a_nachricht_text(516, 1) = "You do not have Heal others!";
		a_nachricht_text(516, 2) = "Du kennst den Spruch andere heilen nicht!";
		a_nachricht_text(516, 3) = "No conoces el hechizo curar otros!";
		a_nachricht_text(517, 1) = "You do not have a Healing Potion!";
		a_nachricht_text(517, 2) = "Du besitzt keinen Heiltrank!";
		a_nachricht_text(517, 3) = "No tienes una pocion de curacion!";
		a_nachricht_text(518, 1) = "M: Automap";
		a_nachricht_text(518, 2) = "M: Automap";
		a_nachricht_text(518, 3) = "M: Automapa";
		a_nachricht_text(519, 1) = "Screenmode changed!";
		a_nachricht_text(519, 2) = "Fenstermodus gewechselt!";
		a_nachricht_text(519, 3) = "Modo de Ventana cambiado!";
		a_nachricht_text(520, 1) = "Restart the Program!";
		a_nachricht_text(520, 2) = "Starte das Programm neu!";
		a_nachricht_text(520, 3) = "Reinicia el programa!";
		a_nachricht_text(521, 1) = "You get teleported back to the entry!";
		a_nachricht_text(521, 2) = "Du wirst zum Eingang teleportiert!";
		a_nachricht_text(521, 3) = "Eres teletransportado a la entrada!";
		a_nachricht_text(522, 1) = "The monster is alerted!";
		a_nachricht_text(522, 2) = "Das monster ist alarmiert!";
		a_nachricht_text(522, 3) = "El monstruo esta alerta!";
		a_nachricht_text(523, 1) = "What do you want to offer the gods?";
		a_nachricht_text(523, 2) = "Was m\366chtest du den G\366ttern opfern?";
		a_nachricht_text(523, 3) = "Que quieres sacrificar a los Dioses?";
		a_nachricht_text(524, 1) = "You cannot open this door!";
		a_nachricht_text(524, 2) = "Diese T\374r kannst du nicht \366ffnen!";
		a_nachricht_text(524, 3) = "No puedes abrir esta puerta!";
		a_nachricht_text(525, 1) = "Level:";
		a_nachricht_text(525, 2) = "Ebene:";
		a_nachricht_text(525, 3) = "Nivel:";
		a_nachricht_text(526, 1) = "Duration: ";
		a_nachricht_text(526, 2) = "Brenndauer: ";
		a_nachricht_text(526, 3) = "Duracion: ";
		a_nachricht_text(527, 1) = "Light?";
		a_nachricht_text(527, 2) = "Entfachen?";
		a_nachricht_text(527, 3) = "Encender?";
		a_nachricht_text(528, 1) = "Put out?";
		a_nachricht_text(528, 2) = "L\366schen?";
		a_nachricht_text(528, 3) = "Apagar?";
		a_nachricht_text(529, 1) = "Eat?";
		a_nachricht_text(529, 2) = "Essen?";
		a_nachricht_text(529, 3) = "Come?";
		a_nachricht_text(530, 1) = "Value: ";
		a_nachricht_text(530, 2) = "N\344hrwert: ";
		a_nachricht_text(530, 3) = "Valor: ";
		a_nachricht_text(531, 1) = "Heal 1-6 Lifepoints";
		a_nachricht_text(531, 2) = "Heilen 1-6 Lebenspunkte";
		a_nachricht_text(531, 3) = "Curan 1-6 Puntos de Vida";
		a_nachricht_text(532, 1) = "Wear?";
		a_nachricht_text(532, 2) = "Anziehen?";
		a_nachricht_text(532, 3) = "Ponerse?";
		a_nachricht_text(533, 1) = "Remove?";
		a_nachricht_text(533, 2) = "Ausziehen?";
		a_nachricht_text(533, 3) = "Quitarse?";
		a_nachricht_text(534, 1) = "Enc: ";
		a_nachricht_text(534, 2) = "Beh: ";
		a_nachricht_text(534, 3) = "Ent: ";
		a_nachricht_text(535, 1) = " Prot: ";
		a_nachricht_text(535, 2) = " Schu: ";
		a_nachricht_text(535, 3) = " Prot: ";
		a_nachricht_text(536, 1) = "(Dam) ";
		a_nachricht_text(536, 2) = "(Besch) ";
		a_nachricht_text(536, 3) = "(Danado) ";
		a_nachricht_text(537, 1) = "(Dest) ";
		a_nachricht_text(537, 2) = "(Zerst) ";
		a_nachricht_text(537, 3) = "(Roto) ";
		a_nachricht_text(538, 1) = "(Ench) ";
		a_nachricht_text(538, 2) = "(Verz) ";
		a_nachricht_text(538, 3) = "(Hechi) ";
		a_nachricht_text(539, 1) = "(Poisoned) ";
		a_nachricht_text(539, 2) = "(Vergiftet) ";
		a_nachricht_text(539, 3) = "(Envenenado) ";
		a_nachricht_text(540, 1) = "Equip?";
		a_nachricht_text(540, 2) = "In die Hand nehmen?";
		a_nachricht_text(540, 3) = "Equipar?";
		a_nachricht_text(541, 1) = "Unequip?";
		a_nachricht_text(541, 2) = "In Rucksack?";
		a_nachricht_text(541, 3) = "Desequipar?";
		a_nachricht_text(542, 1) = "Throw?";
		a_nachricht_text(542, 2) = "Werfen?";
		a_nachricht_text(542, 3) = "Tirar?";
		a_nachricht_text(543, 1) = "Att: ";
		a_nachricht_text(543, 2) = "Att: ";
		a_nachricht_text(543, 3) = "Ata: ";
		a_nachricht_text(544, 1) = " Dam: ";
		a_nachricht_text(544, 2) = " Schad: ";
		a_nachricht_text(544, 3) = " Dano: ";
		a_nachricht_text(545, 1) = " Crit: ";
		a_nachricht_text(545, 2) = " Krit: ";
		a_nachricht_text(545, 3) = " Crit: ";
		a_nachricht_text(546, 1) = "Am. ";
		a_nachricht_text(546, 2) = "Anz. ";
		a_nachricht_text(546, 3) = "Am. ";
		a_nachricht_text(547, 1) = " +2 Strength";
		a_nachricht_text(547, 2) = " +2 St\344rke";
		a_nachricht_text(547, 3) = " +2 Fuerza";
		a_nachricht_text(548, 1) = " Charges: ";
		a_nachricht_text(548, 2) = " Ladungen: ";
		a_nachricht_text(548, 3) = " Cargas: ";
		a_nachricht_text(549, 1) = "Drink?";
		a_nachricht_text(549, 2) = "Trinken?";
		a_nachricht_text(549, 3) = "Beber?";
		a_nachricht_text(550, 1) = " sips";
		a_nachricht_text(550, 2) = " Schluck";
		a_nachricht_text(550, 3) = " Sorbos";
		a_nachricht_text(551, 1) = "Use?";
		a_nachricht_text(551, 2) = "Benutzen?";
		a_nachricht_text(551, 3) = "Usar?";
		a_nachricht_text(552, 1) = "Learn?";
		a_nachricht_text(552, 2) = "Lernen?";
		a_nachricht_text(552, 3) = "Aprender?";
		a_nachricht_text(553, 1) = "Unknown ";
		a_nachricht_text(553, 2) = "Unbekannt ";
		a_nachricht_text(553, 3) = "Desconocido ";
		a_nachricht_text(554, 1) = "(Opens Chests and Doors)";
		a_nachricht_text(554, 2) = "(\326ffnet Truhen und T\374ren)";
		a_nachricht_text(554, 3) = "(Abre cajas y puertas)";
		a_nachricht_text(555, 1) = "View?";
		a_nachricht_text(555, 2) = "Anschauen?";
		a_nachricht_text(555, 3) = "Ver?";
		a_nachricht_text(556, 1) = "Shows Map. Charges: ";
		a_nachricht_text(556, 2) = "Zeigt Karte. Ladungen: ";
		a_nachricht_text(556, 3) = "Muestra mapa. Cargas: ";
		a_nachricht_text(557, 1) = "Poison?";
		a_nachricht_text(557, 2) = "Vergiften?";
		a_nachricht_text(557, 3) = "Envenenar?";
		a_nachricht_text(558, 1) = "Thaumaturgy?";
		a_nachricht_text(558, 2) = "Thaumaturgie?";
		a_nachricht_text(558, 3) = "Taumaturgia?";
		a_nachricht_text(559, 1) = "Climb down?";
		a_nachricht_text(559, 2) = "Hinabsteigen?";
		a_nachricht_text(559, 3) = "Bajar?";
		a_nachricht_text(560, 1) = "Fish here?";
		a_nachricht_text(560, 2) = "Hier angeln?";
		a_nachricht_text(560, 3) = "Pescar aqui?";
		a_nachricht_text(561, 1) = "Dig?";
		a_nachricht_text(561, 2) = "Graben?";
		a_nachricht_text(561, 3) = "Cavar?";
		a_nachricht_text(562, 1) = "You repaired your weapons/shield/armor!";
		a_nachricht_text(562, 2) = "Du hast deine Waffen/Schilde/R\374stungen repariert!";
		a_nachricht_text(562, 3) = "Arreglaste tus armas/armaduras/escudos!";
		a_nachricht_text(563, 1) = "Repair?";
		a_nachricht_text(563, 2) = "Reparieren?";
		a_nachricht_text(563, 3) = "Arreglar?";
		a_nachricht_text(564, 1) = "Combine with a weapon?";
		a_nachricht_text(564, 2) = "Mit Waffe kombinieren?";
		a_nachricht_text(564, 3) = "Combinar con una arma?";
		a_nachricht_text(565, 1) = "With which weapon?";
		a_nachricht_text(565, 2) = "Mit welcher Waffe?";
		a_nachricht_text(565, 3) = "Con que arma?";
		a_nachricht_text(566, 1) = "Is not the right weapon!";
		a_nachricht_text(566, 2) = "Ist keine geeignete!";
		a_nachricht_text(566, 3) = "Esa arma no sirve!";
		a_nachricht_text(567, 1) = "You created a magical Weapon!";
		a_nachricht_text(567, 2) = "Du hast eine magische Waffe erschaffen!";
		a_nachricht_text(567, 3) = "Creaste una arma magica!";
		a_nachricht_text(568, 1) = "Save your Lost Labyrinth Games";
		a_nachricht_text(568, 2) = "Speichere deine Lost Labyrinth Spielst\344nde";
		a_nachricht_text(568, 3) = "Guarda tus partidas de Lost Labyrinth";
		a_nachricht_text(569, 1) = "Select a slot";
		a_nachricht_text(569, 2) = "W\344hle eine Position aus";
		a_nachricht_text(569, 3) = "Seleciona una posicion";
		a_nachricht_text(570, 1) = "Load your Lost Labyrinth Games";
		a_nachricht_text(570, 2) = "Lade deine Lost Labyrinth Spielst\344nde";
		a_nachricht_text(570, 3) = "Carga tus partidas de Lost Labyrinth";
		a_nachricht_text(571, 1) = "Name:";
		a_nachricht_text(571, 2) = "Name:";
		a_nachricht_text(571, 3) = "Nombre:";
		a_nachricht_text(572, 1) = "Help: Special Keys";
		a_nachricht_text(572, 2) = "Hilfe: Tastenbelegung";
		a_nachricht_text(572, 3) = "Ayuda: Teclas especiales";
		a_nachricht_text(573, 1) = "Monsterlore";
		a_nachricht_text(573, 2) = "Monsterkunde";
		a_nachricht_text(573, 3) = "Conocimiento de Montruos";
		a_nachricht_text(574, 1) = "Sneak";
		a_nachricht_text(574, 2) = "Schleichen";
		a_nachricht_text(574, 3) = "Caminar en silencio";
		a_nachricht_text(575, 1) = "Climb";
		a_nachricht_text(575, 2) = "Klettern";
		a_nachricht_text(575, 3) = "Escalar";
		a_nachricht_text(576, 1) = "Steal";
		a_nachricht_text(576, 2) = "Stehlen";
		a_nachricht_text(576, 3) = "Robar";
		a_nachricht_text(577, 1) = "Inventory";
		a_nachricht_text(577, 2) = "Inventar";
		a_nachricht_text(577, 3) = "Inventorio";
		a_nachricht_text(578, 1) = "Attributes";
		a_nachricht_text(578, 2) = "Attribute";
		a_nachricht_text(578, 3) = "Atributos";
		a_nachricht_text(579, 1) = "Ranged Combat";
		a_nachricht_text(579, 2) = "Fernkampf";
		a_nachricht_text(579, 3) = "Arco";
		a_nachricht_text(580, 1) = "Cast Spell";
		a_nachricht_text(580, 2) = "Zaubern";
		a_nachricht_text(580, 3) = "Hechizar";
		a_nachricht_text(581, 1) = "Options";
		a_nachricht_text(581, 2) = "Optionen";
		a_nachricht_text(581, 3) = "Opciones";
		a_nachricht_text(582, 1) = "Skip Turn";
		a_nachricht_text(582, 2) = "Runde beenden";
		a_nachricht_text(582, 3) = "Terminar turno";
		a_nachricht_text(583, 1) = "Mystic Bolt";
		a_nachricht_text(583, 2) = "Mystischer Schlag";
		a_nachricht_text(583, 3) = "Ataque mistico";
		a_nachricht_text(584, 1) = "Unknown scroll";
		a_nachricht_text(584, 2) = "Unbekannte Schriftrolle";
		a_nachricht_text(584, 3) = "Hechizo desconocido";
		a_nachricht_text(585, 1) = "Unknown Mushroom";
		a_nachricht_text(585, 2) = "Unbekannter Pilz";
		a_nachricht_text(585, 3) = "Hongo desconocido";
		a_nachricht_text(586, 1) = "Unknown Potion";
		a_nachricht_text(586, 2) = "Unbekannter Trank";
		a_nachricht_text(586, 3) = "Pocion desconocida";
		a_nachricht_text(587, 1) = "The Merchant offers: ";
		a_nachricht_text(587, 2) = "Der H\344ndler bietet: ";
		a_nachricht_text(587, 3) = "El comerciante ofrece: ";
		a_nachricht_text(588, 1) = "Template: Warrior";
		a_nachricht_text(588, 2) = "Template: K\344mpfer";
		a_nachricht_text(588, 3) = "Predefinido: Luchador";
		a_nachricht_text(589, 1) = "Template: Thief";
		a_nachricht_text(589, 2) = "Template: Dieb";
		a_nachricht_text(589, 3) = "Predefinido: Ladron";
		a_nachricht_text(590, 1) = "Template: White Mage";
		a_nachricht_text(590, 2) = "Template: Weisser Magier";
		a_nachricht_text(590, 3) = "Predefinido: Mago Blanco";
		a_nachricht_text(591, 1) = "Template: Archer";
		a_nachricht_text(591, 2) = "Template: Bogensch\374tze";
		a_nachricht_text(591, 3) = "Predefinido: Arquero";
		a_nachricht_text(592, 1) = "Template: Necromancer";
		a_nachricht_text(592, 2) = "Template: Nekromant";
		a_nachricht_text(592, 3) = "Predefinido: Nicromanto";
		a_nachricht_text(593, 1) = "Select your spell:";
		a_nachricht_text(593, 2) = "W\344hle deinen Zauber:";
		a_nachricht_text(593, 3) = "Elige tu hechizo:";
		a_nachricht_text(594, 1) = "Your active spells get terminated!";
		a_nachricht_text(594, 2) = "Deine aktiven Zauber werden beendet!";
		a_nachricht_text(594, 3) = "Tus hechizos activas se han acabado!";
		a_nachricht_text(595, 1) = "Sacrifice a valuable Item";
		a_nachricht_text(595, 2) = "Opfere einen wertvollen Gegenstand";
		a_nachricht_text(595, 3) = "Sacrifica un objeto de valor";
		a_nachricht_text(596, 1) = "Not valuable enough!";
		a_nachricht_text(596, 2) = "Nicht wertvoll genug!";
		a_nachricht_text(596, 3) = "No tiene valor sufficiente!";
		a_nachricht_text(597, 1) = "Weight: ";
		a_nachricht_text(597, 2) = "Gewicht: ";
		a_nachricht_text(597, 3) = "Peso: ";
		a_nachricht_text(598, 1) = " Kilo";
		a_nachricht_text(598, 2) = " Kilo";
		a_nachricht_text(598, 3) = " Kilo";
		a_nachricht_text(599, 1) = "Does not want to talk to you!";
		a_nachricht_text(599, 2) = "Will nicht mit dir reden!";
		a_nachricht_text(599, 3) = "No quiere hablar contigo!";
		a_nachricht_text(600, 1) = "Is not a monster!";
		a_nachricht_text(600, 2) = "Ist kein Monster!";
		a_nachricht_text(600, 3) = "No es un monstruo!";
		a_nachricht_text(601, 1) = "Is not a plant";
		a_nachricht_text(601, 2) = "Ist keine Pflanze!";
		a_nachricht_text(601, 3) = "No es una planta!";
		a_nachricht_text(602, 1) = "Is not a ghost!";
		a_nachricht_text(602, 2) = "Ist kein Geist!";
		a_nachricht_text(602, 3) = "No es una fantasma!";
		a_nachricht_text(603, 1) = "The monster shows you the exit!";
		a_nachricht_text(603, 2) = "Das Tier zeigt dir den Ausgang!";
		a_nachricht_text(603, 3) = "El animal te muestra la escalera!";
		a_nachricht_text(604, 1) = "Sacrifice a gem";
		a_nachricht_text(604, 2) = "Opfere einen Edelstein";
		a_nachricht_text(604, 3) = "Sacrifica una piedra preciosa";
		a_nachricht_text(605, 1) = "Not a gem!";
		a_nachricht_text(605, 2) = "Kein Edelstein!";
		a_nachricht_text(605, 3) = "No es una piedra preciosa!";
		a_nachricht_text(606, 1) = "Buy Experience (5000 G)?";
		a_nachricht_text(606, 2) = "Kaufe Erfahrung (5000 G)?";
		a_nachricht_text(606, 3) = "Compra Experiencia (5000 O)?";
		a_nachricht_text(607, 1) = "Alerted Monsters!";
		a_nachricht_text(607, 2) = "Alarmierte Monster!";
		a_nachricht_text(607, 3) = "Monstruos alertados!";
		a_nachricht_text(608, 1) = "All monsters in this level know you";
		a_nachricht_text(608, 2) = "Alle monster in diesem Level wissen das";
		a_nachricht_text(608, 3) = "Todos los monstruos en este nivel saben";
		a_nachricht_text(609, 1) = "are coming and are alerted!";
		a_nachricht_text(609, 2) = "du kommst und sind alarmiert!";
		a_nachricht_text(609, 3) = "que vienes y son alertados!";
		a_nachricht_text(610, 1) = "Gives 1-6 Manapoints";
		a_nachricht_text(610, 2) = "Gibt 1-6 Manapunkte";
		a_nachricht_text(610, 3) = "Da 1-6 Puntos de Mana";
		a_nachricht_text(611, 1) = "You cannot blow this away!";
		a_nachricht_text(611, 2) = "Das kannst du nicht wegblasen!";
		a_nachricht_text(611, 3) = "No puedes soplar de lejos eso!";
		a_nachricht_text(612, 1) = "Critical Hits: ";
		a_nachricht_text(612, 2) = "Kritische Treffer: ";
		a_nachricht_text(612, 3) = "Golpes Criticos: ";
		a_nachricht_text(613, 1) = "Avoid Traps: ";
		a_nachricht_text(613, 2) = "Fallen ausweichen: ";
		a_nachricht_text(613, 3) = "Eludir Trampas: ";
		a_nachricht_text(614, 1) = "Find Traps/Secret Doors: ";
		a_nachricht_text(614, 2) = "Fallen/Geheimt\374ren finden: ";
		a_nachricht_text(614, 3) = "Encontrar Trampas/Puertas: ";
		a_nachricht_text(615, 1) = "To Hit chance: ";
		a_nachricht_text(615, 2) = "Trefferchance: ";
		a_nachricht_text(615, 3) = "Posibilidades de alcanzar: ";
		a_nachricht_text(616, 1) = "The monster is blind!";
		a_nachricht_text(616, 2) = "Das monster ist blind!";
		a_nachricht_text(616, 3) = "El monstruo es ciego!";
		a_nachricht_text(617, 1) = "Alchemy?";
		a_nachricht_text(617, 2) = "Alchemie?";
		a_nachricht_text(617, 3) = "Alquimia?";
		a_nachricht_text(618, 1) = "Goblinlore";
		a_nachricht_text(618, 2) = "Goblinlehre";
		a_nachricht_text(618, 3) = "Sabiduria de goblins";
		a_nachricht_text(619, 1) = "Spiderlore";
		a_nachricht_text(619, 2) = "Spinnenlehre";
		a_nachricht_text(619, 3) = "Sabiduria de aranas";
		a_nachricht_text(620, 1) = "Undeadlore";
		a_nachricht_text(620, 2) = "Untotenlehre";
		a_nachricht_text(620, 3) = "Sabiduria de no-muertos";
		a_nachricht_text(621, 1) = "Animallore";
		a_nachricht_text(621, 2) = "Tierkunde";
		a_nachricht_text(621, 3) = "Sabiduria de animales";
		a_nachricht_text(622, 1) = "Traplore";
		a_nachricht_text(622, 2) = "Fallenlehre";
		a_nachricht_text(622, 3) = "Sabiduria de trampas";
		a_nachricht_text(623, 1) = "Poisonlore";
		a_nachricht_text(623, 2) = "Giftlehre";
		a_nachricht_text(623, 3) = "Sabiduria de venenos";
		a_nachricht_text(624, 1) = "Read?";
		a_nachricht_text(624, 2) = "Leser?";
		a_nachricht_text(624, 3) = "Leer?";
		a_nachricht_text(625, 1) = "You learned something new!";
		a_nachricht_text(625, 2) = "Du hast etwas neues gelernt!";
		a_nachricht_text(625, 3) = "Aprendiste algo nuevo!";
		a_nachricht_text(626, 1) = "Killed by ";
		a_nachricht_text(626, 2) = "Erschlagen von ";
		a_nachricht_text(626, 3) = "Muerto por ";
		a_nachricht_text(627, 1) = " destroyed!";
		a_nachricht_text(627, 2) = " vernichtet!";
		a_nachricht_text(627, 3) = " destruido!";
		a_nachricht_text(628, 1) = "Plantlore";
		a_nachricht_text(628, 2) = "Pflanzenkunde";
		a_nachricht_text(628, 3) = "Sabiduria de Plantas";
		a_nachricht_text(629, 1) = "Prevent Attack: ";
		a_nachricht_text(629, 2) = "Angriff vermeiden: ";
		a_nachricht_text(629, 3) = "Prevenir ataque: ";
		a_nachricht_text(630, 1) = "Turned to Stone";
		a_nachricht_text(630, 2) = "Versteinert";
		a_nachricht_text(630, 3) = "Convierta en Piedra";
		a_nachricht_text(631, 1) = "Killed by Ancient Hydra";
		a_nachricht_text(631, 2) = "Erschlagen von Uralter Hydra";
		a_nachricht_text(631, 3) = "Muerto por una Hydra anciana";
		a_nachricht_text(632, 1) = "Only on empty field!";
		a_nachricht_text(632, 2) = "Nur auf leerem Feld!";
		a_nachricht_text(632, 3) = "Solamente en un campo vacio!";
		a_nachricht_text(633, 1) = "No anchor point!";
		a_nachricht_text(633, 2) = "Kein Ankerpunkt!";
		a_nachricht_text(633, 3) = "No punto de ancla!";
		a_nachricht_text(634, 1) = "Set anchor point";
		a_nachricht_text(634, 2) = "Ankerpunkt setzen";
		a_nachricht_text(634, 3) = "Crear punto de ancla";
		a_nachricht_text(635, 1) = "Go to anchor point";
		a_nachricht_text(635, 2) = "Zum Ankerpunkt gehen";
		a_nachricht_text(635, 3) = "Mover a punto de ancla";
		a_nachricht_text(634, 1) = "Set anchor point";
		a_nachricht_text(634, 2) = "Ankerpunkt setzen";
		a_nachricht_text(634, 3) = "Crear punto de ancla";
		a_nachricht_text(635, 1) = "Go to anchor point";
		a_nachricht_text(635, 2) = "Zum Ankerpunkt gehen";
		a_nachricht_text(635, 3) = "Mover a punto de ancla";
		a_nachricht_text(636, 1) = " (Unarmed)";
		a_nachricht_text(636, 2) = " (Waffenlos)";
		a_nachricht_text(636, 3) = " (Sin arma)";
		a_nachricht_text(637, 1) = "Sacrifice a black gem";
		a_nachricht_text(637, 2) = "Opfere einen schwarzen Edelstein";
		a_nachricht_text(637, 3) = "Sacrifica una piedra preciosa negra";
		a_nachricht_text(638, 1) = "Not a black gem!";
		a_nachricht_text(638, 2) = "Kein schwarzer Edelstein!";
		a_nachricht_text(638, 3) = "No es una piedra preciosa negra!";
		a_nachricht_text(639, 1) = "All Skills";
		a_nachricht_text(639, 2) = "Alle F\344higkeiten";
		a_nachricht_text(639, 3) = "Todas las Habilidades";
		a_nachricht_text(640, 1) = "Monstertrap!";
		a_nachricht_text(640, 2) = "Monsterfalle!";
		a_nachricht_text(640, 3) = "Trampa de monstruos!";
		a_nachricht_text(641, 1) = "At first the room seems empty...";
		a_nachricht_text(641, 2) = "Zuerst scheint der Raum leer zu sein...";
		a_nachricht_text(641, 3) = "Al principio crees que la habitacion es vacia...";
		a_nachricht_text(642, 1) = "But then you realize that you have";
		a_nachricht_text(642, 2) = "Doch dann bemerkt du das du von";
		a_nachricht_text(642, 3) = "Pero pronto ves que tu estas rodeado";
		a_nachricht_text(643, 1) = "been surrounded by monsters!";
		a_nachricht_text(643, 2) = "Monstern umringt wurdest!";
		a_nachricht_text(643, 3) = "por monstruos!";
		a_nachricht_text(644, 1) = "Choose how you look like (Player ";
		a_nachricht_text(644, 2) = "W\344hle wie du aussiehst (Spieler ";
		a_nachricht_text(644, 3) = "Selecciona tu Figura (Jugador ";
		a_nachricht_text(645, 1) = "Poisoned ";
		a_nachricht_text(645, 2) = "Vergiftet ";
		a_nachricht_text(645, 3) = "Envenenado ";
		a_nachricht_text(646, 1) = "Weapon damaged!";
		a_nachricht_text(646, 2) = "Waffe besch\344digt!";
		a_nachricht_text(646, 3) = "Arma danada!";
		a_nachricht_text(647, 1) = "Armor damaged!";
		a_nachricht_text(647, 2) = "R\374stung besch\344digt!";
		a_nachricht_text(647, 3) = "Armadura danada!";
		a_nachricht_text(648, 1) = "The rune prevents you from trespassing!";
		a_nachricht_text(648, 2) = "Die Rune verhindert das du die \374berquerst!";
		a_nachricht_text(648, 3) = "La runa no te deja continuar!";
		a_nachricht_text(649, 1) = "Drop";
		a_nachricht_text(649, 2) = "Ablegen";
		a_nachricht_text(649, 3) = "Quitar";
		a_nachricht_text(650, 1) = "Cancel";
		a_nachricht_text(650, 2) = "Abbrechen";
		a_nachricht_text(650, 3) = "Cancelar";
		a_nachricht_text(651, 1) = "Illusionary Walls!";
		a_nachricht_text(651, 2) = "Illusionsw\344nde!";
		a_nachricht_text(651, 3) = "Paredes iluscionarias!";
		a_nachricht_text(652, 1) = "This level contains a lot of";
		a_nachricht_text(652, 2) = "Diese Ebene enth\344lt eine";
		a_nachricht_text(652, 3) = "Este nivel contiene muchas";
		a_nachricht_text(653, 1) = "walls you can walk through!";
		a_nachricht_text(653, 2) = "Menge Geheimt\374ren!";
		a_nachricht_text(653, 3) = "puertas secretas!";
		a_nachricht_text(654, 1) = "No more sacrifices here!";
		a_nachricht_text(654, 2) = "Keine Opfer mehr hier!";
		a_nachricht_text(654, 3) = "No mas sacrificios aqui!";
		a_nachricht_text(655, 1) = "You have no god!";
		a_nachricht_text(655, 2) = "Du hast keinen Gott!";
		a_nachricht_text(655, 3) = "No tienes dios!";
		a_nachricht_text(656, 1) = "Dispel";
		a_nachricht_text(656, 2) = "Aufl\366sen";
		a_nachricht_text(656, 3) = "Dispel";
		a_nachricht_text(657, 1) = "Q: Old Messages";
		a_nachricht_text(657, 2) = "Q: Alte Nachrichten";
		a_nachricht_text(657, 3) = "Q: Mensajes viejos";
		a_nachricht_text(658, 1) = "Scroll";
		a_nachricht_text(658, 2) = "Schriftrolle";
		a_nachricht_text(658, 3) = "Hechizo";
		a_nachricht_text(659, 1) = "Jewel";
		a_nachricht_text(659, 2) = "Edelstein";
		a_nachricht_text(659, 3) = "Piedra preciosa";
		a_nachricht_text(659, 1) = "Jewel";
		a_nachricht_text(659, 2) = "Edelstein";
		a_nachricht_text(659, 3) = "Piedra preciosa";
		a_nachricht_text(660, 1) = "Old Messages";
		a_nachricht_text(660, 2) = "Alte Nachrichten";
		a_nachricht_text(660, 3) = "Mensajes viejos";
		a_nachricht_text(661, 1) = "Few Lifepoints!!!";
		a_nachricht_text(661, 2) = "Wenig Lebenspunkte!!!";
		a_nachricht_text(661, 3) = "Pocos puntos de vida!!!";
		a_nachricht_text(662, 1) = "Dying!!!";
		a_nachricht_text(662, 2) = "Am sterben!!!";
		a_nachricht_text(662, 3) = "Cerca al muerte!!!";
		a_nachricht_text(663, 1) = "You get teleported to an old level!";
		a_nachricht_text(663, 2) = "Du wirst in einen alten Level teleportiert!";
		a_nachricht_text(663, 3) = "Te teleportan a un nivel viejo!";
		a_nachricht_text(664, 1) = "Choose the Gamespeed";
		a_nachricht_text(664, 2) = "W\344hle die Spielgeschwindigkeit";
		a_nachricht_text(664, 3) = "Elije la velocidad del juego";
		a_nachricht_text(665, 1) = "Messages";
		a_nachricht_text(665, 2) = "Nachrichten";
		a_nachricht_text(665, 3) = "Mensajes";
		a_nachricht_text(666, 1) = "Release Creature";
		a_nachricht_text(666, 2) = "Kreatur freigeben";
		a_nachricht_text(666, 3) = "Librar Kriatura";
		a_nachricht_text(667, 1) = "You released your Creature";
		a_nachricht_text(667, 2) = "Du hast deine Kreatur freigegeben";
		a_nachricht_text(667, 3) = "Libraste tu Kriatura";
		a_nachricht_text(668, 1) = "Only in Water";
		a_nachricht_text(668, 2) = "Nur im Wasser";
		a_nachricht_text(668, 3) = "Solo en Aqua";
		a_nachricht_text(669, 1) = "Unique";
		a_nachricht_text(669, 2) = "Einmalig";
		a_nachricht_text(669, 3) = "Unique";
		a_nachricht_text(670, 1) = "Spider";
		a_nachricht_text(670, 2) = "Spinne";
		a_nachricht_text(670, 3) = "Arana";
		a_nachricht_text(671, 1) = "Goblin";
		a_nachricht_text(671, 2) = "Goblin";
		a_nachricht_text(671, 3) = "Goblin";
		a_nachricht_text(672, 1) = "Undead";
		a_nachricht_text(672, 2) = "Untot";
		a_nachricht_text(672, 3) = "No-muerto";
		a_nachricht_text(673, 1) = "Rat";
		a_nachricht_text(673, 2) = "Ratte";
		a_nachricht_text(673, 3) = "Rata";
		a_nachricht_text(674, 1) = "Wolf";
		a_nachricht_text(674, 2) = "Wolf";
		a_nachricht_text(674, 3) = "Lobo";
		a_nachricht_text(675, 1) = "Bat";
		a_nachricht_text(675, 2) = "Fledermaus";
		a_nachricht_text(675, 3) = "Murcielago";
		a_nachricht_text(676, 1) = "Cat";
		a_nachricht_text(676, 2) = "Katze";
		a_nachricht_text(676, 3) = "Gato";
		a_nachricht_text(677, 1) = "Breaks Weapons";
		a_nachricht_text(677, 2) = "Zerbricht Waffen";
		a_nachricht_text(677, 3) = "Rota Armas";
		a_nachricht_text(678, 1) = "Breaks Armor";
		a_nachricht_text(678, 2) = "Zerbricht R\374stung";
		a_nachricht_text(678, 3) = "Rota Armadura";
		a_nachricht_text(679, 1) = "A stone gets thrown at you!";
		a_nachricht_text(679, 2) = "Ein Stein wird nach dir geworfen!";
		a_nachricht_text(679, 3) = "Se lanza una piedra a ti!";
		a_nachricht_text(680, 1) = "Killed by a Speartrap";
		a_nachricht_text(680, 2) = "Get\366tet von Speerfalle";
		a_nachricht_text(680, 3) = "Muerto de una Trampa de Lanza";
		a_nachricht_text(681, 1) = "Killed by a Axetrap";
		a_nachricht_text(681, 2) = "Get\366tet von Axtfalle";
		a_nachricht_text(681, 3) = "Muerto de una Trampa de Hacha";
		a_nachricht_text(682, 1) = "Killed by a Darttrap";
		a_nachricht_text(682, 2) = "Get\366tet von Pfeilfalle";
		a_nachricht_text(682, 3) = "Muerto de una Trampa de Dardo";
		a_nachricht_text(683, 1) = "Killed by a Trapdoor";
		a_nachricht_text(683, 2) = "Get\366tet von Fallgrube";
		a_nachricht_text(683, 3) = "Muerto de una trampilla";
		a_nachricht_text(684, 1) = "Killed by a Fireball";
		a_nachricht_text(684, 2) = "Get\366tet von Feuerball";
		a_nachricht_text(684, 3) = "Muerto de una bola de fuego";
		a_nachricht_text(685, 1) = "Killed by a Frostball";
		a_nachricht_text(685, 2) = "Get\366tet von Eisschlag";
		a_nachricht_text(685, 3) = "Muerto de una bola de hielo";
		a_nachricht_text(686, 1) = "Killed by a Drain Life";
		a_nachricht_text(686, 2) = "Get\366tet von Dunklem Sog";
		a_nachricht_text(686, 3) = "Muerto de una chupa vida";
		a_nachricht_text(687, 1) = "Killed by Starvation";
		a_nachricht_text(687, 2) = "Verdursted";
		a_nachricht_text(687, 3) = "Muerto de sed";
		a_nachricht_text(688, 1) = "Killed by Starvation";
		a_nachricht_text(688, 2) = "Verhungert";
		a_nachricht_text(688, 3) = "Muerto de hambre";
		a_nachricht_text(689, 1) = "Killed by Poison";
		a_nachricht_text(689, 2) = "Get\366tet von Gift";
		a_nachricht_text(689, 3) = "Muerto de veneno";
		a_nachricht_text(690, 1) = "Killed by Fire";
		a_nachricht_text(690, 2) = "Get\366tet von Feuer";
		a_nachricht_text(690, 3) = "Muerto de fuego";
		a_nachricht_text(691, 1) = "Drowned";
		a_nachricht_text(691, 2) = "Ertrunken";
		a_nachricht_text(691, 3) = "Aogado";
		a_nachricht_text(692, 1) = "Froze to Death";
		a_nachricht_text(692, 2) = "Erfroren";
		a_nachricht_text(692, 3) = "Muerto de Frio";
		a_nachricht_text(693, 1) = "Survived the Labyrinth!";
		a_nachricht_text(693, 2) = "\334berlebte das Labyrinth!";
		a_nachricht_text(693, 3) = "Sobrevivio el Labirinto!";
		a_nachricht_text(694, 1) = "Only three times per level!";
		a_nachricht_text(694, 2) = "Nur dreimal pro Ebene!";
		a_nachricht_text(694, 3) = "Solamente 3 veces por nivel!";
		a_nachricht_text(695, 1) = "(Common) ";
		a_nachricht_text(695, 2) = "(Normaler) ";
		a_nachricht_text(695, 3) = "(Menor) ";
		a_nachricht_text(696, 1) = "(Elder) ";
		a_nachricht_text(696, 2) = "(Alter) ";
		a_nachricht_text(696, 3) = "(Normal) ";
		a_nachricht_text(697, 1) = "(Ancient) ";
		a_nachricht_text(697, 2) = "(Uralter) ";
		a_nachricht_text(697, 3) = "(Mayor) ";
		a_nachricht_text(698, 1) = "M: Automapping";
		a_nachricht_text(698, 2) = "M: Automapping";
		a_nachricht_text(698, 3) = "M: Mapa automatico";
		a_nachricht_text(699, 1) = "Drunken";
		a_nachricht_text(699, 2) = "Betrunken";
		a_nachricht_text(699, 3) = "Boracho";
		a_nachricht_text(700, 1) = "You found some water";
		a_nachricht_text(700, 2) = "Du findest etwas Wasser";
		a_nachricht_text(700, 3) = "Encontraste poco aqua";
		a_nachricht_text(701, 1) = "The monster does not notice you!";
		a_nachricht_text(701, 2) = "Das Monster bemerkt dich nicht!";
		a_nachricht_text(701, 3) = "El monstruo no te anota!";
		a_nachricht_text(702, 1) = "Animations";
		a_nachricht_text(702, 2) = "Animationen";
		a_nachricht_text(702, 3) = "Animaciones";
		a_nachricht_text(703, 1) = "Magic resistence:";
		a_nachricht_text(703, 2) = "Magieresistenz:";
		a_nachricht_text(703, 3) = "Resistencia magia:";
		a_nachricht_text(704, 1) = "Destroy?";
		a_nachricht_text(704, 2) = "Zerst\366ren?";
		a_nachricht_text(704, 3) = "Romper?";
		a_nachricht_text(705, 1) = "Sure?";
		a_nachricht_text(705, 2) = "Sicher?";
		a_nachricht_text(705, 3) = "Seguro?";
		a_nachricht_text(706, 1) = "The monster explodes!";
		a_nachricht_text(706, 2) = "Das monster explodiert!";
		a_nachricht_text(706, 3) = "El monstruo explota!";
		a_nachricht_text(707, 1) = "Died in an explosion!";
		a_nachricht_text(707, 2) = "Starb an einer Explosion!";
		a_nachricht_text(707, 3) = "Muerto de explosion!";
		a_nachricht_text(708, 1) = "You cannot attack!";
		a_nachricht_text(708, 2) = "Du kannst nicht angreifen!";
		a_nachricht_text(708, 3) = "No puedes atacar!";
		a_nachricht_text(709, 1) = "Normal";
		a_nachricht_text(709, 2) = "normal";
		a_nachricht_text(709, 3) = "normal";
		a_nachricht_text(710, 1) = "Offensive combat";
		a_nachricht_text(710, 2) = "Offensiver Kampf";
		a_nachricht_text(710, 3) = "Combate ofensivo";
		a_nachricht_text(711, 1) = "Defensive combat";
		a_nachricht_text(711, 2) = "Defensiver Kampf";
		a_nachricht_text(711, 3) = "Combate defensivo";
		a_nachricht_text(712, 1) = "Sunder";
		a_nachricht_text(712, 2) = "Hammer";
		a_nachricht_text(712, 3) = "Martillo";
		a_nachricht_text(713, 1) = "Impale";
		a_nachricht_text(713, 2) = "Verhaken";
		a_nachricht_text(713, 3) = "Impale";
		a_nachricht_text(714, 1) = "Whirling Blades";
		a_nachricht_text(714, 2) = "Wirbelnde Klingen";
		a_nachricht_text(714, 3) = "Dagas vuelas";
		a_nachricht_text(715, 1) = "Staff Defense";
		a_nachricht_text(715, 2) = "Stabverteidigung";
		a_nachricht_text(715, 3) = "Baston defensa";
		a_nachricht_text(716, 1) = "Swift Blade";
		a_nachricht_text(716, 2) = "Flinke Klinge";
		a_nachricht_text(716, 3) = "Ataque rapido";
		a_nachricht_text(717, 1) = "Hidden Blade";
		a_nachricht_text(717, 2) = "Versteckte Klinge";
		a_nachricht_text(717, 3) = "Ataque escondido";
		a_nachricht_text(718, 1) = "Sweeping Attack";
		a_nachricht_text(718, 2) = "Sturmangriff";
		a_nachricht_text(718, 3) = "Ataque continuo";
		a_nachricht_text(719, 1) = "Is used!";
		a_nachricht_text(719, 2) = "Wird benutzt!";
		a_nachricht_text(719, 3) = "Esta usada!";
		a_nachricht_text(720, 1) = "Space: Toggle";
		a_nachricht_text(720, 2) = "Space: Ausl\366sen";
		a_nachricht_text(720, 3) = "Space: Usar";
		a_nachricht_text(721, 1) = "Toggle? (Space)";
		a_nachricht_text(721, 2) = "Ausl\366sen? (Space)";
		a_nachricht_text(721, 3) = "Usar? (Space)";
		a_nachricht_text(722, 1) = "A lot of treasure!";
		a_nachricht_text(722, 2) = "Ein grosser Schatz!";
		a_nachricht_text(722, 3) = "Un tesoro grande!";
		a_nachricht_text(723, 1) = "And it seems...";
		a_nachricht_text(723, 2) = "Und er scheint...";
		a_nachricht_text(723, 3) = "Y parece...";
		a_nachricht_text(724, 1) = "unprotected...";
		a_nachricht_text(724, 2) = "unbewacht zu sein...";
		a_nachricht_text(724, 3) = "desprotegido...";
		a_nachricht_text(725, 1) = "You found a prison!";
		a_nachricht_text(725, 2) = "Du hast ein Gef\344ngnis entdeckt!";
		a_nachricht_text(725, 3) = "Encontraste un prision!";
		a_nachricht_text(726, 1) = "Maybe there are prisoners inside...";
		a_nachricht_text(726, 2) = "Vielleicht hat es Gefangene...";
		a_nachricht_text(726, 3) = "Tal vez hay prisionieros...";
		a_nachricht_text(727, 1) = "And maybe something of worth...";
		a_nachricht_text(727, 2) = "Und vielleicht etwas von wert...";
		a_nachricht_text(727, 3) = "Y tal vez cosas de valor...";
		a_nachricht_text(728, 1) = "Mix with another potion?";
		a_nachricht_text(728, 2) = "Mit anderem Trank mischen?";
		a_nachricht_text(728, 3) = "Mezclar con otro pocion?";
		a_nachricht_text(729, 1) = "Select another potion!";
		a_nachricht_text(729, 2) = "W\344hle anderen Trank!";
		a_nachricht_text(729, 3) = "Elige otra pocion!";
		a_nachricht_text(730, 1) = "This is not a potion!";
		a_nachricht_text(730, 2) = "Das ist kein Trank!";
		a_nachricht_text(730, 3) = "No es pocion!";
		a_nachricht_text(731, 1) = "Not with itself!";
		a_nachricht_text(731, 2) = "Nicht mit sich selber!";
		a_nachricht_text(731, 3) = "No consigo misma!";
		a_nachricht_text(732, 1) = "The potion explodes!";
		a_nachricht_text(732, 2) = "Der Trank explodiert!";
		a_nachricht_text(732, 3) = "La pocion explota!";
		a_nachricht_text(733, 1) = "You created a new potion!";
		a_nachricht_text(733, 2) = "Du hast nun einen neuen Trank!";
		a_nachricht_text(733, 3) = "Ahora tienes una nuava pocion!";
		a_nachricht_text(734, 1) = "Potion";
		a_nachricht_text(734, 2) = "Trank";
		a_nachricht_text(734, 3) = "Pocion";
		a_nachricht_text(735, 1) = "Has no life!";
		a_nachricht_text(735, 2) = "Hat kein Leben!";
		a_nachricht_text(735, 3) = "No tiene vida!";
		a_nachricht_text(736, 1) = "Cannot be damaged by normal weapons!";
		a_nachricht_text(736, 2) = "Kann nicht mit normalen Waffen verletzt werden!";
		a_nachricht_text(736, 3) = "No lo puedes danar con armas normales!";
		a_nachricht_text(737, 1) = "You had a special success with this spell!";
		a_nachricht_text(737, 2) = "Dieser Zauber ist dir besonders gut gelungen!";
		a_nachricht_text(737, 3) = "Este hechizo era mejor como normal!";
		a_nachricht_text(738, 1) = "You botched with this spell!";
		a_nachricht_text(738, 2) = "Dieser Zauber war ein R\374ckschlag!";
		a_nachricht_text(738, 3) = "Este hechizo era un fracaso!";
		a_nachricht_text(739, 1) = "Dies by a Botch";
		a_nachricht_text(739, 2) = "Wurde von Zauberfehlschlag get\366tet";
		a_nachricht_text(739, 3) = "Muerto de un Fracaso con un hechizo";
		a_nachricht_text(740, 1) = "Joystick 1 and 'Y' = Yes";
		a_nachricht_text(740, 2) = "Joystick 1 und 'Y' = Ja";
		a_nachricht_text(740, 3) = "Joystick 1 y 'Y' = Si";
		a_nachricht_text(741, 1) = "Joystick 2 and 'N' = No";
		a_nachricht_text(741, 2) = "Joystick 2 und 'N' = Nein";
		a_nachricht_text(741, 3) = "Joystick 2 y 'N' = No";
		a_nachricht_text(742, 1) = "Orc Village";
		a_nachricht_text(742, 2) = "Ork Dorf";
		a_nachricht_text(742, 3) = "Pueblo Orcos";
		a_nachricht_text(743, 1) = "You can see a lot of Orcs";
		a_nachricht_text(743, 2) = "Du kannst eine Menge Orks";
		a_nachricht_text(743, 3) = "Puedes ver un monton de orcos";
		a_nachricht_text(744, 1) = "and some huts here.";
		a_nachricht_text(744, 2) = "und einige H\374tten sehen.";
		a_nachricht_text(744, 3) = "y algunos casitas.";
		a_nachricht_text(745, 1) = "Maybe they are hiding something?";
		a_nachricht_text(745, 2) = "Vielleicht verstecken sie etwas?";
		a_nachricht_text(745, 3) = "Tal vez les esconden algo?";
		a_nachricht_text(746, 1) = "Witch garden";
		a_nachricht_text(746, 2) = "Hexenhaus";
		a_nachricht_text(746, 3) = "Casa de Bruja";
		a_nachricht_text(747, 1) = "Be careful that she does not see you!";
		a_nachricht_text(747, 2) = "Sei vorsichtig das sie dich nicht sieht!";
		a_nachricht_text(747, 3) = "Cuidate que la no te ve!";
		a_nachricht_text(748, 1) = "Upload your Highscore?";
		a_nachricht_text(748, 2) = "Deinen Highscore hochladen?";
		a_nachricht_text(748, 3) = "Subir su alta puntaje?";
		a_nachricht_text(749, 1) = "Curse of Magneto";
		a_nachricht_text(749, 2) = "Fluch des Magneto";
		a_nachricht_text(749, 3) = "Maldicion de Magneto";
		a_nachricht_text(750, 1) = "Curse of Gaia";
		a_nachricht_text(750, 2) = "Fluch der Gaia";
		a_nachricht_text(750, 3) = "Maldicion de la Gaia";
		a_nachricht_text(751, 1) = "Curse of Nosferatu";
		a_nachricht_text(751, 2) = "Fluch des Nosferatu";
		a_nachricht_text(751, 3) = "Maldicion de Nosferatu";
		a_nachricht_text(752, 1) = "Nothing";
		a_nachricht_text(752, 2) = "Nichts";
		a_nachricht_text(752, 3) = "Nada";
		a_nachricht_text(753, 1) = "Wall";
		a_nachricht_text(753, 2) = "Mauer";
		a_nachricht_text(753, 3) = "Muralla";
		a_nachricht_text(754, 1) = "Exit";
		a_nachricht_text(754, 2) = "Ausgang";
		a_nachricht_text(754, 3) = "Salida";
		a_nachricht_text(755, 1) = "Entrance";
		a_nachricht_text(755, 2) = "Eingang";
		a_nachricht_text(755, 3) = "Entrada";
		a_nachricht_text(756, 1) = "Empty";
		a_nachricht_text(756, 2) = "Leer";
		a_nachricht_text(756, 3) = "Vacio";
		a_nachricht_text(757, 1) = "Skeleton";
		a_nachricht_text(757, 2) = "Skelett";
		a_nachricht_text(757, 3) = "Esqueleton";
		a_nachricht_text(758, 1) = "Chest";
		a_nachricht_text(758, 2) = "Truhe";
		a_nachricht_text(758, 3) = "Caja";
		a_nachricht_text(759, 1) = "Sanctum";
		a_nachricht_text(759, 2) = "Sanktum";
		a_nachricht_text(759, 3) = "Santuario";
		a_nachricht_text(760, 1) = "Nexus";
		a_nachricht_text(760, 2) = "Nexus";
		a_nachricht_text(760, 3) = "Nexus";
		a_nachricht_text(761, 1) = "Books";
		a_nachricht_text(761, 2) = "B\374cher";
		a_nachricht_text(761, 3) = "Libros";
		a_nachricht_text(762, 1) = "Laboratory";
		a_nachricht_text(762, 2) = "Labor";
		a_nachricht_text(762, 3) = "Laboratorio";
		a_nachricht_text(763, 1) = "Switch";
		a_nachricht_text(763, 2) = "Schalter";
		a_nachricht_text(763, 3) = "Interuptor";
		a_nachricht_text(764, 1) = "Door";
		a_nachricht_text(764, 2) = "T\374re";
		a_nachricht_text(764, 3) = "Puerta";
		a_nachricht_text(765, 1) = "Speartrap";
		a_nachricht_text(765, 2) = "Speerfalle";
		a_nachricht_text(765, 3) = "Trampa de Lanzas";
		a_nachricht_text(766, 1) = "Darttrap";
		a_nachricht_text(766, 2) = "Pfeilfalle";
		a_nachricht_text(766, 3) = "Trampa de Dartos";
		a_nachricht_text(767, 1) = "Trapdoor";
		a_nachricht_text(767, 2) = "Fallgrube";
		a_nachricht_text(767, 3) = "Trampilla";
		a_nachricht_text(768, 1) = "Runetrap";
		a_nachricht_text(768, 2) = "Runenfalle";
		a_nachricht_text(768, 3) = "Trampa de runas";
		a_nachricht_text(769, 1) = "Axetrap";
		a_nachricht_text(769, 2) = "Axtfalle";
		a_nachricht_text(769, 3) = "Trampa de hachas";
		a_nachricht_text(770, 1) = "Fire";
		a_nachricht_text(770, 2) = "Feuer";
		a_nachricht_text(770, 3) = "Fuego";
		a_nachricht_text(771, 1) = "Stars";
		a_nachricht_text(771, 2) = "Sterne";
		a_nachricht_text(771, 3) = "Estrellas";
		a_nachricht_text(772, 1) = "Room";
		a_nachricht_text(772, 2) = "Raum";
		a_nachricht_text(772, 3) = "Habitacion";
		a_nachricht_text(773, 1) = "Island";
		a_nachricht_text(773, 2) = "Insel";
		a_nachricht_text(773, 3) = "Isla";
		a_nachricht_text(774, 1) = "Water";
		a_nachricht_text(774, 2) = "Wasser";
		a_nachricht_text(774, 3) = "Aqua";
		a_nachricht_text(775, 1) = "Pond";
		a_nachricht_text(775, 2) = "Brunnen";
		a_nachricht_text(775, 3) = "Fuente";
		a_nachricht_text(776, 1) = "Tombstone";
		a_nachricht_text(776, 2) = "Grabstein";
		a_nachricht_text(776, 3) = "Lapida";
		a_nachricht_text(777, 1) = "Tree";
		a_nachricht_text(777, 2) = "Baum";
		a_nachricht_text(777, 3) = "Arbol";
		a_nachricht_text(778, 1) = "Merchant";
		a_nachricht_text(778, 2) = "H\344ndler";
		a_nachricht_text(778, 3) = "Comerciante";
		a_nachricht_text(779, 1) = "Hole";
		a_nachricht_text(779, 2) = "Schacht";
		a_nachricht_text(779, 3) = "Agujero";
		a_nachricht_text(780, 1) = "Teleporter";
		a_nachricht_text(780, 2) = "Teleporter";
		a_nachricht_text(780, 3) = "Teleportador";
		a_nachricht_text(781, 1) = "Throne";
		a_nachricht_text(781, 2) = "Thron";
		a_nachricht_text(781, 3) = "Trono";
		a_nachricht_text(782, 1) = "Altar";
		a_nachricht_text(782, 2) = "Altar";
		a_nachricht_text(782, 3) = "Altar";
		a_nachricht_text(783, 1) = "Ice";
		a_nachricht_text(783, 2) = "Eis";
		a_nachricht_text(783, 3) = "Hielo";
		a_nachricht_text(784, 1) = "Poison";
		a_nachricht_text(784, 2) = "Gift";
		a_nachricht_text(784, 3) = "Veneno";
		a_nachricht_text(785, 1) = "Trainer";
		a_nachricht_text(785, 2) = "Lehrer";
		a_nachricht_text(785, 3) = "Entrenador";
		a_nachricht_text(786, 1) = "Hydra";
		a_nachricht_text(786, 2) = "Hydra";
		a_nachricht_text(786, 3) = "Hidra";
		a_nachricht_text(787, 1) = "Grass";
		a_nachricht_text(787, 2) = "Grass";
		a_nachricht_text(787, 3) = "Grama";
		a_nachricht_text(788, 1) = "Bush";
		a_nachricht_text(788, 2) = "Busch";
		a_nachricht_text(788, 3) = "Arbusto";
		a_nachricht_text(789, 1) = "Lava";
		a_nachricht_text(789, 2) = "Lava";
		a_nachricht_text(789, 3) = "Lava";
		a_nachricht_text(790, 1) = "Stone";
		a_nachricht_text(790, 2) = "Stein";
		a_nachricht_text(790, 3) = "Piedra";
		a_nachricht_text(791, 1) = "Staffpiece";
		a_nachricht_text(791, 2) = "Stabteil";
		a_nachricht_text(791, 3) = "Trozo del Baston";
		a_nachricht_text(792, 1) = "Forge";
		a_nachricht_text(792, 2) = "Amboss";
		a_nachricht_text(792, 3) = "Forja";
		a_nachricht_text(793, 1) = "Spidernet";
		a_nachricht_text(793, 2) = "Spinnen-Netz";
		a_nachricht_text(793, 3) = "Telarana";
		a_nachricht_text(794, 1) = "Rune";
		a_nachricht_text(794, 2) = "Rune";
		a_nachricht_text(794, 3) = "Runa";
		a_nachricht_text(795, 1) = "Bones";
		a_nachricht_text(795, 2) = "Knochen";
		a_nachricht_text(795, 3) = "Huesos";
		a_nachricht_text(796, 1) = "Candle";
		a_nachricht_text(796, 2) = "Leuchter";
		a_nachricht_text(796, 3) = "Lampara";
		a_nachricht_text(797, 1) = "Sand";
		a_nachricht_text(797, 2) = "Sand";
		a_nachricht_text(797, 3) = "Arena";
		a_nachricht_text(798, 1) = "Palmtree";
		a_nachricht_text(798, 2) = "Palme";
		a_nachricht_text(798, 3) = "Palmera";
		a_nachricht_text(799, 1) = "Cactus";
		a_nachricht_text(799, 2) = "Kaktus";
		a_nachricht_text(799, 3) = "Cactus";
		a_nachricht_text(800, 1) = "Carpet";
		a_nachricht_text(800, 2) = "Teppich";
		a_nachricht_text(800, 3) = "Tapete";
		a_nachricht_text(801, 1) = "Swamp";
		a_nachricht_text(801, 2) = "Sumpf";
		a_nachricht_text(801, 3) = "Pantano";
		a_nachricht_text(802, 1) = "Plant";
		a_nachricht_text(802, 2) = "Pflanze";
		a_nachricht_text(802, 3) = "Planta";
		a_nachricht_text(803, 1) = "Hero";
		a_nachricht_text(803, 2) = "Held";
		a_nachricht_text(803, 3) = "Heroe";
		a_nachricht_text(804, 1) = "Snow";
		a_nachricht_text(804, 2) = "Schnee";
		a_nachricht_text(804, 3) = "Nieve";
		a_nachricht_text(805, 1) = "Hut";
		a_nachricht_text(805, 2) = "H\374tte";
		a_nachricht_text(805, 3) = "Cabana";
		a_nachricht_text(806, 1) = "G: Steal";
		a_nachricht_text(806, 2) = "G: Stehlen";
		a_nachricht_text(806, 3) = "G: Robar";
		a_nachricht_text(807, 1) = "L: Look arround";
		a_nachricht_text(807, 2) = "L: Umschauen";
		a_nachricht_text(807, 3) = "L: Observar";
		a_nachricht_text(808, 1) = "V: Climb";
		a_nachricht_text(808, 2) = "V: Klettern";
		a_nachricht_text(808, 3) = "V: Trepar";
		a_nachricht_text(809, 1) = "Manaloss";
		a_nachricht_text(809, 2) = "Manaschwund";
		a_nachricht_text(809, 3) = "Perder Mana";
		a_nachricht_text(810, 1) = "This level seems to";
		a_nachricht_text(810, 2) = "Diese Ebene scheint dir";
		a_nachricht_text(810, 3) = "Te parece que este nivel";
		a_nachricht_text(811, 1) = "steal your mana!";
		a_nachricht_text(811, 2) = "dein Mana zu stehlen!";
		a_nachricht_text(811, 3) = "te roba el mana!";
		a_nachricht_text(812, 1) = "Indestructible walls";
		a_nachricht_text(812, 2) = "Unzerst\366rbare W\344nde";
		a_nachricht_text(812, 3) = "Pareds indestruibles";
		a_nachricht_text(813, 1) = "The walls in this level are";
		a_nachricht_text(813, 2) = "Die W\344nde in dieser Ebene";
		a_nachricht_text(813, 3) = "Los pareds en este nivel no";
		a_nachricht_text(814, 1) = "unaffected by portal";
		a_nachricht_text(814, 2) = "sind immun gegen Portal";
		a_nachricht_text(814, 3) = "se puede affectar con portal";
		a_nachricht_text(815, 1) = "Teleporterlock";
		a_nachricht_text(815, 2) = "Teleportersperre";
		a_nachricht_text(815, 3) = "No teleportacion";
		a_nachricht_text(816, 1) = "In this levels all teleport";
		a_nachricht_text(816, 2) = "In dieser Ebene sind alle";
		a_nachricht_text(816, 3) = "En este nivel todos los hechizos";
		a_nachricht_text(817, 1) = "spells are useless!";
		a_nachricht_text(817, 2) = "Teleport Zauber nutzlos!";
		a_nachricht_text(817, 3) = "de teleportacion no funcionan!";
		a_nachricht_text(818, 1) = "Light";
		a_nachricht_text(818, 2) = "Licht";
		a_nachricht_text(818, 3) = "Luz";
		a_nachricht_text(819, 1) = "Readme";
		a_nachricht_text(819, 2) = "Liesmich";
		a_nachricht_text(819, 3) = "Leeme";
		a_nachricht_text(820, 1) = "Readme Spells";
		a_nachricht_text(820, 2) = "Liesmich Zauber";
		a_nachricht_text(820, 3) = "Leeme Hechizos";
		a_nachricht_text(821, 1) = "Throws stones";
		a_nachricht_text(821, 2) = "Wirft Steine";
		a_nachricht_text(821, 3) = "Tira piedras";
		a_nachricht_text(822, 1) = "Explodes";
		a_nachricht_text(822, 2) = "Explodiert";
		a_nachricht_text(822, 3) = "Explota";
		a_nachricht_text(823, 1) = "Multiplies";
		a_nachricht_text(823, 2) = "Vermehrend";
		a_nachricht_text(823, 3) = "Multiplica";
		a_nachricht_text(824, 1) = "Infectious";
		a_nachricht_text(824, 2) = "Ansteckend";
		a_nachricht_text(824, 3) = "Contagioso";
		a_nachricht_text(825, 1) = "Disease";
		a_nachricht_text(825, 2) = "Krankheit";
		a_nachricht_text(825, 3) = "Enfermedad";
		a_nachricht_text(826, 1) = "Cannot be moved!";
		a_nachricht_text(826, 2) = "Kann nicht geschoben werden!";
		a_nachricht_text(826, 3) = "No lo se puede mover!";
		a_nachricht_text(827, 1) = "You have been too weak!";
		a_nachricht_text(827, 2) = "Du warst zu schwach!";
		a_nachricht_text(827, 3) = "Estuviste demasiado debil!";
		a_nachricht_text(828, 1) = "You moved the stone!";
		a_nachricht_text(828, 2) = "Du hast den Stein verschoben!";
		a_nachricht_text(828, 3) = "Moviste la piedra!";
		a_nachricht_text(829, 1) = "You open the gate!";
		a_nachricht_text(829, 2) = "Du \366ffnest das Gatter!";
		a_nachricht_text(829, 3) = "Abres la puerta!";
		a_nachricht_text(830, 1) = "Killed by Nailpit";
		a_nachricht_text(830, 2) = "Get\366tet von Nagelgrube";
		a_nachricht_text(830, 3) = "Muerto de trampa de clavos";
		a_nachricht_text(831, 1) = "You got hurt by a nailpit!";
		a_nachricht_text(831, 2) = "Du wurdest von Nagelgrube verletzt!";
		a_nachricht_text(831, 3) = "Te heriste en una trampa de clavos!";
		a_nachricht_text(832, 1) = "Your shoes protect you from the nails!";
		a_nachricht_text(832, 2) = "Deine Schuhe sch\374tzen dich vor den N\344geln!";
		a_nachricht_text(832, 3) = "Tus Zapatos te protegen de los clavos!";
		a_nachricht_text(833, 1) = "Your creature got hurt by a nailpit!";
		a_nachricht_text(833, 2) = "Deine Kreatur wurde von Nagelgrube verletzt!";
		a_nachricht_text(833, 3) = "Tu criatura fue heride de una trampa de clavos!";
		a_nachricht_text(834, 1) = "Immune to Wind";
		a_nachricht_text(834, 2) = "Immun gegen Wind";
		a_nachricht_text(834, 3) = "Imune a Viento";
		a_nachricht_text(835, 1) = "Immune to Arcane Energies";
		a_nachricht_text(835, 2) = "Immun gegen Arkane Energien";
		a_nachricht_text(835, 3) = "Imune a Energias Arcanicas";
		a_nachricht_text(836, 1) = "Nailpit";
		a_nachricht_text(836, 2) = "Nagelgrube";
		a_nachricht_text(836, 3) = "Trampa de clavos";
		a_nachricht_text(837, 1) = "Gate";
		a_nachricht_text(837, 2) = "Gatter";
		a_nachricht_text(837, 3) = "Puerta";
		a_nachricht_text(838, 1) = "No experience gain";
		a_nachricht_text(838, 2) = "Kein Erfahrungsgewinn";
		a_nachricht_text(838, 3) = "No ganas experiencia";
		a_nachricht_text(839, 1) = "One Point Damage per Round";
		a_nachricht_text(839, 2) = "Ein Punkt Schaden pro Runde";
		a_nachricht_text(839, 3) = "Un punto dano por turno";
		a_nachricht_text(840, 1) = "Your Power is 1";
		a_nachricht_text(840, 2) = "Deine Zaubermacht ist 1";
		a_nachricht_text(840, 3) = "Tu poder de hechizos es 1";
		a_nachricht_text(841, 1) = "Your Attack is 1";
		a_nachricht_text(841, 2) = "Deine Attacke ist 1";
		a_nachricht_text(841, 3) = "Tu ataque es 1";
		a_nachricht_text(842, 1) = "Your Movement is 1";
		a_nachricht_text(842, 2) = "Deine Bewegung ist 1";
		a_nachricht_text(842, 3) = "Tu movimiento es 1";
		a_nachricht_text(843, 1) = "Your Dexetrity is 1";
		a_nachricht_text(843, 2) = "Deine Geschicklichkeit ist 1";
		a_nachricht_text(843, 3) = "Tu destreza es 1";
		a_nachricht_text(844, 1) = "Monsters do double Damage";
		a_nachricht_text(844, 2) = "Monster richten doppelten Schaden an";
		a_nachricht_text(844, 3) = "Monstruos haces el doble dano";
		a_nachricht_text(845, 1) = "Sight is 1";
		a_nachricht_text(845, 2) = "Sichtweite ist 1";
		a_nachricht_text(845, 3) = "Tu vista es 1";
		a_nachricht_text(846, 1) = "Armor is useless";
		a_nachricht_text(846, 2) = "R\374stung ist nutzlos";
		a_nachricht_text(846, 3) = "Armor es inutil";
		a_nachricht_text(847, 1) = "All skeletons wake up";
		a_nachricht_text(847, 2) = "Alle skelette wachen auf";
		a_nachricht_text(847, 3) = "Todos los esqueletones se levantan";
		a_nachricht_text(848, 1) = "You can't use pentagrams";
		a_nachricht_text(848, 2) = "Du kannt das Pentagramm nicht benutzen";
		a_nachricht_text(848, 3) = "No puedes usar el pentagramo";
		a_nachricht_text(849, 1) = "Poison lasts endless";
		a_nachricht_text(849, 2) = "Gift dauert endlos";
		a_nachricht_text(849, 3) = "Veneno dura sin limite";
		a_nachricht_text(850, 1) = "You starve twice as fast - hunger";
		a_nachricht_text(850, 2) = "Du verhungerst doppelt so schnell";
		a_nachricht_text(850, 3) = "Necesitas el doble amonto de comida";
		a_nachricht_text(851, 1) = "You starve twice as fast - thirst";
		a_nachricht_text(851, 2) = "Du verdurstest doppelt so schnell";
		a_nachricht_text(851, 3) = "Necesitas el doble amonto de aqua";
		a_nachricht_text(852, 1) = "You can't use the sanktum";
		a_nachricht_text(852, 2) = "Du kannst das Sanktum nicht benutzen";
		a_nachricht_text(852, 3) = "No puedes usar el sanctum";
		a_nachricht_text(853, 1) = "You can't pick up gold";
		a_nachricht_text(853, 2) = "Du kannst kein Gold aufnehmen";
		a_nachricht_text(853, 3) = "No puedes llevar oro";
		a_nachricht_text(854, 1) = "Ambushes twice as often";
		a_nachricht_text(854, 2) = "Doppelt so viele Hinterhalte";
		a_nachricht_text(854, 3) = "El doble amonto de emboscadas";
		a_nachricht_text(855, 1) = "All chests are empty";
		a_nachricht_text(855, 2) = "Alle Truhen sind leer";
		a_nachricht_text(855, 3) = "Todas la cajas estan vacias";
		a_nachricht_text(856, 1) = "Double damage from drowning";
		a_nachricht_text(856, 2) = "Doppelter Schaden durch ertrinken";
		a_nachricht_text(856, 3) = "El doble amonto de dano de huir";
		a_nachricht_text(857, 1) = "Duration of all spells halfed";
		a_nachricht_text(857, 2) = "Dauer aller Zauber halbiert";
		a_nachricht_text(857, 3) = "Duracion de los hechizos es la mitad";
		a_nachricht_text(858, 1) = "Monsters hit better in Close Combat";
		a_nachricht_text(858, 2) = "Monster treffen besser im Nahkampf";
		a_nachricht_text(858, 3) = "Los montros alcazan mejor en combate cerca";
		a_nachricht_text(859, 1) = "Monsters hit better in ranged combat";
		a_nachricht_text(859, 2) = "Monster treffen besser im Fernkampf";
		a_nachricht_text(859, 3) = "Los montros alcazan mejor en combate lejos";
		a_nachricht_text(860, 1) = "Very bad attributes";
		a_nachricht_text(860, 2) = "Sehr schlechte Attribute";
		a_nachricht_text(860, 3) = "Muy malos atributos";
		a_nachricht_text(861, 1) = "Weight counts twice";
		a_nachricht_text(861, 2) = "Gewicht z\344hlt doppelt";
		a_nachricht_text(861, 3) = "Peso cuenta dos veces";
		a_nachricht_text(862, 1) = "Weapons and Armor break twice as often";
		a_nachricht_text(862, 2) = "Waffen und R\374stungen brechen doppelt so oft";
		a_nachricht_text(862, 3) = "Armas y armor se danan dos veces mas probable";
		a_nachricht_text(863, 1) = "Merchants and Trainers flee from you";
		a_nachricht_text(863, 2) = "H\344ndler und Lehrer fliehen vor dir";
		a_nachricht_text(863, 3) = "Comerciantes y profesores se escapan de ti";
		a_nachricht_text(864, 1) = "Only a Witch can ride that!";
		a_nachricht_text(864, 2) = "Nur eine Hexe kann darauf reiten!";
		a_nachricht_text(864, 3) = "Solo una bruja puede montar eso!";
		a_nachricht_text(865, 1) = "You fly over the nailpit!";
		a_nachricht_text(865, 2) = "Du fliegst \374ber die Nagelgrube!";
		a_nachricht_text(865, 3) = "Volas sobre la trampa de clavos!";
		a_nachricht_text(866, 1) = "Move through time?";
		a_nachricht_text(866, 2) = "Springe durch die Zeit?";
		a_nachricht_text(866, 3) = "Saltar a traves del tiempo?";
		a_nachricht_text(867, 1) = "Room Text Dummy1";
		a_nachricht_text(867, 2) = "Room Text Dummy1";
		a_nachricht_text(867, 3) = "Room Text Dummy1";
		a_nachricht_text(868, 1) = "Room Text Dummy2";
		a_nachricht_text(868, 2) = "Room Text Dummy2";
		a_nachricht_text(868, 3) = "Room Text Dummy2";
		a_nachricht_text(869, 1) = "Room Text Dummy3";
		a_nachricht_text(869, 2) = "Room Text Dummy3";
		a_nachricht_text(869, 3) = "Room Text Dummy3";
		a_nachricht_text(870, 1) = "Room Text Dummy4";
		a_nachricht_text(870, 2) = "Room Text Dummy4";
		a_nachricht_text(870, 3) = "Room Text Dummy4";
		a_nachricht_text(871, 1) = "You have been robbed: ";
		a_nachricht_text(871, 2) = "Du wurdest bestohlen: ";
		a_nachricht_text(871, 3) = "Te han robado: ";
		a_nachricht_text(872, 1) = "You can't wear armor";
		a_nachricht_text(872, 2) = "Du kannst keine R\374stung tragen";
		a_nachricht_text(872, 3) = "No puedes usar armadura";
		a_nachricht_text(873, 1) = "You can't use weapons";
		a_nachricht_text(873, 2) = "Du kannst keine Waffe tragen";
		a_nachricht_text(873, 3) = "No puedes usar armas";
		a_nachricht_text(874, 1) = "You can't use bows";
		a_nachricht_text(874, 2) = "Du kannst keinen bogen tragen";
		a_nachricht_text(874, 3) = "No puedes usar arcos";
		a_nachricht_text(875, 1) = "    Choose a scroll to copy:";
		a_nachricht_text(875, 2) = "W\344hle eine Schriftrolle zum kopieren:";
		a_nachricht_text(875, 3) = "Escoje un Pergamento para copiarlo:";
		a_nachricht_text(876, 1) = "Is not a scroll";
		a_nachricht_text(876, 2) = "Ist keine Schriftrolle";
		a_nachricht_text(876, 3) = "No es pergamento";
		a_nachricht_text(877, 1) = "You copied a scroll";
		a_nachricht_text(877, 2) = "Du hast eine Schriftrolle kopiert";
		a_nachricht_text(877, 3) = "Copiaste un pergamento";
		a_nachricht_text(878, 1) = "LP:";
		a_nachricht_text(878, 2) = "LP:";
		a_nachricht_text(878, 3) = "PdV:";
		a_nachricht_text(879, 1) = "MP:";
		a_nachricht_text(879, 2) = "MP:";
		a_nachricht_text(879, 3) = "PdM:";
		a_nachricht_text(880, 1) = "Your awareness prevents the robbing attempt!";
		a_nachricht_text(880, 2) = "Deine Aufmerksamkeit verhindert den Diebstahl!";
		a_nachricht_text(880, 3) = "Su atento impede que te roban!";
		a_nachricht_text(881, 1) = "";
		a_nachricht_text(881, 2) = "";
		a_nachricht_text(881, 3) = "";
		a_nachricht_text(901, 1) = "Save current skills to Template";
		a_nachricht_text(901, 2) = "Gew\344hlte F\344higkeiten in Template speichern";
		a_nachricht_text(901, 3) = "Guarda las abilidades seletadas a un template";
		a_nachricht_text(902, 1) = "Saves the actual selection to template";
		a_nachricht_text(902, 2) = "Speichert die Auswahl in ein Template";
		a_nachricht_text(902, 3) = "Guarda la selecion actual en un template";
		a_nachricht_text(903, 1) = "Please distribute all skill points";
		a_nachricht_text(903, 2) = "Bitte verteile alle Skill Punkte";
		a_nachricht_text(903, 3) = "Por favor distribuye todos los puntos de abilidades";
		a_nachricht_text(904, 1) = "";
		a_nachricht_text(904, 2) = "";
		a_nachricht_text(904, 3) = "";
		a_nachricht_text(905, 1) = "";
		a_nachricht_text(905, 2) = "";
		a_nachricht_text(905, 3) = "";
		a_nachricht_text(906, 1) = "";
		a_nachricht_text(906, 2) = "";
		a_nachricht_text(906, 3) = "";
		a_nachricht_text(907, 0) = "English";
		a_nachricht_text(907, 1) = "Englisch";
		a_nachricht_text(907, 2) = "Ingles";
		a_nachricht_text(908, 0) = "German";
		a_nachricht_text(908, 1) = "Deutsch";
		a_nachricht_text(908, 2) = "Aleman";
		a_nachricht_text(909, 0) = "Spanish";
		a_nachricht_text(909, 1) = "Spanisch";
		a_nachricht_text(909, 2) = "Espanol";
		g_spalte = 0;
		g_zeile = 0;
		v_ok_button = 0;
		if (((g_nr == 2) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level + 1)) == 9))) {
			g_nr = 174;
		}
		if (((g_nr == 2) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level + 1)) == 6))) {
			g_nr = 166;
		}
		if (((g_nr == 2) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level + 1)) == 10))) {
			g_nr = 173;
		}
		if (((g_nr == 2) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level + 1)) == 11))) {
			g_nr = 188;
		}
		if (((g_nr == 2) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 9))) {
			g_nr = 167;
		}
		if (((g_nr == 2) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 6))) {
			g_nr = 167;
		}
		if (((g_nr == 2) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 10))) {
			g_nr = 167;
		}
		if (((g_nr == 2) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 11))) {
			g_nr = 167;
		}
		if ((a_spieler(g_akt_spieler).f_level > 1)) {
			if (((g_nr == 3) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level - 1)) == 9))) {
				g_nr = 174;
			}
			if (((g_nr == 3) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level - 1)) == 6))) {
				g_nr = 166;
			}
			if (((g_nr == 3) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level - 1)) == 10))) {
				g_nr = 173;
			}
			if (((g_nr == 3) && (a_sonderlevel((a_spieler(g_akt_spieler).f_level - 1)) == 11))) {
				g_nr = 188;
			}
		}
		if (((g_nr == 3) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 9))) {
			g_nr = 167;
		}
		if (((g_nr == 3) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 6))) {
			g_nr = 167;
		}
		if (((g_nr == 3) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 10))) {
			g_nr = 167;
		}
		if (((g_nr == 3) && (a_sonderlevel(a_spieler(g_akt_spieler).f_level) == 11))) {
			g_nr = 167;
		}
		for (v_i = 1; v_i <= 406; v_i += 1) {
			a_gegenstand(v_i).f_name[2] = "";
			a_gegenstand(v_i).f_name[1] = "";
			a_gegenstand(v_i).f_name[3] = "";
			a_gegenstand(v_i).f_art = 0;
			a_gegenstand(v_i).f_klasse = 0;
			a_gegenstand(v_i).f_magisch = 0;
			a_gegenstand(v_i).f_qualitaet = 0;
			a_gegenstand(v_i).f_info[2] = "";
			a_gegenstand(v_i).f_info[1] = "";
			a_gegenstand(v_i).f_info[3] = "";
			a_gegenstand(v_i).f_einkauf = 0;
			a_gegenstand(v_i).f_verkauf = 0;
			a_gegenstand(v_i).f_gewicht = 0;
			a_gegenstand(v_i).f_attri1 = 0;
			a_gegenstand(v_i).f_attri2 = 0;
			a_gegenstand(v_i).f_attri3 = 0;
			a_gegenstand(v_i).f_attri4 = 0;
		}
		a_gegenstand(1).f_name[2] = "Dolch";
		a_gegenstand(1).f_name[1] = "Dagger";
		a_gegenstand(1).f_name[3] = "Daga";
		a_gegenstand(1).f_art = 1;
		a_gegenstand(1).f_klasse = 5;
		a_gegenstand(1).f_einkauf = 5;
		a_gegenstand(1).f_verkauf = 3;
		a_gegenstand(1).f_gewicht = 5;
		a_gegenstand(1).f_attri1 = 0;
		a_gegenstand(1).f_attri2 = 1;
		a_gegenstand(1).f_attri3 = 5;
		a_gegenstand(1).f_attri4 = 1;
		a_gegenstand(2).f_name[2] = "Bih\344nder (2H)";
		a_gegenstand(2).f_name[1] = "Bastardsword (2H)";
		a_gegenstand(2).f_name[3] = "Espada Bastarda (2M)";
		a_gegenstand(2).f_art = 1;
		a_gegenstand(2).f_klasse = 1;
		a_gegenstand(2).f_einkauf = 50;
		a_gegenstand(2).f_verkauf = 30;
		a_gegenstand(2).f_gewicht = 30;
		a_gegenstand(2).f_attri1 = 0;
		a_gegenstand(2).f_attri2 = 4;
		a_gegenstand(2).f_attri3 = 5;
		a_gegenstand(2).f_attri4 = 2;
		a_gegenstand(3).f_name[2] = "Langschwert";
		a_gegenstand(3).f_name[1] = "Longsword";
		a_gegenstand(3).f_name[3] = "Espada Larga";
		a_gegenstand(3).f_art = 1;
		a_gegenstand(3).f_klasse = 1;
		a_gegenstand(3).f_einkauf = 40;
		a_gegenstand(3).f_verkauf = 20;
		a_gegenstand(3).f_gewicht = 25;
		a_gegenstand(3).f_attri1 = 1;
		a_gegenstand(3).f_attri2 = 3;
		a_gegenstand(3).f_attri3 = 5;
		a_gegenstand(3).f_attri4 = 1;
		a_gegenstand(4).f_name[2] = "Peitsche";
		a_gegenstand(4).f_name[1] = "Whip";
		a_gegenstand(4).f_name[3] = "Latigo";
		a_gegenstand(4).f_art = 1;
		a_gegenstand(4).f_einkauf = 10;
		a_gegenstand(4).f_verkauf = 5;
		a_gegenstand(4).f_gewicht = 10;
		a_gegenstand(4).f_attri1 = 2;
		a_gegenstand(4).f_attri2 = 1;
		a_gegenstand(4).f_attri3 = 10;
		a_gegenstand(4).f_attri4 = 1;
		a_gegenstand(5).f_name[2] = "Stabkeule";
		a_gegenstand(5).f_name[1] = "Poleaxe";
		a_gegenstand(5).f_name[3] = "Hacha";
		a_gegenstand(5).f_art = 1;
		a_gegenstand(5).f_klasse = 4;
		a_gegenstand(5).f_einkauf = 20;
		a_gegenstand(5).f_verkauf = 10;
		a_gegenstand(5).f_gewicht = 20;
		a_gegenstand(5).f_attri1 = 0;
		a_gegenstand(5).f_attri2 = 3;
		a_gegenstand(5).f_attri3 = 5;
		a_gegenstand(5).f_attri4 = 1;
		a_gegenstand(6).f_name[2] = "Kampfstab (2H)";
		a_gegenstand(6).f_name[1] = "Fightingstick (2H)";
		a_gegenstand(6).f_name[3] = "Baston de Combate (2M)";
		a_gegenstand(6).f_art = 1;
		a_gegenstand(6).f_klasse = 6;
		a_gegenstand(6).f_einkauf = 10;
		a_gegenstand(6).f_verkauf = 5;
		a_gegenstand(6).f_gewicht = 15;
		a_gegenstand(6).f_attri1 = 1;
		a_gegenstand(6).f_attri2 = 2;
		a_gegenstand(6).f_attri3 = 15;
		a_gegenstand(6).f_attri4 = 2;
		a_gegenstand(7).f_name[2] = "Morgenstern 1H";
		a_gegenstand(7).f_name[1] = "Morningstar 1h";
		a_gegenstand(7).f_name[3] = "Estrella del Alba 1h";
		a_gegenstand(7).f_art = 1;
		a_gegenstand(7).f_einkauf = 40;
		a_gegenstand(7).f_verkauf = 20;
		a_gegenstand(7).f_gewicht = 25;
		a_gegenstand(7).f_attri1 = 1;
		a_gegenstand(7).f_attri2 = 2;
		a_gegenstand(7).f_attri3 = 10;
		a_gegenstand(7).f_attri4 = 1;
		a_gegenstand(8).f_name[2] = "Morgenstern (2H)";
		a_gegenstand(8).f_name[1] = "Morningstar (2H)";
		a_gegenstand(8).f_name[3] = "Estrella del Alba (2M)";
		a_gegenstand(8).f_art = 1;
		a_gegenstand(8).f_einkauf = 45;
		a_gegenstand(8).f_verkauf = 25;
		a_gegenstand(8).f_gewicht = 35;
		a_gegenstand(8).f_attri1 = 2;
		a_gegenstand(8).f_attri2 = 4;
		a_gegenstand(8).f_attri3 = 10;
		a_gegenstand(8).f_attri4 = 2;
		a_gegenstand(9).f_name[2] = "Speer";
		a_gegenstand(9).f_name[1] = "Spear";
		a_gegenstand(9).f_name[3] = "Lanza";
		a_gegenstand(9).f_art = 1;
		a_gegenstand(9).f_klasse = 3;
		a_gegenstand(9).f_einkauf = 30;
		a_gegenstand(9).f_verkauf = 15;
		a_gegenstand(9).f_gewicht = 20;
		a_gegenstand(9).f_attri1 = 2;
		a_gegenstand(9).f_attri2 = 3;
		a_gegenstand(9).f_attri3 = 10;
		a_gegenstand(9).f_attri4 = 1;
		a_gegenstand(10).f_name[2] = "Dreizack (2H)";
		a_gegenstand(10).f_name[1] = "Pike (2H)";
		a_gegenstand(10).f_name[3] = "Pica (2M)";
		a_gegenstand(10).f_art = 1;
		a_gegenstand(10).f_klasse = 8;
		a_gegenstand(10).f_einkauf = 40;
		a_gegenstand(10).f_verkauf = 20;
		a_gegenstand(10).f_gewicht = 30;
		a_gegenstand(10).f_attri1 = 0;
		a_gegenstand(10).f_attri2 = 4;
		a_gegenstand(10).f_attri3 = 10;
		a_gegenstand(10).f_attri4 = 2;
		a_gegenstand(11).f_name[2] = "Axt (1H)";
		a_gegenstand(11).f_name[1] = "Axe (1H)";
		a_gegenstand(11).f_name[3] = "Hacha (1M)";
		a_gegenstand(11).f_art = 1;
		a_gegenstand(11).f_klasse = 2;
		a_gegenstand(11).f_einkauf = 40;
		a_gegenstand(11).f_verkauf = 20;
		a_gegenstand(11).f_gewicht = 25;
		a_gegenstand(11).f_attri1 = -1;
		a_gegenstand(11).f_attri2 = 3;
		a_gegenstand(11).f_attri3 = 5;
		a_gegenstand(11).f_attri4 = 1;
		a_gegenstand(12).f_name[2] = "Speer (2H)";
		a_gegenstand(12).f_name[1] = "Spear (2H)";
		a_gegenstand(12).f_name[3] = "Lanza (2M)";
		a_gegenstand(12).f_art = 1;
		a_gegenstand(12).f_klasse = 3;
		a_gegenstand(12).f_einkauf = 50;
		a_gegenstand(12).f_verkauf = 30;
		a_gegenstand(12).f_gewicht = 30;
		a_gegenstand(12).f_attri1 = -1;
		a_gegenstand(12).f_attri2 = 4;
		a_gegenstand(12).f_attri3 = 5;
		a_gegenstand(12).f_attri4 = 2;
		a_gegenstand(13).f_name[2] = "Axt";
		a_gegenstand(13).f_name[1] = "Axe";
		a_gegenstand(13).f_name[3] = "Hacha";
		a_gegenstand(13).f_art = 1;
		a_gegenstand(13).f_klasse = 2;
		a_gegenstand(13).f_einkauf = 30;
		a_gegenstand(13).f_verkauf = 20;
		a_gegenstand(13).f_gewicht = 30;
		a_gegenstand(13).f_attri1 = 1;
		a_gegenstand(13).f_attri2 = 2;
		a_gegenstand(13).f_attri3 = 5;
		a_gegenstand(13).f_attri4 = 1;
		a_gegenstand(14).f_name[2] = "Axt (2H)";
		a_gegenstand(14).f_name[1] = "Axe (2H)";
		a_gegenstand(14).f_name[3] = "Hacha (2H)";
		a_gegenstand(14).f_art = 1;
		a_gegenstand(14).f_klasse = 2;
		a_gegenstand(14).f_einkauf = 40;
		a_gegenstand(14).f_verkauf = 25;
		a_gegenstand(14).f_gewicht = 35;
		a_gegenstand(14).f_attri1 = 1;
		a_gegenstand(14).f_attri2 = 3;
		a_gegenstand(14).f_attri3 = 6;
		a_gegenstand(14).f_attri4 = 2;
		a_gegenstand(15).f_name[2] = "Stabaxt (2H)";
		a_gegenstand(15).f_name[1] = "Poleaxe (2H)";
		a_gegenstand(15).f_name[3] = "Hacha (2M)";
		a_gegenstand(15).f_art = 1;
		a_gegenstand(15).f_klasse = 8;
		a_gegenstand(15).f_einkauf = 45;
		a_gegenstand(15).f_verkauf = 25;
		a_gegenstand(15).f_gewicht = 35;
		a_gegenstand(15).f_attri1 = 2;
		a_gegenstand(15).f_attri2 = 4;
		a_gegenstand(15).f_attri3 = 6;
		a_gegenstand(15).f_attri4 = 2;
		a_gegenstand(16).f_name[2] = "Stabaxt (2H)";
		a_gegenstand(16).f_name[1] = "Poleaxe (2H)";
		a_gegenstand(16).f_name[3] = "Hacha (2M)";
		a_gegenstand(16).f_art = 1;
		a_gegenstand(16).f_klasse = 8;
		a_gegenstand(16).f_einkauf = 55;
		a_gegenstand(16).f_verkauf = 35;
		a_gegenstand(16).f_gewicht = 35;
		a_gegenstand(16).f_attri1 = 2;
		a_gegenstand(16).f_attri2 = 5;
		a_gegenstand(16).f_attri3 = 10;
		a_gegenstand(16).f_attri4 = 2;
		a_gegenstand(21).f_name[2] = "Bogen";
		a_gegenstand(21).f_name[1] = "Bow";
		a_gegenstand(21).f_name[3] = "Arco";
		a_gegenstand(21).f_art = 10;
		a_gegenstand(21).f_einkauf = 45;
		a_gegenstand(21).f_verkauf = 25;
		a_gegenstand(21).f_gewicht = 20;
		a_gegenstand(21).f_attri1 = 1;
		a_gegenstand(21).f_attri2 = 3;
		a_gegenstand(21).f_attri3 = 10;
		a_gegenstand(21).f_attri4 = 2;
		a_gegenstand(22).f_name[2] = "Armbrust";
		a_gegenstand(22).f_name[1] = "Crossbow";
		a_gegenstand(22).f_name[3] = "Ballesta";
		a_gegenstand(22).f_art = 10;
		a_gegenstand(22).f_einkauf = 55;
		a_gegenstand(22).f_verkauf = 35;
		a_gegenstand(22).f_gewicht = 30;
		a_gegenstand(22).f_attri1 = 3;
		a_gegenstand(22).f_attri2 = 4;
		a_gegenstand(22).f_attri3 = 10;
		a_gegenstand(22).f_attri4 = 2;
		a_gegenstand(18).f_name[2] = "Kriegshammer (2H)";
		a_gegenstand(18).f_name[1] = "Warhammer (2H)";
		a_gegenstand(18).f_name[3] = "Martillo de Guerra (2M)";
		a_gegenstand(18).f_art = 1;
		a_gegenstand(18).f_klasse = 4;
		a_gegenstand(18).f_einkauf = 55;
		a_gegenstand(18).f_verkauf = 30;
		a_gegenstand(18).f_gewicht = 45;
		a_gegenstand(18).f_attri1 = -1;
		a_gegenstand(18).f_attri2 = 5;
		a_gegenstand(18).f_attri3 = 10;
		a_gegenstand(18).f_attri4 = 2;
		a_gegenstand(19).f_name[2] = "Schleuder";
		a_gegenstand(19).f_name[1] = "Sling";
		a_gegenstand(19).f_name[3] = "Honda";
		a_gegenstand(19).f_art = 10;
		a_gegenstand(19).f_einkauf = 15;
		a_gegenstand(19).f_verkauf = 10;
		a_gegenstand(19).f_gewicht = 5;
		a_gegenstand(19).f_attri1 = 1;
		a_gegenstand(19).f_attri2 = 2;
		a_gegenstand(19).f_attri3 = 5;
		a_gegenstand(19).f_attri4 = 2;
		a_gegenstand(17).f_name[2] = "Nunchakus (2H)";
		a_gegenstand(17).f_name[1] = "Nunchakus (2H)";
		a_gegenstand(17).f_name[3] = "Nunchakus (2M)";
		a_gegenstand(17).f_art = 1;
		a_gegenstand(17).f_einkauf = 30;
		a_gegenstand(17).f_verkauf = 15;
		a_gegenstand(17).f_gewicht = 15;
		a_gegenstand(17).f_attri1 = 1;
		a_gegenstand(17).f_attri2 = 3;
		a_gegenstand(17).f_attri3 = 15;
		a_gegenstand(17).f_attri4 = 2;
		a_gegenstand(20).f_name[2] = "Pfeile";
		a_gegenstand(20).f_name[1] = "Arrows";
		a_gegenstand(20).f_name[3] = "Flechas";
		a_gegenstand(20).f_art = 13;
		a_gegenstand(20).f_einkauf = 4;
		a_gegenstand(20).f_verkauf = 2;
		a_gegenstand(20).f_gewicht = 1;
		a_gegenstand(20).f_attri1 = 10;
		a_gegenstand(20).f_attri2 = 0;
		a_gegenstand(20).f_attri3 = 1;
		a_gegenstand(20).f_attri4 = 5;
		a_gegenstand(23).f_name[2] = "Umhang";
		a_gegenstand(23).f_name[1] = "Cape";
		a_gegenstand(23).f_name[3] = "Capa";
		a_gegenstand(23).f_art = 9;
		a_gegenstand(23).f_einkauf = 10;
		a_gegenstand(23).f_verkauf = 5;
		a_gegenstand(23).f_gewicht = 5;
		a_gegenstand(23).f_attri1 = 0;
		a_gegenstand(23).f_attri2 = 0;
		a_gegenstand(23).f_attri3 = 1;
		a_gegenstand(24).f_name[2] = "Lederhelm";
		a_gegenstand(24).f_name[1] = "Leatherhelmet";
		a_gegenstand(24).f_name[3] = "Casco de Cuero";
		a_gegenstand(24).f_art = 6;
		a_gegenstand(24).f_einkauf = 5;
		a_gegenstand(24).f_verkauf = 2;
		a_gegenstand(24).f_gewicht = 5;
		a_gegenstand(24).f_attri1 = 0;
		a_gegenstand(24).f_attri2 = 0;
		a_gegenstand(24).f_attri3 = 1;
		a_gegenstand(25).f_name[2] = "Knochenhelm";
		a_gegenstand(25).f_name[1] = "Boneshelmet";
		a_gegenstand(25).f_name[3] = "Casco de Huesos";
		a_gegenstand(25).f_art = 6;
		a_gegenstand(25).f_einkauf = 10;
		a_gegenstand(25).f_verkauf = 5;
		a_gegenstand(25).f_gewicht = 10;
		a_gegenstand(25).f_attri1 = 0;
		a_gegenstand(25).f_attri2 = 0;
		a_gegenstand(25).f_attri3 = 2;
		a_gegenstand(26).f_name[2] = "Lederstiefel";
		a_gegenstand(26).f_name[1] = "Leatherboots";
		a_gegenstand(26).f_name[3] = "Botas de Cuero";
		a_gegenstand(26).f_art = 8;
		a_gegenstand(26).f_einkauf = 6;
		a_gegenstand(26).f_verkauf = 3;
		a_gegenstand(26).f_gewicht = 5;
		a_gegenstand(26).f_attri1 = 0;
		a_gegenstand(26).f_attri2 = 0;
		a_gegenstand(26).f_attri3 = 1;
		a_gegenstand(27).f_name[2] = "Lederstiefel";
		a_gegenstand(27).f_name[1] = "Leatherboots";
		a_gegenstand(27).f_name[3] = "Botas de Cuero";
		a_gegenstand(27).f_art = 8;
		a_gegenstand(27).f_einkauf = 7;
		a_gegenstand(27).f_verkauf = 4;
		a_gegenstand(27).f_gewicht = 7;
		a_gegenstand(27).f_attri1 = 0;
		a_gegenstand(27).f_attri2 = 0;
		a_gegenstand(27).f_attri3 = 2;
		a_gegenstand(28).f_name[2] = "Handschuhe";
		a_gegenstand(28).f_name[1] = "Gloves";
		a_gegenstand(28).f_name[3] = "Guantes";
		a_gegenstand(28).f_art = 7;
		a_gegenstand(28).f_einkauf = 5;
		a_gegenstand(28).f_verkauf = 2;
		a_gegenstand(28).f_gewicht = 2;
		a_gegenstand(28).f_attri1 = 0;
		a_gegenstand(28).f_attri2 = 0;
		a_gegenstand(28).f_attri3 = 1;
		a_gegenstand(29).f_name[2] = "Handschuhe";
		a_gegenstand(29).f_name[1] = "Gloves";
		a_gegenstand(29).f_name[3] = "Guantes";
		a_gegenstand(29).f_art = 7;
		a_gegenstand(29).f_einkauf = 7;
		a_gegenstand(29).f_verkauf = 3;
		a_gegenstand(29).f_gewicht = 3;
		a_gegenstand(29).f_attri1 = 0;
		a_gegenstand(29).f_attri2 = 0;
		a_gegenstand(29).f_attri3 = 2;
		a_gegenstand(30).f_name[2] = "Rundschild";
		a_gegenstand(30).f_name[1] = "Roundshield";
		a_gegenstand(30).f_name[3] = "Escudo Redondo";
		a_gegenstand(30).f_art = 11;
		a_gegenstand(30).f_einkauf = 7;
		a_gegenstand(30).f_verkauf = 3;
		a_gegenstand(30).f_gewicht = 10;
		a_gegenstand(30).f_attri1 = 1;
		a_gegenstand(30).f_attri2 = 1;
		a_gegenstand(30).f_attri3 = 2;
		a_gegenstand(31).f_name[2] = "Kiteschild";
		a_gegenstand(31).f_name[1] = "Kiteshield";
		a_gegenstand(31).f_name[3] = "Escudo Cometa";
		a_gegenstand(31).f_art = 11;
		a_gegenstand(31).f_einkauf = 15;
		a_gegenstand(31).f_verkauf = 8;
		a_gegenstand(31).f_gewicht = 20;
		a_gegenstand(31).f_attri1 = 2;
		a_gegenstand(31).f_attri2 = 2;
		a_gegenstand(31).f_attri3 = 3;
		a_gegenstand(32).f_name[2] = "Lederr\374stung";
		a_gegenstand(32).f_name[1] = "Leatherarmor";
		a_gegenstand(32).f_name[3] = "Armadura de Cuero";
		a_gegenstand(32).f_art = 9;
		a_gegenstand(32).f_einkauf = 30;
		a_gegenstand(32).f_verkauf = 15;
		a_gegenstand(32).f_gewicht = 20;
		a_gegenstand(32).f_attri1 = 1;
		a_gegenstand(32).f_attri2 = 0;
		a_gegenstand(32).f_attri3 = 2;
		a_gegenstand(33).f_name[2] = "Wattierte Lederr\374stung";
		a_gegenstand(33).f_name[1] = "Enforced Leatherarmor";
		a_gegenstand(33).f_name[3] = "Armadura de Cuero Endurecido";
		a_gegenstand(33).f_art = 9;
		a_gegenstand(33).f_einkauf = 40;
		a_gegenstand(33).f_verkauf = 25;
		a_gegenstand(33).f_gewicht = 20;
		a_gegenstand(33).f_attri1 = 2;
		a_gegenstand(33).f_attri2 = 1;
		a_gegenstand(33).f_attri3 = 2;
		a_gegenstand(34).f_name[2] = "Schuppenpanzer";
		a_gegenstand(34).f_name[1] = "Scalemail";
		a_gegenstand(34).f_name[3] = "Cota de Escamas";
		a_gegenstand(34).f_art = 9;
		a_gegenstand(34).f_einkauf = 60;
		a_gegenstand(34).f_verkauf = 30;
		a_gegenstand(34).f_gewicht = 30;
		a_gegenstand(34).f_attri1 = 3;
		a_gegenstand(34).f_attri2 = 1;
		a_gegenstand(34).f_attri3 = 3;
		a_gegenstand(35).f_name[2] = "Kettenhemd";
		a_gegenstand(35).f_name[1] = "Chainmail";
		a_gegenstand(35).f_name[3] = "Cota de Malla";
		a_gegenstand(35).f_art = 9;
		a_gegenstand(35).f_einkauf = 65;
		a_gegenstand(35).f_verkauf = 35;
		a_gegenstand(35).f_gewicht = 50;
		a_gegenstand(35).f_attri1 = 3;
		a_gegenstand(35).f_attri2 = 2;
		a_gegenstand(35).f_attri3 = 3;
		a_gegenstand(36).f_name[2] = "Plattenpanzer";
		a_gegenstand(36).f_name[1] = "Platemail";
		a_gegenstand(36).f_name[3] = "Cota de Placas";
		a_gegenstand(36).f_art = 9;
		a_gegenstand(36).f_einkauf = 150;
		a_gegenstand(36).f_verkauf = 80;
		a_gegenstand(36).f_gewicht = 125;
		a_gegenstand(36).f_attri1 = 4;
		a_gegenstand(36).f_attri2 = 2;
		a_gegenstand(36).f_attri3 = 4;
		a_gegenstand(37).f_name[2] = "Vollr\374stung";
		a_gegenstand(37).f_name[1] = "Full Armor";
		a_gegenstand(37).f_name[3] = "Armadura Completa";
		a_gegenstand(37).f_art = 9;
		a_gegenstand(37).f_einkauf = 200;
		a_gegenstand(37).f_verkauf = 120;
		a_gegenstand(37).f_gewicht = 160;
		a_gegenstand(37).f_attri1 = 4;
		a_gegenstand(37).f_attri2 = 3;
		a_gegenstand(37).f_attri3 = 4;
		a_gegenstand(156).f_name[2] = "Zauberr\374stung";
		a_gegenstand(156).f_name[1] = "Magical Armor";
		a_gegenstand(156).f_name[3] = "Armadura Magica";
		a_gegenstand(156).f_art = 9;
		a_gegenstand(156).f_einkauf = 400;
		a_gegenstand(156).f_verkauf = 0;
		a_gegenstand(156).f_gewicht = 100;
		a_gegenstand(156).f_attri1 = 3;
		a_gegenstand(156).f_attri2 = 3;
		a_gegenstand(156).f_attri3 = 5;
		a_gegenstand(39).f_name[2] = "Lampe";
		a_gegenstand(39).f_name[1] = "Lamp";
		a_gegenstand(39).f_name[3] = "Lampara";
		a_gegenstand(39).f_art = 2;
		a_gegenstand(39).f_einkauf = 15;
		a_gegenstand(39).f_verkauf = 7;
		a_gegenstand(39).f_gewicht = 10;
		a_gegenstand(39).f_attri1 = 150;
		a_gegenstand(44).f_name[2] = "Brot";
		a_gegenstand(44).f_name[1] = "Bread";
		a_gegenstand(44).f_name[3] = "Pan";
		a_gegenstand(44).f_art = 3;
		a_gegenstand(44).f_einkauf = 10;
		a_gegenstand(44).f_verkauf = 5;
		a_gegenstand(44).f_gewicht = 3;
		a_gegenstand(44).f_attri1 = 120;
		a_gegenstand(42).f_name[2] = "Schinken";
		a_gegenstand(42).f_name[1] = "Ham";
		a_gegenstand(42).f_name[3] = "Jamon";
		a_gegenstand(42).f_art = 3;
		a_gegenstand(42).f_einkauf = 20;
		a_gegenstand(42).f_verkauf = 10;
		a_gegenstand(42).f_gewicht = 5;
		a_gegenstand(42).f_attri1 = 150;
		a_gegenstand(43).f_name[2] = "H\374hnchen";
		a_gegenstand(43).f_name[1] = "Chicken";
		a_gegenstand(43).f_name[3] = "Pollo";
		a_gegenstand(43).f_art = 3;
		a_gegenstand(43).f_einkauf = 15;
		a_gegenstand(43).f_verkauf = 8;
		a_gegenstand(43).f_gewicht = 3;
		a_gegenstand(43).f_attri1 = 100;
		a_gegenstand(46).f_name[2] = "Fackel";
		a_gegenstand(46).f_name[1] = "Torch";
		a_gegenstand(46).f_name[3] = "Antorcha";
		a_gegenstand(46).f_art = 2;
		a_gegenstand(46).f_einkauf = 3;
		a_gegenstand(46).f_verkauf = 1;
		a_gegenstand(46).f_gewicht = 3;
		a_gegenstand(46).f_attri1 = 100;
		a_gegenstand(54).f_name[2] = "Hut des Erzmagiers";
		a_gegenstand(54).f_name[1] = "Hat of the Archmage";
		a_gegenstand(54).f_name[3] = "Sombrero del Archimago";
		a_gegenstand(54).f_info[2] = "+7 Mana";
		a_gegenstand(54).f_info[1] = "+7 Mana";
		a_gegenstand(54).f_info[3] = "+7 Mana";
		a_gegenstand(54).f_art = 6;
		a_gegenstand(54).f_einkauf = 800;
		a_gegenstand(54).f_verkauf = 400;
		a_gegenstand(54).f_gewicht = 5;
		a_gegenstand(56).f_name[2] = "Apfel";
		a_gegenstand(56).f_name[1] = "Apple";
		a_gegenstand(56).f_name[3] = "Manzana";
		a_gegenstand(56).f_art = 3;
		a_gegenstand(56).f_einkauf = 3;
		a_gegenstand(56).f_verkauf = 1;
		a_gegenstand(56).f_gewicht = 1;
		a_gegenstand(56).f_attri1 = 30;
		a_gegenstand(242).f_name[2] = "Magischer Apfel";
		a_gegenstand(242).f_name[1] = "Magic Apple";
		a_gegenstand(242).f_name[3] = "Manzana Magica";
		a_gegenstand(242).f_art = 3;
		a_gegenstand(242).f_einkauf = 0;
		a_gegenstand(242).f_verkauf = 0;
		a_gegenstand(242).f_gewicht = 1;
		a_gegenstand(242).f_attri1 = 60;
		a_gegenstand(55).f_name[2] = "Erdbeere";
		a_gegenstand(55).f_name[1] = "Strawberry";
		a_gegenstand(55).f_name[3] = "Fresa";
		a_gegenstand(55).f_art = 3;
		a_gegenstand(55).f_einkauf = 3;
		a_gegenstand(55).f_verkauf = 1;
		a_gegenstand(55).f_gewicht = 1;
		a_gegenstand(55).f_attri1 = 25;
		a_gegenstand(57).f_name[2] = "Bananen";
		a_gegenstand(57).f_name[1] = "Bananas";
		a_gegenstand(57).f_name[3] = "Bananas";
		a_gegenstand(57).f_art = 3;
		a_gegenstand(57).f_einkauf = 3;
		a_gegenstand(57).f_verkauf = 1;
		a_gegenstand(57).f_gewicht = 1;
		a_gegenstand(57).f_attri1 = 40;
		a_gegenstand(58).f_name[2] = "Birne";
		a_gegenstand(58).f_name[1] = "Pear";
		a_gegenstand(58).f_name[3] = "Pera";
		a_gegenstand(58).f_art = 3;
		a_gegenstand(58).f_einkauf = 3;
		a_gegenstand(58).f_verkauf = 1;
		a_gegenstand(58).f_gewicht = 1;
		a_gegenstand(58).f_attri1 = 30;
		a_gegenstand(59).f_name[2] = "Ananas";
		a_gegenstand(59).f_name[1] = "Pineapple";
		a_gegenstand(59).f_name[3] = "Pinas";
		a_gegenstand(59).f_art = 3;
		a_gegenstand(59).f_einkauf = 3;
		a_gegenstand(59).f_verkauf = 1;
		a_gegenstand(59).f_gewicht = 1;
		a_gegenstand(59).f_attri1 = 30;
		a_gegenstand(60).f_name[2] = "Tomate";
		a_gegenstand(60).f_name[1] = "Tomato";
		a_gegenstand(60).f_name[3] = "Tomate";
		a_gegenstand(60).f_art = 3;
		a_gegenstand(60).f_einkauf = 3;
		a_gegenstand(60).f_verkauf = 1;
		a_gegenstand(60).f_gewicht = 1;
		a_gegenstand(60).f_attri1 = 30;
		a_gegenstand(61).f_name[2] = "Kirschen";
		a_gegenstand(61).f_name[1] = "Cherrys";
		a_gegenstand(61).f_name[3] = "Cerezas";
		a_gegenstand(61).f_art = 3;
		a_gegenstand(61).f_einkauf = 3;
		a_gegenstand(61).f_verkauf = 1;
		a_gegenstand(61).f_gewicht = 1;
		a_gegenstand(61).f_attri1 = 25;
		a_gegenstand(62).f_name[2] = "Zitrone";
		a_gegenstand(62).f_name[1] = "Lemon";
		a_gegenstand(62).f_name[3] = "Limon";
		a_gegenstand(62).f_art = 3;
		a_gegenstand(62).f_einkauf = 3;
		a_gegenstand(62).f_verkauf = 1;
		a_gegenstand(62).f_gewicht = 1;
		a_gegenstand(62).f_attri1 = 30;
		a_gegenstand(63).f_name[2] = "Orange";
		a_gegenstand(63).f_name[1] = "Orange";
		a_gegenstand(63).f_name[3] = "Naranja";
		a_gegenstand(63).f_art = 3;
		a_gegenstand(63).f_einkauf = 3;
		a_gegenstand(63).f_verkauf = 1;
		a_gegenstand(63).f_gewicht = 1;
		a_gegenstand(63).f_attri1 = 30;
		a_gegenstand(64).f_name[2] = "Trauben";
		a_gegenstand(64).f_name[1] = "Grapes";
		a_gegenstand(64).f_name[3] = "Uvas";
		a_gegenstand(64).f_art = 3;
		a_gegenstand(64).f_einkauf = 3;
		a_gegenstand(64).f_verkauf = 1;
		a_gegenstand(64).f_gewicht = 1;
		a_gegenstand(64).f_attri1 = 25;
		a_gegenstand(134).f_name[2] = "\326l";
		a_gegenstand(134).f_name[1] = "Oil";
		a_gegenstand(134).f_name[3] = "Aceite";
		a_gegenstand(134).f_art = 2;
		a_gegenstand(134).f_einkauf = 3;
		a_gegenstand(134).f_verkauf = 1;
		a_gegenstand(134).f_gewicht = 1;
		a_gegenstand(147).f_name[2] = "Magische Pfeile";
		a_gegenstand(147).f_name[1] = "Magic Arrows";
		a_gegenstand(147).f_name[3] = "Flechas Magicas";
		a_gegenstand(147).f_art = 13;
		a_gegenstand(147).f_einkauf = 2;
		a_gegenstand(147).f_verkauf = 0;
		a_gegenstand(147).f_gewicht = 1;
		a_gegenstand(147).f_magisch = 1;
		a_gegenstand(147).f_attri1 = 10;
		a_gegenstand(147).f_attri2 = 1;
		a_gegenstand(147).f_attri3 = 2;
		a_gegenstand(147).f_attri4 = 10;
		a_gegenstand(163).f_name[2] = "Zauberschwert";
		a_gegenstand(163).f_name[1] = "Magical Sword";
		a_gegenstand(163).f_name[3] = "Espada Magica";
		a_gegenstand(163).f_art = 1;
		a_gegenstand(163).f_klasse = 1;
		a_gegenstand(163).f_einkauf = 40;
		a_gegenstand(163).f_verkauf = 0;
		a_gegenstand(163).f_gewicht = 25;
		a_gegenstand(163).f_magisch = 1;
		a_gegenstand(163).f_attri1 = 2;
		a_gegenstand(163).f_attri2 = 5;
		a_gegenstand(163).f_attri3 = 10;
		a_gegenstand(163).f_attri4 = 1;
		a_gegenstand(186).f_name[2] = "Zauberbuch";
		a_gegenstand(186).f_name[1] = "Grimoire";
		a_gegenstand(186).f_name[3] = "Grimoire";
		a_gegenstand(186).f_art = 14;
		a_gegenstand(186).f_einkauf = 1600;
		a_gegenstand(186).f_verkauf = 800;
		a_gegenstand(186).f_gewicht = 2;
		a_gegenstand(193).f_name[2] = "Wasserschlauch";
		a_gegenstand(193).f_name[1] = "Waterskin";
		a_gegenstand(193).f_name[3] = "Piel para Agua";
		a_gegenstand(193).f_art = 15;
		a_gegenstand(193).f_einkauf = 10;
		a_gegenstand(193).f_verkauf = 3;
		a_gegenstand(193).f_gewicht = 5;
		a_gegenstand(193).f_attri1 = 7;
		a_gegenstand(240).f_name[2] = "Udjat Auge";
		a_gegenstand(240).f_name[1] = "Udjat Eye";
		a_gegenstand(240).f_name[3] = "Ojo de Udjat";
		a_gegenstand(240).f_art = 15;
		a_gegenstand(240).f_einkauf = 2000;
		a_gegenstand(240).f_verkauf = 1000;
		a_gegenstand(240).f_gewicht = 2;
		a_gegenstand(240).f_attri1 = 3;
		a_gegenstand(254).f_name[2] = "Zauberschild";
		a_gegenstand(254).f_name[1] = "Magical Shield";
		a_gegenstand(254).f_name[3] = "Escudo Magico";
		a_gegenstand(254).f_art = 11;
		a_gegenstand(254).f_einkauf = 15;
		a_gegenstand(254).f_verkauf = 0;
		a_gegenstand(254).f_gewicht = 20;
		a_gegenstand(254).f_attri1 = 1;
		a_gegenstand(254).f_attri2 = 2;
		a_gegenstand(254).f_attri3 = 3;
		a_gegenstand(254).f_attri4 = 2;
		a_gegenstand(239).f_name[2] = "Handschuhe des Gargantua";
		a_gegenstand(239).f_name[1] = "Gloves of Gargantua";
		a_gegenstand(239).f_name[3] = "Guantes de Gargantua";
		a_gegenstand(239).f_art = 7;
		a_gegenstand(239).f_einkauf = 600;
		a_gegenstand(239).f_verkauf = 300;
		a_gegenstand(239).f_gewicht = 2;
		a_gegenstand(248).f_name[2] = "Kessel der Alchimie";
		a_gegenstand(248).f_name[1] = "Mortar of Alchemy";
		a_gegenstand(248).f_name[3] = "Mortero de Alquimista";
		a_gegenstand(248).f_art = 15;
		a_gegenstand(248).f_einkauf = 1600;
		a_gegenstand(248).f_verkauf = 800;
		a_gegenstand(248).f_gewicht = 50;
		a_gegenstand(200).f_name[2] = "Schuhe des Hermes";
		a_gegenstand(200).f_name[1] = "Shoes of Hermes";
		a_gegenstand(200).f_name[3] = "Zapatos Hermes";
		a_gegenstand(200).f_info[2] = "+3 Zugweite";
		a_gegenstand(200).f_info[1] = "+3 Speed";
		a_gegenstand(200).f_info[3] = "+3 Velocidad";
		a_gegenstand(200).f_art = 8;
		a_gegenstand(200).f_einkauf = 500;
		a_gegenstand(200).f_verkauf = 250;
		a_gegenstand(200).f_gewicht = 5;
		a_gegenstand(142).f_name[2] = "Flammenschwert";
		a_gegenstand(142).f_name[1] = "Flaming Sword";
		a_gegenstand(142).f_name[3] = "Espada Llameante";
		a_gegenstand(142).f_art = 1;
		a_gegenstand(142).f_klasse = 1;
		a_gegenstand(142).f_einkauf = 600;
		a_gegenstand(142).f_verkauf = 350;
		a_gegenstand(142).f_gewicht = 25;
		a_gegenstand(142).f_magisch = 1;
		a_gegenstand(142).f_attri1 = 2;
		a_gegenstand(142).f_attri2 = 4;
		a_gegenstand(142).f_attri3 = 7;
		a_gegenstand(142).f_attri4 = 1;
		a_gegenstand(143).f_name[2] = "Eisschwert";
		a_gegenstand(143).f_name[1] = "Ice Sword";
		a_gegenstand(143).f_name[3] = "Espada de Hielo";
		a_gegenstand(143).f_art = 1;
		a_gegenstand(143).f_klasse = 1;
		a_gegenstand(143).f_einkauf = 600;
		a_gegenstand(143).f_verkauf = 350;
		a_gegenstand(143).f_gewicht = 25;
		a_gegenstand(143).f_magisch = 1;
		a_gegenstand(143).f_attri1 = 2;
		a_gegenstand(143).f_attri2 = 4;
		a_gegenstand(143).f_attri3 = 7;
		a_gegenstand(143).f_attri4 = 1;
		a_gegenstand(144).f_name[2] = "Giftschwert";
		a_gegenstand(144).f_name[1] = "Poisoneous Sword";
		a_gegenstand(144).f_name[3] = "Espada Envenenosa";
		a_gegenstand(144).f_art = 1;
		a_gegenstand(144).f_klasse = 1;
		a_gegenstand(144).f_einkauf = 600;
		a_gegenstand(144).f_verkauf = 300;
		a_gegenstand(144).f_gewicht = 25;
		a_gegenstand(144).f_magisch = 1;
		a_gegenstand(144).f_attri1 = 2;
		a_gegenstand(144).f_attri2 = 4;
		a_gegenstand(144).f_attri3 = 7;
		a_gegenstand(144).f_attri4 = 1;
		a_gegenstand(177).f_name[2] = "Stab der Portale";
		a_gegenstand(177).f_name[1] = "Staff of Portals";
		a_gegenstand(177).f_name[3] = "Vara de los Portales";
		a_gegenstand(177).f_art = 22;
		a_gegenstand(177).f_einkauf = 800;
		a_gegenstand(177).f_verkauf = 400;
		a_gegenstand(177).f_gewicht = 3;
		a_gegenstand(177).f_attri1 = 21;
		a_gegenstand(178).f_name[2] = "Stab des Schutzes";
		a_gegenstand(178).f_name[1] = "Staff of Protection";
		a_gegenstand(178).f_name[3] = "Vara de Proteccion";
		a_gegenstand(178).f_art = 22;
		a_gegenstand(178).f_einkauf = 600;
		a_gegenstand(178).f_verkauf = 300;
		a_gegenstand(178).f_gewicht = 3;
		a_gegenstand(178).f_attri1 = 18;
		a_gegenstand(179).f_name[2] = "Stab des Todes";
		a_gegenstand(179).f_name[1] = "Staff of Death";
		a_gegenstand(179).f_name[3] = "Vara de la muerte";
		a_gegenstand(179).f_art = 22;
		a_gegenstand(179).f_einkauf = 600;
		a_gegenstand(179).f_verkauf = 300;
		a_gegenstand(179).f_gewicht = 3;
		a_gegenstand(179).f_attri1 = 67;
		a_gegenstand(180).f_name[2] = "Stab des Lichtes";
		a_gegenstand(180).f_name[1] = "Staff of Light";
		a_gegenstand(180).f_name[3] = "Vara de la Llama";
		a_gegenstand(180).f_art = 22;
		a_gegenstand(180).f_einkauf = 700;
		a_gegenstand(180).f_verkauf = 400;
		a_gegenstand(180).f_gewicht = 3;
		a_gegenstand(180).f_attri1 = 30;
		a_gegenstand(181).f_name[2] = "Stab der Heilung";
		a_gegenstand(181).f_name[1] = "Staff of Healing";
		a_gegenstand(181).f_name[3] = "Vara de la Curacion";
		a_gegenstand(181).f_art = 22;
		a_gegenstand(181).f_einkauf = 800;
		a_gegenstand(181).f_verkauf = 400;
		a_gegenstand(181).f_gewicht = 3;
		a_gegenstand(181).f_attri1 = 3;
		a_gegenstand(182).f_name[2] = "Stab des Midas";
		a_gegenstand(182).f_name[1] = "Staff of Midas";
		a_gegenstand(182).f_name[3] = "Vara de Midas";
		a_gegenstand(182).f_art = 22;
		a_gegenstand(182).f_einkauf = 2000;
		a_gegenstand(182).f_verkauf = 1000;
		a_gegenstand(182).f_gewicht = 3;
		a_gegenstand(182).f_attri1 = 42;
		a_gegenstand(183).f_name[2] = "Stab des \326ffnens";
		a_gegenstand(183).f_name[1] = "Staff of Open";
		a_gegenstand(183).f_name[3] = "Vara de la abertura";
		a_gegenstand(183).f_art = 22;
		a_gegenstand(183).f_einkauf = 800;
		a_gegenstand(183).f_verkauf = 400;
		a_gegenstand(183).f_gewicht = 3;
		a_gegenstand(183).f_attri1 = 27;
		a_gegenstand(184).f_name[2] = "Stab des Feuers";
		a_gegenstand(184).f_name[1] = "Staff of Fire";
		a_gegenstand(184).f_name[3] = "Vara del Fuego";
		a_gegenstand(184).f_art = 22;
		a_gegenstand(184).f_einkauf = 500;
		a_gegenstand(184).f_verkauf = 250;
		a_gegenstand(184).f_gewicht = 3;
		a_gegenstand(184).f_attri1 = 22;
		a_gegenstand(152).f_name[2] = "Stab der K\344lte";
		a_gegenstand(152).f_name[1] = "Staff of Coldness";
		a_gegenstand(152).f_name[3] = "Vara del Frio";
		a_gegenstand(152).f_art = 22;
		a_gegenstand(152).f_einkauf = 300;
		a_gegenstand(152).f_verkauf = 150;
		a_gegenstand(152).f_gewicht = 3;
		a_gegenstand(152).f_attri1 = 28;
		a_gegenstand(295).f_name[2] = "Stab der Winde";
		a_gegenstand(295).f_name[1] = "Staff of Winds";
		a_gegenstand(295).f_name[3] = "Vara del Viento";
		a_gegenstand(295).f_art = 22;
		a_gegenstand(295).f_einkauf = 450;
		a_gegenstand(295).f_verkauf = 225;
		a_gegenstand(295).f_gewicht = 3;
		a_gegenstand(295).f_attri1 = 108;
		a_gegenstand(296).f_name[2] = "Stab der Meteore";
		a_gegenstand(296).f_name[1] = "Staff of Meteors";
		a_gegenstand(296).f_name[3] = "Vara de los Meteoros";
		a_gegenstand(296).f_art = 22;
		a_gegenstand(296).f_einkauf = 500;
		a_gegenstand(296).f_verkauf = 250;
		a_gegenstand(296).f_gewicht = 3;
		a_gegenstand(296).f_attri1 = 117;
		a_gegenstand(297).f_name[2] = "Stab der Trockenheit";
		a_gegenstand(297).f_name[1] = "Staff of Dryness";
		a_gegenstand(297).f_name[3] = "Vara de la Aridez";
		a_gegenstand(297).f_art = 22;
		a_gegenstand(297).f_einkauf = 400;
		a_gegenstand(297).f_verkauf = 200;
		a_gegenstand(297).f_gewicht = 3;
		a_gegenstand(297).f_attri1 = 29;
		a_gegenstand(298).f_name[2] = "Stab des Wassers";
		a_gegenstand(298).f_name[1] = "Staff of Water";
		a_gegenstand(298).f_name[3] = "Vara del Aqua";
		a_gegenstand(298).f_art = 22;
		a_gegenstand(298).f_einkauf = 500;
		a_gegenstand(298).f_verkauf = 250;
		a_gegenstand(298).f_gewicht = 3;
		a_gegenstand(298).f_attri1 = 73;
		a_gegenstand(299).f_name[2] = "Stab des Feuers";
		a_gegenstand(299).f_name[1] = "Staff of Fire";
		a_gegenstand(299).f_name[3] = "Vara del Fuego";
		a_gegenstand(299).f_art = 22;
		a_gegenstand(299).f_einkauf = 500;
		a_gegenstand(299).f_verkauf = 250;
		a_gegenstand(299).f_gewicht = 3;
		a_gegenstand(299).f_attri1 = 22;
		a_gegenstand(300).f_name[2] = "Stab des Sternenfeuers";
		a_gegenstand(300).f_name[1] = "Staff of Starfire";
		a_gegenstand(300).f_name[3] = "Vara de las Estrellas";
		a_gegenstand(300).f_art = 22;
		a_gegenstand(300).f_einkauf = 500;
		a_gegenstand(300).f_verkauf = 250;
		a_gegenstand(300).f_gewicht = 3;
		a_gegenstand(300).f_attri1 = 76;
		a_gegenstand(301).f_name[2] = "Stab der Untoten";
		a_gegenstand(301).f_name[1] = "Staff of the Undead";
		a_gegenstand(301).f_name[3] = "Vara de los No-Muertos";
		a_gegenstand(301).f_art = 22;
		a_gegenstand(301).f_einkauf = 400;
		a_gegenstand(301).f_verkauf = 200;
		a_gegenstand(301).f_gewicht = 3;
		a_gegenstand(301).f_attri1 = 17;
		a_gegenstand(267).f_name[2] = "Haupt der Medusa";
		a_gegenstand(267).f_name[1] = "Head of Medusa";
		a_gegenstand(267).f_name[3] = "Cabeza de la Medusa";
		a_gegenstand(267).f_art = 15;
		a_gegenstand(267).f_einkauf = 800;
		a_gegenstand(267).f_verkauf = 400;
		a_gegenstand(267).f_gewicht = 10;
		a_gegenstand(267).f_attri1 = 62;
		a_gegenstand(267).f_attri2 = 10;
		a_gegenstand(169).f_name[2] = "Karte";
		a_gegenstand(169).f_name[1] = "Map";
		a_gegenstand(169).f_name[3] = "Mapa";
		a_gegenstand(169).f_art = 15;
		a_gegenstand(169).f_einkauf = 900;
		a_gegenstand(169).f_verkauf = 450;
		a_gegenstand(169).f_gewicht = 1;
		a_gegenstand(197).f_name[2] = "Edelstein T\374rkies";
		a_gegenstand(197).f_name[1] = "Turquoise Gem";
		a_gegenstand(197).f_name[3] = "Piedra Preciosa Turquesa";
		a_gegenstand(197).f_art = 16;
		a_gegenstand(197).f_einkauf = 450;
		a_gegenstand(197).f_verkauf = 225;
		a_gegenstand(197).f_gewicht = 1;
		a_gegenstand(198).f_name[2] = "Edelstein Gelb";
		a_gegenstand(198).f_name[1] = "Yellow Gem";
		a_gegenstand(198).f_name[3] = "Piedra Preciosa Amarilla";
		a_gegenstand(198).f_art = 16;
		a_gegenstand(198).f_einkauf = 350;
		a_gegenstand(198).f_verkauf = 175;
		a_gegenstand(198).f_gewicht = 1;
		a_gegenstand(199).f_name[2] = "Edelstein Blau";
		a_gegenstand(199).f_name[1] = "Blue Gem";
		a_gegenstand(199).f_name[3] = "Piedra Preciosa Azul";
		a_gegenstand(199).f_art = 16;
		a_gegenstand(199).f_einkauf = 500;
		a_gegenstand(199).f_verkauf = 250;
		a_gegenstand(199).f_gewicht = 1;
		a_gegenstand(209).f_name[2] = "Edelstein Rot";
		a_gegenstand(209).f_name[1] = "Red Gem";
		a_gegenstand(209).f_name[3] = "Piedra Preciosa Roja";
		a_gegenstand(209).f_art = 16;
		a_gegenstand(209).f_einkauf = 600;
		a_gegenstand(209).f_verkauf = 300;
		a_gegenstand(209).f_gewicht = 1;
		a_gegenstand(210).f_name[2] = "Bernstein";
		a_gegenstand(210).f_name[1] = "Amberstone";
		a_gegenstand(210).f_name[3] = "Ambar";
		a_gegenstand(210).f_art = 16;
		a_gegenstand(210).f_einkauf = 400;
		a_gegenstand(210).f_verkauf = 200;
		a_gegenstand(210).f_gewicht = 1;
		a_gegenstand(211).f_name[2] = "Edelstein Gr\374n";
		a_gegenstand(211).f_name[1] = "Green Gem";
		a_gegenstand(211).f_name[3] = "Piedra Preciosa Verde";
		a_gegenstand(211).f_art = 16;
		a_gegenstand(211).f_einkauf = 550;
		a_gegenstand(211).f_verkauf = 275;
		a_gegenstand(211).f_gewicht = 1;
		a_gegenstand(213).f_name[2] = "Edelstein Weiss";
		a_gegenstand(213).f_name[1] = "White Gem";
		a_gegenstand(213).f_name[3] = "Piedra Preciosa Blaca";
		a_gegenstand(213).f_art = 16;
		a_gegenstand(213).f_einkauf = 500;
		a_gegenstand(213).f_verkauf = 250;
		a_gegenstand(213).f_gewicht = 1;
		a_gegenstand(214).f_name[2] = "Edelstein Schwarz";
		a_gegenstand(214).f_name[1] = "Black Gem";
		a_gegenstand(214).f_name[3] = "Piedra Preciosa Negra";
		a_gegenstand(214).f_art = 16;
		a_gegenstand(214).f_einkauf = 370;
		a_gegenstand(214).f_verkauf = 175;
		a_gegenstand(214).f_gewicht = 1;
		a_gegenstand(215).f_name[2] = "Jade";
		a_gegenstand(215).f_name[1] = "Jade";
		a_gegenstand(215).f_name[3] = "Jade";
		a_gegenstand(215).f_art = 16;
		a_gegenstand(215).f_einkauf = 370;
		a_gegenstand(215).f_verkauf = 175;
		a_gegenstand(215).f_gewicht = 1;
		a_gegenstand(216).f_name[2] = "Mondstein";
		a_gegenstand(216).f_name[1] = "Moonstone";
		a_gegenstand(216).f_name[3] = "Piedra de la Luna";
		a_gegenstand(216).f_art = 16;
		a_gegenstand(216).f_einkauf = 400;
		a_gegenstand(216).f_verkauf = 200;
		a_gegenstand(216).f_gewicht = 1;
		a_gegenstand(217).f_name[2] = "Opal";
		a_gegenstand(217).f_name[1] = "Opal";
		a_gegenstand(217).f_name[3] = "Opalo";
		a_gegenstand(217).f_art = 16;
		a_gegenstand(217).f_einkauf = 300;
		a_gegenstand(217).f_verkauf = 150;
		a_gegenstand(217).f_gewicht = 1;
		a_gegenstand(218).f_name[2] = "Tigerauge";
		a_gegenstand(218).f_name[1] = "Tigereye";
		a_gegenstand(218).f_name[3] = "Ojo de tigre";
		a_gegenstand(218).f_art = 16;
		a_gegenstand(218).f_einkauf = 350;
		a_gegenstand(218).f_verkauf = 175;
		a_gegenstand(218).f_gewicht = 1;
		a_gegenstand(212).f_name[2] = "Dietriche";
		a_gegenstand(212).f_name[1] = "Picklocks";
		a_gegenstand(212).f_name[3] = "Ganzuas";
		a_gegenstand(212).f_info[2] = "\326ffnet T\374ren und Truhen";
		a_gegenstand(212).f_info[1] = "Opens Doors and Chests";
		a_gegenstand(212).f_info[3] = "Abre puertas y cajas";
		a_gegenstand(212).f_art = 0;
		a_gegenstand(212).f_einkauf = 100;
		a_gegenstand(212).f_verkauf = 50;
		a_gegenstand(212).f_gewicht = 2;
		a_gegenstand(212).f_attri1 = 20;
		a_gegenstand(220).f_name[2] = "Ring der Zwerge";
		a_gegenstand(220).f_name[1] = "Ring of the Dwarfs";
		a_gegenstand(220).f_name[3] = "Anillo de los Enanos";
		a_gegenstand(220).f_info[2] = "Findet Fallen";
		a_gegenstand(220).f_info[1] = "Finds traps";
		a_gegenstand(220).f_info[3] = "Desvela trampas";
		a_gegenstand(220).f_art = 18;
		a_gegenstand(220).f_einkauf = 700;
		a_gegenstand(220).f_verkauf = 350;
		a_gegenstand(220).f_gewicht = 1;
		a_gegenstand(221).f_name[2] = "Ring des Lebens";
		a_gegenstand(221).f_name[1] = "Ring of Life";
		a_gegenstand(221).f_name[3] = "Anillo de Vida";
		a_gegenstand(221).f_info[2] = "Regenerierst Leben";
		a_gegenstand(221).f_info[1] = "Regenerates Life";
		a_gegenstand(221).f_info[3] = "Regenera Vida";
		a_gegenstand(221).f_art = 18;
		a_gegenstand(221).f_einkauf = 1800;
		a_gegenstand(221).f_verkauf = 900;
		a_gegenstand(221).f_gewicht = 1;
		a_gegenstand(221).f_attri1 = 350;
		a_gegenstand(146).f_name[2] = "Steinernes Herz";
		a_gegenstand(146).f_name[1] = "Heart of Stone";
		a_gegenstand(146).f_name[3] = "Corazon de Piedra";
		a_gegenstand(146).f_art = 15;
		a_gegenstand(146).f_einkauf = 1000;
		a_gegenstand(146).f_verkauf = 500;
		a_gegenstand(146).f_gewicht = 5;
		a_gegenstand(260).f_name[2] = "Hut des Meistersch\374tzen";
		a_gegenstand(260).f_name[1] = "Cap of the Master Archer";
		a_gegenstand(260).f_name[3] = "Sombrero del Maestro del Arco";
		a_gegenstand(260).f_info[2] = "+10 Trefferchance mit Bogen";
		a_gegenstand(260).f_info[1] = "+10 To Hit with Bow";
		a_gegenstand(260).f_info[3] = "+10 para alcanzar con arcos";
		a_gegenstand(260).f_art = 6;
		a_gegenstand(260).f_einkauf = 400;
		a_gegenstand(260).f_verkauf = 200;
		a_gegenstand(260).f_gewicht = 5;
		a_gegenstand(260).f_attri3 = 10;
		a_gegenstand(232).f_name[2] = "Seil";
		a_gegenstand(232).f_name[1] = "Rope";
		a_gegenstand(232).f_name[3] = "Cuerda";
		a_gegenstand(232).f_art = 15;
		a_gegenstand(232).f_einkauf = 20;
		a_gegenstand(232).f_verkauf = 10;
		a_gegenstand(232).f_gewicht = 5;
		a_gegenstand(190).f_name[2] = "Oger-Pfeile";
		a_gegenstand(190).f_name[1] = "Ogre-Arrows";
		a_gegenstand(190).f_name[3] = "Flechas del Ogro";
		a_gegenstand(190).f_art = 13;
		a_gegenstand(190).f_einkauf = 2;
		a_gegenstand(190).f_verkauf = 1;
		a_gegenstand(190).f_gewicht = 1;
		a_gegenstand(190).f_magisch = 1;
		a_gegenstand(190).f_attri1 = 10;
		a_gegenstand(190).f_attri2 = 0;
		a_gegenstand(190).f_attri3 = 5;
		a_gegenstand(190).f_attri4 = 5;
		a_gegenstand(75).f_name[2] = "Wirkungslos";
		a_gegenstand(75).f_name[1] = "Useless";
		a_gegenstand(75).f_name[3] = "Sin utilidad";
		a_gegenstand(75).f_art = 4;
		a_gegenstand(75).f_einkauf = 2;
		a_gegenstand(75).f_verkauf = 0;
		a_gegenstand(75).f_gewicht = 2;
		a_gegenstand(76).f_name[2] = "Schwacher Heiltrank";
		a_gegenstand(76).f_name[1] = "Weak Healingpotion";
		a_gegenstand(76).f_name[3] = "Pocion de Curacion pequena";
		a_gegenstand(76).f_art = 4;
		a_gegenstand(76).f_einkauf = 20;
		a_gegenstand(76).f_verkauf = 10;
		a_gegenstand(76).f_gewicht = 2;
		a_gegenstand(77).f_name[2] = "Starker Heiltrank";
		a_gegenstand(77).f_name[1] = "Strong Healingpotion";
		a_gegenstand(77).f_name[3] = "Pocion de Curacion grande";
		a_gegenstand(77).f_art = 4;
		a_gegenstand(77).f_einkauf = 50;
		a_gegenstand(77).f_verkauf = 25;
		a_gegenstand(77).f_gewicht = 2;
		a_gegenstand(78).f_name[2] = "Schwaches Gift";
		a_gegenstand(78).f_name[1] = "Weak Poison";
		a_gegenstand(78).f_name[3] = "Veneno Debil";
		a_gegenstand(78).f_art = 4;
		a_gegenstand(78).f_einkauf = 20;
		a_gegenstand(78).f_verkauf = 10;
		a_gegenstand(78).f_gewicht = 2;
		a_gegenstand(79).f_name[2] = "Starkes Gift";
		a_gegenstand(79).f_name[1] = "Strong Poison";
		a_gegenstand(79).f_name[3] = "Veneno Fuerte";
		a_gegenstand(79).f_art = 4;
		a_gegenstand(79).f_einkauf = 50;
		a_gegenstand(79).f_verkauf = 25;
		a_gegenstand(79).f_gewicht = 2;
		a_gegenstand(80).f_name[2] = "Trank der Helden";
		a_gegenstand(80).f_name[1] = "Potion of Heroes";
		a_gegenstand(80).f_name[3] = "Pocion del Heroe";
		a_gegenstand(80).f_art = 4;
		a_gegenstand(80).f_einkauf = 200;
		a_gegenstand(80).f_verkauf = 100;
		a_gegenstand(80).f_gewicht = 2;
		a_gegenstand(81).f_name[2] = "Trank der G\366tter";
		a_gegenstand(81).f_name[1] = "Potion of the Gods";
		a_gegenstand(81).f_name[3] = "Pocion de los Dioses";
		a_gegenstand(81).f_art = 4;
		a_gegenstand(81).f_einkauf = 700;
		a_gegenstand(81).f_verkauf = 350;
		a_gegenstand(81).f_gewicht = 2;
		a_gegenstand(82).f_name[2] = "St\344rketrank";
		a_gegenstand(82).f_name[1] = "Potion of Strength";
		a_gegenstand(82).f_name[3] = "Pocion de la Fuerza";
		a_gegenstand(82).f_art = 4;
		a_gegenstand(82).f_einkauf = 50;
		a_gegenstand(82).f_verkauf = 25;
		a_gegenstand(82).f_gewicht = 2;
		a_gegenstand(83).f_name[2] = "Schw\344chetrank";
		a_gegenstand(83).f_name[1] = "Potion of Weakness";
		a_gegenstand(83).f_name[3] = "Pocion de la Debilidad";
		a_gegenstand(83).f_art = 4;
		a_gegenstand(83).f_einkauf = 40;
		a_gegenstand(83).f_verkauf = 20;
		a_gegenstand(83).f_gewicht = 2;
		a_gegenstand(84).f_name[2] = "Paralysetrank";
		a_gegenstand(84).f_name[1] = "Potion of Paralysis";
		a_gegenstand(84).f_name[3] = "Pocion de la Paralisis";
		a_gegenstand(84).f_art = 4;
		a_gegenstand(84).f_einkauf = 40;
		a_gegenstand(84).f_verkauf = 20;
		a_gegenstand(84).f_gewicht = 2;
		a_gegenstand(85).f_name[2] = "Trank des Fliegens";
		a_gegenstand(85).f_name[1] = "Flyingpotion";
		a_gegenstand(85).f_name[3] = "Pocion para Volar";
		a_gegenstand(85).f_art = 4;
		a_gegenstand(85).f_einkauf = 50;
		a_gegenstand(85).f_verkauf = 25;
		a_gegenstand(85).f_gewicht = 2;
		a_gegenstand(86).f_name[2] = "Trank des Schutzes";
		a_gegenstand(86).f_name[1] = "Potion of Protection";
		a_gegenstand(86).f_name[3] = "Pocion de Proteccion";
		a_gegenstand(86).f_art = 4;
		a_gegenstand(86).f_einkauf = 50;
		a_gegenstand(86).f_verkauf = 25;
		a_gegenstand(86).f_gewicht = 2;
		a_gegenstand(87).f_name[2] = "Schwacher Manatrank";
		a_gegenstand(87).f_name[1] = "Weak Manapotion";
		a_gegenstand(87).f_name[3] = "Pocion de Mana pequena";
		a_gegenstand(87).f_art = 4;
		a_gegenstand(87).f_einkauf = 50;
		a_gegenstand(87).f_verkauf = 25;
		a_gegenstand(87).f_gewicht = 2;
		a_gegenstand(88).f_name[2] = "Starker Manatrank";
		a_gegenstand(88).f_name[1] = "Strong Manapotion";
		a_gegenstand(88).f_name[3] = "Pocion de Mana grande";
		a_gegenstand(88).f_art = 4;
		a_gegenstand(88).f_einkauf = 100;
		a_gegenstand(88).f_verkauf = 50;
		a_gegenstand(88).f_gewicht = 2;
		a_gegenstand(89).f_name[2] = "Gegengift";
		a_gegenstand(89).f_name[1] = "Antidote";
		a_gegenstand(89).f_name[3] = "Antidoto";
		a_gegenstand(89).f_art = 4;
		a_gegenstand(89).f_einkauf = 50;
		a_gegenstand(89).f_verkauf = 25;
		a_gegenstand(89).f_gewicht = 2;
		a_gegenstand(90).f_name[2] = "K\344lteschutz";
		a_gegenstand(90).f_name[1] = "Cold Protection";
		a_gegenstand(90).f_name[3] = "Protecion contra Frio";
		a_gegenstand(90).f_art = 4;
		a_gegenstand(90).f_einkauf = 40;
		a_gegenstand(90).f_verkauf = 20;
		a_gegenstand(90).f_gewicht = 2;
		a_gegenstand(91).f_name[2] = "Hitzeschutz";
		a_gegenstand(91).f_name[1] = "Heat Protection";
		a_gegenstand(91).f_name[3] = "Protecion contra Calor";
		a_gegenstand(91).f_art = 4;
		a_gegenstand(91).f_einkauf = 40;
		a_gegenstand(91).f_verkauf = 20;
		a_gegenstand(91).f_gewicht = 2;
		a_gegenstand(92).f_name[2] = "Magieleere";
		a_gegenstand(92).f_name[1] = "Mana Void";
		a_gegenstand(92).f_name[3] = "Perder Mana";
		a_gegenstand(92).f_art = 4;
		a_gegenstand(92).f_einkauf = 20;
		a_gegenstand(92).f_verkauf = 10;
		a_gegenstand(92).f_gewicht = 2;
		a_gegenstand(93).f_name[2] = "Unsichtbarkeit";
		a_gegenstand(93).f_name[1] = "Invisibility";
		a_gegenstand(93).f_name[3] = "Invisibilidad";
		a_gegenstand(93).f_art = 4;
		a_gegenstand(93).f_einkauf = 40;
		a_gegenstand(93).f_verkauf = 20;
		a_gegenstand(93).f_gewicht = 2;
		a_gegenstand(94).f_name[2] = "Macht";
		a_gegenstand(94).f_name[1] = "Might";
		a_gegenstand(94).f_name[3] = "Poder";
		a_gegenstand(94).f_art = 4;
		a_gegenstand(94).f_einkauf = 50;
		a_gegenstand(94).f_verkauf = 25;
		a_gegenstand(94).f_gewicht = 2;
		a_gegenstand(95).f_name[2] = "Fallen sp\374hren";
		a_gegenstand(95).f_name[1] = "Sense Traps";
		a_gegenstand(95).f_name[3] = "Sentir Trampas";
		a_gegenstand(95).f_art = 4;
		a_gegenstand(95).f_einkauf = 40;
		a_gegenstand(95).f_verkauf = 20;
		a_gegenstand(95).f_gewicht = 2;
		a_gegenstand(96).f_name[2] = "Winteratem";
		a_gegenstand(96).f_name[1] = "Breath of Winter";
		a_gegenstand(96).f_name[3] = "Aliento invernal";
		a_gegenstand(96).f_art = 4;
		a_gegenstand(96).f_einkauf = 40;
		a_gegenstand(96).f_verkauf = 20;
		a_gegenstand(96).f_gewicht = 2;
		a_gegenstand(97).f_name[2] = "Flammenaura";
		a_gegenstand(97).f_name[1] = "Aura of Fire";
		a_gegenstand(97).f_name[3] = "Aura de fuego";
		a_gegenstand(97).f_art = 4;
		a_gegenstand(97).f_einkauf = 40;
		a_gegenstand(97).f_verkauf = 20;
		a_gegenstand(97).f_gewicht = 2;
		a_gegenstand(98).f_name[2] = "Fledermausgestalt";
		a_gegenstand(98).f_name[1] = "Bat Shape";
		a_gegenstand(98).f_name[3] = "Cuerpo de Murcielago";
		a_gegenstand(98).f_art = 4;
		a_gegenstand(98).f_einkauf = 20;
		a_gegenstand(98).f_verkauf = 10;
		a_gegenstand(98).f_gewicht = 2;
		a_gegenstand(99).f_name[2] = "Wolfsgestalt";
		a_gegenstand(99).f_name[1] = "Wolf Shape";
		a_gegenstand(99).f_name[3] = "Cuerpo de lobo";
		a_gegenstand(99).f_art = 4;
		a_gegenstand(99).f_einkauf = 60;
		a_gegenstand(99).f_verkauf = 30;
		a_gegenstand(99).f_gewicht = 2;
		a_gegenstand(100).f_name[2] = "Vogelgestalt";
		a_gegenstand(100).f_name[1] = "Bird Shape";
		a_gegenstand(100).f_name[3] = "Cuerpo de pajaro";
		a_gegenstand(100).f_art = 4;
		a_gegenstand(100).f_einkauf = 20;
		a_gegenstand(100).f_verkauf = 10;
		a_gegenstand(100).f_gewicht = 2;
		a_gegenstand(101).f_name[2] = "Katzengestalt";
		a_gegenstand(101).f_name[1] = "Cat Shape";
		a_gegenstand(101).f_name[3] = "Cuerpo de gato";
		a_gegenstand(101).f_art = 4;
		a_gegenstand(101).f_einkauf = 40;
		a_gegenstand(101).f_verkauf = 20;
		a_gegenstand(101).f_gewicht = 2;
		a_gegenstand(102).f_name[2] = "Drachengestalt";
		a_gegenstand(102).f_name[1] = "Dragon Shape";
		a_gegenstand(102).f_name[3] = "Cuerpo de dragon";
		a_gegenstand(102).f_art = 4;
		a_gegenstand(102).f_einkauf = 80;
		a_gegenstand(102).f_verkauf = 40;
		a_gegenstand(102).f_gewicht = 2;
		a_gegenstand(103).f_name[2] = "\334bers Wasser gehen";
		a_gegenstand(103).f_name[1] = "Walk on Water";
		a_gegenstand(103).f_name[3] = "Caminar sobre el agua";
		a_gegenstand(103).f_art = 4;
		a_gegenstand(103).f_einkauf = 35;
		a_gegenstand(103).f_verkauf = 18;
		a_gegenstand(103).f_gewicht = 2;
		a_gegenstand(104).f_name[2] = "Schutz vor Geschossen";
		a_gegenstand(104).f_name[1] = "Ward against Missiles";
		a_gegenstand(104).f_name[3] = "Proteccion contra misiles";
		a_gegenstand(104).f_art = 4;
		a_gegenstand(104).f_einkauf = 35;
		a_gegenstand(104).f_verkauf = 18;
		a_gegenstand(104).f_gewicht = 2;
		a_gegenstand(105).f_name[2] = "Unsichtbares sehen";
		a_gegenstand(105).f_name[1] = "View Invisible";
		a_gegenstand(105).f_name[3] = "Ver lo invisible";
		a_gegenstand(105).f_art = 4;
		a_gegenstand(105).f_einkauf = 20;
		a_gegenstand(105).f_verkauf = 10;
		a_gegenstand(105).f_gewicht = 2;
		a_gegenstand(106).f_name[2] = "Magieschutz";
		a_gegenstand(106).f_name[1] = "Ward against Magic";
		a_gegenstand(106).f_name[3] = "Proteccion magica";
		a_gegenstand(106).f_art = 4;
		a_gegenstand(106).f_einkauf = 50;
		a_gegenstand(106).f_verkauf = 25;
		a_gegenstand(106).f_gewicht = 2;
		a_gegenstand(107).f_name[2] = "Hexensicht";
		a_gegenstand(107).f_name[1] = "Witch Sight";
		a_gegenstand(107).f_name[3] = "Vista de bruja";
		a_gegenstand(107).f_art = 4;
		a_gegenstand(107).f_einkauf = 40;
		a_gegenstand(107).f_verkauf = 20;
		a_gegenstand(107).f_gewicht = 2;
		a_gegenstand(108).f_name[2] = "Unverwundbarkeit";
		a_gegenstand(108).f_name[1] = "Invulnerability";
		a_gegenstand(108).f_name[3] = "Invulnerabilidad";
		a_gegenstand(108).f_art = 4;
		a_gegenstand(108).f_einkauf = 90;
		a_gegenstand(108).f_verkauf = 45;
		a_gegenstand(108).f_gewicht = 2;
		a_gegenstand(109).f_name[2] = "Regeneration";
		a_gegenstand(109).f_name[1] = "Regeneration";
		a_gegenstand(109).f_name[3] = "Regeneracion";
		a_gegenstand(109).f_art = 4;
		a_gegenstand(109).f_einkauf = 30;
		a_gegenstand(109).f_verkauf = 15;
		a_gegenstand(109).f_gewicht = 2;
		a_gegenstand(110).f_name[2] = "Giftschutz";
		a_gegenstand(110).f_name[1] = "Poison Protection";
		a_gegenstand(110).f_name[3] = "Protecion veneno";
		a_gegenstand(110).f_art = 4;
		a_gegenstand(110).f_einkauf = 30;
		a_gegenstand(110).f_verkauf = 15;
		a_gegenstand(110).f_gewicht = 2;
		a_gegenstand(111).f_name[2] = "Selbsthypnose";
		a_gegenstand(111).f_name[1] = "Selfhypnosis";
		a_gegenstand(111).f_name[3] = "Hypnotizar uno mismo";
		a_gegenstand(111).f_art = 4;
		a_gegenstand(111).f_einkauf = 20;
		a_gegenstand(111).f_verkauf = 10;
		a_gegenstand(111).f_gewicht = 2;
		a_gegenstand(112).f_name[2] = "Lebensbund";
		a_gegenstand(112).f_name[1] = "Lifebond";
		a_gegenstand(112).f_name[3] = "Bondo de vida";
		a_gegenstand(112).f_art = 4;
		a_gegenstand(112).f_einkauf = 25;
		a_gegenstand(112).f_verkauf = 12;
		a_gegenstand(112).f_gewicht = 2;
		a_gegenstand(65).f_name[2] = "Wirkungslos";
		a_gegenstand(65).f_name[1] = "Useless";
		a_gegenstand(65).f_name[3] = "Sin utilidad";
		a_gegenstand(65).f_art = 17;
		a_gegenstand(65).f_einkauf = 2;
		a_gegenstand(65).f_verkauf = 0;
		a_gegenstand(65).f_gewicht = 1;
		a_gegenstand(66).f_name[2] = "Schwacher Heilpilz";
		a_gegenstand(66).f_name[1] = "Weak Healingmushroom";
		a_gegenstand(66).f_name[3] = "Hongo de Curacion pequeno";
		a_gegenstand(66).f_art = 17;
		a_gegenstand(66).f_einkauf = 4;
		a_gegenstand(66).f_verkauf = 2;
		a_gegenstand(66).f_gewicht = 1;
		a_gegenstand(67).f_name[2] = "Starker Heilpilz";
		a_gegenstand(67).f_name[1] = "Strong Healingmushroom";
		a_gegenstand(67).f_name[3] = "Hongo de Curacion grande";
		a_gegenstand(67).f_art = 17;
		a_gegenstand(67).f_einkauf = 8;
		a_gegenstand(67).f_verkauf = 4;
		a_gegenstand(67).f_gewicht = 1;
		a_gegenstand(68).f_name[2] = "Schwach Giftig";
		a_gegenstand(68).f_name[1] = "Weak Poisoning";
		a_gegenstand(68).f_name[3] = "Poco Venenoso";
		a_gegenstand(68).f_art = 17;
		a_gegenstand(68).f_einkauf = 2;
		a_gegenstand(68).f_verkauf = 0;
		a_gegenstand(68).f_gewicht = 1;
		a_gegenstand(69).f_name[2] = "Stark Giftig";
		a_gegenstand(69).f_name[1] = "Strong Poisoning";
		a_gegenstand(69).f_name[3] = "Muy Venenoso";
		a_gegenstand(69).f_art = 17;
		a_gegenstand(69).f_einkauf = 4;
		a_gegenstand(69).f_verkauf = 0;
		a_gegenstand(69).f_gewicht = 1;
		a_gegenstand(70).f_name[2] = "St\344rkepilz";
		a_gegenstand(70).f_name[1] = "Mushroom of Strength";
		a_gegenstand(70).f_name[3] = "Hongo de Fuerza";
		a_gegenstand(70).f_art = 17;
		a_gegenstand(70).f_einkauf = 2;
		a_gegenstand(70).f_verkauf = 0;
		a_gegenstand(70).f_gewicht = 1;
		a_gegenstand(71).f_name[2] = "Schw\344chepilz";
		a_gegenstand(71).f_name[1] = "Mushroom of Strength";
		a_gegenstand(71).f_name[3] = "Hongo de Fuerza";
		a_gegenstand(71).f_art = 17;
		a_gegenstand(71).f_einkauf = 2;
		a_gegenstand(71).f_verkauf = 0;
		a_gegenstand(71).f_gewicht = 1;
		a_gegenstand(72).f_name[2] = "Paralysepilz";
		a_gegenstand(72).f_name[1] = "Paralysing Mushroom";
		a_gegenstand(72).f_name[3] = "Hongo Paralizante";
		a_gegenstand(72).f_art = 17;
		a_gegenstand(72).f_einkauf = 4;
		a_gegenstand(72).f_verkauf = 2;
		a_gegenstand(72).f_gewicht = 1;
		a_gegenstand(73).f_name[2] = "Schwacher Manapilz";
		a_gegenstand(73).f_name[1] = "Weak Manamushroom";
		a_gegenstand(73).f_name[3] = "Hongo de Mana pequeno";
		a_gegenstand(73).f_art = 17;
		a_gegenstand(73).f_einkauf = 2;
		a_gegenstand(73).f_verkauf = 1;
		a_gegenstand(73).f_gewicht = 1;
		a_gegenstand(74).f_name[2] = "Starker Manapilz";
		a_gegenstand(74).f_name[1] = "Strong Manamushroom";
		a_gegenstand(74).f_name[3] = "Hongo de Mana grande";
		a_gegenstand(74).f_art = 17;
		a_gegenstand(74).f_einkauf = 6;
		a_gegenstand(74).f_verkauf = 3;
		a_gegenstand(74).f_gewicht = 1;
		a_gegenstand(145).f_name[2] = "G\374rtel der Riesenst\344rke";
		a_gegenstand(145).f_name[1] = "Belt of Giant Srength";
		a_gegenstand(145).f_name[3] = "Cinturon de la Fuerza";
		a_gegenstand(145).f_info[2] = " St\344rke";
		a_gegenstand(145).f_info[1] = " Strength";
		a_gegenstand(145).f_info[3] = " Fuerza";
		a_gegenstand(145).f_art = 19;
		a_gegenstand(145).f_qualitaet = 1;
		a_gegenstand(145).f_einkauf = 200;
		a_gegenstand(145).f_verkauf = 100;
		a_gegenstand(145).f_gewicht = 3;
		a_gegenstand(51).f_name[2] = "Helm des gr\374nen Ritters";
		a_gegenstand(51).f_name[1] = "Helmet of the green Knight";
		a_gegenstand(51).f_name[3] = "Casco del Caballero Verde";
		a_gegenstand(51).f_info[2] = "+7 Lebenspunkte";
		a_gegenstand(51).f_info[1] = "+7 To Lifepoints";
		a_gegenstand(51).f_info[3] = "+7 Puntos de Vida";
		a_gegenstand(51).f_art = 6;
		a_gegenstand(51).f_einkauf = 300;
		a_gegenstand(51).f_verkauf = 150;
		a_gegenstand(51).f_gewicht = 7;
		a_gegenstand(51).f_attri1 = 0;
		a_gegenstand(51).f_attri2 = 0;
		a_gegenstand(51).f_attri3 = 8;
		a_gegenstand(255).f_name[2] = "Ring der Sidhe";
		a_gegenstand(255).f_name[1] = "Ring of the Sidhe";
		a_gegenstand(255).f_name[3] = "Anillo del Sidhe";
		a_gegenstand(255).f_info[2] = " Zauberkraft";
		a_gegenstand(255).f_info[1] = " Spellpower";
		a_gegenstand(255).f_info[3] = " Poder de Hechizos";
		a_gegenstand(255).f_art = 18;
		a_gegenstand(255).f_qualitaet = 1;
		a_gegenstand(255).f_einkauf = 200;
		a_gegenstand(255).f_verkauf = 100;
		a_gegenstand(255).f_gewicht = 1;
		a_gegenstand(135).f_name[2] = "Amulett der Geister";
		a_gegenstand(135).f_name[1] = "Amulett of the Ghosts";
		a_gegenstand(135).f_name[3] = "Medallon de las Fantasmas";
		a_gegenstand(135).f_info[2] = "Unsichtbares sehen";
		a_gegenstand(135).f_info[1] = "See Invisible";
		a_gegenstand(135).f_info[3] = "Ver lo invisible";
		a_gegenstand(135).f_art = 20;
		a_gegenstand(135).f_einkauf = 150;
		a_gegenstand(135).f_verkauf = 75;
		a_gegenstand(135).f_gewicht = 2;
		a_gegenstand(136).f_name[2] = "Amulett der Hexenk\366nigin";
		a_gegenstand(136).f_name[1] = "Amulett of the Witchqueen";
		a_gegenstand(136).f_name[3] = "Medallon de la Bruja Maestra";
		a_gegenstand(136).f_info[2] = "Schutz gegen Blitze";
		a_gegenstand(136).f_info[1] = "Protection: Lightning";
		a_gegenstand(136).f_info[3] = "Protecion de Rayos";
		a_gegenstand(136).f_art = 20;
		a_gegenstand(136).f_einkauf = 200;
		a_gegenstand(136).f_verkauf = 100;
		a_gegenstand(136).f_gewicht = 2;
		a_gegenstand(137).f_name[2] = "Amulett des Bergk\366nigs";
		a_gegenstand(137).f_name[1] = "Amulett of the Mountainking";
		a_gegenstand(137).f_name[3] = "Medallon del rey de la montana";
		a_gegenstand(137).f_info[2] = "Schutz gegen Versteinern";
		a_gegenstand(137).f_info[1] = "Protection: Turn to Stone";
		a_gegenstand(137).f_info[3] = "Protecion de convertir a piedra";
		a_gegenstand(137).f_art = 20;
		a_gegenstand(137).f_einkauf = 300;
		a_gegenstand(137).f_verkauf = 150;
		a_gegenstand(137).f_gewicht = 2;
		a_gegenstand(138).f_name[2] = "Drachenaugen Amulett";
		a_gegenstand(138).f_name[1] = "Dragons Eye Medallion";
		a_gegenstand(138).f_name[3] = "Medallon del Dragon";
		a_gegenstand(138).f_info[2] = " Zauberkraft";
		a_gegenstand(138).f_info[1] = " Spellpower";
		a_gegenstand(138).f_info[3] = " Poder de Hechizos";
		a_gegenstand(138).f_art = 20;
		a_gegenstand(138).f_qualitaet = 1;
		a_gegenstand(138).f_einkauf = 200;
		a_gegenstand(138).f_verkauf = 100;
		a_gegenstand(138).f_gewicht = 2;
		a_gegenstand(139).f_name[2] = "Amulett des ewigen Winters";
		a_gegenstand(139).f_name[1] = "Amulett of eternal cold";
		a_gegenstand(139).f_name[3] = "Medallon del invierno";
		a_gegenstand(139).f_info[2] = "K\344lteaura";
		a_gegenstand(139).f_info[1] = "Aura of Cold";
		a_gegenstand(139).f_info[3] = "Aura de Frio";
		a_gegenstand(139).f_art = 20;
		a_gegenstand(139).f_einkauf = 400;
		a_gegenstand(139).f_verkauf = 200;
		a_gegenstand(139).f_gewicht = 2;
		a_gegenstand(140).f_name[2] = "Amulett des D\344monenf\374rsten";
		a_gegenstand(140).f_name[1] = "Amulett of the Demonlord";
		a_gegenstand(140).f_name[3] = "Medallon del Rey Demonio";
		a_gegenstand(140).f_info[2] = "Hitzeaura";
		a_gegenstand(140).f_info[1] = "Aura of Heat";
		a_gegenstand(140).f_info[3] = "Aura de Calor";
		a_gegenstand(140).f_art = 20;
		a_gegenstand(140).f_einkauf = 400;
		a_gegenstand(140).f_verkauf = 200;
		a_gegenstand(140).f_gewicht = 2;
		a_gegenstand(261).f_name[2] = "Amulett der Zwerge";
		a_gegenstand(261).f_name[1] = "Amulett of the Dwarves";
		a_gegenstand(261).f_name[3] = "Medallon de los enanos";
		a_gegenstand(261).f_info[2] = "Findet Fallen";
		a_gegenstand(261).f_info[1] = "Finds Traps";
		a_gegenstand(261).f_info[3] = "Encuantra Trampas";
		a_gegenstand(261).f_art = 20;
		a_gegenstand(261).f_einkauf = 250;
		a_gegenstand(261).f_verkauf = 125;
		a_gegenstand(261).f_gewicht = 2;
		a_gegenstand(262).f_name[2] = "Amulett des Gl\374cks";
		a_gegenstand(262).f_name[1] = "Amulett of Luck";
		a_gegenstand(262).f_name[3] = "Medallon de la suerte";
		a_gegenstand(262).f_info[2] = " Gl\374ck";
		a_gegenstand(262).f_info[1] = " Luck";
		a_gegenstand(262).f_info[3] = " Suerte";
		a_gegenstand(262).f_art = 20;
		a_gegenstand(262).f_qualitaet = 1;
		a_gegenstand(262).f_einkauf = 200;
		a_gegenstand(262).f_verkauf = 100;
		a_gegenstand(262).f_gewicht = 2;
		a_gegenstand(263).f_name[2] = "Amulett der Dualit\344t";
		a_gegenstand(263).f_name[1] = "Amulett of Duality";
		a_gegenstand(263).f_name[3] = "Medallon de la Distraccion";
		a_gegenstand(263).f_info[2] = "Lenkt Gegner ab";
		a_gegenstand(263).f_info[1] = "Distracts Enemys";
		a_gegenstand(263).f_info[3] = "Distrae Enemigos";
		a_gegenstand(263).f_art = 20;
		a_gegenstand(263).f_einkauf = 500;
		a_gegenstand(263).f_verkauf = 250;
		a_gegenstand(263).f_gewicht = 2;
		a_gegenstand(264).f_name[2] = "Amulett der Feen";
		a_gegenstand(264).f_name[1] = "Amulett of the Faeries";
		a_gegenstand(264).f_name[3] = "Medallon de las hadas";
		a_gegenstand(264).f_info[2] = "Unsichtbarkeit";
		a_gegenstand(264).f_info[1] = "Invisibility";
		a_gegenstand(264).f_info[3] = "Invisibilidad";
		a_gegenstand(264).f_art = 20;
		a_gegenstand(264).f_einkauf = 700;
		a_gegenstand(264).f_verkauf = 350;
		a_gegenstand(264).f_gewicht = 2;
		a_gegenstand(265).f_name[2] = "Amulett der vier Winde";
		a_gegenstand(265).f_name[1] = "Amulett of the four winds";
		a_gegenstand(265).f_name[3] = "Medallon de los cuatro vientos";
		a_gegenstand(265).f_info[2] = " Geschwindigkeit";
		a_gegenstand(265).f_info[1] = " Speed";
		a_gegenstand(265).f_info[3] = " Velocidad";
		a_gegenstand(265).f_art = 20;
		a_gegenstand(265).f_qualitaet = 1;
		a_gegenstand(265).f_einkauf = 200;
		a_gegenstand(265).f_verkauf = 100;
		a_gegenstand(265).f_gewicht = 2;
		a_gegenstand(266).f_name[2] = "Amulett der Troglodyten";
		a_gegenstand(266).f_name[1] = "Amulett of the Troglodytes";
		a_gegenstand(266).f_name[3] = "Medallon de los Troglodytes";
		a_gegenstand(266).f_info[2] = "\334bers Wasser gehen";
		a_gegenstand(266).f_info[1] = "Walk on Water";
		a_gegenstand(266).f_info[3] = "Camina sobre el aqua";
		a_gegenstand(266).f_art = 20;
		a_gegenstand(266).f_einkauf = 200;
		a_gegenstand(266).f_verkauf = 100;
		a_gegenstand(266).f_gewicht = 2;
		a_gegenstand(148).f_name[2] = "Maske des vergessenen K\366nigs";
		a_gegenstand(148).f_name[1] = "Mask of the forgotten King";
		a_gegenstand(148).f_name[3] = "Mascara del Rey olvidado";
		a_gegenstand(148).f_info[2] = " Wahrnehmung";
		a_gegenstand(148).f_info[1] = " Perception";
		a_gegenstand(148).f_info[3] = " Percepcion";
		a_gegenstand(148).f_art = 21;
		a_gegenstand(148).f_qualitaet = 1;
		a_gegenstand(148).f_einkauf = 200;
		a_gegenstand(148).f_verkauf = 100;
		a_gegenstand(148).f_gewicht = 3;
		a_gegenstand(148).f_attri1 = 0;
		a_gegenstand(148).f_attri2 = 0;
		a_gegenstand(148).f_attri3 = 1;
		a_gegenstand(187).f_name[2] = "Elfen Bogen";
		a_gegenstand(187).f_name[1] = "Bow of the Elves";
		a_gegenstand(187).f_name[3] = "Arco de los Elfos";
		a_gegenstand(187).f_art = 10;
		a_gegenstand(187).f_einkauf = 45;
		a_gegenstand(187).f_verkauf = 25;
		a_gegenstand(187).f_gewicht = 15;
		a_gegenstand(187).f_magisch = 1;
		a_gegenstand(187).f_attri1 = 2;
		a_gegenstand(187).f_attri2 = 5;
		a_gegenstand(187).f_attri3 = 10;
		a_gegenstand(187).f_attri4 = 2;
		a_gegenstand(157).f_name[2] = "Magischer Bogen";
		a_gegenstand(157).f_name[1] = "Magic Bow";
		a_gegenstand(157).f_name[3] = "Arco magico";
		a_gegenstand(157).f_art = 10;
		a_gegenstand(157).f_einkauf = 45;
		a_gegenstand(157).f_verkauf = 0;
		a_gegenstand(157).f_gewicht = 12;
		a_gegenstand(157).f_magisch = 1;
		a_gegenstand(157).f_attri1 = 2;
		a_gegenstand(157).f_attri2 = 5;
		a_gegenstand(157).f_attri3 = 10;
		a_gegenstand(157).f_attri4 = 2;
		a_gegenstand(201).f_name[2] = "G\374rtel der Mitternacht";
		a_gegenstand(201).f_name[1] = "Belt of Midnight";
		a_gegenstand(201).f_name[3] = "Cinturon de la Medianoche";
		a_gegenstand(201).f_info[2] = "+10% Schleichen";
		a_gegenstand(201).f_info[1] = "+10% Stealth";
		a_gegenstand(201).f_info[3] = "+10% Furtivo";
		a_gegenstand(201).f_art = 19;
		a_gegenstand(201).f_einkauf = 50;
		a_gegenstand(201).f_verkauf = 25;
		a_gegenstand(201).f_gewicht = 3;
		a_gegenstand(201).f_attri1 = 0;
		a_gegenstand(201).f_attri2 = 0;
		a_gegenstand(201).f_attri3 = 0;
		a_gegenstand(256).f_name[2] = "Ring der verlorenen Tr\344ume";
		a_gegenstand(256).f_name[1] = "Ring of lost Dreams";
		a_gegenstand(256).f_name[3] = "Anillo de los Suenos perdidos";
		a_gegenstand(256).f_info[2] = " Wahrnehmung";
		a_gegenstand(256).f_info[1] = " Perception";
		a_gegenstand(256).f_info[3] = " Percepcion";
		a_gegenstand(256).f_art = 18;
		a_gegenstand(256).f_qualitaet = 1;
		a_gegenstand(256).f_einkauf = 200;
		a_gegenstand(256).f_verkauf = 100;
		a_gegenstand(256).f_gewicht = 1;
		a_gegenstand(257).f_name[2] = "Ring des Blutdurstes";
		a_gegenstand(257).f_name[1] = "Ring of Bloodlust";
		a_gegenstand(257).f_name[3] = "Anillo del Dano";
		a_gegenstand(257).f_info[2] = " Schaden";
		a_gegenstand(257).f_info[1] = " Damage";
		a_gegenstand(257).f_info[3] = " Dano";
		a_gegenstand(257).f_art = 18;
		a_gegenstand(257).f_qualitaet = 1;
		a_gegenstand(257).f_einkauf = 150;
		a_gegenstand(257).f_verkauf = 75;
		a_gegenstand(257).f_gewicht = 1;
		a_gegenstand(231).f_name[2] = "Silberner Schl\374ssel";
		a_gegenstand(231).f_name[1] = "Silver Key";
		a_gegenstand(231).f_name[3] = "Llave de Plata";
		a_gegenstand(231).f_art = 15;
		a_gegenstand(231).f_einkauf = 10;
		a_gegenstand(231).f_verkauf = 5;
		a_gegenstand(231).f_gewicht = 1;
		a_gegenstand(219).f_name[2] = "Goldener Schl\374ssel";
		a_gegenstand(219).f_name[1] = "Golden Key";
		a_gegenstand(219).f_name[3] = "Llave de Oro";
		a_gegenstand(219).f_art = 15;
		a_gegenstand(219).f_einkauf = 30;
		a_gegenstand(219).f_verkauf = 15;
		a_gegenstand(219).f_gewicht = 1;
		a_gegenstand(222).f_name[2] = "Umhang der Sidhe";
		a_gegenstand(222).f_name[1] = "Robe of the Sidhe";
		a_gegenstand(222).f_name[3] = "Capa del Sidhe";
		a_gegenstand(222).f_info[2] = " Zauberkraft";
		a_gegenstand(222).f_info[1] = " Spellpower";
		a_gegenstand(222).f_info[3] = " Poder de Hechizos";
		a_gegenstand(222).f_art = 9;
		a_gegenstand(222).f_qualitaet = 1;
		a_gegenstand(222).f_einkauf = 200;
		a_gegenstand(222).f_verkauf = 100;
		a_gegenstand(222).f_gewicht = 5;
		a_gegenstand(222).f_attri1 = 0;
		a_gegenstand(222).f_attri2 = 0;
		a_gegenstand(222).f_attri3 = 1;
		a_gegenstand(223).f_name[2] = "Umhang des wahnsinnigen Magiers";
		a_gegenstand(223).f_name[1] = "Robe of the mad Magician";
		a_gegenstand(223).f_name[3] = "Capa del mago loco";
		a_gegenstand(223).f_info[2] = "+4 Lebenspunkte";
		a_gegenstand(223).f_info[1] = "+4 Lifepoints";
		a_gegenstand(223).f_info[3] = "+4 Puntos de Vida";
		a_gegenstand(223).f_art = 9;
		a_gegenstand(223).f_einkauf = 300;
		a_gegenstand(223).f_verkauf = 150;
		a_gegenstand(223).f_gewicht = 5;
		a_gegenstand(223).f_attri1 = 0;
		a_gegenstand(223).f_attri2 = 0;
		a_gegenstand(223).f_attri3 = 1;
		a_gegenstand(269).f_name[2] = "Spitzhacke";
		a_gegenstand(269).f_name[1] = "Pick Axe";
		a_gegenstand(269).f_name[3] = "Piqueta";
		a_gegenstand(269).f_info[2] = "Entfernt Steine";
		a_gegenstand(269).f_info[1] = "Removes Bowlders";
		a_gegenstand(269).f_info[3] = "Remueve piedras";
		a_gegenstand(269).f_art = 15;
		a_gegenstand(269).f_klasse = 2;
		a_gegenstand(269).f_einkauf = 30;
		a_gegenstand(269).f_verkauf = 15;
		a_gegenstand(269).f_gewicht = 25;
		a_gegenstand(270).f_name[2] = "Schaufel";
		a_gegenstand(270).f_name[1] = "Shovel";
		a_gegenstand(270).f_name[3] = "Pala";
		a_gegenstand(270).f_info[2] = "Findet vergrabene Sch\344tze";
		a_gegenstand(270).f_info[1] = "Finds hidden Treasures";
		a_gegenstand(270).f_info[3] = "Encuentra Tesoros enterrados";
		a_gegenstand(270).f_art = 15;
		a_gegenstand(270).f_einkauf = 30;
		a_gegenstand(270).f_verkauf = 15;
		a_gegenstand(270).f_gewicht = 20;
		a_gegenstand(149).f_name[2] = "Ring der Naiaden";
		a_gegenstand(149).f_name[1] = "Ring of the Naiads";
		a_gegenstand(149).f_name[3] = "Anillo de las Niades";
		a_gegenstand(149).f_info[2] = "+4 Mana";
		a_gegenstand(149).f_info[1] = "+4 Mana";
		a_gegenstand(149).f_info[3] = "+4 Mana";
		a_gegenstand(149).f_art = 18;
		a_gegenstand(149).f_einkauf = 220;
		a_gegenstand(149).f_verkauf = 110;
		a_gegenstand(149).f_gewicht = 1;
		a_gegenstand(253).f_name[2] = "Ring der Ogerst\344rke";
		a_gegenstand(253).f_name[1] = "Ring of Ogre Strength";
		a_gegenstand(253).f_name[3] = "Anillo de la Fuerza de Ogro";
		a_gegenstand(253).f_info[2] = " St\344rke";
		a_gegenstand(253).f_info[1] = " Strength";
		a_gegenstand(253).f_info[3] = " Fuerza";
		a_gegenstand(253).f_art = 18;
		a_gegenstand(253).f_qualitaet = 1;
		a_gegenstand(253).f_einkauf = 200;
		a_gegenstand(253).f_verkauf = 100;
		a_gegenstand(253).f_gewicht = 1;
		a_gegenstand(153).f_name[2] = "Umhang der Schatten";
		a_gegenstand(153).f_name[1] = "Robe of Shadows";
		a_gegenstand(153).f_name[3] = "Capa de las Sombras";
		a_gegenstand(153).f_info[2] = "+2 Schleichen";
		a_gegenstand(153).f_info[1] = "+2 Sneaking";
		a_gegenstand(153).f_info[3] = "+2 Escaparse";
		a_gegenstand(153).f_art = 9;
		a_gegenstand(153).f_einkauf = 200;
		a_gegenstand(153).f_verkauf = 100;
		a_gegenstand(153).f_gewicht = 5;
		a_gegenstand(153).f_attri1 = 0;
		a_gegenstand(153).f_attri2 = 0;
		a_gegenstand(153).f_attri3 = 1;
		a_gegenstand(228).f_name[2] = "Umhang aus Drachenschuppen";
		a_gegenstand(228).f_name[1] = "Robe of Dragonscales";
		a_gegenstand(228).f_name[3] = "Capa de piel de dragon";
		a_gegenstand(228).f_info[2] = "+2 St\344rke";
		a_gegenstand(228).f_info[1] = "+2 Strength";
		a_gegenstand(228).f_info[3] = "+2 Fuerza";
		a_gegenstand(228).f_art = 9;
		a_gegenstand(228).f_qualitaet = 1;
		a_gegenstand(228).f_einkauf = 200;
		a_gegenstand(228).f_verkauf = 100;
		a_gegenstand(228).f_gewicht = 5;
		a_gegenstand(228).f_attri1 = 0;
		a_gegenstand(228).f_attri2 = 0;
		a_gegenstand(228).f_attri3 = 2;
		a_gegenstand(229).f_name[2] = "Krone der K\366nigin der Sidhe";
		a_gegenstand(229).f_name[1] = "Crown of the Sidhe Queen";
		a_gegenstand(229).f_name[3] = "Corona de la Reina de los Sidhe";
		a_gegenstand(229).f_info[2] = "+2 Zauberkraft";
		a_gegenstand(229).f_info[1] = "+2 Spellpower";
		a_gegenstand(229).f_info[3] = "+2 Poder de Hechizos";
		a_gegenstand(229).f_art = 6;
		a_gegenstand(229).f_qualitaet = 1;
		a_gegenstand(229).f_einkauf = 200;
		a_gegenstand(229).f_verkauf = 100;
		a_gegenstand(229).f_gewicht = 3;
		a_gegenstand(229).f_attri1 = 0;
		a_gegenstand(229).f_attri2 = 0;
		a_gegenstand(229).f_attri3 = 1;
		a_gegenstand(230).f_name[2] = "Krone der Drachen";
		a_gegenstand(230).f_name[1] = "Crown of the Dragons";
		a_gegenstand(230).f_name[3] = "Corona de los Dragones";
		a_gegenstand(230).f_info[2] = "+2 St\344rke";
		a_gegenstand(230).f_info[1] = "+2 Strength";
		a_gegenstand(230).f_info[3] = "+2 Fuerza";
		a_gegenstand(230).f_art = 6;
		a_gegenstand(230).f_qualitaet = 1;
		a_gegenstand(230).f_einkauf = 200;
		a_gegenstand(230).f_verkauf = 100;
		a_gegenstand(230).f_gewicht = 3;
		a_gegenstand(230).f_attri1 = 0;
		a_gegenstand(230).f_attri2 = 0;
		a_gegenstand(230).f_attri3 = 1;
		a_gegenstand(237).f_name[2] = "Schwert des Lichts";
		a_gegenstand(237).f_name[1] = "Sword of Light";
		a_gegenstand(237).f_name[3] = "Espada de la Luz";
		a_gegenstand(237).f_art = 1;
		a_gegenstand(237).f_klasse = 1;
		a_gegenstand(237).f_einkauf = 1000;
		a_gegenstand(237).f_verkauf = 500;
		a_gegenstand(237).f_gewicht = 25;
		a_gegenstand(237).f_magisch = 1;
		a_gegenstand(237).f_attri1 = 2;
		a_gegenstand(237).f_attri2 = 4;
		a_gegenstand(237).f_attri3 = 10;
		a_gegenstand(237).f_attri4 = 1;
		a_gegenstand(224).f_name[2] = "Umhang der Feen";
		a_gegenstand(224).f_name[1] = "Robe of the Faeries";
		a_gegenstand(224).f_name[3] = "Capa de las Hagas";
		a_gegenstand(224).f_info[2] = "+20% Magieschutz";
		a_gegenstand(224).f_info[1] = "+20% Magical Resistance";
		a_gegenstand(224).f_info[3] = "+20% Resistencia magica";
		a_gegenstand(224).f_art = 9;
		a_gegenstand(224).f_einkauf = 230;
		a_gegenstand(224).f_verkauf = 115;
		a_gegenstand(224).f_gewicht = 5;
		a_gegenstand(224).f_attri1 = 0;
		a_gegenstand(224).f_attri2 = 0;
		a_gegenstand(224).f_attri3 = 1;
		a_gegenstand(225).f_name[2] = "Umhang des ewigen Frosts";
		a_gegenstand(225).f_name[1] = "Robe of eternal Frost";
		a_gegenstand(225).f_name[3] = "Capa de Invierno eterno";
		a_gegenstand(225).f_info[2] = "Erschafft K\344lteaura";
		a_gegenstand(225).f_info[1] = "Creates Aura of Cold";
		a_gegenstand(225).f_info[3] = "Crea Zona de Fria";
		a_gegenstand(225).f_art = 9;
		a_gegenstand(225).f_einkauf = 300;
		a_gegenstand(225).f_verkauf = 150;
		a_gegenstand(225).f_gewicht = 5;
		a_gegenstand(225).f_attri1 = 0;
		a_gegenstand(225).f_attri2 = 0;
		a_gegenstand(225).f_attri3 = 1;
		a_gegenstand(247).f_name[2] = "Spiegel aus Obsidian";
		a_gegenstand(247).f_name[1] = "Obsidian Mirror";
		a_gegenstand(247).f_name[3] = "Espejo de Obsidiano";
		a_gegenstand(247).f_info[2] = "Zeigt Karte";
		a_gegenstand(247).f_info[1] = "Shows Map";
		a_gegenstand(247).f_info[3] = "Muestra mapa";
		a_gegenstand(247).f_art = 15;
		a_gegenstand(247).f_einkauf = 1500;
		a_gegenstand(247).f_verkauf = 750;
		a_gegenstand(247).f_gewicht = 3;
		a_gegenstand(247).f_attri1 = 15;
		a_gegenstand(244).f_name[2] = "Kristallkugel";
		a_gegenstand(244).f_name[1] = "Crystal Ball";
		a_gegenstand(244).f_name[3] = "Bola de Cristal";
		a_gegenstand(244).f_info[2] = "Zeigt Karte";
		a_gegenstand(244).f_info[1] = "Shows Map";
		a_gegenstand(244).f_info[3] = "Muestra mapa";
		a_gegenstand(244).f_art = 15;
		a_gegenstand(244).f_einkauf = 1200;
		a_gegenstand(244).f_verkauf = 600;
		a_gegenstand(244).f_gewicht = 3;
		a_gegenstand(244).f_attri1 = 10;
		a_gegenstand(241).f_name[2] = "Flaschengeist";
		a_gegenstand(241).f_name[1] = "Ghost in a Bottle";
		a_gegenstand(241).f_name[3] = "Fantasma en Botella";
		a_gegenstand(241).f_art = 15;
		a_gegenstand(241).f_einkauf = 200;
		a_gegenstand(241).f_verkauf = 100;
		a_gegenstand(241).f_gewicht = 2;
		a_gegenstand(292).f_name[2] = "Stahlkugeln";
		a_gegenstand(292).f_name[1] = "Stones of Steel";
		a_gegenstand(292).f_name[3] = "Bolas de Piedra";
		a_gegenstand(292).f_art = 13;
		a_gegenstand(292).f_einkauf = 4;
		a_gegenstand(292).f_verkauf = 2;
		a_gegenstand(292).f_gewicht = 2;
		a_gegenstand(292).f_attri1 = 20;
		a_gegenstand(292).f_attri2 = 1;
		a_gegenstand(292).f_attri3 = 1;
		a_gegenstand(292).f_attri4 = 5;
		a_gegenstand(291).f_name[2] = "Steine";
		a_gegenstand(291).f_name[1] = "Stones";
		a_gegenstand(291).f_name[3] = "Piedras";
		a_gegenstand(291).f_art = 13;
		a_gegenstand(291).f_einkauf = 4;
		a_gegenstand(291).f_verkauf = 2;
		a_gegenstand(291).f_gewicht = 2;
		a_gegenstand(291).f_attri1 = 10;
		a_gegenstand(291).f_attri2 = 0;
		a_gegenstand(291).f_attri3 = 1;
		a_gegenstand(291).f_attri4 = 5;
		a_gegenstand(302).f_name[2] = "Ring der Schatten";
		a_gegenstand(302).f_name[1] = "Ring of Shadows";
		a_gegenstand(302).f_name[3] = "Anillo de las Sombras";
		a_gegenstand(302).f_info[2] = " Schleichen";
		a_gegenstand(302).f_info[1] = " Stealth";
		a_gegenstand(302).f_info[3] = " Escabullirse";
		a_gegenstand(302).f_art = 18;
		a_gegenstand(302).f_qualitaet = 1;
		a_gegenstand(302).f_einkauf = 150;
		a_gegenstand(302).f_verkauf = 75;
		a_gegenstand(302).f_gewicht = 1;
		a_gegenstand(303).f_name[2] = "Ring der Elfen";
		a_gegenstand(303).f_name[1] = "Ring of the Elves";
		a_gegenstand(303).f_name[3] = "Anillo de los Elfos";
		a_gegenstand(303).f_info[2] = " Angriff im Fernkampf";
		a_gegenstand(303).f_info[1] = " Attack Ranged Weapons";
		a_gegenstand(303).f_info[3] = " Ataque con Arcos";
		a_gegenstand(303).f_art = 18;
		a_gegenstand(303).f_qualitaet = 1;
		a_gegenstand(303).f_einkauf = 150;
		a_gegenstand(303).f_verkauf = 75;
		a_gegenstand(303).f_gewicht = 1;
		a_gegenstand(304).f_name[2] = "Ring der Naga";
		a_gegenstand(304).f_name[1] = "Ring of the Naga";
		a_gegenstand(304).f_name[3] = "Anillo del Naga";
		a_gegenstand(304).f_info[2] = " Schaden im Fernkampf";
		a_gegenstand(304).f_info[1] = " Damage in Ranged Combat";
		a_gegenstand(304).f_info[3] = " Dano con Arcos";
		a_gegenstand(304).f_art = 18;
		a_gegenstand(304).f_qualitaet = 1;
		a_gegenstand(304).f_einkauf = 150;
		a_gegenstand(304).f_verkauf = 75;
		a_gegenstand(304).f_gewicht = 1;
		a_gegenstand(305).f_name[2] = "Ring der Feenk\366nigin";
		a_gegenstand(305).f_name[1] = "Ring of the Faery Queen";
		a_gegenstand(305).f_name[3] = "Anillo de la reina de las hadas";
		a_gegenstand(305).f_info[2] = " Wiederstand gegen Magie";
		a_gegenstand(305).f_info[1] = " Resistance to Magic";
		a_gegenstand(305).f_info[3] = " Resistencia contra magia";
		a_gegenstand(305).f_art = 18;
		a_gegenstand(305).f_qualitaet = 1;
		a_gegenstand(305).f_einkauf = 150;
		a_gegenstand(305).f_verkauf = 75;
		a_gegenstand(305).f_gewicht = 1;
		a_gegenstand(306).f_name[2] = "Ring des Gehenna";
		a_gegenstand(306).f_name[1] = "Ring of Gehenna";
		a_gegenstand(306).f_name[3] = "Anillo de Gehenna";
		a_gegenstand(306).f_info[2] = "Flammenaura";
		a_gegenstand(306).f_info[1] = "Aura of Fire";
		a_gegenstand(306).f_info[3] = "Aura de Fuego";
		a_gegenstand(306).f_art = 18;
		a_gegenstand(306).f_einkauf = 400;
		a_gegenstand(306).f_verkauf = 200;
		a_gegenstand(306).f_gewicht = 1;
		a_gegenstand(307).f_name[2] = "Ring der Schneek\366nigin";
		a_gegenstand(307).f_name[1] = "Ring of the Snowqueen";
		a_gegenstand(307).f_name[3] = "Anillo de la Reina de la Nieve";
		a_gegenstand(307).f_info[2] = "K\344lteaura";
		a_gegenstand(307).f_info[1] = "Aura of Cold";
		a_gegenstand(307).f_info[3] = "Aura de Frio";
		a_gegenstand(307).f_art = 18;
		a_gegenstand(307).f_einkauf = 400;
		a_gegenstand(307).f_verkauf = 200;
		a_gegenstand(307).f_gewicht = 1;
		a_gegenstand(155).f_name[2] = "Klinge des letzten Ritters";
		a_gegenstand(155).f_name[1] = "Sword of the last Knight";
		a_gegenstand(155).f_name[3] = "Espada del ultimo Caballero";
		a_gegenstand(155).f_art = 1;
		a_gegenstand(155).f_klasse = 1;
		a_gegenstand(155).f_einkauf = 150;
		a_gegenstand(155).f_verkauf = 75;
		a_gegenstand(155).f_gewicht = 25;
		a_gegenstand(155).f_attri1 = 2;
		a_gegenstand(155).f_attri2 = 5;
		a_gegenstand(155).f_attri3 = 10;
		a_gegenstand(155).f_attri4 = 1;
		a_gegenstand(156).f_name[2] = "Magisches Kettenhemd";
		a_gegenstand(156).f_name[1] = "Magical Chainmail";
		a_gegenstand(156).f_name[3] = "Cota de Malla Magica";
		a_gegenstand(156).f_art = 9;
		a_gegenstand(156).f_einkauf = 400;
		a_gegenstand(156).f_verkauf = 240;
		a_gegenstand(156).f_gewicht = 50;
		a_gegenstand(156).f_attri1 = 2;
		a_gegenstand(156).f_attri2 = 4;
		a_gegenstand(156).f_attri3 = 5;
		a_gegenstand(157).f_name[2] = "ZauberBogen";
		a_gegenstand(157).f_name[1] = "Magical Bow";
		a_gegenstand(157).f_name[3] = "Arco Magico";
		a_gegenstand(157).f_art = 10;
		a_gegenstand(157).f_einkauf = 120;
		a_gegenstand(157).f_verkauf = 60;
		a_gegenstand(157).f_gewicht = 15;
		a_gegenstand(157).f_magisch = 1;
		a_gegenstand(157).f_attri1 = 2;
		a_gegenstand(157).f_attri2 = 5;
		a_gegenstand(157).f_attri3 = 15;
		a_gegenstand(157).f_attri4 = 2;
		a_gegenstand(158).f_name[2] = "Elfen Pfeile";
		a_gegenstand(158).f_name[1] = "Elven Arrows";
		a_gegenstand(158).f_name[3] = "Flechas de los Elfos";
		a_gegenstand(158).f_art = 13;
		a_gegenstand(158).f_einkauf = 10;
		a_gegenstand(158).f_verkauf = 5;
		a_gegenstand(158).f_gewicht = 1;
		a_gegenstand(158).f_magisch = 1;
		a_gegenstand(158).f_attri1 = 20;
		a_gegenstand(158).f_attri2 = 2;
		a_gegenstand(158).f_attri3 = 3;
		a_gegenstand(158).f_attri4 = 15;
		a_gegenstand(160).f_name[2] = "Magische Lederr\374stung";
		a_gegenstand(160).f_name[1] = "Magical Leatherarmor";
		a_gegenstand(160).f_name[3] = "Armadura de Cuero Magica";
		a_gegenstand(160).f_art = 9;
		a_gegenstand(160).f_einkauf = 100;
		a_gegenstand(160).f_verkauf = 50;
		a_gegenstand(160).f_gewicht = 10;
		a_gegenstand(160).f_attri1 = 2;
		a_gegenstand(160).f_attri2 = 2;
		a_gegenstand(160).f_attri3 = 3;
		a_gegenstand(41).f_name[2] = "Degen";
		a_gegenstand(41).f_name[1] = "Rapier";
		a_gegenstand(41).f_name[3] = "Florette";
		a_gegenstand(41).f_art = 1;
		a_gegenstand(41).f_klasse = 7;
		a_gegenstand(41).f_einkauf = 15;
		a_gegenstand(41).f_verkauf = 8;
		a_gegenstand(41).f_gewicht = 10;
		a_gegenstand(41).f_attri1 = 1;
		a_gegenstand(41).f_attri2 = 2;
		a_gegenstand(41).f_attri3 = 6;
		a_gegenstand(41).f_attri4 = 1;
		a_gegenstand(161).f_name[2] = "Magischer Degen";
		a_gegenstand(161).f_name[1] = "Magical Rapier";
		a_gegenstand(161).f_name[3] = "Florette Magico";
		a_gegenstand(161).f_art = 1;
		a_gegenstand(161).f_klasse = 7;
		a_gegenstand(161).f_einkauf = 45;
		a_gegenstand(161).f_verkauf = 26;
		a_gegenstand(161).f_gewicht = 10;
		a_gegenstand(161).f_magisch = 1;
		a_gegenstand(161).f_attri1 = 2;
		a_gegenstand(161).f_attri2 = 4;
		a_gegenstand(161).f_attri3 = 10;
		a_gegenstand(161).f_attri4 = 1;
		a_gegenstand(53).f_name[2] = "Nahrung";
		a_gegenstand(53).f_name[1] = "Food";
		a_gegenstand(53).f_name[3] = "Comida";
		a_gegenstand(53).f_art = 3;
		a_gegenstand(53).f_einkauf = 15;
		a_gegenstand(53).f_verkauf = 8;
		a_gegenstand(53).f_gewicht = 3;
		a_gegenstand(53).f_attri1 = 150;
		a_gegenstand(52).f_name[2] = "Fellkappe";
		a_gegenstand(52).f_name[1] = "Leatherhat";
		a_gegenstand(52).f_name[3] = "Gorro de Piel";
		a_gegenstand(52).f_art = 6;
		a_gegenstand(52).f_einkauf = 4;
		a_gegenstand(52).f_verkauf = 2;
		a_gegenstand(52).f_gewicht = 3;
		a_gegenstand(52).f_attri1 = 0;
		a_gegenstand(52).f_attri2 = 0;
		a_gegenstand(52).f_attri3 = 1;
		a_gegenstand(164).f_name[2] = "Drachent\366ter (+7 Ang/Sch)";
		a_gegenstand(164).f_name[1] = "Dragonslayer (+7 Att/Dam)";
		a_gegenstand(164).f_name[3] = "Mata Dragones (+7 Ata/Dan)";
		a_gegenstand(164).f_art = 1;
		a_gegenstand(164).f_klasse = 1;
		a_gegenstand(164).f_einkauf = 150;
		a_gegenstand(164).f_verkauf = 75;
		a_gegenstand(164).f_gewicht = 25;
		a_gegenstand(164).f_magisch = 1;
		a_gegenstand(164).f_attri1 = 1;
		a_gegenstand(164).f_attri2 = 4;
		a_gegenstand(164).f_attri3 = 8;
		a_gegenstand(164).f_attri4 = 1;
		a_gegenstand(162).f_name[2] = "D\344monent\366ter (+7 Ang/Sch)";
		a_gegenstand(162).f_name[1] = "Demonslayer (+7 Att/Dam)";
		a_gegenstand(162).f_name[3] = "Mata Demonios (+7 Ata/Dan)";
		a_gegenstand(162).f_art = 1;
		a_gegenstand(162).f_klasse = 1;
		a_gegenstand(162).f_einkauf = 150;
		a_gegenstand(162).f_verkauf = 75;
		a_gegenstand(162).f_gewicht = 25;
		a_gegenstand(162).f_magisch = 1;
		a_gegenstand(162).f_attri1 = 1;
		a_gegenstand(162).f_attri2 = 4;
		a_gegenstand(162).f_attri3 = 8;
		a_gegenstand(162).f_attri4 = 1;
		a_gegenstand(326).f_name[2] = "Kette des ewigen Wassers";
		a_gegenstand(326).f_name[1] = "Necklace of hydration";
		a_gegenstand(326).f_name[3] = "Colgante de la Hidratacion";
		a_gegenstand(326).f_info[2] = "Verlangsamt Verdursten";
		a_gegenstand(326).f_info[1] = "Slows down thirst";
		a_gegenstand(326).f_info[3] = "Calma la sed";
		a_gegenstand(326).f_art = 20;
		a_gegenstand(326).f_einkauf = 250;
		a_gegenstand(326).f_verkauf = 125;
		a_gegenstand(326).f_gewicht = 2;
		a_gegenstand(327).f_name[2] = "Kette der Askese";
		a_gegenstand(327).f_name[1] = "Necklace of slow digestion";
		a_gegenstand(327).f_name[3] = "Cadena de la digestion lenta";
		a_gegenstand(327).f_info[2] = "Verlangsamt Verhungern";
		a_gegenstand(327).f_info[1] = "Slows down hunger";
		a_gegenstand(327).f_info[3] = "Calma el hambre";
		a_gegenstand(327).f_art = 20;
		a_gegenstand(327).f_einkauf = 250;
		a_gegenstand(327).f_verkauf = 125;
		a_gegenstand(327).f_gewicht = 2;
		a_gegenstand(353).f_name[2] = "Heilkr\344uter";
		a_gegenstand(353).f_name[1] = "Healing Herbs";
		a_gegenstand(353).f_name[3] = "Hierbas curativas";
		a_gegenstand(353).f_art = 15;
		a_gegenstand(353).f_einkauf = 2;
		a_gegenstand(353).f_verkauf = 1;
		a_gegenstand(353).f_gewicht = 1;
		a_gegenstand(355).f_name[2] = "Angel";
		a_gegenstand(355).f_name[1] = "Fishing Rod";
		a_gegenstand(355).f_name[3] = "Cana de Pescar";
		a_gegenstand(355).f_art = 15;
		a_gegenstand(355).f_einkauf = 15;
		a_gegenstand(355).f_verkauf = 7;
		a_gegenstand(355).f_gewicht = 4;
		a_gegenstand(356).f_name[2] = "Fisch";
		a_gegenstand(356).f_name[1] = "Fish";
		a_gegenstand(356).f_name[3] = "Pescado";
		a_gegenstand(356).f_art = 3;
		a_gegenstand(356).f_einkauf = 4;
		a_gegenstand(356).f_verkauf = 2;
		a_gegenstand(356).f_gewicht = 2;
		a_gegenstand(356).f_attri1 = 60;
		a_gegenstand(165).f_name[2] = "Gefrorene Blitze";
		a_gegenstand(165).f_name[1] = "Frozen Lightning";
		a_gegenstand(165).f_name[3] = "Rayos helados";
		a_gegenstand(165).f_info[2] = "Blitzschlag";
		a_gegenstand(165).f_info[1] = "Lightningbolt";
		a_gegenstand(165).f_info[3] = "Relampago";
		a_gegenstand(165).f_art = 15;
		a_gegenstand(165).f_einkauf = 500;
		a_gegenstand(165).f_verkauf = 250;
		a_gegenstand(165).f_gewicht = 2;
		a_gegenstand(165).f_attri1 = 15;
		a_gegenstand(289).f_name[2] = "Fallenwerkzeug";
		a_gegenstand(289).f_name[1] = "Traptoolkit";
		a_gegenstand(289).f_name[3] = "Herramientos para Trampas";
		a_gegenstand(289).f_info[2] = "Zerst\366rt Fallen";
		a_gegenstand(289).f_info[1] = "Disarms traps";
		a_gegenstand(289).f_info[3] = "Destruye trampas";
		a_gegenstand(289).f_art = 15;
		a_gegenstand(289).f_einkauf = 100;
		a_gegenstand(289).f_verkauf = 50;
		a_gegenstand(289).f_gewicht = 2;
		a_gegenstand(289).f_attri1 = 10;
		a_gegenstand(280).f_name[2] = "Goldene Stabaxt (2h)";
		a_gegenstand(280).f_name[1] = "Golden Poleaxe (2h)";
		a_gegenstand(280).f_name[3] = "Hacha de Oro (2M)";
		a_gegenstand(280).f_art = 1;
		a_gegenstand(280).f_klasse = 8;
		a_gegenstand(280).f_einkauf = 140;
		a_gegenstand(280).f_verkauf = 70;
		a_gegenstand(280).f_gewicht = 35;
		a_gegenstand(280).f_attri1 = 3;
		a_gegenstand(280).f_attri2 = 8;
		a_gegenstand(280).f_attri3 = 10;
		a_gegenstand(280).f_attri4 = 2;
		a_gegenstand(281).f_name[2] = "Goldener Kriegshammer";
		a_gegenstand(281).f_name[1] = "Golden Warhammer";
		a_gegenstand(281).f_name[3] = "Martillo de Guerra de Oro";
		a_gegenstand(281).f_art = 1;
		a_gegenstand(281).f_klasse = 4;
		a_gegenstand(281).f_einkauf = 120;
		a_gegenstand(281).f_verkauf = 60;
		a_gegenstand(281).f_gewicht = 45;
		a_gegenstand(281).f_attri1 = 0;
		a_gegenstand(281).f_attri2 = 4;
		a_gegenstand(281).f_attri3 = 8;
		a_gegenstand(281).f_attri4 = 1;
		a_gegenstand(286).f_name[2] = "Roter Speer";
		a_gegenstand(286).f_name[1] = "Red Spear";
		a_gegenstand(286).f_name[3] = "Lanza Roja";
		a_gegenstand(286).f_art = 1;
		a_gegenstand(286).f_klasse = 3;
		a_gegenstand(286).f_einkauf = 100;
		a_gegenstand(286).f_verkauf = 50;
		a_gegenstand(286).f_gewicht = 25;
		a_gegenstand(286).f_attri1 = 2;
		a_gegenstand(286).f_attri2 = 5;
		a_gegenstand(286).f_attri3 = 12;
		a_gegenstand(286).f_attri4 = 1;
		a_gegenstand(284).f_name[2] = "Goldener Dreizack (2H)";
		a_gegenstand(284).f_name[1] = "Golden Pike (2H)";
		a_gegenstand(284).f_name[3] = "Pica de Oro (2M)";
		a_gegenstand(284).f_art = 1;
		a_gegenstand(284).f_einkauf = 120;
		a_gegenstand(284).f_verkauf = 60;
		a_gegenstand(284).f_gewicht = 35;
		a_gegenstand(284).f_attri1 = 1;
		a_gegenstand(284).f_attri2 = 6;
		a_gegenstand(284).f_attri3 = 12;
		a_gegenstand(284).f_attri4 = 2;
		a_gegenstand(287).f_name[2] = "Blutige Streitaxt (2h)";
		a_gegenstand(287).f_name[1] = "Bloody Battleaxe (2h)";
		a_gegenstand(287).f_name[3] = "Hacha de Combate de la Sangre (2M)";
		a_gegenstand(287).f_art = 1;
		a_gegenstand(287).f_klasse = 2;
		a_gegenstand(287).f_einkauf = 140;
		a_gegenstand(287).f_verkauf = 70;
		a_gegenstand(287).f_gewicht = 35;
		a_gegenstand(287).f_attri1 = 3;
		a_gegenstand(287).f_attri2 = 7;
		a_gegenstand(287).f_attri3 = 9;
		a_gegenstand(287).f_attri4 = 2;
		a_gegenstand(288).f_name[2] = "Goldener Streitkolben";
		a_gegenstand(288).f_name[1] = "Golden Battlemace";
		a_gegenstand(288).f_name[3] = "Hacha de Oro";
		a_gegenstand(288).f_art = 1;
		a_gegenstand(288).f_klasse = 4;
		a_gegenstand(288).f_einkauf = 130;
		a_gegenstand(288).f_verkauf = 65;
		a_gegenstand(288).f_gewicht = 30;
		a_gegenstand(288).f_attri1 = 1;
		a_gegenstand(288).f_attri2 = 5;
		a_gegenstand(288).f_attri3 = 8;
		a_gegenstand(288).f_attri4 = 1;
		a_gegenstand(357).f_name[2] = "Stahlhelm";
		a_gegenstand(357).f_name[1] = "Steelhelmet";
		a_gegenstand(357).f_name[3] = "Casco de Acero";
		a_gegenstand(357).f_art = 6;
		a_gegenstand(357).f_einkauf = 25;
		a_gegenstand(357).f_verkauf = 12;
		a_gegenstand(357).f_gewicht = 10;
		a_gegenstand(357).f_attri1 = 1;
		a_gegenstand(357).f_attri2 = 1;
		a_gegenstand(357).f_attri3 = 2;
		a_gegenstand(358).f_name[2] = "Stahlhelm mit Kette";
		a_gegenstand(358).f_name[1] = "Steelhelmet with Chain";
		a_gegenstand(358).f_name[3] = "Casco de Acero con Cadena";
		a_gegenstand(358).f_art = 6;
		a_gegenstand(358).f_einkauf = 35;
		a_gegenstand(358).f_verkauf = 17;
		a_gegenstand(358).f_gewicht = 12;
		a_gegenstand(358).f_attri1 = 1;
		a_gegenstand(358).f_attri2 = 1;
		a_gegenstand(358).f_attri3 = 3;
		a_gegenstand(359).f_name[2] = "Dolchs\344ge";
		a_gegenstand(359).f_name[1] = "Daggersaw";
		a_gegenstand(359).f_name[3] = "Daga con sierra";
		a_gegenstand(359).f_art = 1;
		a_gegenstand(359).f_klasse = 5;
		a_gegenstand(359).f_einkauf = 8;
		a_gegenstand(359).f_verkauf = 4;
		a_gegenstand(359).f_gewicht = 4;
		a_gegenstand(359).f_attri1 = 0;
		a_gegenstand(359).f_attri2 = 2;
		a_gegenstand(359).f_attri3 = 6;
		a_gegenstand(359).f_attri4 = 1;
		a_gegenstand(360).f_name[2] = "Florette";
		a_gegenstand(360).f_name[1] = "Florette";
		a_gegenstand(360).f_name[3] = "Florette";
		a_gegenstand(360).f_art = 1;
		a_gegenstand(360).f_klasse = 7;
		a_gegenstand(360).f_einkauf = 18;
		a_gegenstand(360).f_verkauf = 9;
		a_gegenstand(360).f_gewicht = 10;
		a_gegenstand(360).f_attri1 = 1;
		a_gegenstand(360).f_attri2 = 2;
		a_gegenstand(360).f_attri3 = 8;
		a_gegenstand(360).f_attri4 = 1;
		a_gegenstand(361).f_name[2] = "Langdolch";
		a_gegenstand(361).f_name[1] = "Long Dagger";
		a_gegenstand(361).f_name[3] = "Daga larga";
		a_gegenstand(361).f_art = 1;
		a_gegenstand(361).f_klasse = 5;
		a_gegenstand(361).f_einkauf = 10;
		a_gegenstand(361).f_verkauf = 5;
		a_gegenstand(361).f_gewicht = 5;
		a_gegenstand(361).f_attri1 = 0;
		a_gegenstand(361).f_attri2 = 2;
		a_gegenstand(361).f_attri3 = 7;
		a_gegenstand(361).f_attri4 = 1;
		a_gegenstand(362).f_name[2] = "Langdolch 2";
		a_gegenstand(362).f_name[1] = "Long Dagger 2";
		a_gegenstand(362).f_name[3] = "Daga larga 2";
		a_gegenstand(362).f_art = 1;
		a_gegenstand(362).f_klasse = 5;
		a_gegenstand(362).f_einkauf = 12;
		a_gegenstand(362).f_verkauf = 6;
		a_gegenstand(362).f_gewicht = 6;
		a_gegenstand(362).f_attri1 = 0;
		a_gegenstand(362).f_attri2 = 2;
		a_gegenstand(362).f_attri3 = 9;
		a_gegenstand(362).f_attri4 = 1;
		a_gegenstand(363).f_name[2] = "Kurzschwert";
		a_gegenstand(363).f_name[1] = "Shortsword";
		a_gegenstand(363).f_name[3] = "Espada Corta";
		a_gegenstand(363).f_art = 1;
		a_gegenstand(363).f_klasse = 1;
		a_gegenstand(363).f_einkauf = 30;
		a_gegenstand(363).f_verkauf = 15;
		a_gegenstand(363).f_gewicht = 15;
		a_gegenstand(363).f_attri1 = 1;
		a_gegenstand(363).f_attri2 = 2;
		a_gegenstand(363).f_attri3 = 5;
		a_gegenstand(363).f_attri4 = 1;
		a_gegenstand(364).f_name[2] = "Falchion";
		a_gegenstand(364).f_name[1] = "Falchion";
		a_gegenstand(364).f_name[3] = "Bachete";
		a_gegenstand(364).f_art = 1;
		a_gegenstand(364).f_klasse = 1;
		a_gegenstand(364).f_einkauf = 50;
		a_gegenstand(364).f_verkauf = 25;
		a_gegenstand(364).f_gewicht = 25;
		a_gegenstand(364).f_attri1 = 1;
		a_gegenstand(364).f_attri2 = 3;
		a_gegenstand(364).f_attri3 = 10;
		a_gegenstand(364).f_attri4 = 1;
		a_gegenstand(365).f_name[2] = "Gewellter Dolch";
		a_gegenstand(365).f_name[1] = "Snakeformed Dagger";
		a_gegenstand(365).f_name[3] = "Daga con Forma de Serpiente";
		a_gegenstand(365).f_art = 1;
		a_gegenstand(365).f_klasse = 5;
		a_gegenstand(365).f_einkauf = 14;
		a_gegenstand(365).f_verkauf = 7;
		a_gegenstand(365).f_gewicht = 6;
		a_gegenstand(365).f_attri1 = 0;
		a_gegenstand(365).f_attri2 = 2;
		a_gegenstand(365).f_attri3 = 12;
		a_gegenstand(365).f_attri4 = 1;
		a_gegenstand(366).f_name[2] = "Falchion 2";
		a_gegenstand(366).f_name[1] = "Falchion 2";
		a_gegenstand(366).f_name[3] = "Machete 2";
		a_gegenstand(366).f_art = 1;
		a_gegenstand(366).f_klasse = 1;
		a_gegenstand(366).f_einkauf = 60;
		a_gegenstand(366).f_verkauf = 30;
		a_gegenstand(366).f_gewicht = 30;
		a_gegenstand(366).f_attri1 = 1;
		a_gegenstand(366).f_attri2 = 3;
		a_gegenstand(366).f_attri3 = 15;
		a_gegenstand(366).f_attri4 = 1;
		a_gegenstand(368).f_name[2] = "Breitschwert";
		a_gegenstand(368).f_name[1] = "Broadsword";
		a_gegenstand(368).f_name[3] = "Espada Gruesa";
		a_gegenstand(368).f_art = 1;
		a_gegenstand(368).f_klasse = 1;
		a_gegenstand(368).f_einkauf = 50;
		a_gegenstand(368).f_verkauf = 25;
		a_gegenstand(368).f_gewicht = 30;
		a_gegenstand(368).f_attri1 = 1;
		a_gegenstand(368).f_attri2 = 4;
		a_gegenstand(368).f_attri3 = 0;
		a_gegenstand(368).f_attri4 = 1;
		a_gegenstand(369).f_name[2] = "Breitschwert 2";
		a_gegenstand(369).f_name[1] = "Broadsword 2";
		a_gegenstand(369).f_name[3] = "Espada Gruesa 2";
		a_gegenstand(369).f_art = 1;
		a_gegenstand(369).f_klasse = 1;
		a_gegenstand(369).f_einkauf = 60;
		a_gegenstand(369).f_verkauf = 30;
		a_gegenstand(369).f_gewicht = 32;
		a_gegenstand(369).f_attri1 = 1;
		a_gegenstand(369).f_attri2 = 4;
		a_gegenstand(369).f_attri3 = 5;
		a_gegenstand(369).f_attri4 = 1;
		a_gegenstand(370).f_name[2] = "Zweih\344nder";
		a_gegenstand(370).f_name[1] = "Twohanded Sword";
		a_gegenstand(370).f_name[3] = "Espada a dos Manos";
		a_gegenstand(370).f_art = 1;
		a_gegenstand(370).f_klasse = 1;
		a_gegenstand(370).f_einkauf = 80;
		a_gegenstand(370).f_verkauf = 40;
		a_gegenstand(370).f_gewicht = 35;
		a_gegenstand(370).f_attri1 = 2;
		a_gegenstand(370).f_attri2 = 6;
		a_gegenstand(370).f_attri3 = 5;
		a_gegenstand(370).f_attri4 = 2;
		a_gegenstand(371).f_name[2] = "Zweih\344nder 2";
		a_gegenstand(371).f_name[1] = "Twohanded Sword 2";
		a_gegenstand(371).f_name[3] = "Espada a dos Manos 2";
		a_gegenstand(371).f_art = 1;
		a_gegenstand(371).f_klasse = 1;
		a_gegenstand(371).f_einkauf = 90;
		a_gegenstand(371).f_verkauf = 45;
		a_gegenstand(371).f_gewicht = 40;
		a_gegenstand(371).f_attri1 = 2;
		a_gegenstand(371).f_attri2 = 6;
		a_gegenstand(371).f_attri3 = 10;
		a_gegenstand(371).f_attri4 = 2;
		a_gegenstand(372).f_name[2] = "Stahl Hellebarde (2H)";
		a_gegenstand(372).f_name[1] = "Steel Poleaxe (2H)";
		a_gegenstand(372).f_name[3] = "Hacha de Acero (2M)";
		a_gegenstand(372).f_art = 1;
		a_gegenstand(372).f_klasse = 8;
		a_gegenstand(372).f_einkauf = 80;
		a_gegenstand(372).f_verkauf = 40;
		a_gegenstand(372).f_gewicht = 45;
		a_gegenstand(372).f_attri1 = 2;
		a_gegenstand(372).f_attri2 = 6;
		a_gegenstand(372).f_attri3 = 10;
		a_gegenstand(372).f_attri4 = 2;
		a_gegenstand(373).f_name[2] = "Stahl Helebarde 2 (2H)";
		a_gegenstand(373).f_name[1] = "Steel Poleaxe 2 (2H)";
		a_gegenstand(373).f_name[3] = "Hacha de Acero 2 (2M)";
		a_gegenstand(373).f_art = 1;
		a_gegenstand(373).f_klasse = 8;
		a_gegenstand(373).f_einkauf = 90;
		a_gegenstand(373).f_verkauf = 45;
		a_gegenstand(373).f_gewicht = 47;
		a_gegenstand(373).f_attri1 = 2;
		a_gegenstand(373).f_attri2 = 7;
		a_gegenstand(373).f_attri3 = 12;
		a_gegenstand(373).f_attri4 = 2;
		a_gegenstand(374).f_name[2] = "Holz Sense";
		a_gegenstand(374).f_name[1] = "Wooden Sickle";
		a_gegenstand(374).f_name[3] = "Hoz de Madera";
		a_gegenstand(374).f_art = 1;
		a_gegenstand(374).f_einkauf = 30;
		a_gegenstand(374).f_verkauf = 15;
		a_gegenstand(374).f_gewicht = 20;
		a_gegenstand(374).f_attri1 = 0;
		a_gegenstand(374).f_attri2 = 4;
		a_gegenstand(374).f_attri3 = 15;
		a_gegenstand(374).f_attri4 = 2;
		a_gegenstand(375).f_name[2] = "Stahl Sense";
		a_gegenstand(375).f_name[1] = "Steel Sickle";
		a_gegenstand(375).f_name[3] = "Hoz de Acero";
		a_gegenstand(375).f_art = 1;
		a_gegenstand(375).f_einkauf = 50;
		a_gegenstand(375).f_verkauf = 25;
		a_gegenstand(375).f_gewicht = 25;
		a_gegenstand(375).f_attri1 = 0;
		a_gegenstand(375).f_attri2 = 5;
		a_gegenstand(375).f_attri3 = 15;
		a_gegenstand(375).f_attri4 = 2;
		a_gegenstand(347).f_name[2] = "Schuhe des Wasserwandelns";
		a_gegenstand(347).f_name[1] = "Shoes of Waterwalking";
		a_gegenstand(347).f_name[3] = "Zapatos del caminante del aqua";
		a_gegenstand(347).f_art = 8;
		a_gegenstand(347).f_einkauf = 200;
		a_gegenstand(347).f_verkauf = 100;
		a_gegenstand(347).f_gewicht = 3;
		a_gegenstand(347).f_attri1 = 0;
		a_gegenstand(347).f_attri2 = 0;
		a_gegenstand(347).f_attri3 = 1;
		a_gegenstand(348).f_name[2] = "Schuhe des Eiswandelns";
		a_gegenstand(348).f_name[1] = "Shoes of Icewalking";
		a_gegenstand(348).f_name[3] = "Zapatos del caminante del hielo";
		a_gegenstand(348).f_art = 8;
		a_gegenstand(348).f_einkauf = 200;
		a_gegenstand(348).f_verkauf = 100;
		a_gegenstand(348).f_gewicht = 3;
		a_gegenstand(348).f_attri1 = 0;
		a_gegenstand(348).f_attri2 = 0;
		a_gegenstand(348).f_attri3 = 1;
		a_gegenstand(349).f_name[2] = "Schuhe des Feuerwandelns";
		a_gegenstand(349).f_name[1] = "Shoes of Firewalking";
		a_gegenstand(349).f_name[3] = "Zapatos del caminante del fuego";
		a_gegenstand(349).f_art = 8;
		a_gegenstand(349).f_einkauf = 200;
		a_gegenstand(349).f_verkauf = 100;
		a_gegenstand(349).f_gewicht = 3;
		a_gegenstand(349).f_attri1 = 0;
		a_gegenstand(349).f_attri2 = 0;
		a_gegenstand(349).f_attri3 = 1;
		a_gegenstand(150).f_name[2] = "Geldbeutel";
		a_gegenstand(150).f_name[1] = "Moneybag";
		a_gegenstand(150).f_name[3] = "Billetera";
		a_gegenstand(150).f_art = 15;
		a_gegenstand(150).f_gewicht = 3;
		a_gegenstand(351).f_name[2] = "Horn eines Einhorns (Heilt gift)";
		a_gegenstand(351).f_name[1] = "Horn of a Unicorn (Heals poison)";
		a_gegenstand(351).f_name[3] = "Cornudo de unicornio (cura veneno)";
		a_gegenstand(351).f_art = 15;
		a_gegenstand(351).f_einkauf = 40;
		a_gegenstand(351).f_verkauf = 20;
		a_gegenstand(351).f_gewicht = 2;
		a_gegenstand(354).f_name[2] = "Crysolit";
		a_gegenstand(354).f_name[1] = "Crysolit";
		a_gegenstand(354).f_name[3] = "Crysolit";
		a_gegenstand(354).f_art = 15;
		a_gegenstand(354).f_einkauf = 6;
		a_gegenstand(354).f_verkauf = 3;
		a_gegenstand(354).f_gewicht = 1;
		a_gegenstand(171).f_name[2] = "Pfeile der Naga";
		a_gegenstand(171).f_name[1] = "Naga Arrows";
		a_gegenstand(171).f_name[3] = "Flechas del Naga";
		a_gegenstand(171).f_art = 13;
		a_gegenstand(171).f_einkauf = 12;
		a_gegenstand(171).f_verkauf = 6;
		a_gegenstand(171).f_gewicht = 1;
		a_gegenstand(171).f_magisch = 1;
		a_gegenstand(171).f_attri1 = 10;
		a_gegenstand(171).f_attri2 = 0;
		a_gegenstand(171).f_attri3 = 1;
		a_gegenstand(171).f_attri4 = 5;
		a_gegenstand(249).f_name[2] = "Buch des Wissens";
		a_gegenstand(249).f_name[1] = "Lorebook";
		a_gegenstand(249).f_name[3] = "Libro de Sabiduria";
		a_gegenstand(249).f_art = 15;
		a_gegenstand(249).f_einkauf = 150;
		a_gegenstand(249).f_verkauf = 75;
		a_gegenstand(249).f_gewicht = 2;
		a_gegenstand(159).f_name[2] = "Tor des Universums";
		a_gegenstand(159).f_name[1] = "Dimensional Gate";
		a_gegenstand(159).f_name[3] = "Puerta dimensional";
		a_gegenstand(159).f_art = 15;
		a_gegenstand(159).f_einkauf = 1500;
		a_gegenstand(159).f_verkauf = 750;
		a_gegenstand(159).f_gewicht = 4;
		a_gegenstand(159).f_attri1 = 3;
		a_gegenstand(376).f_name[2] = "Flammenaxt";
		a_gegenstand(376).f_name[1] = "Flaming Axe";
		a_gegenstand(376).f_name[3] = "Hacha Llameante";
		a_gegenstand(376).f_art = 1;
		a_gegenstand(376).f_klasse = 2;
		a_gegenstand(376).f_einkauf = 650;
		a_gegenstand(376).f_verkauf = 325;
		a_gegenstand(376).f_gewicht = 28;
		a_gegenstand(376).f_magisch = 1;
		a_gegenstand(376).f_attri1 = 2;
		a_gegenstand(376).f_attri2 = 4;
		a_gegenstand(376).f_attri3 = 9;
		a_gegenstand(376).f_attri4 = 1;
		a_gegenstand(377).f_name[2] = "Flammenspeer";
		a_gegenstand(377).f_name[1] = "Flaming Spear";
		a_gegenstand(377).f_name[3] = "Lanza Llameante";
		a_gegenstand(377).f_art = 1;
		a_gegenstand(377).f_klasse = 3;
		a_gegenstand(377).f_einkauf = 700;
		a_gegenstand(377).f_verkauf = 350;
		a_gegenstand(377).f_gewicht = 30;
		a_gegenstand(377).f_magisch = 1;
		a_gegenstand(377).f_attri1 = 2;
		a_gegenstand(377).f_attri2 = 5;
		a_gegenstand(377).f_attri3 = 7;
		a_gegenstand(377).f_attri4 = 2;
		a_gegenstand(378).f_name[2] = "Eisaxt";
		a_gegenstand(378).f_name[1] = "Ice Axe";
		a_gegenstand(378).f_name[3] = "Hacha de Hielo";
		a_gegenstand(378).f_art = 1;
		a_gegenstand(378).f_klasse = 2;
		a_gegenstand(378).f_einkauf = 650;
		a_gegenstand(378).f_verkauf = 325;
		a_gegenstand(378).f_gewicht = 28;
		a_gegenstand(378).f_magisch = 1;
		a_gegenstand(378).f_attri1 = 2;
		a_gegenstand(378).f_attri2 = 4;
		a_gegenstand(378).f_attri3 = 9;
		a_gegenstand(378).f_attri4 = 1;
		a_gegenstand(379).f_name[2] = "Eisspeer";
		a_gegenstand(379).f_name[1] = "Ice Spear";
		a_gegenstand(379).f_name[3] = "Lanza de Hielo";
		a_gegenstand(379).f_art = 1;
		a_gegenstand(379).f_klasse = 3;
		a_gegenstand(379).f_einkauf = 700;
		a_gegenstand(379).f_verkauf = 350;
		a_gegenstand(379).f_gewicht = 30;
		a_gegenstand(379).f_magisch = 1;
		a_gegenstand(379).f_attri1 = 2;
		a_gegenstand(379).f_attri2 = 5;
		a_gegenstand(379).f_attri3 = 7;
		a_gegenstand(379).f_attri4 = 2;
		a_gegenstand(381).f_name[2] = "Giftige Axt";
		a_gegenstand(381).f_name[1] = "Poisenous Axe";
		a_gegenstand(381).f_name[3] = "Hacha de Veneno";
		a_gegenstand(381).f_art = 1;
		a_gegenstand(381).f_klasse = 2;
		a_gegenstand(381).f_einkauf = 650;
		a_gegenstand(381).f_verkauf = 325;
		a_gegenstand(381).f_gewicht = 28;
		a_gegenstand(381).f_magisch = 1;
		a_gegenstand(381).f_attri1 = 2;
		a_gegenstand(381).f_attri2 = 4;
		a_gegenstand(381).f_attri3 = 9;
		a_gegenstand(381).f_attri4 = 1;
		a_gegenstand(382).f_name[2] = "Giftiger Speer";
		a_gegenstand(382).f_name[1] = "Poisenous Spear";
		a_gegenstand(382).f_name[3] = "Lanza de Veneno";
		a_gegenstand(382).f_art = 1;
		a_gegenstand(382).f_klasse = 3;
		a_gegenstand(382).f_einkauf = 700;
		a_gegenstand(382).f_verkauf = 350;
		a_gegenstand(382).f_gewicht = 30;
		a_gegenstand(382).f_magisch = 1;
		a_gegenstand(382).f_attri1 = 2;
		a_gegenstand(382).f_attri2 = 5;
		a_gegenstand(382).f_attri3 = 7;
		a_gegenstand(382).f_attri4 = 2;
		a_gegenstand(49).f_name[2] = "Speer des Lichts";
		a_gegenstand(49).f_name[1] = "Spear of Light";
		a_gegenstand(49).f_name[3] = "Lanza de la Luz";
		a_gegenstand(49).f_art = 1;
		a_gegenstand(49).f_klasse = 3;
		a_gegenstand(49).f_einkauf = 1000;
		a_gegenstand(49).f_verkauf = 500;
		a_gegenstand(49).f_gewicht = 30;
		a_gegenstand(49).f_magisch = 1;
		a_gegenstand(49).f_attri1 = 2;
		a_gegenstand(49).f_attri2 = 5;
		a_gegenstand(49).f_attri3 = 7;
		a_gegenstand(49).f_attri4 = 2;
		a_gegenstand(380).f_name[2] = "Magische Axt";
		a_gegenstand(380).f_name[1] = "Magic Axe";
		a_gegenstand(380).f_name[3] = "Hacha Magica";
		a_gegenstand(380).f_art = 1;
		a_gegenstand(380).f_klasse = 2;
		a_gegenstand(380).f_einkauf = 600;
		a_gegenstand(380).f_verkauf = 300;
		a_gegenstand(380).f_gewicht = 20;
		a_gegenstand(380).f_magisch = 1;
		a_gegenstand(380).f_attri1 = 2;
		a_gegenstand(380).f_attri2 = 4;
		a_gegenstand(380).f_attri3 = 15;
		a_gegenstand(380).f_attri4 = 2;
		a_gegenstand(383).f_name[2] = "Bier";
		a_gegenstand(383).f_name[1] = "Beer";
		a_gegenstand(383).f_name[3] = "Cerveza";
		a_gegenstand(383).f_art = 23;
		a_gegenstand(383).f_einkauf = 5;
		a_gegenstand(383).f_verkauf = 2;
		a_gegenstand(383).f_gewicht = 2;
		a_gegenstand(383).f_attri1 = 35;
		a_gegenstand(383).f_attri2 = 20;
		a_gegenstand(384).f_name[2] = "Wein";
		a_gegenstand(384).f_name[1] = "Wine";
		a_gegenstand(384).f_name[3] = "Vino";
		a_gegenstand(384).f_art = 23;
		a_gegenstand(384).f_einkauf = 6;
		a_gegenstand(384).f_verkauf = 3;
		a_gegenstand(384).f_gewicht = 2;
		a_gegenstand(384).f_attri1 = 35;
		a_gegenstand(384).f_attri2 = 30;
		a_gegenstand(170).f_name[2] = "Explodierende Pfeile";
		a_gegenstand(170).f_name[1] = "Exploding Arrows";
		a_gegenstand(170).f_name[3] = "Flechas que explotan";
		a_gegenstand(170).f_art = 13;
		a_gegenstand(170).f_einkauf = 10;
		a_gegenstand(170).f_verkauf = 5;
		a_gegenstand(170).f_gewicht = 1;
		a_gegenstand(170).f_magisch = 1;
		a_gegenstand(170).f_attri1 = 10;
		a_gegenstand(170).f_attri2 = 0;
		a_gegenstand(170).f_attri3 = 2;
		a_gegenstand(170).f_attri4 = 5;
		a_gegenstand(173).f_name[2] = "Zielsuchende Pfeile";
		a_gegenstand(173).f_name[1] = "Aiming Arrows";
		a_gegenstand(173).f_name[3] = "Flechas de alcanzar";
		a_gegenstand(173).f_art = 13;
		a_gegenstand(173).f_einkauf = 8;
		a_gegenstand(173).f_verkauf = 4;
		a_gegenstand(173).f_gewicht = 1;
		a_gegenstand(173).f_magisch = 1;
		a_gegenstand(173).f_attri1 = 10;
		a_gegenstand(173).f_attri2 = 0;
		a_gegenstand(173).f_attri3 = 3;
		a_gegenstand(173).f_attri4 = 15;
		a_gegenstand(387).f_name[2] = "Stab der Pflanzenvernichtung";
		a_gegenstand(387).f_name[1] = "Staff of Destroy Plants";
		a_gegenstand(387).f_name[3] = "Vara de la muerte de plantas";
		a_gegenstand(387).f_art = 22;
		a_gegenstand(387).f_einkauf = 400;
		a_gegenstand(387).f_verkauf = 300;
		a_gegenstand(387).f_gewicht = 3;
		a_gegenstand(387).f_attri1 = 132;
		a_gegenstand(388).f_name[2] = "Stab des Vergiftens";
		a_gegenstand(388).f_name[1] = "Staff of Poisening";
		a_gegenstand(388).f_name[3] = "Vara de envenenar";
		a_gegenstand(388).f_art = 22;
		a_gegenstand(388).f_einkauf = 400;
		a_gegenstand(388).f_verkauf = 200;
		a_gegenstand(388).f_gewicht = 3;
		a_gegenstand(388).f_attri1 = 125;
		a_gegenstand(389).f_name[2] = "Stab des ewigen Schalfs";
		a_gegenstand(389).f_name[1] = "Staff of eternal Sleep";
		a_gegenstand(389).f_name[3] = "Vara de dormir";
		a_gegenstand(389).f_art = 22;
		a_gegenstand(389).f_einkauf = 400;
		a_gegenstand(389).f_verkauf = 200;
		a_gegenstand(389).f_gewicht = 3;
		a_gegenstand(389).f_attri1 = 127;
		a_gegenstand(390).f_name[2] = "Stab der Telekinesis";
		a_gegenstand(390).f_name[1] = "Staff of Telekinesis";
		a_gegenstand(390).f_name[3] = "Vara de telekinesis";
		a_gegenstand(390).f_art = 22;
		a_gegenstand(390).f_einkauf = 500;
		a_gegenstand(390).f_verkauf = 250;
		a_gegenstand(390).f_gewicht = 3;
		a_gegenstand(390).f_attri1 = 129;
		a_gegenstand(391).f_name[2] = "Stab der Luftleere";
		a_gegenstand(391).f_name[1] = "Staff of vacuum";
		a_gegenstand(391).f_name[3] = "Vara del vacuum";
		a_gegenstand(391).f_art = 22;
		a_gegenstand(391).f_einkauf = 500;
		a_gegenstand(391).f_verkauf = 250;
		a_gegenstand(391).f_gewicht = 3;
		a_gegenstand(391).f_attri1 = 131;
		a_gegenstand(392).f_name[2] = "Stab des Blendens";
		a_gegenstand(392).f_name[1] = "Staff of blindness";
		a_gegenstand(392).f_name[3] = "Vara del ciego";
		a_gegenstand(392).f_art = 22;
		a_gegenstand(392).f_einkauf = 500;
		a_gegenstand(392).f_verkauf = 250;
		a_gegenstand(392).f_gewicht = 3;
		a_gegenstand(392).f_attri1 = 137;
		a_gegenstand(393).f_name[2] = "Stab des Dimensionstausches";
		a_gegenstand(393).f_name[1] = "Staff of planeshifting";
		a_gegenstand(393).f_name[3] = "Vara del cambio de dimensiones";
		a_gegenstand(393).f_art = 22;
		a_gegenstand(393).f_einkauf = 500;
		a_gegenstand(393).f_verkauf = 250;
		a_gegenstand(393).f_gewicht = 3;
		a_gegenstand(393).f_attri1 = 144;
		a_gegenstand(394).f_name[2] = "Stab des Verdorrens";
		a_gegenstand(394).f_name[1] = "Staff of withering";
		a_gegenstand(394).f_name[3] = "Vara de machitarse";
		a_gegenstand(394).f_art = 22;
		a_gegenstand(394).f_einkauf = 500;
		a_gegenstand(394).f_verkauf = 250;
		a_gegenstand(394).f_gewicht = 3;
		a_gegenstand(394).f_attri1 = 149;
		a_gegenstand(395).f_name[2] = "Stab der Todeswolke";
		a_gegenstand(395).f_name[1] = "Staff of deathcloud";
		a_gegenstand(395).f_name[3] = "Vara de la nube de muerte";
		a_gegenstand(395).f_art = 22;
		a_gegenstand(395).f_einkauf = 500;
		a_gegenstand(395).f_verkauf = 250;
		a_gegenstand(395).f_gewicht = 3;
		a_gegenstand(395).f_attri1 = 150;
		a_gegenstand(172).f_name[2] = "Frost Pfeile";
		a_gegenstand(172).f_name[1] = "Freezing Arrows";
		a_gegenstand(172).f_name[3] = "Flechas de hielo";
		a_gegenstand(172).f_art = 13;
		a_gegenstand(172).f_einkauf = 10;
		a_gegenstand(172).f_verkauf = 5;
		a_gegenstand(172).f_gewicht = 1;
		a_gegenstand(172).f_magisch = 1;
		a_gegenstand(172).f_attri1 = 10;
		a_gegenstand(172).f_attri2 = 0;
		a_gegenstand(172).f_attri3 = 3;
		a_gegenstand(172).f_attri4 = 5;
		a_gegenstand(396).f_name[2] = "Honig";
		a_gegenstand(396).f_name[1] = "Honey";
		a_gegenstand(396).f_name[3] = "Miel";
		a_gegenstand(396).f_art = 3;
		a_gegenstand(396).f_einkauf = 5;
		a_gegenstand(396).f_verkauf = 2;
		a_gegenstand(396).f_gewicht = 2;
		a_gegenstand(396).f_attri1 = 50;
		a_gegenstand(399).f_name[2] = "Stundenglas";
		a_gegenstand(399).f_name[1] = "Hourglass";
		a_gegenstand(399).f_name[3] = "Horas Cristal";
		a_gegenstand(399).f_info[2] = "(Reverts turn)";
		a_gegenstand(399).f_info[1] = "(Setzt Zug zur\374ck)";
		a_gegenstand(399).f_info[3] = "(Reverta al turno)";
		a_gegenstand(399).f_art = 15;
		a_gegenstand(399).f_einkauf = 800;
		a_gegenstand(399).f_verkauf = 450;
		a_gegenstand(399).f_gewicht = 1;
		a_gegenstand(399).f_attri1 = 10;
		a_gegenstand(400).f_name[2] = "Fliegender Besen";
		a_gegenstand(400).f_name[1] = "Broomstick";
		a_gegenstand(400).f_name[3] = "Escoba Volando";
		a_gegenstand(400).f_art = 15;
		a_gegenstand(400).f_einkauf = 700;
		a_gegenstand(400).f_verkauf = 0;
		a_gegenstand(400).f_gewicht = 10;
		a_gegenstand(401).f_name[2] = "Kalligrafie Set";
		a_gegenstand(401).f_name[1] = "Calligraphy Set";
		a_gegenstand(401).f_name[3] = "Instrumentos de caligrafia";
		a_gegenstand(401).f_art = 15;
		a_gegenstand(401).f_einkauf = 100;
		a_gegenstand(401).f_verkauf = 50;
		a_gegenstand(401).f_gewicht = 2;
		a_gegenstand(401).f_attri1 = 3;
		a_gegenstand(233).f_name[2] = "Feuerhammer (2H)";
		a_gegenstand(233).f_name[1] = "Firehammer (2H)";
		a_gegenstand(233).f_name[3] = "Martillo de Fuego (2M)";
		a_gegenstand(233).f_art = 1;
		a_gegenstand(233).f_klasse = 4;
		a_gegenstand(233).f_einkauf = 600;
		a_gegenstand(233).f_verkauf = 300;
		a_gegenstand(233).f_gewicht = 42;
		a_gegenstand(233).f_magisch = 1;
		a_gegenstand(233).f_attri1 = -1;
		a_gegenstand(233).f_attri2 = 5;
		a_gegenstand(233).f_attri3 = 12;
		a_gegenstand(233).f_attri4 = 2;
		a_gegenstand(234).f_name[2] = "Eisenhammer (2H)";
		a_gegenstand(234).f_name[1] = "Ironhammer (2H)";
		a_gegenstand(234).f_name[3] = "Martillo de hierro (2M)";
		a_gegenstand(234).f_art = 1;
		a_gegenstand(234).f_klasse = 4;
		a_gegenstand(234).f_einkauf = 40;
		a_gegenstand(234).f_verkauf = 20;
		a_gegenstand(234).f_gewicht = 38;
		a_gegenstand(234).f_attri1 = -1;
		a_gegenstand(234).f_attri2 = 4;
		a_gegenstand(234).f_attri3 = 10;
		a_gegenstand(234).f_attri4 = 2;
		a_gegenstand(235).f_name[2] = "Eishammer (2H)";
		a_gegenstand(235).f_name[1] = "Icehammer (2H)";
		a_gegenstand(235).f_name[3] = "Martillo de Hielo (2M)";
		a_gegenstand(235).f_art = 1;
		a_gegenstand(235).f_klasse = 4;
		a_gegenstand(235).f_einkauf = 600;
		a_gegenstand(235).f_verkauf = 300;
		a_gegenstand(235).f_gewicht = 42;
		a_gegenstand(235).f_magisch = 1;
		a_gegenstand(235).f_attri1 = -1;
		a_gegenstand(235).f_attri2 = 5;
		a_gegenstand(235).f_attri3 = 12;
		a_gegenstand(235).f_attri4 = 2;
		a_gegenstand(236).f_name[2] = "Hammer des Lichts (2H)";
		a_gegenstand(236).f_name[1] = "Hammer of Light (2H)";
		a_gegenstand(236).f_name[3] = "Martillo de la Luz (2M)";
		a_gegenstand(236).f_art = 1;
		a_gegenstand(236).f_klasse = 4;
		a_gegenstand(236).f_einkauf = 1000;
		a_gegenstand(236).f_verkauf = 500;
		a_gegenstand(236).f_gewicht = 35;
		a_gegenstand(236).f_magisch = 1;
		a_gegenstand(236).f_attri1 = -1;
		a_gegenstand(236).f_attri2 = 4;
		a_gegenstand(236).f_attri3 = 10;
		a_gegenstand(236).f_attri4 = 2;
		a_gegenstand(238).f_name[2] = "Gifthammer (2H)";
		a_gegenstand(238).f_name[1] = "Poison Hammer (2H)";
		a_gegenstand(238).f_name[3] = "Martillo de veneno (2M)";
		a_gegenstand(238).f_art = 1;
		a_gegenstand(238).f_klasse = 4;
		a_gegenstand(238).f_einkauf = 550;
		a_gegenstand(238).f_verkauf = 275;
		a_gegenstand(238).f_gewicht = 42;
		a_gegenstand(238).f_magisch = 1;
		a_gegenstand(238).f_attri1 = -1;
		a_gegenstand(238).f_attri2 = 5;
		a_gegenstand(238).f_attri3 = 12;
		a_gegenstand(238).f_attri4 = 2;
		for (v_i = 1; v_i <= 150; v_i += 1) {
			a_monster(v_i).f_sound = 0;
			a_monster(v_i).f_eigenschaft1 = 0;
			a_monster(v_i).f_eigenschaft2 = 0;
			a_monster(v_i).f_eigenschaft3 = 0;
			a_monster(v_i).f_eigenschaft4 = 0;
			a_monster(v_i).f_eigenschaft5 = 0;
			a_monster(v_i).f_eigenschaft6 = 0;
			a_monster(v_i).f_eigenschaft7 = 0;
			a_monster(v_i).f_eigenschaft8 = 0;
			a_monster(v_i).f_eigenschaft9 = 0;
			a_monster(v_i).f_eigenschaft10 = 0;
		}
		a_monster(1).f_name[2] = "Fledermaus";
		a_monster(1).f_name[1] = "Bat";
		a_monster(1).f_name[3] = "Murcielago";
		a_monster(1).f_nr = 4;
		a_monster(1).f_art = 1;
		a_monster(1).f_lebenspunkte = 1;
		a_monster(1).f_angriff = 1;
		a_monster(1).f_abwehr = 3;
		a_monster(1).f_staerke = 1;
		a_monster(1).f_ruestung = 0;
		a_monster(1).f_zauberkraft = 0;
		a_monster(1).f_zauber = 0;
		a_monster(1).f_reichweite = 0;
		a_monster(1).f_minlevel = 1;
		a_monster(1).f_eigenschaft1 = 1;
		a_monster(1).f_eigenschaft2 = 8;
		a_monster(1).f_eigenschaft3 = 29;
		a_monster(1).f_eigenschaft4 = 37;
		a_monster(2).f_name[2] = "Riesenratte";
		a_monster(2).f_name[1] = "Giant Rat";
		a_monster(2).f_name[3] = "Rata Gigante";
		a_monster(2).f_nr = 1;
		a_monster(2).f_art = 1;
		a_monster(2).f_lebenspunkte = 3;
		a_monster(2).f_angriff = 1;
		a_monster(2).f_abwehr = 0;
		a_monster(2).f_staerke = 1;
		a_monster(2).f_ruestung = 0;
		a_monster(2).f_zauberkraft = 0;
		a_monster(2).f_zauber = 0;
		a_monster(2).f_reichweite = 0;
		a_monster(2).f_minlevel = 1;
		a_monster(2).f_sound = 45;
		a_monster(2).f_eigenschaft1 = 2;
		a_monster(2).f_eigenschaft2 = 6;
		a_monster(2).f_eigenschaft3 = 8;
		a_monster(2).f_eigenschaft4 = 29;
		a_monster(2).f_eigenschaft5 = 35;
		if ((g_test == 1)) {
			a_monster(2).f_eigenschaft6 = 44;
		}
		a_monster(3).f_name[2] = "Goblin";
		a_monster(3).f_name[1] = "Goblin";
		a_monster(3).f_name[3] = "Goblin";
		a_monster(3).f_nr = 61;
		a_monster(3).f_art = 2;
		a_monster(3).f_lebenspunkte = 2;
		a_monster(3).f_angriff = 2;
		a_monster(3).f_abwehr = 1;
		a_monster(3).f_staerke = 2;
		a_monster(3).f_ruestung = 0;
		a_monster(3).f_zauberkraft = 0;
		a_monster(3).f_zauber = 0;
		a_monster(3).f_reichweite = 3;
		a_monster(3).f_minlevel = 1;
		a_monster(3).f_eigenschaft1 = 2;
		a_monster(3).f_eigenschaft2 = 4;
		a_monster(3).f_eigenschaft3 = 5;
		a_monster(3).f_eigenschaft4 = 6;
		a_monster(3).f_eigenschaft5 = 29;
		a_monster(3).f_eigenschaft6 = 33;
		a_monster(4).f_name[2] = "Skelettkrieger";
		a_monster(4).f_name[1] = "Skeleton Warrior";
		a_monster(4).f_name[3] = "Guerrero Esqueleto";
		a_monster(4).f_nr = 23;
		a_monster(4).f_art = 3;
		a_monster(4).f_lebenspunkte = 1;
		a_monster(4).f_angriff = 3;
		a_monster(4).f_abwehr = 2;
		a_monster(4).f_staerke = 3;
		a_monster(4).f_ruestung = 1;
		a_monster(4).f_zauberkraft = 0;
		a_monster(4).f_zauber = 0;
		a_monster(4).f_reichweite = 0;
		a_monster(4).f_minlevel = 1;
		a_monster(4).f_eigenschaft1 = 7;
		a_monster(4).f_eigenschaft2 = 34;
		a_monster(5).f_name[2] = "Goblinschamane";
		a_monster(5).f_name[1] = "Goblin Shaman";
		a_monster(5).f_name[3] = "Chaman Goblin";
		a_monster(5).f_nr = 50;
		a_monster(5).f_art = 2;
		a_monster(5).f_lebenspunkte = 2;
		a_monster(5).f_angriff = 0;
		a_monster(5).f_abwehr = 0;
		a_monster(5).f_staerke = 1;
		a_monster(5).f_ruestung = 0;
		a_monster(5).f_zauberkraft = 1;
		a_monster(5).f_zauber = 1;
		a_monster(5).f_reichweite = 5;
		a_monster(5).f_minlevel = 1;
		a_monster(5).f_eigenschaft1 = 4;
		a_monster(5).f_eigenschaft2 = 8;
		a_monster(5).f_eigenschaft3 = 27;
		a_monster(5).f_eigenschaft4 = 29;
		a_monster(5).f_eigenschaft5 = 33;
		a_monster(6).f_name[2] = "Geier";
		a_monster(6).f_name[1] = "Vulture";
		a_monster(6).f_name[3] = "Buitre";
		a_monster(6).f_nr = 70;
		a_monster(6).f_art = 1;
		a_monster(6).f_lebenspunkte = 2;
		a_monster(6).f_angriff = 2;
		a_monster(6).f_abwehr = 1;
		a_monster(6).f_staerke = 2;
		a_monster(6).f_ruestung = 0;
		a_monster(6).f_zauberkraft = 0;
		a_monster(6).f_zauber = 0;
		a_monster(6).f_reichweite = 0;
		a_monster(6).f_minlevel = 1;
		a_monster(6).f_eigenschaft1 = 1;
		a_monster(6).f_eigenschaft2 = 8;
		a_monster(6).f_eigenschaft3 = 29;
		a_monster(7).f_name[2] = "Dunkelwolf";
		a_monster(7).f_name[1] = "Dark Wolf";
		a_monster(7).f_name[3] = "Lobo Oscuro";
		a_monster(7).f_nr = 69;
		a_monster(7).f_art = 1;
		a_monster(7).f_lebenspunkte = 4;
		a_monster(7).f_angriff = 4;
		a_monster(7).f_abwehr = 1;
		a_monster(7).f_staerke = 2;
		a_monster(7).f_ruestung = 0;
		a_monster(7).f_zauberkraft = 0;
		a_monster(7).f_zauber = 0;
		a_monster(7).f_reichweite = 0;
		a_monster(7).f_minlevel = 1;
		a_monster(7).f_sound = 36;
		a_monster(7).f_eigenschaft1 = 2;
		a_monster(7).f_eigenschaft2 = 8;
		a_monster(7).f_eigenschaft3 = 29;
		a_monster(7).f_eigenschaft4 = 36;
		a_monster(8).f_name[2] = "Schlinggras";
		a_monster(8).f_name[1] = "Grapplevines";
		a_monster(8).f_name[3] = "Enredaderas";
		a_monster(8).f_nr = 9;
		a_monster(8).f_art = 4;
		a_monster(8).f_lebenspunkte = 8;
		a_monster(8).f_angriff = 1;
		a_monster(8).f_abwehr = 0;
		a_monster(8).f_staerke = 4;
		a_monster(8).f_ruestung = 0;
		a_monster(8).f_zauberkraft = 0;
		a_monster(8).f_zauber = 0;
		a_monster(8).f_reichweite = 0;
		a_monster(8).f_minlevel = 1;
		a_monster(8).f_eigenschaft1 = 11;
		a_monster(9).f_name[2] = "Dieb";
		a_monster(9).f_name[1] = "Thief";
		a_monster(9).f_name[3] = "Ladron";
		a_monster(9).f_nr = 65;
		a_monster(9).f_art = 2;
		a_monster(9).f_lebenspunkte = 3;
		a_monster(9).f_angriff = 6;
		a_monster(9).f_abwehr = 1;
		a_monster(9).f_staerke = 2;
		a_monster(9).f_ruestung = 0;
		a_monster(9).f_zauberkraft = 0;
		a_monster(9).f_zauber = 0;
		a_monster(9).f_reichweite = 0;
		a_monster(9).f_minlevel = 2;
		a_monster(9).f_eigenschaft1 = 8;
		a_monster(9).f_eigenschaft2 = 9;
		a_monster(9).f_eigenschaft3 = 10;
		a_monster(9).f_eigenschaft4 = 26;
		a_monster(9).f_eigenschaft5 = 29;
		a_monster(10).f_name[2] = "Riesenschlange";
		a_monster(10).f_name[1] = "Giant Snake";
		a_monster(10).f_name[3] = "Serpiente Gigante";
		a_monster(10).f_nr = 6;
		a_monster(10).f_art = 1;
		a_monster(10).f_lebenspunkte = 5;
		a_monster(10).f_angriff = 3;
		a_monster(10).f_abwehr = 1;
		a_monster(10).f_staerke = 2;
		a_monster(10).f_ruestung = 0;
		a_monster(10).f_zauberkraft = 0;
		a_monster(10).f_zauber = 0;
		a_monster(10).f_reichweite = 0;
		a_monster(10).f_minlevel = 2;
		a_monster(10).f_eigenschaft1 = 8;
		a_monster(10).f_eigenschaft2 = 3;
		a_monster(10).f_eigenschaft3 = 29;
		a_monster(11).f_name[2] = "Riesenmade";
		a_monster(11).f_name[1] = "Giant Maggot";
		a_monster(11).f_name[3] = "Oruga Gigante";
		a_monster(11).f_nr = 47;
		a_monster(11).f_art = 1;
		a_monster(11).f_lebenspunkte = 10;
		a_monster(11).f_angriff = 2;
		a_monster(11).f_abwehr = 0;
		a_monster(11).f_staerke = 3;
		a_monster(11).f_ruestung = 0;
		a_monster(11).f_zauberkraft = 0;
		a_monster(11).f_zauber = 0;
		a_monster(11).f_reichweite = 0;
		a_monster(11).f_minlevel = 2;
		a_monster(11).f_sound = 45;
		a_monster(11).f_eigenschaft1 = 29;
		a_monster(12).f_name[2] = "Zauberlehrling";
		a_monster(12).f_name[1] = "Apprentice Wizard";
		a_monster(12).f_name[3] = "Aprendiz de Mago";
		a_monster(12).f_nr = 71;
		a_monster(12).f_art = 2;
		a_monster(12).f_lebenspunkte = 3;
		a_monster(12).f_angriff = 0;
		a_monster(12).f_abwehr = 0;
		a_monster(12).f_staerke = 1;
		a_monster(12).f_ruestung = 0;
		a_monster(12).f_zauberkraft = 2;
		a_monster(12).f_zauber = 3;
		a_monster(12).f_reichweite = 5;
		a_monster(12).f_minlevel = 3;
		a_monster(12).f_eigenschaft1 = 8;
		a_monster(12).f_eigenschaft2 = 9;
		a_monster(12).f_eigenschaft3 = 4;
		a_monster(12).f_eigenschaft4 = 27;
		a_monster(12).f_eigenschaft5 = 29;
		a_monster(13).f_name[2] = "Monsterschildkr\357\277\275e";
		a_monster(13).f_name[1] = "Monstruous Turtle";
		a_monster(13).f_name[3] = "Tortuga Monstruosa";
		a_monster(13).f_nr = 13;
		a_monster(13).f_art = 1;
		a_monster(13).f_lebenspunkte = 3;
		a_monster(13).f_angriff = 0;
		a_monster(13).f_abwehr = 0;
		a_monster(13).f_staerke = 1;
		a_monster(13).f_ruestung = 6;
		a_monster(13).f_zauberkraft = 0;
		a_monster(13).f_zauber = 0;
		a_monster(13).f_reichweite = 0;
		a_monster(13).f_minlevel = 3;
		a_monster(13).f_eigenschaft1 = 8;
		a_monster(13).f_eigenschaft2 = 9;
		a_monster(13).f_eigenschaft3 = 29;
		a_monster(14).f_name[2] = "Riesenechse";
		a_monster(14).f_name[1] = "Giant Lizard";
		a_monster(14).f_name[3] = "Lagarto Gigante";
		a_monster(14).f_nr = 19;
		a_monster(14).f_art = 1;
		a_monster(14).f_lebenspunkte = 6;
		a_monster(14).f_angriff = 3;
		a_monster(14).f_abwehr = 1;
		a_monster(14).f_staerke = 3;
		a_monster(14).f_ruestung = 1;
		a_monster(14).f_zauberkraft = 0;
		a_monster(14).f_zauber = 0;
		a_monster(14).f_reichweite = 0;
		a_monster(14).f_minlevel = 4;
		a_monster(14).f_eigenschaft1 = 8;
		a_monster(14).f_eigenschaft2 = 9;
		a_monster(14).f_eigenschaft3 = 29;
		a_monster(15).f_name[2] = "Ork";
		a_monster(15).f_name[1] = "Orc";
		a_monster(15).f_name[3] = "Orco";
		a_monster(15).f_nr = 62;
		a_monster(15).f_art = 2;
		a_monster(15).f_lebenspunkte = 7;
		a_monster(15).f_angriff = 3;
		a_monster(15).f_abwehr = 2;
		a_monster(15).f_staerke = 4;
		a_monster(15).f_ruestung = 1;
		a_monster(15).f_zauberkraft = 0;
		a_monster(15).f_zauber = 0;
		a_monster(15).f_reichweite = 0;
		a_monster(15).f_minlevel = 4;
		a_monster(15).f_eigenschaft1 = 2;
		a_monster(15).f_eigenschaft2 = 4;
		a_monster(15).f_eigenschaft3 = 8;
		a_monster(15).f_eigenschaft4 = 9;
		a_monster(15).f_eigenschaft5 = 26;
		a_monster(15).f_eigenschaft6 = 29;
		a_monster(15).f_eigenschaft7 = 33;
		a_monster(16).f_name[2] = "Zombie";
		a_monster(16).f_name[1] = "Zombie";
		a_monster(16).f_name[3] = "Zombi";
		a_monster(16).f_nr = 42;
		a_monster(16).f_art = 3;
		a_monster(16).f_lebenspunkte = 12;
		a_monster(16).f_angriff = 2;
		a_monster(16).f_abwehr = 0;
		a_monster(16).f_staerke = 5;
		a_monster(16).f_ruestung = 0;
		a_monster(16).f_zauberkraft = 0;
		a_monster(16).f_zauber = 0;
		a_monster(16).f_reichweite = 0;
		a_monster(16).f_minlevel = 4;
		a_monster(16).f_sound = 44;
		a_monster(16).f_eigenschaft1 = 34;
		a_monster(16).f_eigenschaft2 = 44;
		a_monster(17).f_name[2] = "Dunkelelf";
		a_monster(17).f_name[1] = "Dark Elf";
		a_monster(17).f_name[3] = "Elfo Oscuro";
		a_monster(17).f_nr = 63;
		a_monster(17).f_art = 2;
		a_monster(17).f_lebenspunkte = 5;
		a_monster(17).f_angriff = 5;
		a_monster(17).f_abwehr = 5;
		a_monster(17).f_staerke = 3;
		a_monster(17).f_ruestung = 0;
		a_monster(17).f_zauberkraft = 0;
		a_monster(17).f_zauber = 0;
		a_monster(17).f_reichweite = 7;
		a_monster(17).f_minlevel = 4;
		a_monster(17).f_eigenschaft1 = 5;
		a_monster(17).f_eigenschaft2 = 3;
		a_monster(17).f_eigenschaft3 = 2;
		a_monster(17).f_eigenschaft4 = 4;
		a_monster(17).f_eigenschaft5 = 8;
		a_monster(17).f_eigenschaft6 = 9;
		a_monster(17).f_eigenschaft7 = 26;
		a_monster(18).f_name[2] = "Riesenameise";
		a_monster(18).f_name[1] = "Giant Ant";
		a_monster(18).f_name[3] = "Hormiga Gigante";
		a_monster(18).f_nr = 38;
		a_monster(18).f_art = 1;
		a_monster(18).f_lebenspunkte = 5;
		a_monster(18).f_angriff = 5;
		a_monster(18).f_abwehr = 2;
		a_monster(18).f_staerke = 4;
		a_monster(18).f_ruestung = 2;
		a_monster(18).f_zauberkraft = 0;
		a_monster(18).f_zauber = 0;
		a_monster(18).f_reichweite = 0;
		a_monster(18).f_minlevel = 5;
		a_monster(18).f_eigenschaft1 = 2;
		a_monster(18).f_eigenschaft2 = 6;
		a_monster(18).f_eigenschaft3 = 29;
		a_monster(18).f_eigenschaft4 = 43;
		a_monster(19).f_name[2] = "Riesenspinne";
		a_monster(19).f_name[1] = "Giant Spider";
		a_monster(19).f_name[3] = "Arana Gigante";
		a_monster(19).f_nr = 3;
		a_monster(19).f_art = 1;
		a_monster(19).f_lebenspunkte = 6;
		a_monster(19).f_angriff = 6;
		a_monster(19).f_abwehr = 4;
		a_monster(19).f_staerke = 4;
		a_monster(19).f_ruestung = 0;
		a_monster(19).f_zauberkraft = 0;
		a_monster(19).f_zauber = 0;
		a_monster(19).f_reichweite = 0;
		a_monster(19).f_minlevel = 5;
		a_monster(19).f_eigenschaft1 = 29;
		a_monster(19).f_eigenschaft2 = 3;
		a_monster(19).f_eigenschaft3 = 32;
		a_monster(20).f_name[2] = "Irrlicht";
		a_monster(20).f_name[1] = "Will-o-the-Whisp";
		a_monster(20).f_name[3] = "Luciernaga";
		a_monster(20).f_nr = 72;
		a_monster(20).f_art = 10;
		a_monster(20).f_lebenspunkte = 1;
		a_monster(20).f_angriff = 1;
		a_monster(20).f_abwehr = 6;
		a_monster(20).f_staerke = 3;
		a_monster(20).f_ruestung = 0;
		a_monster(20).f_zauberkraft = 0;
		a_monster(20).f_zauber = 0;
		a_monster(20).f_reichweite = 8;
		a_monster(20).f_minlevel = 5;
		a_monster(20).f_eigenschaft1 = 1;
		a_monster(20).f_eigenschaft2 = 7;
		a_monster(20).f_eigenschaft3 = 12;
		a_monster(20).f_eigenschaft4 = 13;
		a_monster(20).f_eigenschaft5 = 10;
		a_monster(20).f_eigenschaft6 = 14;
		a_monster(20).f_eigenschaft7 = 15;
		a_monster(20).f_eigenschaft8 = 45;
		a_monster(21).f_name[2] = "Hobgoblin";
		a_monster(21).f_name[1] = "Hobgoblin";
		a_monster(21).f_name[3] = "Duende Goblin";
		a_monster(21).f_nr = 87;
		a_monster(21).f_art = 2;
		a_monster(21).f_lebenspunkte = 14;
		a_monster(21).f_angriff = 4;
		a_monster(21).f_abwehr = 1;
		a_monster(21).f_staerke = 6;
		a_monster(21).f_ruestung = 1;
		a_monster(21).f_zauberkraft = 0;
		a_monster(21).f_zauber = 0;
		a_monster(21).f_reichweite = 0;
		a_monster(21).f_minlevel = 6;
		a_monster(21).f_eigenschaft1 = 2;
		a_monster(21).f_eigenschaft2 = 4;
		a_monster(21).f_eigenschaft3 = 8;
		a_monster(21).f_eigenschaft4 = 9;
		a_monster(21).f_eigenschaft5 = 26;
		a_monster(21).f_eigenschaft6 = 29;
		a_monster(21).f_eigenschaft7 = 33;
		a_monster(22).f_name[2] = "Riesentausendfssler";
		a_monster(22).f_name[1] = "Giant Centipede";
		a_monster(22).f_name[3] = "Cienpies Gigante";
		a_monster(22).f_nr = 11;
		a_monster(22).f_art = 1;
		a_monster(22).f_lebenspunkte = 12;
		a_monster(22).f_angriff = 4;
		a_monster(22).f_abwehr = 2;
		a_monster(22).f_staerke = 5;
		a_monster(22).f_ruestung = 3;
		a_monster(22).f_zauberkraft = 0;
		a_monster(22).f_zauber = 0;
		a_monster(22).f_reichweite = 0;
		a_monster(22).f_minlevel = 6;
		a_monster(22).f_eigenschaft1 = 2;
		a_monster(22).f_eigenschaft2 = 3;
		a_monster(22).f_eigenschaft3 = 8;
		a_monster(22).f_eigenschaft4 = 29;
		a_monster(23).f_name[2] = "Schleimklumpen";
		a_monster(23).f_name[1] = "Glob";
		a_monster(23).f_name[3] = "Glob";
		a_monster(23).f_nr = 18;
		a_monster(23).f_art = 3;
		a_monster(23).f_lebenspunkte = 25;
		a_monster(23).f_angriff = 2;
		a_monster(23).f_abwehr = 2;
		a_monster(23).f_staerke = 5;
		a_monster(23).f_ruestung = 0;
		a_monster(23).f_zauberkraft = 0;
		a_monster(23).f_zauber = 0;
		a_monster(23).f_reichweite = 0;
		a_monster(23).f_minlevel = 6;
		a_monster(23).f_eigenschaft1 = 6;
		a_monster(24).f_name[2] = "Stachelratte";
		a_monster(24).f_name[1] = "Horned Rat";
		a_monster(24).f_name[3] = "Rata Cornuda";
		a_monster(24).f_nr = 7;
		a_monster(24).f_art = 1;
		a_monster(24).f_lebenspunkte = 10;
		a_monster(24).f_angriff = 6;
		a_monster(24).f_abwehr = 2;
		a_monster(24).f_staerke = 5;
		a_monster(24).f_ruestung = 1;
		a_monster(24).f_zauberkraft = 0;
		a_monster(24).f_zauber = 0;
		a_monster(24).f_reichweite = 0;
		a_monster(24).f_minlevel = 7;
		a_monster(24).f_sound = 45;
		a_monster(24).f_eigenschaft1 = 2;
		a_monster(24).f_eigenschaft2 = 8;
		a_monster(24).f_eigenschaft3 = 29;
		a_monster(24).f_eigenschaft4 = 35;
		a_monster(25).f_name[2] = "Gelatinekubus";
		a_monster(25).f_name[1] = "Gelatinous Cube";
		a_monster(25).f_name[3] = "Cubo Gelatinoso";
		a_monster(25).f_nr = 2;
		a_monster(25).f_art = 6;
		a_monster(25).f_lebenspunkte = 30;
		a_monster(25).f_angriff = 0;
		a_monster(25).f_abwehr = 0;
		a_monster(25).f_staerke = 2;
		a_monster(25).f_ruestung = 0;
		a_monster(25).f_zauberkraft = 0;
		a_monster(25).f_zauber = 0;
		a_monster(25).f_reichweite = 0;
		a_monster(25).f_minlevel = 7;
		a_monster(25).f_eigenschaft1 = 16;
		a_monster(26).f_name[2] = "Gespenst";
		a_monster(26).f_name[1] = "Wraith";
		a_monster(26).f_name[3] = "Espiritu";
		a_monster(26).f_nr = 27;
		a_monster(26).f_art = 10;
		a_monster(26).f_lebenspunkte = 1;
		a_monster(26).f_angriff = 3;
		a_monster(26).f_abwehr = 3;
		a_monster(26).f_staerke = 3;
		a_monster(26).f_ruestung = 0;
		a_monster(26).f_zauberkraft = 0;
		a_monster(26).f_zauber = 0;
		a_monster(26).f_reichweite = 0;
		a_monster(26).f_minlevel = 7;
		a_monster(26).f_eigenschaft1 = 17;
		a_monster(26).f_eigenschaft2 = 18;
		a_monster(26).f_eigenschaft3 = 7;
		a_monster(27).f_name[2] = "Oger";
		a_monster(27).f_name[1] = "Ogre";
		a_monster(27).f_name[3] = "Ogro";
		a_monster(27).f_nr = 80;
		a_monster(27).f_art = 2;
		a_monster(27).f_lebenspunkte = 18;
		a_monster(27).f_angriff = 5;
		a_monster(27).f_abwehr = 1;
		a_monster(27).f_staerke = 7;
		a_monster(27).f_ruestung = 1;
		a_monster(27).f_zauberkraft = 0;
		a_monster(27).f_zauber = 0;
		a_monster(27).f_reichweite = 0;
		a_monster(27).f_minlevel = 8;
		a_monster(27).f_eigenschaft1 = 8;
		a_monster(27).f_eigenschaft2 = 9;
		a_monster(27).f_eigenschaft3 = 26;
		a_monster(27).f_eigenschaft4 = 29;
		a_monster(27).f_eigenschaft5 = 33;
		a_monster(28).f_name[2] = "Riesenmoskito";
		a_monster(28).f_name[1] = "Giant Mosquito";
		a_monster(28).f_name[3] = "Mosquito Gigante";
		a_monster(28).f_nr = 12;
		a_monster(28).f_art = 1;
		a_monster(28).f_lebenspunkte = 5;
		a_monster(28).f_angriff = 8;
		a_monster(28).f_abwehr = 4;
		a_monster(28).f_staerke = 3;
		a_monster(28).f_ruestung = 0;
		a_monster(28).f_zauberkraft = 0;
		a_monster(28).f_zauber = 0;
		a_monster(28).f_reichweite = 0;
		a_monster(28).f_minlevel = 8;
		a_monster(28).f_eigenschaft1 = 1;
		a_monster(28).f_eigenschaft2 = 8;
		a_monster(28).f_eigenschaft3 = 6;
		a_monster(28).f_eigenschaft4 = 29;
		a_monster(28).f_eigenschaft5 = 44;
		a_monster(29).f_name[2] = "Unsichtbarer Schleicher";
		a_monster(29).f_name[1] = "Invisible Stalker";
		a_monster(29).f_name[3] = "Tallador Invisible";
		a_monster(29).f_nr = 77;
		a_monster(29).f_art = 10;
		a_monster(29).f_lebenspunkte = 3;
		a_monster(29).f_angriff = 7;
		a_monster(29).f_abwehr = 1;
		a_monster(29).f_staerke = 4;
		a_monster(29).f_ruestung = 0;
		a_monster(29).f_zauberkraft = 0;
		a_monster(29).f_zauber = 0;
		a_monster(29).f_reichweite = 0;
		a_monster(29).f_minlevel = 8;
		a_monster(29).f_eigenschaft1 = 19;
		a_monster(30).f_name[2] = "Killerfrosch";
		a_monster(30).f_name[1] = "Killer Frog";
		a_monster(30).f_name[3] = "Rana Asesina";
		a_monster(30).f_nr = 17;
		a_monster(30).f_art = 1;
		a_monster(28).f_lebenspunkte = 8;
		a_monster(30).f_angriff = 5;
		a_monster(30).f_abwehr = 1;
		a_monster(30).f_staerke = 5;
		a_monster(30).f_ruestung = 0;
		a_monster(30).f_zauberkraft = 0;
		a_monster(30).f_zauber = 0;
		a_monster(30).f_reichweite = 0;
		a_monster(30).f_minlevel = 9;
		a_monster(30).f_sound = 33;
		a_monster(30).f_eigenschaft1 = 8;
		a_monster(30).f_eigenschaft2 = 29;
		a_monster(31).f_name[2] = "S\357\277\275elzahntiger";
		a_monster(31).f_name[1] = "Sabertooth Tiger";
		a_monster(31).f_name[3] = "Tigre Dientes de Sable";
		a_monster(31).f_nr = 75;
		a_monster(31).f_art = 1;
		a_monster(31).f_lebenspunkte = 17;
		a_monster(31).f_angriff = 7;
		a_monster(31).f_abwehr = 4;
		a_monster(31).f_staerke = 6;
		a_monster(31).f_ruestung = 1;
		a_monster(31).f_zauberkraft = 0;
		a_monster(31).f_zauber = 0;
		a_monster(31).f_reichweite = 0;
		a_monster(31).f_minlevel = 9;
		a_monster(31).f_sound = 35;
		a_monster(31).f_eigenschaft1 = 29;
		a_monster(31).f_eigenschaft2 = 38;
		a_monster(32).f_name[2] = "Magma Echse";
		a_monster(32).f_name[1] = "Magma Lizard";
		a_monster(32).f_name[3] = "Lagarto de Magma";
		a_monster(32).f_nr = 20;
		a_monster(32).f_art = 1;
		a_monster(32).f_lebenspunkte = 11;
		a_monster(32).f_angriff = 5;
		a_monster(32).f_abwehr = 2;
		a_monster(32).f_staerke = 5;
		a_monster(32).f_ruestung = 1;
		a_monster(32).f_zauberkraft = 0;
		a_monster(32).f_zauber = 0;
		a_monster(32).f_reichweite = 3;
		a_monster(32).f_minlevel = 9;
		a_monster(32).f_eigenschaft1 = 20;
		a_monster(32).f_eigenschaft2 = 12;
		a_monster(32).f_eigenschaft3 = 8;
		a_monster(32).f_eigenschaft4 = 29;
		a_monster(32).f_eigenschaft5 = 39;
		a_monster(32).f_eigenschaft6 = 42;
		a_monster(33).f_name[2] = "Skelettritter";
		a_monster(33).f_name[1] = "Undead Knight";
		a_monster(33).f_name[3] = "Guerrero No Muerto";
		a_monster(33).f_nr = 22;
		a_monster(33).f_art = 3;
		a_monster(33).f_lebenspunkte = 7;
		a_monster(33).f_angriff = 9;
		a_monster(33).f_abwehr = 2;
		a_monster(33).f_staerke = 5;
		a_monster(33).f_ruestung = 5;
		a_monster(33).f_zauberkraft = 0;
		a_monster(33).f_zauber = 0;
		a_monster(33).f_reichweite = 0;
		a_monster(33).f_minlevel = 10;
		a_monster(33).f_sound = 45;
		a_monster(33).f_eigenschaft1 = 7;
		a_monster(33).f_eigenschaft2 = 34;
		a_monster(34).f_name[2] = "Ninja";
		a_monster(34).f_name[1] = "Ninja";
		a_monster(34).f_name[3] = "Ninja";
		a_monster(34).f_nr = 36;
		a_monster(34).f_art = 2;
		a_monster(34).f_lebenspunkte = 3;
		a_monster(34).f_angriff = 12;
		a_monster(34).f_abwehr = 10;
		a_monster(34).f_staerke = 3;
		a_monster(34).f_ruestung = 0;
		a_monster(34).f_zauberkraft = 0;
		a_monster(34).f_zauber = 0;
		a_monster(34).f_reichweite = 0;
		a_monster(34).f_minlevel = 10;
		a_monster(34).f_eigenschaft1 = 3;
		a_monster(34).f_eigenschaft2 = 2;
		a_monster(34).f_eigenschaft3 = 8;
		a_monster(34).f_eigenschaft4 = 9;
		a_monster(34).f_eigenschaft5 = 29;
		a_monster(35).f_name[2] = "Purpurwurm";
		a_monster(35).f_name[1] = "Purple Worm";
		a_monster(35).f_name[3] = "Gusano Purpura";
		a_monster(35).f_nr = 10;
		a_monster(35).f_art = 1;
		a_monster(35).f_lebenspunkte = 22;
		a_monster(35).f_angriff = 7;
		a_monster(35).f_abwehr = 0;
		a_monster(35).f_staerke = 5;
		a_monster(35).f_ruestung = 3;
		a_monster(35).f_zauberkraft = 0;
		a_monster(35).f_zauber = 0;
		a_monster(35).f_reichweite = 0;
		a_monster(35).f_minlevel = 10;
		a_monster(35).f_eigenschaft1 = 29;
		a_monster(35).f_eigenschaft2 = 42;
		a_monster(36).f_name[2] = "Riesenskorpion";
		a_monster(36).f_name[1] = "Giant Scorpion";
		a_monster(36).f_name[3] = "Escorpion Gigante";
		a_monster(36).f_nr = 14;
		a_monster(36).f_art = 1;
		a_monster(36).f_lebenspunkte = 12;
		a_monster(36).f_angriff = 11;
		a_monster(36).f_abwehr = 4;
		a_monster(36).f_staerke = 5;
		a_monster(36).f_ruestung = 4;
		a_monster(36).f_zauberkraft = 0;
		a_monster(36).f_zauber = 0;
		a_monster(36).f_reichweite = 0;
		a_monster(36).f_minlevel = 11;
		a_monster(36).f_eigenschaft1 = 3;
		a_monster(36).f_eigenschaft2 = 8;
		a_monster(36).f_eigenschaft3 = 29;
		a_monster(37).f_name[2] = "Hexe";
		a_monster(37).f_name[1] = "Witch";
		a_monster(37).f_name[3] = "Bruja";
		a_monster(37).f_nr = 74;
		a_monster(37).f_art = 2;
		a_monster(37).f_lebenspunkte = 7;
		a_monster(37).f_angriff = 0;
		a_monster(37).f_abwehr = 0;
		a_monster(37).f_staerke = 1;
		a_monster(37).f_ruestung = 0;
		a_monster(37).f_zauberkraft = 3;
		a_monster(37).f_zauber = 2;
		a_monster(37).f_reichweite = 7;
		a_monster(37).f_minlevel = 11;
		a_monster(37).f_eigenschaft1 = 4;
		a_monster(37).f_eigenschaft2 = 8;
		a_monster(37).f_eigenschaft3 = 9;
		a_monster(37).f_eigenschaft4 = 25;
		a_monster(37).f_eigenschaft5 = 27;
		a_monster(37).f_eigenschaft6 = 29;
		a_monster(38).f_name[2] = "Riesenkrake";
		a_monster(38).f_name[1] = "Giant Octopus";
		a_monster(38).f_name[3] = "Pulpo Gigante";
		a_monster(38).f_nr = 96;
		a_monster(38).f_art = 1;
		a_monster(38).f_lebenspunkte = 20;
		a_monster(38).f_angriff = 8;
		a_monster(38).f_abwehr = 4;
		a_monster(38).f_staerke = 7;
		a_monster(38).f_ruestung = 3;
		a_monster(38).f_zauberkraft = 0;
		a_monster(38).f_zauber = 0;
		a_monster(38).f_minlevel = 9;
		a_monster(38).f_eigenschaft1 = 9;
		a_monster(38).f_eigenschaft2 = 29;
		a_monster(38).f_eigenschaft3 = 30;
		a_monster(39).f_name[2] = "Zentaur";
		a_monster(39).f_name[1] = "Centaur";
		a_monster(39).f_name[3] = "Centauro";
		a_monster(39).f_nr = 58;
		a_monster(39).f_art = 2;
		a_monster(39).f_lebenspunkte = 12;
		a_monster(39).f_angriff = 7;
		a_monster(39).f_abwehr = 7;
		a_monster(39).f_staerke = 5;
		a_monster(39).f_ruestung = 1;
		a_monster(39).f_zauberkraft = 0;
		a_monster(39).f_zauber = 0;
		a_monster(39).f_reichweite = 10;
		a_monster(39).f_minlevel = 12;
		a_monster(39).f_sound = 39;
		a_monster(39).f_eigenschaft1 = 5;
		a_monster(39).f_eigenschaft2 = 2;
		a_monster(39).f_eigenschaft3 = 4;
		a_monster(39).f_eigenschaft4 = 8;
		a_monster(39).f_eigenschaft5 = 9;
		a_monster(39).f_eigenschaft6 = 26;
		a_monster(39).f_eigenschaft7 = 29;
		a_monster(40).f_name[2] = "Schatten";
		a_monster(40).f_name[1] = "Shadow";
		a_monster(40).f_name[3] = "Sombra";
		a_monster(40).f_nr = 26;
		a_monster(40).f_art = 10;
		a_monster(40).f_lebenspunkte = 5;
		a_monster(40).f_angriff = 3;
		a_monster(40).f_abwehr = 8;
		a_monster(40).f_staerke = 4;
		a_monster(40).f_ruestung = 0;
		a_monster(40).f_zauberkraft = 0;
		a_monster(40).f_zauber = 0;
		a_monster(40).f_minlevel = 12;
		a_monster(40).f_eigenschaft1 = 17;
		a_monster(40).f_eigenschaft2 = 18;
		a_monster(40).f_eigenschaft3 = 7;
		a_monster(40).f_eigenschaft4 = 15;
		a_monster(41).f_name[2] = "Nekromant";
		a_monster(41).f_name[1] = "Necromancer";
		a_monster(41).f_name[3] = "Nigromante";
		a_monster(41).f_nr = 51;
		a_monster(41).f_art = 3;
		a_monster(41).f_lebenspunkte = 15;
		a_monster(41).f_angriff = 2;
		a_monster(41).f_abwehr = 2;
		a_monster(41).f_staerke = 3;
		a_monster(41).f_ruestung = 2;
		a_monster(41).f_zauberkraft = 5;
		a_monster(41).f_zauber = 4;
		a_monster(41).f_reichweite = 7;
		a_monster(41).f_minlevel = 12;
		a_monster(41).f_eigenschaft1 = 4;
		a_monster(41).f_eigenschaft2 = 15;
		a_monster(41).f_eigenschaft3 = 27;
		a_monster(41).f_eigenschaft4 = 29;
		a_monster(42).f_name[2] = "Mumie";
		a_monster(42).f_name[1] = "Mummy";
		a_monster(42).f_name[3] = "Momia";
		a_monster(42).f_nr = 66;
		a_monster(42).f_art = 3;
		a_monster(42).f_lebenspunkte = 28;
		a_monster(42).f_angriff = 4;
		a_monster(42).f_abwehr = 2;
		a_monster(42).f_staerke = 7;
		a_monster(42).f_ruestung = 1;
		a_monster(42).f_zauberkraft = 0;
		a_monster(42).f_zauber = 0;
		a_monster(42).f_reichweite = 0;
		a_monster(42).f_minlevel = 13;
		a_monster(42).f_sound = 45;
		a_monster(42).f_eigenschaft1 = 7;
		a_monster(42).f_eigenschaft2 = 11;
		a_monster(42).f_eigenschaft3 = 28;
		a_monster(42).f_eigenschaft4 = 34;
		a_monster(42).f_eigenschaft5 = 44;
		a_monster(43).f_name[2] = "Succubus";
		a_monster(43).f_name[1] = "Succubus";
		a_monster(43).f_name[3] = "Scubo";
		a_monster(43).f_nr = 96;
		a_monster(43).f_art = 2;
		a_monster(43).f_lebenspunkte = 12;
		a_monster(43).f_angriff = 5;
		a_monster(43).f_abwehr = 8;
		a_monster(43).f_staerke = 4;
		a_monster(43).f_ruestung = 1;
		a_monster(43).f_zauberkraft = 0;
		a_monster(43).f_zauber = 0;
		a_monster(43).f_reichweite = 0;
		a_monster(43).f_minlevel = 13;
		a_monster(43).f_eigenschaft1 = 1;
		a_monster(43).f_eigenschaft2 = 3;
		a_monster(43).f_eigenschaft3 = 2;
		a_monster(43).f_eigenschaft4 = 8;
		a_monster(43).f_eigenschaft5 = 10;
		a_monster(43).f_eigenschaft6 = 14;
		a_monster(43).f_eigenschaft7 = 28;
		a_monster(43).f_eigenschaft8 = 30;
		a_monster(44).f_name[2] = "Skelettmagier";
		a_monster(44).f_name[1] = "Lich";
		a_monster(44).f_name[3] = "Mago Esqueleto";
		a_monster(44).f_nr = 24;
		a_monster(44).f_art = 3;
		a_monster(44).f_lebenspunkte = 25;
		a_monster(44).f_angriff = 5;
		a_monster(44).f_abwehr = 2;
		a_monster(44).f_staerke = 7;
		a_monster(44).f_ruestung = 4;
		a_monster(44).f_zauberkraft = 7;
		a_monster(44).f_zauber = 1;
		a_monster(44).f_reichweite = 8;
		a_monster(44).f_minlevel = 13;
		a_monster(44).f_eigenschaft1 = 7;
		a_monster(44).f_eigenschaft2 = 34;
		a_monster(45).f_name[2] = "Betrachter";
		a_monster(45).f_name[1] = "Beholder";
		a_monster(45).f_name[3] = "Observador";
		a_monster(45).f_nr = 5;
		a_monster(45).f_art = 6;
		a_monster(45).f_lebenspunkte = 21;
		a_monster(45).f_angriff = 4;
		a_monster(45).f_abwehr = 7;
		a_monster(45).f_staerke = 4;
		a_monster(45).f_ruestung = 1;
		a_monster(45).f_zauberkraft = 0;
		a_monster(45).f_zauber = 0;
		a_monster(45).f_reichweite = 5;
		a_monster(45).f_minlevel = 14;
		a_monster(45).f_eigenschaft1 = 3;
		a_monster(45).f_eigenschaft2 = 21;
		a_monster(45).f_eigenschaft3 = 2;
		a_monster(45).f_eigenschaft4 = 1;
		a_monster(45).f_eigenschaft5 = 8;
		a_monster(45).f_eigenschaft6 = 29;
		a_monster(46).f_name[2] = "Tarantel";
		a_monster(46).f_name[1] = "Tarantula";
		a_monster(46).f_name[3] = "Tarantula";
		a_monster(46).f_nr = 100;
		a_monster(46).f_art = 1;
		a_monster(46).f_lebenspunkte = 15;
		a_monster(46).f_angriff = 8;
		a_monster(46).f_abwehr = 4;
		a_monster(46).f_staerke = 5;
		a_monster(46).f_ruestung = 1;
		a_monster(46).f_zauberkraft = 0;
		a_monster(46).f_zauber = 0;
		a_monster(46).f_reichweite = 0;
		a_monster(46).f_minlevel = 14;
		a_monster(46).f_eigenschaft1 = 3;
		a_monster(46).f_eigenschaft2 = 2;
		a_monster(46).f_eigenschaft3 = 11;
		a_monster(46).f_eigenschaft4 = 29;
		a_monster(47).f_name[2] = "Phantom";
		a_monster(47).f_name[1] = "Phantom";
		a_monster(47).f_name[3] = "Fantasma";
		a_monster(47).f_nr = 39;
		a_monster(47).f_art = 10;
		a_monster(47).f_lebenspunkte = 20;
		a_monster(47).f_angriff = 7;
		a_monster(47).f_abwehr = 3;
		a_monster(47).f_staerke = 5;
		a_monster(47).f_ruestung = 2;
		a_monster(47).f_zauberkraft = 0;
		a_monster(47).f_zauber = 0;
		a_monster(47).f_reichweite = 0;
		a_monster(47).f_minlevel = 14;
		a_monster(47).f_sound = 45;
		a_monster(47).f_eigenschaft1 = 17;
		a_monster(47).f_eigenschaft2 = 3;
		a_monster(47).f_eigenschaft3 = 18;
		a_monster(47).f_eigenschaft4 = 7;
		a_monster(47).f_eigenschaft5 = 13;
		a_monster(47).f_eigenschaft6 = 15;
		a_monster(48).f_name[2] = "Wasserdrache";
		a_monster(48).f_name[1] = "Water Dragon";
		a_monster(48).f_name[3] = "Dragon de Agua";
		a_monster(48).f_nr = 15;
		a_monster(48).f_art = 8;
		a_monster(48).f_lebenspunkte = 50;
		a_monster(48).f_angriff = 9;
		a_monster(48).f_abwehr = 9;
		a_monster(48).f_staerke = 9;
		a_monster(48).f_ruestung = 9;
		a_monster(48).f_zauberkraft = 0;
		a_monster(48).f_zauber = 0;
		a_monster(48).f_reichweite = 5;
		a_monster(48).f_minlevel = 15;
		a_monster(48).f_sound = 44;
		a_monster(48).f_eigenschaft1 = 20;
		a_monster(48).f_eigenschaft2 = 1;
		a_monster(48).f_eigenschaft3 = 25;
		a_monster(48).f_eigenschaft4 = 30;
		a_monster(49).f_name[2] = "Gorgone";
		a_monster(49).f_name[1] = "Gorgon";
		a_monster(49).f_name[3] = "Gorgona";
		a_monster(49).f_nr = 30;
		a_monster(49).f_art = 1;
		a_monster(49).f_lebenspunkte = 15;
		a_monster(49).f_angriff = 3;
		a_monster(49).f_abwehr = 5;
		a_monster(49).f_staerke = 4;
		a_monster(49).f_ruestung = 1;
		a_monster(49).f_zauberkraft = 0;
		a_monster(49).f_zauber = 0;
		a_monster(49).f_reichweite = 6;
		a_monster(49).f_minlevel = 15;
		a_monster(49).f_eigenschaft1 = 3;
		a_monster(49).f_eigenschaft2 = 8;
		a_monster(49).f_eigenschaft3 = 22;
		a_monster(49).f_eigenschaft4 = 29;
		a_monster(50).f_name[2] = "Schwarzer Magier";
		a_monster(50).f_name[1] = "Black Magician";
		a_monster(50).f_name[3] = "Mago Negro";
		a_monster(50).f_nr = 52;
		a_monster(50).f_art = 2;
		a_monster(50).f_lebenspunkte = 8;
		a_monster(50).f_angriff = 3;
		a_monster(50).f_abwehr = 2;
		a_monster(50).f_staerke = 1;
		a_monster(50).f_ruestung = 1;
		a_monster(50).f_zauberkraft = 12;
		a_monster(50).f_zauber = 5;
		a_monster(50).f_reichweite = 9;
		a_monster(50).f_minlevel = 15;
		a_monster(50).f_eigenschaft1 = 4;
		a_monster(50).f_eigenschaft2 = 15;
		a_monster(50).f_eigenschaft3 = 27;
		a_monster(50).f_eigenschaft4 = 29;
		a_monster(51).f_name[2] = "Steingolem";
		a_monster(51).f_name[1] = "Stone Golem";
		a_monster(51).f_name[3] = "Golem de Piedra";
		a_monster(51).f_nr = 28;
		a_monster(51).f_art = 9;
		a_monster(51).f_lebenspunkte = 60;
		a_monster(51).f_angriff = 4;
		a_monster(51).f_abwehr = 2;
		a_monster(51).f_staerke = 8;
		a_monster(51).f_ruestung = 10;
		a_monster(51).f_zauberkraft = 0;
		a_monster(51).f_zauber = 0;
		a_monster(51).f_reichweite = 0;
		a_monster(51).f_minlevel = 16;
		a_monster(51).f_sound = 38;
		a_monster(51).f_eigenschaft1 = 7;
		a_monster(51).f_eigenschaft2 = 13;
		a_monster(51).f_eigenschaft3 = 25;
		a_monster(51).f_eigenschaft4 = 28;
		a_monster(51).f_eigenschaft5 = 40;
		a_monster(52).f_name[2] = "Greif";
		a_monster(52).f_name[1] = "Gryphon";
		a_monster(52).f_name[3] = "Grifo";
		a_monster(52).f_nr = 8;
		a_monster(52).f_art = 1;
		a_monster(52).f_lebenspunkte = 30;
		a_monster(52).f_angriff = 15;
		a_monster(52).f_abwehr = 5;
		a_monster(52).f_staerke = 7;
		a_monster(52).f_ruestung = 1;
		a_monster(52).f_zauberkraft = 0;
		a_monster(52).f_zauber = 0;
		a_monster(52).f_reichweite = 0;
		a_monster(52).f_minlevel = 16;
		a_monster(52).f_eigenschaft1 = 1;
		a_monster(52).f_eigenschaft2 = 29;
		a_monster(53).f_name[2] = "Ph\357\277\275ix";
		a_monster(53).f_name[1] = "Ph\357\277\275ix";
		a_monster(53).f_name[3] = "Fenix";
		a_monster(53).f_nr = 64;
		a_monster(53).f_art = 1;
		a_monster(53).f_lebenspunkte = 8;
		a_monster(53).f_angriff = 24;
		a_monster(53).f_abwehr = 18;
		a_monster(53).f_staerke = 21;
		a_monster(53).f_ruestung = 0;
		a_monster(53).f_zauberkraft = 0;
		a_monster(53).f_zauber = 0;
		a_monster(53).f_reichweite = 0;
		a_monster(53).f_minlevel = 16;
		a_monster(53).f_eigenschaft1 = 12;
		a_monster(53).f_eigenschaft2 = 1;
		a_monster(53).f_eigenschaft3 = 7;
		a_monster(53).f_eigenschaft4 = 13;
		a_monster(53).f_eigenschaft5 = 29;
		a_monster(53).f_eigenschaft6 = 39;
		a_monster(53).f_eigenschaft7 = 42;
		a_monster(54).f_name[2] = "Grabesschatten";
		a_monster(54).f_name[1] = "Tomb Shadow";
		a_monster(54).f_name[3] = "Sombra de Tumba";
		a_monster(54).f_nr = 43;
		a_monster(54).f_art = 10;
		a_monster(54).f_lebenspunkte = 16;
		a_monster(54).f_angriff = 8;
		a_monster(54).f_abwehr = 2;
		a_monster(54).f_staerke = 5;
		a_monster(54).f_ruestung = 5;
		a_monster(54).f_zauberkraft = 0;
		a_monster(54).f_zauber = 0;
		a_monster(54).f_reichweite = 0;
		a_monster(54).f_minlevel = 17;
		a_monster(54).f_eigenschaft1 = 17;
		a_monster(54).f_eigenschaft2 = 3;
		a_monster(54).f_eigenschaft3 = 18;
		a_monster(54).f_eigenschaft4 = 7;
		a_monster(54).f_eigenschaft5 = 19;
		a_monster(54).f_eigenschaft6 = 15;
		a_monster(55).f_name[2] = "Lamia";
		a_monster(55).f_name[1] = "Lamia";
		a_monster(55).f_name[3] = "Lamia";
		a_monster(55).f_nr = 83;
		a_monster(55).f_art = 2;
		a_monster(55).f_lebenspunkte = 18;
		a_monster(55).f_angriff = 9;
		a_monster(55).f_abwehr = 6;
		a_monster(55).f_staerke = 5;
		a_monster(55).f_ruestung = 2;
		a_monster(55).f_zauberkraft = 0;
		a_monster(55).f_zauber = 0;
		a_monster(55).f_reichweite = 7;
		a_monster(55).f_minlevel = 17;
		a_monster(55).f_sound = 43;
		a_monster(55).f_eigenschaft1 = 3;
		a_monster(55).f_eigenschaft2 = 4;
		a_monster(55).f_eigenschaft3 = 8;
		a_monster(55).f_eigenschaft4 = 9;
		a_monster(55).f_eigenschaft5 = 16;
		a_monster(55).f_eigenschaft6 = 13;
		a_monster(55).f_eigenschaft7 = 22;
		a_monster(56).f_name[2] = "Feuerd\357\277\275on";
		a_monster(56).f_name[1] = "Fire Demon";
		a_monster(56).f_name[3] = "Demonio de Fuego";
		a_monster(56).f_nr = 29;
		a_monster(56).f_art = 3;
		a_monster(56).f_lebenspunkte = 30;
		a_monster(56).f_angriff = 12;
		a_monster(56).f_abwehr = 2;
		a_monster(56).f_staerke = 12;
		a_monster(56).f_ruestung = 2;
		a_monster(56).f_zauberkraft = 0;
		a_monster(56).f_zauber = 0;
		a_monster(56).f_reichweite = 0;
		a_monster(56).f_minlevel = 17;
		a_monster(56).f_eigenschaft1 = 12;
		a_monster(56).f_eigenschaft2 = 7;
		a_monster(56).f_eigenschaft3 = 13;
		a_monster(56).f_eigenschaft4 = 40;
		a_monster(56).f_eigenschaft5 = 42;
		a_monster(57).f_name[2] = "Eisd\357\277\275on";
		a_monster(57).f_name[1] = "Frost Demon";
		a_monster(57).f_name[3] = "Demonio de Hielo";
		a_monster(57).f_nr = 16;
		a_monster(57).f_art = 7;
		a_monster(57).f_lebenspunkte = 40;
		a_monster(57).f_angriff = 10;
		a_monster(57).f_abwehr = 6;
		a_monster(57).f_staerke = 10;
		a_monster(57).f_ruestung = 6;
		a_monster(57).f_zauberkraft = 0;
		a_monster(57).f_zauber = 0;
		a_monster(57).f_reichweite = 4;
		a_monster(57).f_minlevel = 18;
		a_monster(57).f_eigenschaft1 = 11;
		a_monster(57).f_eigenschaft2 = 23;
		a_monster(57).f_eigenschaft3 = 18;
		a_monster(57).f_eigenschaft4 = 13;
		a_monster(58).f_name[2] = "Sturmd\357\277\275on";
		a_monster(58).f_name[1] = "Storm Demon";
		a_monster(58).f_name[3] = "Demonio de Tormenta";
		a_monster(58).f_nr = 91;
		a_monster(58).f_art = 7;
		a_monster(58).f_lebenspunkte = 25;
		a_monster(58).f_angriff = 11;
		a_monster(58).f_abwehr = 12;
		a_monster(58).f_staerke = 9;
		a_monster(58).f_ruestung = 0;
		a_monster(58).f_zauberkraft = 0;
		a_monster(58).f_zauber = 0;
		a_monster(58).f_reichweite = 0;
		a_monster(58).f_minlevel = 18;
		a_monster(58).f_eigenschaft1 = 17;
		a_monster(58).f_eigenschaft2 = 7;
		a_monster(58).f_eigenschaft3 = 14;
		a_monster(58).f_eigenschaft4 = 25;
		a_monster(58).f_eigenschaft5 = 42;
		a_monster(59).f_name[2] = "Wyvern";
		a_monster(59).f_name[1] = "Wyvern";
		a_monster(59).f_name[3] = "Wyvern";
		a_monster(59).f_nr = 95;
		a_monster(59).f_art = 1;
		a_monster(59).f_lebenspunkte = 45;
		a_monster(59).f_angriff = 13;
		a_monster(59).f_abwehr = 7;
		a_monster(59).f_staerke = 11;
		a_monster(59).f_ruestung = 5;
		a_monster(59).f_zauberkraft = 0;
		a_monster(59).f_zauber = 0;
		a_monster(59).f_reichweite = 0;
		a_monster(59).f_minlevel = 18;
		a_monster(59).f_eigenschaft1 = 3;
		a_monster(59).f_eigenschaft2 = 29;
		a_monster(60).f_name[2] = "Hydra";
		a_monster(60).f_name[1] = "Hydra";
		a_monster(60).f_name[3] = "Hidra";
		a_monster(60).f_nr = 78;
		a_monster(60).f_art = 1;
		a_monster(60).f_lebenspunkte = 60;
		a_monster(60).f_angriff = 12;
		a_monster(60).f_abwehr = 9;
		a_monster(60).f_staerke = 10;
		a_monster(60).f_ruestung = 6;
		a_monster(60).f_zauberkraft = 0;
		a_monster(60).f_zauber = 0;
		a_monster(60).f_reichweite = 0;
		a_monster(60).f_minlevel = 19;
		a_monster(60).f_sound = 44;
		a_monster(60).f_eigenschaft1 = 3;
		a_monster(60).f_eigenschaft2 = 16;
		a_monster(60).f_eigenschaft3 = 28;
		a_monster(60).f_eigenschaft4 = 39;
		a_monster(60).f_eigenschaft5 = 40;
		a_monster(61).f_name[2] = "Banshee";
		a_monster(61).f_name[1] = "Banshee";
		a_monster(61).f_name[3] = "Banshee";
		a_monster(61).f_nr = 90;
		a_monster(61).f_art = 3;
		a_monster(61).f_lebenspunkte = 50;
		a_monster(61).f_angriff = 9;
		a_monster(61).f_abwehr = 21;
		a_monster(61).f_staerke = 13;
		a_monster(61).f_ruestung = 6;
		a_monster(61).f_zauberkraft = 0;
		a_monster(61).f_zauber = 0;
		a_monster(61).f_reichweite = 5;
		a_monster(61).f_minlevel = 19;
		a_monster(61).f_sound = 43;
		a_monster(61).f_eigenschaft1 = 1;
		a_monster(61).f_eigenschaft2 = 3;
		a_monster(61).f_eigenschaft3 = 17;
		a_monster(61).f_eigenschaft4 = 7;
		a_monster(61).f_eigenschaft5 = 13;
		a_monster(61).f_eigenschaft6 = 24;
		a_monster(61).f_eigenschaft7 = 40;
		a_monster(61).f_eigenschaft8 = 45;
		a_monster(62).f_name[2] = "Grner Drache";
		a_monster(62).f_name[1] = "Green Dragon";
		a_monster(62).f_name[3] = "Dragon Verde";
		a_monster(62).f_nr = 33;
		a_monster(62).f_art = 8;
		a_monster(62).f_lebenspunkte = 75;
		a_monster(62).f_angriff = 12;
		a_monster(62).f_abwehr = 12;
		a_monster(62).f_staerke = 15;
		a_monster(62).f_ruestung = 10;
		a_monster(62).f_zauberkraft = 0;
		a_monster(62).f_zauber = 0;
		a_monster(62).f_reichweite = 6;
		a_monster(62).f_minlevel = 19;
		a_monster(62).f_sound = 44;
		a_monster(62).f_eigenschaft1 = 3;
		a_monster(62).f_eigenschaft2 = 21;
		a_monster(62).f_eigenschaft3 = 1;
		a_monster(62).f_eigenschaft4 = 27;
		a_monster(63).f_name[2] = "Roc";
		a_monster(63).f_name[1] = "Roc";
		a_monster(63).f_name[3] = "Rocho";
		a_monster(63).f_nr = 94;
		a_monster(63).f_art = 1;
		a_monster(63).f_lebenspunkte = 90;
		a_monster(63).f_angriff = 13;
		a_monster(63).f_abwehr = 11;
		a_monster(63).f_staerke = 16;
		a_monster(63).f_ruestung = 4;
		a_monster(63).f_zauberkraft = 0;
		a_monster(63).f_zauber = 0;
		a_monster(63).f_reichweite = 0;
		a_monster(63).f_minlevel = 20;
		a_monster(63).f_eigenschaft1 = 1;
		a_monster(63).f_eigenschaft2 = 29;
		a_monster(64).f_name[2] = "Blauer Drache";
		a_monster(64).f_name[1] = "Blue Dragon";
		a_monster(64).f_name[3] = "Dragon Azul";
		a_monster(64).f_nr = 34;
		a_monster(64).f_art = 8;
		a_monster(64).f_lebenspunkte = 120;
		a_monster(64).f_angriff = 13;
		a_monster(64).f_abwehr = 13;
		a_monster(64).f_staerke = 12;
		a_monster(64).f_ruestung = 11;
		a_monster(64).f_zauberkraft = 0;
		a_monster(64).f_zauber = 0;
		a_monster(64).f_reichweite = 6;
		a_monster(64).f_minlevel = 19;
		a_monster(64).f_sound = 44;
		a_monster(64).f_eigenschaft1 = 23;
		a_monster(64).f_eigenschaft2 = 1;
		a_monster(64).f_eigenschaft3 = 18;
		a_monster(64).f_eigenschaft4 = 27;
		a_monster(64).f_eigenschaft5 = 29;
		a_monster(65).f_name[2] = "Skelettdrache";
		a_monster(65).f_name[1] = "Skeleton Dragon";
		a_monster(65).f_name[3] = "Dragon Esceleto";
		a_monster(65).f_nr = 35;
		a_monster(65).f_art = 8;
		a_monster(65).f_lebenspunkte = 155;
		a_monster(65).f_angriff = 15;
		a_monster(65).f_abwehr = 7;
		a_monster(65).f_staerke = 18;
		a_monster(65).f_ruestung = 13;
		a_monster(65).f_zauberkraft = 0;
		a_monster(65).f_zauber = 0;
		a_monster(65).f_reichweite = 5;
		a_monster(65).f_minlevel = 20;
		a_monster(65).f_sound = 44;
		a_monster(65).f_eigenschaft1 = 7;
		a_monster(65).f_eigenschaft2 = 20;
		a_monster(66).f_name[2] = "Riese";
		a_monster(66).f_name[1] = "Giant";
		a_monster(66).f_name[3] = "Gigante";
		a_monster(66).f_nr = 59;
		a_monster(66).f_art = 2;
		a_monster(66).f_lebenspunkte = 200;
		a_monster(66).f_angriff = 13;
		a_monster(66).f_abwehr = 4;
		a_monster(66).f_staerke = 35;
		a_monster(66).f_ruestung = 4;
		a_monster(66).f_zauberkraft = 0;
		a_monster(66).f_zauber = 0;
		a_monster(66).f_reichweite = 0;
		a_monster(66).f_minlevel = 21;
		a_monster(66).f_eigenschaft1 = 4;
		a_monster(66).f_eigenschaft2 = 9;
		a_monster(66).f_eigenschaft3 = 13;
		a_monster(66).f_eigenschaft4 = 26;
		a_monster(66).f_eigenschaft5 = 29;
		a_monster(66).f_eigenschaft6 = 40;
		a_monster(67).f_name[2] = "Roter Drache";
		a_monster(67).f_name[1] = "Red Dragon";
		a_monster(67).f_name[3] = "Dragon Rojo";
		a_monster(67).f_nr = 88;
		a_monster(67).f_art = 8;
		a_monster(67).f_lebenspunkte = 210;
		a_monster(67).f_angriff = 20;
		a_monster(67).f_abwehr = 8;
		a_monster(67).f_staerke = 21;
		a_monster(67).f_ruestung = 11;
		a_monster(67).f_zauberkraft = 0;
		a_monster(67).f_zauber = 0;
		a_monster(67).f_reichweite = 6;
		a_monster(67).f_minlevel = 21;
		a_monster(67).f_sound = 44;
		a_monster(67).f_eigenschaft1 = 20;
		a_monster(67).f_eigenschaft2 = 1;
		a_monster(67).f_eigenschaft3 = 12;
		a_monster(67).f_eigenschaft4 = 27;
		a_monster(67).f_eigenschaft5 = 28;
		a_monster(68).f_name[2] = "Goldener Drache";
		a_monster(68).f_name[1] = "Golden Dragon";
		a_monster(68).f_name[3] = "Dragon de Oro";
		a_monster(68).f_nr = 89;
		a_monster(68).f_art = 8;
		a_monster(68).f_lebenspunkte = 270;
		a_monster(68).f_angriff = 18;
		a_monster(68).f_abwehr = 15;
		a_monster(68).f_staerke = 20;
		a_monster(68).f_ruestung = 10;
		a_monster(68).f_zauberkraft = 0;
		a_monster(68).f_zauber = 0;
		a_monster(68).f_reichweite = 7;
		a_monster(68).f_minlevel = 21;
		a_monster(68).f_sound = 44;
		a_monster(68).f_eigenschaft1 = 23;
		a_monster(68).f_eigenschaft2 = 1;
		a_monster(68).f_eigenschaft3 = 12;
		a_monster(68).f_eigenschaft4 = 27;
		a_monster(68).f_eigenschaft5 = 28;
		a_monster(69).f_name[2] = "Todesengel";
		a_monster(69).f_name[1] = "Angel of Death";
		a_monster(69).f_name[3] = "Angel de la Muerte";
		a_monster(69).f_nr = 97;
		a_monster(69).f_art = 5;
		a_monster(69).f_lebenspunkte = 1000;
		a_monster(69).f_angriff = 25;
		a_monster(69).f_abwehr = 25;
		a_monster(69).f_staerke = 25;
		a_monster(69).f_ruestung = 25;
		a_monster(69).f_zauberkraft = 0;
		a_monster(69).f_zauber = 0;
		a_monster(69).f_reichweite = 10;
		a_monster(69).f_minlevel = 25;
		a_monster(69).f_sound = 43;
		a_monster(69).f_eigenschaft1 = 1;
		a_monster(69).f_eigenschaft2 = 12;
		a_monster(69).f_eigenschaft3 = 17;
		a_monster(69).f_eigenschaft4 = 18;
		a_monster(69).f_eigenschaft5 = 7;
		a_monster(69).f_eigenschaft6 = 24;
		a_monster(69).f_eigenschaft7 = 15;
		a_monster(69).f_eigenschaft8 = 28;
		a_monster(70).f_name[2] = "Mimic";
		a_monster(70).f_name[1] = "Mimic";
		a_monster(70).f_name[3] = "Mimic";
		a_monster(70).f_nr = 101;
		a_monster(70).f_art = 1;
		a_monster(70).f_lebenspunkte = 270;
		a_monster(70).f_angriff = 18;
		a_monster(70).f_abwehr = 15;
		a_monster(70).f_staerke = 20;
		a_monster(70).f_ruestung = 10;
		a_monster(70).f_zauberkraft = 0;
		a_monster(70).f_zauber = 0;
		a_monster(70).f_reichweite = 5;
		a_monster(70).f_minlevel = 25;
		a_monster(70).f_sound = 38;
		a_monster(70).f_eigenschaft1 = 23;
		a_monster(70).f_eigenschaft2 = 1;
		a_monster(70).f_eigenschaft3 = 12;
		a_monster(71).f_name[2] = "Vogelscheuche";
		a_monster(71).f_name[1] = "Scarecrow";
		a_monster(71).f_name[3] = "Espanta Pajaros";
		a_monster(71).f_nr = 132;
		a_monster(71).f_art = 10;
		a_monster(71).f_lebenspunkte = 4;
		a_monster(71).f_angriff = 2;
		a_monster(71).f_abwehr = 0;
		a_monster(71).f_staerke = 2;
		a_monster(71).f_ruestung = 0;
		a_monster(71).f_zauberkraft = 0;
		a_monster(71).f_zauber = 0;
		a_monster(71).f_reichweite = 0;
		a_monster(71).f_minlevel = 2;
		a_monster(71).f_eigenschaft1 = 18;
		a_monster(71).f_eigenschaft2 = 7;
		a_monster(71).f_eigenschaft3 = 11;
		a_monster(72).f_name[2] = "Riesenkrabbe";
		a_monster(72).f_name[1] = "Giant Crab";
		a_monster(72).f_name[3] = "Cangrejo gigante";
		a_monster(72).f_nr = 40;
		a_monster(72).f_art = 1;
		a_monster(72).f_lebenspunkte = 5;
		a_monster(72).f_angriff = 1;
		a_monster(72).f_abwehr = 0;
		a_monster(72).f_staerke = 3;
		a_monster(72).f_ruestung = 4;
		a_monster(72).f_zauberkraft = 0;
		a_monster(72).f_zauber = 0;
		a_monster(72).f_reichweite = 0;
		a_monster(72).f_minlevel = 3;
		a_monster(72).f_eigenschaft1 = 8;
		a_monster(72).f_eigenschaft2 = 9;
		a_monster(72).f_eigenschaft3 = 29;
		a_monster(73).f_name[2] = "Wahnsinniger Magier";
		a_monster(73).f_name[1] = "Mad Magician";
		a_monster(73).f_name[3] = "Mago loco";
		a_monster(73).f_nr = 25;
		a_monster(73).f_art = 2;
		a_monster(73).f_lebenspunkte = 5;
		a_monster(73).f_angriff = 1;
		a_monster(73).f_abwehr = 0;
		a_monster(73).f_staerke = 3;
		a_monster(73).f_ruestung = 0;
		a_monster(73).f_zauberkraft = 3;
		a_monster(73).f_zauber = 5;
		a_monster(73).f_reichweite = 5;
		a_monster(73).f_minlevel = 5;
		a_monster(73).f_sound = 32;
		a_monster(73).f_eigenschaft1 = 9;
		a_monster(73).f_eigenschaft2 = 27;
		a_monster(73).f_eigenschaft3 = 29;
		a_monster(74).f_name[2] = "K\357\277\275igstausendfssler";
		a_monster(74).f_name[1] = "King Centipede";
		a_monster(74).f_name[3] = "Cienpies rey";
		a_monster(74).f_nr = 130;
		a_monster(74).f_art = 1;
		a_monster(74).f_lebenspunkte = 122;
		a_monster(74).f_angriff = 4;
		a_monster(74).f_abwehr = 2;
		a_monster(74).f_staerke = 5;
		a_monster(74).f_ruestung = 3;
		a_monster(74).f_zauberkraft = 0;
		a_monster(74).f_zauber = 0;
		a_monster(74).f_reichweite = 0;
		a_monster(74).f_minlevel = 6;
		a_monster(74).f_eigenschaft1 = 29;
		a_monster(75).f_name[2] = "Nixe";
		a_monster(75).f_name[1] = "Mermaid";
		a_monster(75).f_name[3] = "Sirena";
		a_monster(75).f_nr = 98;
		a_monster(75).f_art = 2;
		a_monster(75).f_lebenspunkte = 3;
		a_monster(75).f_angriff = 5;
		a_monster(75).f_abwehr = 5;
		a_monster(75).f_staerke = 2;
		a_monster(75).f_ruestung = 0;
		a_monster(75).f_zauberkraft = 0;
		a_monster(75).f_zauber = 0;
		a_monster(75).f_reichweite = 0;
		a_monster(75).f_minlevel = 6;
		a_monster(75).f_sound = 43;
		a_monster(75).f_eigenschaft1 = 11;
		a_monster(75).f_eigenschaft2 = 4;
		a_monster(75).f_eigenschaft3 = 8;
		a_monster(75).f_eigenschaft4 = 9;
		a_monster(75).f_eigenschaft5 = 6;
		a_monster(75).f_eigenschaft6 = 10;
		a_monster(75).f_eigenschaft7 = 29;
		a_monster(75).f_eigenschaft8 = 30;
		a_monster(76).f_name[2] = "Wasserneck";
		a_monster(76).f_name[1] = "Deep One";
		a_monster(76).f_name[3] = "Hombre de la profundidad";
		a_monster(76).f_nr = 120;
		a_monster(76).f_art = 2;
		a_monster(76).f_lebenspunkte = 6;
		a_monster(76).f_angriff = 5;
		a_monster(76).f_abwehr = 2;
		a_monster(76).f_staerke = 3;
		a_monster(76).f_ruestung = 1;
		a_monster(76).f_zauberkraft = 0;
		a_monster(76).f_zauber = 0;
		a_monster(76).f_reichweite = 0;
		a_monster(76).f_minlevel = 8;
		a_monster(76).f_eigenschaft1 = 11;
		a_monster(76).f_eigenschaft2 = 4;
		a_monster(76).f_eigenschaft3 = 8;
		a_monster(76).f_eigenschaft4 = 9;
		a_monster(76).f_eigenschaft5 = 6;
		a_monster(76).f_eigenschaft6 = 29;
		a_monster(76).f_eigenschaft7 = 30;
		a_monster(77).f_name[2] = "Kelpie";
		a_monster(77).f_name[1] = "Kelpie";
		a_monster(77).f_name[3] = "Kelpie";
		a_monster(77).f_nr = 113;
		a_monster(77).f_art = 7;
		a_monster(77).f_lebenspunkte = 27;
		a_monster(77).f_angriff = 8;
		a_monster(77).f_abwehr = 4;
		a_monster(77).f_staerke = 8;
		a_monster(77).f_ruestung = 1;
		a_monster(77).f_zauberkraft = 0;
		a_monster(77).f_zauber = 0;
		a_monster(77).f_reichweite = 0;
		a_monster(77).f_minlevel = 13;
		a_monster(77).f_sound = 39;
		a_monster(77).f_eigenschaft1 = 26;
		a_monster(77).f_eigenschaft2 = 39;
		a_monster(78).f_name[2] = "Junger Roter Drache";
		a_monster(78).f_name[1] = "Young Red Dragon";
		a_monster(78).f_name[3] = "Dragon rojo joven";
		a_monster(78).f_nr = 32;
		a_monster(78).f_art = 7;
		a_monster(78).f_lebenspunkte = 105;
		a_monster(78).f_angriff = 20;
		a_monster(78).f_abwehr = 8;
		a_monster(78).f_staerke = 21;
		a_monster(78).f_ruestung = 11;
		a_monster(78).f_zauberkraft = 0;
		a_monster(78).f_zauber = 0;
		a_monster(78).f_reichweite = 5;
		a_monster(78).f_minlevel = 21;
		a_monster(78).f_sound = 44;
		a_monster(78).f_eigenschaft1 = 20;
		a_monster(78).f_eigenschaft2 = 1;
		a_monster(78).f_eigenschaft3 = 12;
		a_monster(78).f_eigenschaft4 = 26;
		a_monster(79).f_name[2] = "Nosferatu";
		a_monster(79).f_name[1] = "Nosferatu";
		a_monster(79).f_name[3] = "Nosferatu";
		a_monster(79).f_nr = 104;
		a_monster(79).f_art = 3;
		a_monster(79).f_lebenspunkte = 250;
		a_monster(79).f_angriff = 20;
		a_monster(79).f_abwehr = 15;
		a_monster(79).f_staerke = 30;
		a_monster(79).f_ruestung = 5;
		a_monster(79).f_zauberkraft = 0;
		a_monster(79).f_zauber = 0;
		a_monster(79).f_reichweite = 5;
		a_monster(79).f_minlevel = 35;
		a_monster(79).f_eigenschaft1 = 17;
		a_monster(79).f_eigenschaft2 = 4;
		a_monster(79).f_eigenschaft3 = 16;
		a_monster(79).f_eigenschaft4 = 27;
		a_monster(80).f_name[2] = "Meisterillusionist";
		a_monster(80).f_name[1] = "Master Illusionist";
		a_monster(80).f_name[3] = "Maestro Ilusionista";
		a_monster(80).f_nr = 115;
		a_monster(80).f_art = 2;
		a_monster(80).f_lebenspunkte = 25;
		a_monster(80).f_angriff = 16;
		a_monster(80).f_abwehr = 24;
		a_monster(80).f_staerke = 3;
		a_monster(80).f_ruestung = 0;
		a_monster(80).f_zauberkraft = 15;
		a_monster(80).f_zauber = 3;
		a_monster(80).f_reichweite = 5;
		a_monster(80).f_minlevel = 45;
		a_monster(80).f_sound = 32;
		a_monster(80).f_eigenschaft1 = 2;
		a_monster(80).f_eigenschaft2 = 4;
		a_monster(80).f_eigenschaft3 = 8;
		a_monster(80).f_eigenschaft4 = 9;
		a_monster(80).f_eigenschaft5 = 10;
		a_monster(80).f_eigenschaft6 = 19;
		a_monster(80).f_eigenschaft7 = 27;
		a_monster(81).f_name[2] = "Schwebende Augen";
		a_monster(81).f_name[1] = "Floating Eyes";
		a_monster(81).f_name[3] = "Ojos volandos";
		a_monster(81).f_nr = 131;
		a_monster(81).f_art = 6;
		a_monster(81).f_lebenspunkte = 111;
		a_monster(81).f_angriff = 10;
		a_monster(81).f_abwehr = 15;
		a_monster(81).f_staerke = 12;
		a_monster(81).f_ruestung = 5;
		a_monster(81).f_zauberkraft = 20;
		a_monster(81).f_zauber = 2;
		a_monster(81).f_reichweite = 8;
		a_monster(81).f_minlevel = 55;
		a_monster(81).f_eigenschaft1 = 1;
		a_monster(81).f_eigenschaft2 = 40;
		a_monster(82).f_name[2] = "Blutschatten";
		a_monster(82).f_name[1] = "Blood Shadow";
		a_monster(82).f_name[3] = "Sombra del Sangre";
		a_monster(82).f_nr = 131;
		a_monster(82).f_art = 10;
		a_monster(82).f_lebenspunkte = 300;
		a_monster(82).f_angriff = 20;
		a_monster(82).f_abwehr = 25;
		a_monster(82).f_staerke = 40;
		a_monster(82).f_ruestung = 8;
		a_monster(82).f_zauberkraft = 10;
		a_monster(82).f_zauber = 5;
		a_monster(82).f_reichweite = 5;
		a_monster(82).f_minlevel = 65;
		a_monster(82).f_eigenschaft1 = 17;
		a_monster(82).f_eigenschaft2 = 4;
		a_monster(82).f_eigenschaft3 = 16;
		a_monster(82).f_eigenschaft4 = 40;
		a_monster(83).f_name[2] = "Gefr\357\277\275iger D\357\277\275on";
		a_monster(83).f_name[1] = "Gluttonous Demon";
		a_monster(83).f_name[3] = "Demonio hambroso";
		a_monster(83).f_nr = 114;
		a_monster(83).f_art = 7;
		a_monster(83).f_lebenspunkte = 1000;
		a_monster(83).f_angriff = 25;
		a_monster(83).f_abwehr = 10;
		a_monster(83).f_staerke = 55;
		a_monster(83).f_ruestung = 16;
		a_monster(83).f_zauberkraft = 0;
		a_monster(83).f_zauber = 0;
		a_monster(83).f_reichweite = 0;
		a_monster(83).f_minlevel = 75;
		a_monster(83).f_eigenschaft1 = 40;
		a_monster(83).f_eigenschaft2 = 44;
		a_monster(84).f_name[2] = "Bernsteingolem";
		a_monster(84).f_name[1] = "Amber Golem";
		a_monster(84).f_name[3] = "Golem de Amber";
		a_monster(84).f_nr = 103;
		a_monster(84).f_art = 9;
		a_monster(84).f_lebenspunkte = 25;
		a_monster(84).f_angriff = 10;
		a_monster(84).f_abwehr = 0;
		a_monster(84).f_staerke = 15;
		a_monster(84).f_ruestung = 50;
		a_monster(84).f_zauberkraft = 0;
		a_monster(84).f_zauber = 0;
		a_monster(84).f_reichweite = 0;
		a_monster(84).f_minlevel = 25;
		a_monster(84).f_sound = 38;
		a_monster(84).f_eigenschaft1 = 12;
		a_monster(84).f_eigenschaft2 = 18;
		a_monster(84).f_eigenschaft3 = 7;
		a_monster(84).f_eigenschaft4 = 13;
		a_monster(84).f_eigenschaft5 = 39;
		a_monster(85).f_name[2] = "Kristallgolem";
		a_monster(85).f_name[1] = "Crystal Golem";
		a_monster(85).f_name[3] = "Golem de Cristal";
		a_monster(85).f_nr = 110;
		a_monster(85).f_art = 9;
		a_monster(85).f_lebenspunkte = 50;
		a_monster(85).f_angriff = 15;
		a_monster(85).f_abwehr = 5;
		a_monster(85).f_staerke = 120;
		a_monster(85).f_ruestung = 100;
		a_monster(85).f_zauberkraft = 0;
		a_monster(85).f_zauber = 0;
		a_monster(85).f_reichweite = 0;
		a_monster(85).f_minlevel = 85;
		a_monster(85).f_sound = 38;
		a_monster(85).f_eigenschaft1 = 12;
		a_monster(85).f_eigenschaft2 = 18;
		a_monster(85).f_eigenschaft3 = 7;
		a_monster(85).f_eigenschaft4 = 13;
		a_monster(85).f_eigenschaft5 = 39;
		a_monster(86).f_name[2] = "Blitzelementar";
		a_monster(86).f_name[1] = "Lightning Elemental";
		a_monster(86).f_name[3] = "Bola de Rayos";
		a_monster(86).f_nr = 102;
		a_monster(86).f_art = 6;
		a_monster(86).f_lebenspunkte = 100;
		a_monster(86).f_angriff = 40;
		a_monster(86).f_abwehr = 40;
		a_monster(86).f_staerke = 25;
		a_monster(86).f_ruestung = 0;
		a_monster(86).f_zauberkraft = 0;
		a_monster(86).f_zauber = 0;
		a_monster(86).f_reichweite = 12;
		a_monster(86).f_minlevel = 95;
		a_monster(86).f_eigenschaft1 = 1;
		a_monster(86).f_eigenschaft2 = 12;
		a_monster(86).f_eigenschaft3 = 17;
		a_monster(86).f_eigenschaft4 = 7;
		a_monster(86).f_eigenschaft5 = 13;
		a_monster(86).f_eigenschaft6 = 14;
		a_monster(86).f_eigenschaft7 = 25;
		a_monster(86).f_eigenschaft8 = 42;
		a_monster(87).f_name[2] = "Geflgelter D\357\277\275on";
		a_monster(87).f_name[1] = "Winged Demon";
		a_monster(87).f_name[3] = "Demonio de alas";
		a_monster(87).f_nr = 105;
		a_monster(87).f_art = 7;
		a_monster(87).f_lebenspunkte = 500;
		a_monster(87).f_angriff = 25;
		a_monster(87).f_abwehr = 25;
		a_monster(87).f_staerke = 70;
		a_monster(87).f_ruestung = 10;
		a_monster(87).f_zauberkraft = 0;
		a_monster(87).f_zauber = 0;
		a_monster(87).f_reichweite = 0;
		a_monster(87).f_minlevel = 110;
		a_monster(87).f_eigenschaft1 = 1;
		a_monster(87).f_eigenschaft2 = 12;
		a_monster(87).f_eigenschaft3 = 2;
		a_monster(87).f_eigenschaft4 = 6;
		a_monster(87).f_eigenschaft5 = 26;
		a_monster(87).f_eigenschaft6 = 28;
		a_monster(88).f_name[2] = "Schattend\357\277\275on";
		a_monster(88).f_name[1] = "Shadow Demon";
		a_monster(88).f_name[3] = "Demonio de las sombras";
		a_monster(88).f_nr = 123;
		a_monster(88).f_art = 7;
		a_monster(88).f_lebenspunkte = 900;
		a_monster(88).f_angriff = 40;
		a_monster(88).f_abwehr = 60;
		a_monster(88).f_staerke = 80;
		a_monster(88).f_ruestung = 25;
		a_monster(88).f_zauberkraft = 0;
		a_monster(88).f_zauber = 0;
		a_monster(88).f_reichweite = 5;
		a_monster(88).f_minlevel = 130;
		a_monster(88).f_eigenschaft1 = 1;
		a_monster(88).f_eigenschaft2 = 17;
		a_monster(88).f_eigenschaft3 = 7;
		a_monster(88).f_eigenschaft4 = 19;
		a_monster(88).f_eigenschaft5 = 24;
		a_monster(89).f_name[2] = "Alter Skelettmagier";
		a_monster(89).f_name[1] = "Elder Lich";
		a_monster(89).f_name[3] = "Magus esqueleto viejo";
		a_monster(89).f_nr = 111;
		a_monster(89).f_art = 3;
		a_monster(89).f_lebenspunkte = 250;
		a_monster(89).f_angriff = 15;
		a_monster(89).f_abwehr = 10;
		a_monster(89).f_staerke = 12;
		a_monster(89).f_ruestung = 20;
		a_monster(89).f_zauberkraft = 30;
		a_monster(89).f_zauber = 5;
		a_monster(89).f_reichweite = 13;
		a_monster(89).f_minlevel = 140;
		a_monster(89).f_eigenschaft1 = 7;
		a_monster(89).f_eigenschaft2 = 4;
		a_monster(89).f_eigenschaft3 = 15;
		a_monster(90).f_name[2] = "Ifrit";
		a_monster(90).f_name[1] = "Efreet";
		a_monster(90).f_name[3] = "Genio magico";
		a_monster(90).f_nr = 122;
		a_monster(90).f_art = 10;
		a_monster(90).f_lebenspunkte = 2000;
		a_monster(90).f_angriff = 65;
		a_monster(90).f_abwehr = 50;
		a_monster(90).f_staerke = 250;
		a_monster(90).f_ruestung = 20;
		a_monster(90).f_zauberkraft = 0;
		a_monster(90).f_zauber = 0;
		a_monster(90).f_reichweite = 6;
		a_monster(90).f_minlevel = 145;
		a_monster(90).f_eigenschaft1 = 1;
		a_monster(90).f_eigenschaft2 = 12;
		a_monster(90).f_eigenschaft3 = 17;
		a_monster(90).f_eigenschaft4 = 20;
		a_monster(90).f_eigenschaft5 = 15;
		a_monster(90).f_eigenschaft6 = 27;
		a_monster(91).f_name[2] = "Geh\357\277\275nter D\357\277\275on";
		a_monster(91).f_name[1] = "Horned Demon";
		a_monster(91).f_name[3] = "Demonio cornudo";
		a_monster(91).f_nr = 118;
		a_monster(91).f_art = 7;
		a_monster(91).f_lebenspunkte = 1000;
		a_monster(91).f_angriff = 40;
		a_monster(91).f_abwehr = 30;
		a_monster(91).f_staerke = 90;
		a_monster(91).f_ruestung = 20;
		a_monster(91).f_zauberkraft = 0;
		a_monster(91).f_zauber = 0;
		a_monster(91).f_reichweite = 0;
		a_monster(91).f_minlevel = 148;
		a_monster(91).f_eigenschaft1 = 1;
		a_monster(91).f_eigenschaft2 = 12;
		a_monster(91).f_eigenschaft3 = 2;
		a_monster(91).f_eigenschaft4 = 6;
		a_monster(91).f_eigenschaft5 = 28;
		a_monster(92).f_name[2] = "D\357\277\275onenprinz";
		a_monster(92).f_name[1] = "Demon Prince";
		a_monster(92).f_name[3] = "Demonio Rey";
		a_monster(92).f_nr = 119;
		a_monster(92).f_art = 7;
		a_monster(92).f_lebenspunkte = 5000;
		a_monster(92).f_angriff = 90;
		a_monster(92).f_abwehr = 70;
		a_monster(92).f_staerke = 250;
		a_monster(92).f_ruestung = 90;
		a_monster(92).f_zauberkraft = 25;
		a_monster(92).f_zauber = 1;
		a_monster(92).f_reichweite = 8;
		a_monster(92).f_minlevel = 148;
		a_monster(92).f_eigenschaft1 = 1;
		a_monster(92).f_eigenschaft2 = 12;
		a_monster(92).f_eigenschaft3 = 17;
		a_monster(92).f_eigenschaft4 = 27;
		a_monster(92).f_eigenschaft5 = 28;
		a_monster(92).f_eigenschaft6 = 45;
		a_monster(93).f_name[2] = "Lichlord";
		a_monster(93).f_name[1] = "Lich Lord";
		a_monster(93).f_name[3] = "Rey Nomuerto";
		a_monster(93).f_nr = 125;
		a_monster(93).f_art = 3;
		a_monster(93).f_lebenspunkte = 1000;
		a_monster(93).f_angriff = 25;
		a_monster(93).f_abwehr = 20;
		a_monster(93).f_staerke = 30;
		a_monster(93).f_ruestung = 20;
		a_monster(93).f_zauberkraft = 50;
		a_monster(93).f_zauber = 5;
		a_monster(93).f_reichweite = 12;
		a_monster(93).f_minlevel = 148;
		a_monster(93).f_eigenschaft1 = 7;
		a_monster(93).f_eigenschaft2 = 4;
		a_monster(93).f_eigenschaft3 = 15;
		a_monster(93).f_eigenschaft4 = 27;
		a_monster(93).f_eigenschaft5 = 28;
		a_monster(93).f_eigenschaft6 = 44;
		a_monster(94).f_name[2] = "K\357\277\275er";
		a_monster(94).f_name[1] = "Bug";
		a_monster(94).f_name[3] = "Scarabajo";
		a_monster(94).f_nr = 21;
		a_monster(94).f_art = 1;
		a_monster(94).f_lebenspunkte = 3;
		a_monster(94).f_angriff = 2;
		a_monster(94).f_abwehr = 0;
		a_monster(94).f_staerke = 2;
		a_monster(94).f_ruestung = 1;
		a_monster(94).f_zauberkraft = 0;
		a_monster(94).f_zauber = 0;
		a_monster(94).f_reichweite = 0;
		a_monster(94).f_minlevel = 3;
		a_monster(94).f_eigenschaft1 = 8;
		a_monster(94).f_eigenschaft2 = 6;
		a_monster(94).f_eigenschaft3 = 29;
		a_monster(95).f_name[2] = "Giftiger K\357\277\275er";
		a_monster(95).f_name[1] = "Venom Bug";
		a_monster(95).f_name[3] = "Scarabajo venenose";
		a_monster(95).f_nr = 31;
		a_monster(95).f_art = 1;
		a_monster(95).f_lebenspunkte = 3;
		a_monster(95).f_angriff = 2;
		a_monster(95).f_abwehr = 0;
		a_monster(95).f_staerke = 2;
		a_monster(95).f_ruestung = 1;
		a_monster(95).f_zauberkraft = 0;
		a_monster(95).f_zauber = 0;
		a_monster(95).f_reichweite = 0;
		a_monster(95).f_minlevel = 5;
		a_monster(95).f_eigenschaft1 = 8;
		a_monster(95).f_eigenschaft2 = 6;
		a_monster(95).f_eigenschaft3 = 3;
		a_monster(95).f_eigenschaft4 = 2;
		a_monster(95).f_eigenschaft5 = 29;
		a_monster(96).f_name[2] = "K\357\277\275igsratte";
		a_monster(96).f_name[1] = "King Rat";
		a_monster(96).f_name[3] = "Rata Rey";
		a_monster(96).f_nr = 37;
		a_monster(96).f_art = 1;
		a_monster(96).f_lebenspunkte = 6;
		a_monster(96).f_angriff = 3;
		a_monster(96).f_abwehr = 1;
		a_monster(96).f_staerke = 3;
		a_monster(96).f_ruestung = 1;
		a_monster(96).f_zauberkraft = 0;
		a_monster(96).f_zauber = 0;
		a_monster(96).f_reichweite = 0;
		a_monster(96).f_minlevel = 5;
		a_monster(96).f_sound = 45;
		a_monster(96).f_eigenschaft1 = 2;
		a_monster(96).f_eigenschaft2 = 6;
		a_monster(96).f_eigenschaft3 = 8;
		a_monster(96).f_eigenschaft4 = 29;
		a_monster(96).f_eigenschaft5 = 35;
		a_monster(96).f_eigenschaft6 = 43;
		a_monster(96).f_eigenschaft7 = 44;
		a_monster(97).f_name[2] = "Riesenkr\357\277\275e";
		a_monster(97).f_name[1] = "Giant Crow";
		a_monster(97).f_name[3] = "Corneja gigante";
		a_monster(97).f_nr = 41;
		a_monster(97).f_art = 1;
		a_monster(97).f_lebenspunkte = 3;
		a_monster(97).f_angriff = 2;
		a_monster(97).f_abwehr = 1;
		a_monster(97).f_staerke = 2;
		a_monster(97).f_ruestung = 0;
		a_monster(97).f_zauberkraft = 0;
		a_monster(97).f_zauber = 0;
		a_monster(97).f_reichweite = 0;
		a_monster(97).f_minlevel = 3;
		a_monster(97).f_eigenschaft1 = 1;
		a_monster(97).f_eigenschaft2 = 8;
		a_monster(97).f_eigenschaft3 = 10;
		a_monster(97).f_eigenschaft4 = 29;
		a_monster(98).f_name[2] = "Sandmann";
		a_monster(98).f_name[1] = "Sandman";
		a_monster(98).f_name[3] = "Hombre de la Bolsa";
		a_monster(98).f_nr = 45;
		a_monster(98).f_art = 10;
		a_monster(98).f_lebenspunkte = 4;
		a_monster(98).f_angriff = 6;
		a_monster(98).f_abwehr = 2;
		a_monster(98).f_staerke = 3;
		a_monster(98).f_ruestung = 1;
		a_monster(98).f_zauberkraft = 0;
		a_monster(98).f_zauber = 0;
		a_monster(98).f_reichweite = 0;
		a_monster(98).f_minlevel = 5;
		a_monster(98).f_eigenschaft1 = 8;
		a_monster(98).f_eigenschaft2 = 9;
		a_monster(98).f_eigenschaft3 = 6;
		a_monster(99).f_name[2] = "Zombiegeneral";
		a_monster(99).f_name[1] = "Zombie General";
		a_monster(99).f_name[3] = "Zombi General";
		a_monster(99).f_nr = 67;
		a_monster(99).f_art = 3;
		a_monster(99).f_lebenspunkte = 25;
		a_monster(99).f_angriff = 4;
		a_monster(99).f_abwehr = 1;
		a_monster(99).f_staerke = 7;
		a_monster(99).f_ruestung = 1;
		a_monster(99).f_zauberkraft = 0;
		a_monster(99).f_zauber = 0;
		a_monster(99).f_reichweite = 0;
		a_monster(99).f_minlevel = 7;
		a_monster(99).f_sound = 45;
		a_monster(99).f_eigenschaft1 = 44;
		a_monster(100).f_name[2] = "Antiheld";
		a_monster(100).f_name[1] = "Evil Hero";
		a_monster(100).f_name[3] = "AntiHeroe";
		a_monster(100).f_nr = 85;
		a_monster(100).f_art = 2;
		a_monster(100).f_lebenspunkte = 15;
		a_monster(100).f_angriff = 6;
		a_monster(100).f_abwehr = 2;
		a_monster(100).f_staerke = 5;
		a_monster(100).f_ruestung = 3;
		a_monster(100).f_zauberkraft = 0;
		a_monster(100).f_zauber = 0;
		a_monster(100).f_reichweite = 0;
		a_monster(100).f_minlevel = 8;
		a_monster(100).f_eigenschaft1 = 4;
		a_monster(100).f_eigenschaft2 = 9;
		a_monster(100).f_eigenschaft3 = 26;
		a_monster(100).f_eigenschaft4 = 29;
		a_monster(101).f_name[2] = "Springspinne";
		a_monster(101).f_name[1] = "Jumping Spider";
		a_monster(101).f_name[3] = "Arana Saltando";
		a_monster(101).f_nr = 86;
		a_monster(101).f_art = 1;
		a_monster(101).f_lebenspunkte = 12;
		a_monster(101).f_angriff = 6;
		a_monster(101).f_abwehr = 3;
		a_monster(101).f_staerke = 4;
		a_monster(101).f_ruestung = 1;
		a_monster(101).f_zauberkraft = 0;
		a_monster(101).f_zauber = 0;
		a_monster(101).f_reichweite = 0;
		a_monster(101).f_minlevel = 10;
		a_monster(101).f_eigenschaft1 = 3;
		a_monster(101).f_eigenschaft2 = 2;
		a_monster(101).f_eigenschaft3 = 11;
		a_monster(101).f_eigenschaft4 = 29;
		a_monster(101).f_eigenschaft5 = 32;
		a_monster(102).f_name[2] = "Einhorn";
		a_monster(102).f_name[1] = "Unicorn";
		a_monster(102).f_name[3] = "Unicornio";
		a_monster(102).f_nr = 92;
		a_monster(102).f_art = 1;
		a_monster(102).f_lebenspunkte = 12;
		a_monster(102).f_angriff = 7;
		a_monster(102).f_abwehr = 7;
		a_monster(102).f_staerke = 5;
		a_monster(102).f_ruestung = 1;
		a_monster(102).f_zauberkraft = 0;
		a_monster(102).f_zauber = 0;
		a_monster(102).f_reichweite = 0;
		a_monster(102).f_minlevel = 10;
		a_monster(102).f_sound = 39;
		a_monster(102).f_eigenschaft1 = 8;
		a_monster(102).f_eigenschaft2 = 9;
		a_monster(102).f_eigenschaft3 = 16;
		a_monster(102).f_eigenschaft4 = 29;
		a_monster(103).f_name[2] = "Riesenschnecke";
		a_monster(103).f_name[1] = "Giant Snail";
		a_monster(103).f_name[3] = "Caracol gigante";
		a_monster(103).f_nr = 93;
		a_monster(103).f_art = 1;
		a_monster(103).f_lebenspunkte = 3;
		a_monster(103).f_angriff = 1;
		a_monster(103).f_abwehr = 0;
		a_monster(103).f_staerke = 1;
		a_monster(103).f_ruestung = 5;
		a_monster(103).f_zauberkraft = 0;
		a_monster(103).f_zauber = 0;
		a_monster(103).f_reichweite = 0;
		a_monster(103).f_minlevel = 3;
		a_monster(103).f_eigenschaft1 = 8;
		a_monster(103).f_eigenschaft2 = 9;
		a_monster(103).f_eigenschaft3 = 29;
		a_monster(104).f_name[2] = "Poltergeist";
		a_monster(104).f_name[1] = "Poltergeist";
		a_monster(104).f_name[3] = "Poltergeist";
		a_monster(104).f_nr = 84;
		a_monster(104).f_art = 10;
		a_monster(104).f_lebenspunkte = 25;
		a_monster(104).f_angriff = 8;
		a_monster(104).f_abwehr = 3;
		a_monster(104).f_staerke = 7;
		a_monster(104).f_ruestung = 2;
		a_monster(104).f_zauberkraft = 5;
		a_monster(104).f_zauber = 3;
		a_monster(104).f_reichweite = 4;
		a_monster(104).f_minlevel = 15;
		a_monster(104).f_sound = 37;
		a_monster(104).f_eigenschaft1 = 17;
		a_monster(104).f_eigenschaft2 = 18;
		a_monster(104).f_eigenschaft3 = 7;
		a_monster(104).f_eigenschaft4 = 13;
		a_monster(104).f_eigenschaft5 = 15;
		a_monster(105).f_name[2] = "Chim\357\277\275e";
		a_monster(105).f_name[1] = "Chimera";
		a_monster(105).f_name[3] = "Chimera";
		a_monster(105).f_nr = 99;
		a_monster(105).f_art = 6;
		a_monster(105).f_lebenspunkte = 40;
		a_monster(105).f_angriff = 10;
		a_monster(105).f_abwehr = 3;
		a_monster(105).f_staerke = 8;
		a_monster(105).f_ruestung = 2;
		a_monster(105).f_zauberkraft = 0;
		a_monster(105).f_zauber = 0;
		a_monster(105).f_reichweite = 0;
		a_monster(105).f_minlevel = 12;
		a_monster(105).f_sound = 44;
		a_monster(105).f_eigenschaft1 = 1;
		a_monster(105).f_eigenschaft2 = 3;
		a_monster(105).f_eigenschaft3 = 16;
		a_monster(106).f_name[2] = "Djinn";
		a_monster(106).f_name[1] = "Djinn";
		a_monster(106).f_name[3] = "Djini";
		a_monster(106).f_nr = 108;
		a_monster(106).f_art = 10;
		a_monster(106).f_lebenspunkte = 30;
		a_monster(106).f_angriff = 9;
		a_monster(106).f_abwehr = 3;
		a_monster(106).f_staerke = 7;
		a_monster(106).f_ruestung = 2;
		a_monster(106).f_zauberkraft = 5;
		a_monster(106).f_zauber = 1;
		a_monster(106).f_reichweite = 5;
		a_monster(106).f_minlevel = 15;
		a_monster(106).f_eigenschaft1 = 1;
		a_monster(106).f_eigenschaft2 = 13;
		a_monster(106).f_eigenschaft3 = 12;
		a_monster(106).f_eigenschaft4 = 18;
		a_monster(106).f_eigenschaft5 = 45;
		a_monster(107).f_name[2] = "Riesenkobra";
		a_monster(107).f_name[1] = "Giant Cobra";
		a_monster(107).f_name[3] = "Cobra Gigante";
		a_monster(107).f_nr = 107;
		a_monster(107).f_art = 1;
		a_monster(107).f_lebenspunkte = 10;
		a_monster(107).f_angriff = 5;
		a_monster(107).f_abwehr = 1;
		a_monster(107).f_staerke = 4;
		a_monster(107).f_ruestung = 1;
		a_monster(107).f_zauberkraft = 0;
		a_monster(107).f_zauber = 0;
		a_monster(107).f_reichweite = 0;
		a_monster(107).f_minlevel = 6;
		a_monster(107).f_eigenschaft1 = 8;
		a_monster(107).f_eigenschaft2 = 3;
		a_monster(107).f_eigenschaft3 = 29;
		a_monster(108).f_name[2] = "B\357\277\275e Fee";
		a_monster(108).f_name[1] = "Evil Faerie";
		a_monster(108).f_name[3] = "Hada enfadado";
		a_monster(108).f_nr = 109;
		a_monster(108).f_art = 10;
		a_monster(108).f_lebenspunkte = 12;
		a_monster(108).f_angriff = 2;
		a_monster(108).f_abwehr = 0;
		a_monster(108).f_staerke = 2;
		a_monster(108).f_ruestung = 0;
		a_monster(108).f_zauberkraft = 8;
		a_monster(108).f_zauber = 3;
		a_monster(108).f_reichweite = 5;
		a_monster(108).f_minlevel = 10;
		a_monster(108).f_sound = 37;
		a_monster(108).f_eigenschaft1 = 9;
		a_monster(108).f_eigenschaft2 = 8;
		a_monster(108).f_eigenschaft3 = 4;
		a_monster(108).f_eigenschaft4 = 27;
		a_monster(109).f_name[2] = "Alptraum";
		a_monster(109).f_name[1] = "Nightmare";
		a_monster(109).f_name[3] = "Pesadilla";
		a_monster(109).f_nr = 117;
		a_monster(109).f_art = 10;
		a_monster(109).f_lebenspunkte = 90;
		a_monster(109).f_angriff = 12;
		a_monster(109).f_abwehr = 5;
		a_monster(109).f_staerke = 9;
		a_monster(109).f_ruestung = 3;
		a_monster(109).f_zauberkraft = 8;
		a_monster(109).f_zauber = 4;
		a_monster(109).f_reichweite = 5;
		a_monster(109).f_minlevel = 21;
		a_monster(109).f_sound = 44;
		a_monster(109).f_eigenschaft1 = 1;
		a_monster(109).f_eigenschaft2 = 7;
		a_monster(109).f_eigenschaft3 = 13;
		a_monster(109).f_eigenschaft4 = 15;
		a_monster(109).f_eigenschaft5 = 28;
		a_monster(110).f_name[2] = "B\357\277\275es Auge";
		a_monster(110).f_name[1] = "Evil Eye";
		a_monster(110).f_name[3] = "Ojo malo";
		a_monster(110).f_nr = 112;
		a_monster(110).f_art = 10;
		a_monster(110).f_lebenspunkte = 25;
		a_monster(110).f_angriff = 10;
		a_monster(110).f_abwehr = 6;
		a_monster(110).f_staerke = 7;
		a_monster(110).f_ruestung = 3;
		a_monster(110).f_zauberkraft = 7;
		a_monster(110).f_zauber = 2;
		a_monster(110).f_reichweite = 4;
		a_monster(110).f_minlevel = 21;
		a_monster(110).f_eigenschaft1 = 1;
		a_monster(110).f_eigenschaft2 = 7;
		a_monster(110).f_eigenschaft3 = 13;
		a_monster(110).f_eigenschaft4 = 15;
		a_monster(110).f_eigenschaft5 = 19;
		a_monster(111).f_name[2] = "Riesenwespe";
		a_monster(111).f_name[1] = "Giant Wasp";
		a_monster(111).f_name[3] = "Avispa Gigante";
		a_monster(111).f_nr = 133;
		a_monster(111).f_art = 1;
		a_monster(111).f_lebenspunkte = 10;
		a_monster(111).f_angriff = 6;
		a_monster(111).f_abwehr = 3;
		a_monster(111).f_staerke = 5;
		a_monster(111).f_ruestung = 3;
		a_monster(111).f_zauberkraft = 0;
		a_monster(111).f_zauber = 0;
		a_monster(111).f_reichweite = 0;
		a_monster(111).f_minlevel = 6;
		a_monster(111).f_sound = 47;
		a_monster(111).f_eigenschaft1 = 2;
		a_monster(111).f_eigenschaft2 = 6;
		a_monster(111).f_eigenschaft3 = 29;
		a_monster(111).f_eigenschaft4 = 43;
		a_monster(112).f_name[2] = "Riesenhornisse";
		a_monster(112).f_name[1] = "Giant Hornet";
		a_monster(112).f_name[3] = "Abejoro Gigante";
		a_monster(112).f_nr = 134;
		a_monster(112).f_art = 1;
		a_monster(112).f_lebenspunkte = 15;
		a_monster(112).f_angriff = 7;
		a_monster(112).f_abwehr = 4;
		a_monster(112).f_staerke = 6;
		a_monster(112).f_ruestung = 4;
		a_monster(112).f_zauberkraft = 0;
		a_monster(112).f_zauber = 0;
		a_monster(112).f_reichweite = 0;
		a_monster(112).f_minlevel = 7;
		a_monster(112).f_sound = 47;
		a_monster(112).f_eigenschaft1 = 2;
		a_monster(112).f_eigenschaft2 = 6;
		a_monster(112).f_eigenschaft3 = 29;
		a_monster(113).f_name[2] = "Geh\357\277\275nte Kr\357\277\275e";
		a_monster(113).f_name[1] = "Horned Toad";
		a_monster(113).f_name[3] = "Sapo con picados";
		a_monster(113).f_nr = 128;
		a_monster(113).f_art = 1;
		a_monster(113).f_lebenspunkte = 20;
		a_monster(113).f_angriff = 7;
		a_monster(113).f_abwehr = 4;
		a_monster(113).f_staerke = 7;
		a_monster(113).f_ruestung = 4;
		a_monster(113).f_zauberkraft = 0;
		a_monster(113).f_zauber = 0;
		a_monster(113).f_reichweite = 0;
		a_monster(113).f_minlevel = 11;
		a_monster(113).f_eigenschaft1 = 3;
		a_monster(113).f_eigenschaft2 = 29;
		a_monster(114).f_name[2] = "Uralter Vampir";
		a_monster(114).f_name[1] = "Ancient Vampire";
		a_monster(114).f_name[3] = "Vampiro viejo";
		a_monster(114).f_nr = 129;
		a_monster(114).f_art = 3;
		a_monster(114).f_lebenspunkte = 145;
		a_monster(114).f_angriff = 15;
		a_monster(114).f_abwehr = 10;
		a_monster(114).f_staerke = 20;
		a_monster(114).f_ruestung = 5;
		a_monster(114).f_zauberkraft = 0;
		a_monster(114).f_zauber = 0;
		a_monster(114).f_reichweite = 5;
		a_monster(114).f_minlevel = 25;
		a_monster(114).f_eigenschaft1 = 17;
		a_monster(114).f_eigenschaft2 = 4;
		a_monster(114).f_eigenschaft3 = 16;
		a_monster(114).f_eigenschaft4 = 27;
		a_monster(114).f_eigenschaft5 = 44;
		a_monster(115).f_name[2] = "Sturmd\357\277\275on";
		a_monster(115).f_name[1] = "Storm Demon";
		a_monster(115).f_name[3] = "Demonio de las tormentas";
		a_monster(115).f_nr = 124;
		a_monster(115).f_art = 7;
		a_monster(115).f_lebenspunkte = 1000;
		a_monster(115).f_angriff = 45;
		a_monster(115).f_abwehr = 65;
		a_monster(115).f_staerke = 85;
		a_monster(115).f_ruestung = 26;
		a_monster(115).f_zauberkraft = 12;
		a_monster(115).f_zauber = 5;
		a_monster(115).f_reichweite = 5;
		a_monster(115).f_minlevel = 145;
		a_monster(115).f_eigenschaft1 = 13;
		a_monster(115).f_eigenschaft2 = 17;
		a_monster(115).f_eigenschaft3 = 7;
		a_monster(115).f_eigenschaft4 = 28;
		a_monster(115).f_eigenschaft5 = 42;
		a_monster(115).f_eigenschaft6 = 45;
		a_monster(116).f_name[2] = "Riesenzitteraal";
		a_monster(116).f_name[1] = "Giant electric Eel";
		a_monster(116).f_name[3] = "Anguila electrica";
		a_monster(116).f_nr = 135;
		a_monster(116).f_art = 1;
		a_monster(116).f_lebenspunkte = 22;
		a_monster(116).f_angriff = 10;
		a_monster(116).f_abwehr = 10;
		a_monster(116).f_staerke = 8;
		a_monster(116).f_ruestung = 0;
		a_monster(116).f_zauberkraft = 0;
		a_monster(116).f_zauber = 0;
		a_monster(116).f_reichweite = 0;
		a_monster(116).f_minlevel = 15;
		a_monster(116).f_eigenschaft1 = 30;
		a_monster(116).f_eigenschaft2 = 14;
		a_monster(116).f_eigenschaft3 = 25;
		a_monster(116).f_eigenschaft4 = 29;
		a_monster(117).f_name[2] = "Riesen Goldfisch";
		a_monster(117).f_name[1] = "Giant Goldfish";
		a_monster(117).f_name[3] = "Pescado de Oro";
		a_monster(117).f_nr = 136;
		a_monster(117).f_art = 1;
		a_monster(117).f_lebenspunkte = 6;
		a_monster(117).f_angriff = 3;
		a_monster(117).f_abwehr = 2;
		a_monster(117).f_staerke = 3;
		a_monster(117).f_ruestung = 0;
		a_monster(117).f_zauberkraft = 0;
		a_monster(117).f_zauber = 0;
		a_monster(117).f_reichweite = 0;
		a_monster(117).f_minlevel = 5;
		a_monster(117).f_eigenschaft1 = 30;
		a_monster(117).f_eigenschaft2 = 29;
		a_monster(117).f_eigenschaft3 = 6;
		a_monster(118).f_name[2] = "Riesen Kugelfisch";
		a_monster(118).f_name[1] = "Giant Blowfish";
		a_monster(118).f_name[3] = "Pez globo gigante";
		a_monster(118).f_nr = 136;
		a_monster(118).f_art = 1;
		a_monster(118).f_lebenspunkte = 8;
		a_monster(118).f_angriff = 5;
		a_monster(118).f_abwehr = 4;
		a_monster(118).f_staerke = 5;
		a_monster(118).f_ruestung = 1;
		a_monster(118).f_zauberkraft = 0;
		a_monster(118).f_zauber = 0;
		a_monster(118).f_reichweite = 0;
		a_monster(118).f_minlevel = 6;
		a_monster(118).f_eigenschaft1 = 30;
		a_monster(118).f_eigenschaft2 = 29;
		a_monster(118).f_eigenschaft3 = 2;
		a_monster(118).f_eigenschaft4 = 6;
		a_monster(119).f_name[2] = "Riesenqualle";
		a_monster(119).f_name[1] = "Giant Jellyfish";
		a_monster(119).f_name[3] = "Medusa Gigante";
		a_monster(119).f_nr = 136;
		a_monster(119).f_art = 1;
		a_monster(119).f_lebenspunkte = 8;
		a_monster(119).f_angriff = 5;
		a_monster(119).f_abwehr = 4;
		a_monster(119).f_staerke = 5;
		a_monster(119).f_ruestung = 1;
		a_monster(119).f_zauberkraft = 0;
		a_monster(119).f_zauber = 0;
		a_monster(119).f_reichweite = 0;
		a_monster(119).f_minlevel = 6;
		a_monster(119).f_eigenschaft1 = 30;
		a_monster(120).f_name[2] = "Riesenseepferd";
		a_monster(120).f_name[1] = "Giant Seahorse";
		a_monster(120).f_name[3] = "Caballo del Mar gigante";
		a_monster(120).f_nr = 142;
		a_monster(120).f_art = 2;
		a_monster(120).f_lebenspunkte = 25;
		a_monster(120).f_angriff = 7;
		a_monster(120).f_abwehr = 7;
		a_monster(120).f_staerke = 5;
		a_monster(120).f_ruestung = 1;
		a_monster(120).f_zauberkraft = 0;
		a_monster(120).f_zauber = 0;
		a_monster(120).f_reichweite = 9;
		a_monster(120).f_minlevel = 12;
		a_monster(120).f_sound = 39;
		a_monster(120).f_eigenschaft1 = 23;
		a_monster(120).f_eigenschaft2 = 30;
		a_monster(120).f_eigenschaft3 = 29;
		a_monster(121).f_name[2] = "Spinnenk\357\277\275igin";
		a_monster(121).f_name[1] = "Spider Queen";
		a_monster(121).f_name[3] = "Arana Reina";
		a_monster(121).f_nr = 143;
		a_monster(121).f_art = 6;
		a_monster(121).f_lebenspunkte = 130;
		a_monster(121).f_angriff = 14;
		a_monster(121).f_abwehr = 9;
		a_monster(121).f_staerke = 14;
		a_monster(121).f_ruestung = 5;
		a_monster(121).f_zauberkraft = 0;
		a_monster(121).f_zauber = 0;
		a_monster(121).f_reichweite = 0;
		a_monster(121).f_minlevel = 15;
		a_monster(121).f_eigenschaft1 = 3;
		a_monster(121).f_eigenschaft2 = 31;
		a_monster(121).f_eigenschaft3 = 11;
		a_monster(121).f_eigenschaft4 = 28;
		a_monster(122).f_name[2] = "Goblink\357\277\275ig";
		a_monster(122).f_name[1] = "Goblin King";
		a_monster(122).f_name[3] = "Rey Goblin";
		a_monster(122).f_nr = 144;
		a_monster(122).f_art = 6;
		a_monster(122).f_lebenspunkte = 95;
		a_monster(122).f_angriff = 12;
		a_monster(122).f_abwehr = 7;
		a_monster(122).f_staerke = 10;
		a_monster(122).f_ruestung = 4;
		a_monster(122).f_zauberkraft = 7;
		a_monster(122).f_zauber = 1;
		a_monster(122).f_reichweite = 6;
		a_monster(122).f_minlevel = 12;
		a_monster(122).f_eigenschaft1 = 4;
		a_monster(122).f_eigenschaft2 = 31;
		a_monster(122).f_eigenschaft3 = 27;
		a_monster(122).f_eigenschaft4 = 28;
		a_monster(123).f_name[2] = "Herr der Untoten";
		a_monster(123).f_name[1] = "Lord of the Undead";
		a_monster(123).f_name[3] = "Comandante de los No-Moertos";
		a_monster(123).f_nr = 145;
		a_monster(123).f_art = 6;
		a_monster(123).f_lebenspunkte = 80;
		a_monster(123).f_angriff = 12;
		a_monster(123).f_abwehr = 6;
		a_monster(123).f_staerke = 10;
		a_monster(123).f_ruestung = 3;
		a_monster(123).f_zauberkraft = 6;
		a_monster(123).f_zauber = 1;
		a_monster(123).f_reichweite = 5;
		a_monster(123).f_minlevel = 11;
		a_monster(123).f_sound = 44;
		a_monster(123).f_eigenschaft1 = 31;
		a_monster(123).f_eigenschaft2 = 28;
		a_monster(123).f_eigenschaft3 = 42;
		a_monster(124).f_name[2] = "Riesenvogelspinne";
		a_monster(124).f_name[1] = "Giant Birdspider";
		a_monster(124).f_name[3] = "Arana que caza aves";
		a_monster(124).f_nr = 146;
		a_monster(124).f_art = 1;
		a_monster(124).f_lebenspunkte = 18;
		a_monster(124).f_angriff = 7;
		a_monster(124).f_abwehr = 4;
		a_monster(124).f_staerke = 5;
		a_monster(124).f_ruestung = 2;
		a_monster(124).f_zauberkraft = 0;
		a_monster(124).f_zauber = 0;
		a_monster(124).f_reichweite = 0;
		a_monster(124).f_minlevel = 11;
		a_monster(124).f_eigenschaft1 = 3;
		a_monster(124).f_eigenschaft2 = 2;
		a_monster(124).f_eigenschaft3 = 11;
		a_monster(124).f_eigenschaft4 = 29;
		a_monster(124).f_eigenschaft5 = 32;
		a_monster(125).f_name[2] = "Riesenkreuzspinne";
		a_monster(125).f_name[1] = "Giant Cross Spider";
		a_monster(125).f_name[3] = "Arana Cruz Gigante";
		a_monster(125).f_nr = 147;
		a_monster(125).f_art = 1;
		a_monster(125).f_lebenspunkte = 22;
		a_monster(125).f_angriff = 8;
		a_monster(125).f_abwehr = 5;
		a_monster(125).f_staerke = 6;
		a_monster(125).f_ruestung = 3;
		a_monster(125).f_zauberkraft = 0;
		a_monster(125).f_zauber = 0;
		a_monster(125).f_reichweite = 0;
		a_monster(125).f_minlevel = 12;
		a_monster(125).f_eigenschaft1 = 3;
		a_monster(125).f_eigenschaft2 = 29;
		a_monster(125).f_eigenschaft3 = 32;
		a_monster(126).f_name[2] = "Stachelechse";
		a_monster(126).f_name[1] = "Horned Lizard";
		a_monster(126).f_name[3] = "Lagarto Cornuda";
		a_monster(126).f_nr = 68;
		a_monster(126).f_art = 1;
		a_monster(126).f_lebenspunkte = 12;
		a_monster(126).f_angriff = 5;
		a_monster(126).f_abwehr = 2;
		a_monster(126).f_staerke = 5;
		a_monster(126).f_ruestung = 1;
		a_monster(126).f_zauberkraft = 0;
		a_monster(126).f_zauber = 0;
		a_monster(126).f_reichweite = 0;
		a_monster(126).f_minlevel = 7;
		a_monster(126).f_eigenschaft1 = 8;
		a_monster(126).f_eigenschaft2 = 29;
		a_monster(126).f_eigenschaft3 = 3;
		a_monster(127).f_name[2] = "Zweik\357\277\275figer Oger";
		a_monster(127).f_name[1] = "Two-Headed Ogre";
		a_monster(127).f_name[3] = "Ogro con dos Cabezas";
		a_monster(127).f_nr = 79;
		a_monster(127).f_art = 2;
		a_monster(127).f_lebenspunkte = 25;
		a_monster(127).f_angriff = 7;
		a_monster(127).f_abwehr = 4;
		a_monster(127).f_staerke = 8;
		a_monster(127).f_ruestung = 2;
		a_monster(127).f_zauberkraft = 0;
		a_monster(127).f_zauber = 0;
		a_monster(127).f_reichweite = 4;
		a_monster(127).f_minlevel = 10;
		a_monster(127).f_eigenschaft1 = 9;
		a_monster(127).f_eigenschaft2 = 26;
		a_monster(127).f_eigenschaft3 = 29;
		a_monster(127).f_eigenschaft4 = 33;
		a_monster(127).f_eigenschaft5 = 40;
		a_monster(127).f_eigenschaft6 = 41;
		a_monster(128).f_name[2] = "Mammut";
		a_monster(128).f_name[1] = "Mammoth";
		a_monster(128).f_name[3] = "Mamut";
		a_monster(128).f_nr = 76;
		a_monster(128).f_art = 1;
		a_monster(128).f_lebenspunkte = 90;
		a_monster(128).f_angriff = 12;
		a_monster(128).f_abwehr = 8;
		a_monster(128).f_staerke = 12;
		a_monster(128).f_ruestung = 6;
		a_monster(128).f_zauberkraft = 0;
		a_monster(128).f_zauber = 0;
		a_monster(128).f_reichweite = 0;
		a_monster(128).f_minlevel = 18;
		a_monster(128).f_eigenschaft1 = 11;
		a_monster(128).f_eigenschaft2 = 29;
		a_monster(128).f_eigenschaft3 = 18;
		a_monster(129).f_name[2] = "Minotaurus";
		a_monster(129).f_name[1] = "Minotaur";
		a_monster(129).f_name[3] = "Minotauro";
		a_monster(129).f_nr = 126;
		a_monster(129).f_art = 2;
		a_monster(129).f_lebenspunkte = 150;
		a_monster(129).f_angriff = 11;
		a_monster(129).f_abwehr = 4;
		a_monster(129).f_staerke = 21;
		a_monster(129).f_ruestung = 4;
		a_monster(129).f_zauberkraft = 0;
		a_monster(129).f_zauber = 0;
		a_monster(129).f_reichweite = 4;
		a_monster(129).f_minlevel = 18;
		a_monster(129).f_eigenschaft1 = 4;
		a_monster(129).f_eigenschaft2 = 9;
		a_monster(129).f_eigenschaft3 = 26;
		a_monster(129).f_eigenschaft4 = 29;
		a_monster(129).f_eigenschaft5 = 41;
		a_monster(130).f_name[2] = "Geflgelter Teufel";
		a_monster(130).f_name[1] = "Winged Devil";
		a_monster(130).f_name[3] = "Devil de alas";
		a_monster(130).f_nr = 149;
		a_monster(130).f_art = 7;
		a_monster(130).f_lebenspunkte = 80;
		a_monster(130).f_angriff = 12;
		a_monster(130).f_abwehr = 8;
		a_monster(130).f_staerke = 15;
		a_monster(130).f_ruestung = 6;
		a_monster(130).f_zauberkraft = 0;
		a_monster(130).f_zauber = 0;
		a_monster(130).f_reichweite = 0;
		a_monster(130).f_minlevel = 26;
		a_monster(130).f_eigenschaft1 = 1;
		a_monster(130).f_eigenschaft2 = 2;
		a_monster(130).f_eigenschaft3 = 6;
		a_monster(130).f_eigenschaft4 = 16;
		a_monster(130).f_eigenschaft5 = 44;
		a_monster(131).f_name[2] = "Kobold";
		a_monster(131).f_name[1] = "Kobold";
		a_monster(131).f_name[3] = "Kobold";
		a_monster(131).f_nr = 150;
		a_monster(131).f_art = 2;
		a_monster(131).f_lebenspunkte = 10;
		a_monster(131).f_angriff = 3;
		a_monster(131).f_abwehr = 1;
		a_monster(131).f_staerke = 3;
		a_monster(131).f_ruestung = 1;
		a_monster(131).f_zauberkraft = 3;
		a_monster(131).f_zauber = 3;
		a_monster(131).f_reichweite = 5;
		a_monster(131).f_minlevel = 5;
		a_monster(131).f_sound = 37;
		a_monster(131).f_eigenschaft1 = 9;
		a_monster(131).f_eigenschaft2 = 27;
		a_monster(131).f_eigenschaft3 = 29;
		a_monster(131).f_eigenschaft4 = 10;
		a_monster(132).f_name[2] = "Ork mit Kampfstab";
		a_monster(132).f_name[1] = "Orc with Staff";
		a_monster(132).f_name[3] = "Orco con Baston";
		a_monster(132).f_nr = 151;
		a_monster(132).f_art = 2;
		a_monster(132).f_lebenspunkte = 7;
		a_monster(132).f_angriff = 2;
		a_monster(132).f_abwehr = 2;
		a_monster(132).f_staerke = 3;
		a_monster(132).f_ruestung = 1;
		a_monster(132).f_zauberkraft = 0;
		a_monster(132).f_zauber = 0;
		a_monster(132).f_reichweite = 0;
		a_monster(132).f_minlevel = 4;
		a_monster(132).f_eigenschaft1 = 2;
		a_monster(132).f_eigenschaft2 = 4;
		a_monster(132).f_eigenschaft3 = 8;
		a_monster(132).f_eigenschaft4 = 9;
		a_monster(132).f_eigenschaft5 = 26;
		a_monster(132).f_eigenschaft6 = 29;
		a_monster(132).f_eigenschaft7 = 33;
		a_monster(133).f_name[2] = "Orkpriester";
		a_monster(133).f_name[1] = "Orc Priest";
		a_monster(133).f_name[3] = "Orco monje";
		a_monster(133).f_nr = 152;
		a_monster(133).f_art = 2;
		a_monster(133).f_lebenspunkte = 7;
		a_monster(133).f_angriff = 3;
		a_monster(133).f_abwehr = 2;
		a_monster(133).f_staerke = 3;
		a_monster(133).f_ruestung = 1;
		a_monster(133).f_zauberkraft = 5;
		a_monster(133).f_zauber = 7;
		a_monster(133).f_reichweite = 4;
		a_monster(133).f_minlevel = 6;
		a_monster(133).f_eigenschaft1 = 2;
		a_monster(133).f_eigenschaft2 = 4;
		a_monster(133).f_eigenschaft3 = 8;
		a_monster(133).f_eigenschaft4 = 9;
		a_monster(133).f_eigenschaft5 = 26;
		a_monster(133).f_eigenschaft6 = 29;
		a_monster(133).f_eigenschaft7 = 33;
		a_monster(134).f_name[2] = "Orkmagier";
		a_monster(134).f_name[1] = "Orc Mage";
		a_monster(134).f_name[3] = "Orco mago";
		a_monster(134).f_nr = 153;
		a_monster(134).f_art = 2;
		a_monster(134).f_lebenspunkte = 7;
		a_monster(134).f_angriff = 3;
		a_monster(134).f_abwehr = 2;
		a_monster(134).f_staerke = 3;
		a_monster(134).f_ruestung = 1;
		a_monster(134).f_zauberkraft = 5;
		a_monster(134).f_zauber = 1;
		a_monster(134).f_reichweite = 4;
		a_monster(134).f_minlevel = 6;
		a_monster(134).f_eigenschaft1 = 2;
		a_monster(134).f_eigenschaft2 = 4;
		a_monster(134).f_eigenschaft3 = 8;
		a_monster(134).f_eigenschaft4 = 9;
		a_monster(134).f_eigenschaft5 = 26;
		a_monster(134).f_eigenschaft6 = 29;
		a_monster(134).f_eigenschaft7 = 33;
		a_monster(135).f_name[2] = "Orkveteran";
		a_monster(135).f_name[1] = "Orc Veteran";
		a_monster(135).f_name[3] = "Orco veterano";
		a_monster(135).f_nr = 154;
		a_monster(135).f_art = 2;
		a_monster(135).f_lebenspunkte = 19;
		a_monster(135).f_angriff = 5;
		a_monster(135).f_abwehr = 4;
		a_monster(135).f_staerke = 5;
		a_monster(135).f_ruestung = 5;
		a_monster(135).f_zauberkraft = 0;
		a_monster(135).f_zauber = 0;
		a_monster(135).f_reichweite = 0;
		a_monster(135).f_minlevel = 7;
		a_monster(135).f_eigenschaft1 = 2;
		a_monster(135).f_eigenschaft2 = 4;
		a_monster(135).f_eigenschaft3 = 8;
		a_monster(135).f_eigenschaft4 = 9;
		a_monster(135).f_eigenschaft5 = 26;
		a_monster(135).f_eigenschaft6 = 29;
		a_monster(135).f_eigenschaft7 = 33;
		a_monster(136).f_name[2] = "Alter Orkpriester";
		a_monster(136).f_name[1] = "Elder Orcpriest";
		a_monster(136).f_name[3] = "Orco monje viejo";
		a_monster(136).f_nr = 155;
		a_monster(136).f_art = 2;
		a_monster(136).f_lebenspunkte = 10;
		a_monster(136).f_angriff = 5;
		a_monster(136).f_abwehr = 4;
		a_monster(136).f_staerke = 4;
		a_monster(136).f_ruestung = 1;
		a_monster(136).f_zauberkraft = 8;
		a_monster(136).f_zauber = 4;
		a_monster(136).f_reichweite = 5;
		a_monster(136).f_minlevel = 7;
		a_monster(136).f_eigenschaft1 = 2;
		a_monster(136).f_eigenschaft2 = 4;
		a_monster(136).f_eigenschaft3 = 8;
		a_monster(136).f_eigenschaft4 = 9;
		a_monster(136).f_eigenschaft5 = 26;
		a_monster(136).f_eigenschaft6 = 29;
		a_monster(136).f_eigenschaft7 = 33;
		a_monster(137).f_name[2] = "Orkdieb";
		a_monster(137).f_name[1] = "Orc Thief";
		a_monster(137).f_name[3] = "Orco Ladron";
		a_monster(137).f_nr = 156;
		a_monster(137).f_art = 2;
		a_monster(137).f_lebenspunkte = 7;
		a_monster(137).f_angriff = 2;
		a_monster(137).f_abwehr = 2;
		a_monster(137).f_staerke = 3;
		a_monster(137).f_ruestung = 1;
		a_monster(137).f_zauberkraft = 0;
		a_monster(137).f_zauber = 0;
		a_monster(137).f_reichweite = 0;
		a_monster(137).f_minlevel = 5;
		a_monster(137).f_eigenschaft1 = 2;
		a_monster(137).f_eigenschaft2 = 8;
		a_monster(137).f_eigenschaft3 = 9;
		a_monster(137).f_eigenschaft4 = 10;
		a_monster(137).f_eigenschaft5 = 29;
		a_monster(137).f_eigenschaft6 = 33;
		a_monster(138).f_name[2] = "Alter Orkdieb";
		a_monster(138).f_name[1] = "Elder Orc Thief";
		a_monster(138).f_name[3] = "Orco Ladron Viejo";
		a_monster(138).f_nr = 157;
		a_monster(138).f_art = 2;
		a_monster(138).f_lebenspunkte = 10;
		a_monster(138).f_angriff = 5;
		a_monster(138).f_abwehr = 3;
		a_monster(138).f_staerke = 4;
		a_monster(138).f_ruestung = 2;
		a_monster(138).f_zauberkraft = 0;
		a_monster(138).f_zauber = 0;
		a_monster(138).f_reichweite = 0;
		a_monster(138).f_minlevel = 7;
		a_monster(138).f_eigenschaft1 = 2;
		a_monster(138).f_eigenschaft2 = 8;
		a_monster(138).f_eigenschaft3 = 9;
		a_monster(138).f_eigenschaft4 = 10;
		a_monster(138).f_eigenschaft5 = 29;
		a_monster(138).f_eigenschaft6 = 33;
		a_monster(139).f_name[2] = "Alter Orkveteran";
		a_monster(139).f_name[1] = "Elder Orc Veteran";
		a_monster(139).f_name[3] = "Orco veterano veijo";
		a_monster(139).f_nr = 158;
		a_monster(139).f_art = 2;
		a_monster(139).f_lebenspunkte = 25;
		a_monster(139).f_angriff = 6;
		a_monster(139).f_abwehr = 4;
		a_monster(139).f_staerke = 5;
		a_monster(139).f_ruestung = 6;
		a_monster(139).f_zauberkraft = 0;
		a_monster(139).f_zauber = 0;
		a_monster(139).f_reichweite = 0;
		a_monster(139).f_minlevel = 8;
		a_monster(139).f_eigenschaft1 = 2;
		a_monster(139).f_eigenschaft2 = 4;
		a_monster(139).f_eigenschaft3 = 8;
		a_monster(139).f_eigenschaft4 = 9;
		a_monster(139).f_eigenschaft5 = 26;
		a_monster(139).f_eigenschaft6 = 29;
		a_monster(139).f_eigenschaft7 = 33;
		a_monster(140).f_name[2] = "Waffenloser Ork";
		a_monster(140).f_name[1] = "Weaponless Orc";
		a_monster(140).f_name[3] = "Orco sin arma";
		a_monster(140).f_nr = 159;
		a_monster(140).f_art = 2;
		a_monster(140).f_lebenspunkte = 7;
		a_monster(140).f_angriff = 1;
		a_monster(140).f_abwehr = 1;
		a_monster(140).f_staerke = 3;
		a_monster(140).f_ruestung = 1;
		a_monster(140).f_zauberkraft = 0;
		a_monster(140).f_zauber = 0;
		a_monster(140).f_reichweite = 0;
		a_monster(140).f_minlevel = 4;
		a_monster(140).f_eigenschaft1 = 2;
		a_monster(140).f_eigenschaft2 = 4;
		a_monster(140).f_eigenschaft3 = 8;
		a_monster(140).f_eigenschaft4 = 9;
		a_monster(140).f_eigenschaft5 = 26;
		a_monster(140).f_eigenschaft6 = 29;
		a_monster(140).f_eigenschaft7 = 33;
		a_monster(141).f_name[2] = "Alter Ork mit Kampfstab";
		a_monster(141).f_name[1] = "Elder Orc with Staff";
		a_monster(141).f_name[3] = "Orco con baston viejo";
		a_monster(141).f_nr = 160;
		a_monster(141).f_art = 2;
		a_monster(141).f_lebenspunkte = 10;
		a_monster(141).f_angriff = 5;
		a_monster(141).f_abwehr = 3;
		a_monster(141).f_staerke = 4;
		a_monster(141).f_ruestung = 1;
		a_monster(141).f_zauberkraft = 0;
		a_monster(141).f_zauber = 0;
		a_monster(141).f_reichweite = 0;
		a_monster(141).f_minlevel = 5;
		a_monster(141).f_eigenschaft1 = 2;
		a_monster(141).f_eigenschaft2 = 4;
		a_monster(141).f_eigenschaft3 = 8;
		a_monster(141).f_eigenschaft4 = 9;
		a_monster(141).f_eigenschaft5 = 26;
		a_monster(141).f_eigenschaft6 = 29;
		a_monster(141).f_eigenschaft7 = 33;
		a_monster(142).f_name[2] = "Eis Schlinggras";
		a_monster(142).f_name[1] = "Ice Grapplevines";
		a_monster(142).f_name[3] = "Enredaderas de Hielo";
		a_monster(142).f_nr = 161;
		a_monster(142).f_art = 4;
		a_monster(142).f_lebenspunkte = 8;
		a_monster(142).f_angriff = 1;
		a_monster(142).f_abwehr = 0;
		a_monster(142).f_staerke = 4;
		a_monster(142).f_ruestung = 0;
		a_monster(142).f_zauberkraft = 0;
		a_monster(142).f_zauber = 0;
		a_monster(142).f_reichweite = 0;
		a_monster(142).f_minlevel = 1;
		a_monster(142).f_eigenschaft1 = 11;
		a_monster(142).f_eigenschaft2 = 18;
		a_monster(143).f_name[2] = "Giftiges Schlinggras";
		a_monster(143).f_name[1] = "Poisenous Grapplevines";
		a_monster(143).f_name[3] = "Enredaderas de Veneno";
		a_monster(143).f_nr = 162;
		a_monster(143).f_art = 4;
		a_monster(143).f_lebenspunkte = 10;
		a_monster(143).f_angriff = 4;
		a_monster(143).f_abwehr = 2;
		a_monster(143).f_staerke = 6;
		a_monster(143).f_ruestung = 1;
		a_monster(143).f_zauberkraft = 0;
		a_monster(143).f_zauber = 0;
		a_monster(143).f_reichweite = 0;
		a_monster(143).f_minlevel = 4;
		a_monster(143).f_eigenschaft1 = 11;
		a_monster(143).f_eigenschaft2 = 3;
		a_monster(144).f_name[2] = "Steinernes Schlinggras";
		a_monster(144).f_name[1] = "Stone Grapplevines";
		a_monster(144).f_name[3] = "Enredaderas de Piedra";
		a_monster(144).f_nr = 163;
		a_monster(144).f_art = 4;
		a_monster(144).f_lebenspunkte = 12;
		a_monster(144).f_angriff = 5;
		a_monster(144).f_abwehr = 5;
		a_monster(144).f_staerke = 6;
		a_monster(144).f_ruestung = 8;
		a_monster(144).f_zauberkraft = 0;
		a_monster(144).f_zauber = 0;
		a_monster(144).f_reichweite = 0;
		a_monster(144).f_minlevel = 4;
		a_monster(144).f_eigenschaft1 = 12;
		a_monster(144).f_eigenschaft2 = 18;
		a_monster(144).f_eigenschaft3 = 7;
		a_monster(145).f_name[2] = "Wasser Schlinggras";
		a_monster(145).f_name[1] = "Water Grapplevines";
		a_monster(145).f_name[3] = "Enredaderas del Aqua";
		a_monster(145).f_nr = 164;
		a_monster(145).f_art = 4;
		a_monster(145).f_lebenspunkte = 12;
		a_monster(145).f_angriff = 5;
		a_monster(145).f_abwehr = 5;
		a_monster(145).f_staerke = 6;
		a_monster(145).f_ruestung = 8;
		a_monster(145).f_zauberkraft = 0;
		a_monster(145).f_zauber = 0;
		a_monster(145).f_reichweite = 0;
		a_monster(145).f_minlevel = 4;
		a_monster(145).f_eigenschaft1 = 12;
		a_monster(145).f_eigenschaft2 = 30;
		a_monster(146).f_name[2] = "Feuer Schlinggras";
		a_monster(146).f_name[1] = "Fire Grapplevines";
		a_monster(146).f_name[3] = "Enredaderas del Fuego";
		a_monster(146).f_nr = 165;
		a_monster(146).f_art = 4;
		a_monster(146).f_lebenspunkte = 15;
		a_monster(146).f_angriff = 10;
		a_monster(146).f_abwehr = 7;
		a_monster(146).f_staerke = 8;
		a_monster(146).f_ruestung = 9;
		a_monster(146).f_zauberkraft = 0;
		a_monster(146).f_zauber = 0;
		a_monster(146).f_reichweite = 4;
		a_monster(146).f_minlevel = 10;
		a_monster(146).f_eigenschaft1 = 12;
		a_monster(146).f_eigenschaft2 = 20;
		a_monster(147).f_name[2] = "Unsichtbares Schlinggras";
		a_monster(147).f_name[1] = "Invisible Grapplevines";
		a_monster(147).f_name[3] = "Enredaderas de la invisibilidad";
		a_monster(147).f_nr = 166;
		a_monster(147).f_art = 4;
		a_monster(147).f_lebenspunkte = 15;
		a_monster(147).f_angriff = 10;
		a_monster(147).f_abwehr = 7;
		a_monster(147).f_staerke = 8;
		a_monster(147).f_ruestung = 9;
		a_monster(147).f_zauberkraft = 0;
		a_monster(147).f_zauber = 0;
		a_monster(147).f_reichweite = 4;
		a_monster(147).f_minlevel = 9;
		a_monster(147).f_eigenschaft1 = 11;
		a_monster(147).f_eigenschaft2 = 19;
		a_monster(148).f_name[2] = "Feuer Wrgerich";
		a_monster(148).f_name[1] = "Fire Suffocator";
		a_monster(148).f_name[3] = "Destrangulador del Fuego";
		a_monster(148).f_nr = 167;
		a_monster(148).f_art = 4;
		a_monster(148).f_lebenspunkte = 25;
		a_monster(148).f_angriff = 12;
		a_monster(148).f_abwehr = 9;
		a_monster(148).f_staerke = 10;
		a_monster(148).f_ruestung = 10;
		a_monster(148).f_zauberkraft = 0;
		a_monster(148).f_zauber = 1;
		a_monster(148).f_reichweite = 4;
		a_monster(148).f_minlevel = 13;
		a_monster(148).f_eigenschaft1 = 12;
		a_monster(148).f_eigenschaft2 = 20;
		a_monster(148).f_eigenschaft3 = 16;
		a_monster(148).f_eigenschaft4 = 39;
		a_monster(148).f_eigenschaft5 = 42;
		a_monster(149).f_name[2] = "Steinerner Wrgerich";
		a_monster(149).f_name[1] = "Stone Suffocator";
		a_monster(149).f_name[3] = "Destrangulador de Piedra";
		a_monster(149).f_nr = 168;
		a_monster(149).f_art = 4;
		a_monster(149).f_lebenspunkte = 15;
		a_monster(149).f_angriff = 7;
		a_monster(149).f_abwehr = 6;
		a_monster(149).f_staerke = 7;
		a_monster(149).f_ruestung = 8;
		a_monster(149).f_zauberkraft = 0;
		a_monster(149).f_zauber = 0;
		a_monster(149).f_reichweite = 0;
		a_monster(149).f_minlevel = 7;
		a_monster(149).f_eigenschaft1 = 12;
		a_monster(149).f_eigenschaft2 = 18;
		a_monster(149).f_eigenschaft3 = 7;
		a_monster(149).f_eigenschaft4 = 16;
		a_monster(150).f_name[2] = "Giftiger Wrgerich";
		a_monster(150).f_name[1] = "Poisenous Suffocator";
		a_monster(150).f_name[3] = "Destrangulador de Veneno";
		a_monster(150).f_nr = 169;
		a_monster(150).f_art = 4;
		a_monster(150).f_lebenspunkte = 15;
		a_monster(150).f_angriff = 5;
		a_monster(150).f_abwehr = 3;
		a_monster(150).f_staerke = 7;
		a_monster(150).f_ruestung = 1;
		a_monster(150).f_zauberkraft = 0;
		a_monster(150).f_zauber = 0;
		a_monster(150).f_reichweite = 0;
		a_monster(150).f_minlevel = 8;
		a_monster(150).f_eigenschaft1 = 11;
		a_monster(150).f_eigenschaft2 = 3;
		a_monster(150).f_eigenschaft3 = 16;
		a_monster(151).f_name[2] = "Unsichtbarer Wrgerich";
		a_monster(151).f_name[1] = "Invisible Suffocator";
		a_monster(151).f_name[3] = "Destrangulador de la invisibilidad";
		a_monster(151).f_nr = 170;
		a_monster(151).f_art = 4;
		a_monster(151).f_lebenspunkte = 20;
		a_monster(151).f_angriff = 12;
		a_monster(151).f_abwehr = 9;
		a_monster(151).f_staerke = 9;
		a_monster(151).f_ruestung = 9;
		a_monster(151).f_zauberkraft = 0;
		a_monster(151).f_zauber = 4;
		a_monster(151).f_reichweite = 4;
		a_monster(151).f_minlevel = 10;
		a_monster(151).f_eigenschaft1 = 11;
		a_monster(151).f_eigenschaft2 = 19;
		a_monster(151).f_eigenschaft3 = 16;
		a_monster(152).f_name[2] = "Greif";
		a_monster(152).f_name[1] = "Griffin";
		a_monster(152).f_name[3] = "Grifon";
		a_monster(152).f_nr = 116;
		a_monster(152).f_art = 1;
		a_monster(152).f_lebenspunkte = 70;
		a_monster(152).f_angriff = 10;
		a_monster(152).f_abwehr = 10;
		a_monster(152).f_staerke = 9;
		a_monster(152).f_ruestung = 3;
		a_monster(152).f_zauberkraft = 0;
		a_monster(152).f_zauber = 0;
		a_monster(152).f_reichweite = 0;
		a_monster(152).f_minlevel = 15;
		a_monster(152).f_eigenschaft1 = 1;
		a_monster(152).f_eigenschaft2 = 29;
		a_monster(152).f_eigenschaft3 = 27;
		a_monster(152).f_eigenschaft4 = 11;
		a_monster(153).f_name[2] = "Schlangenmensch";
		a_monster(153).f_name[1] = "Human Snake";
		a_monster(153).f_name[3] = "Hombre Serpiente";
		a_monster(153).f_nr = 121;
		a_monster(153).f_art = 2;
		a_monster(153).f_lebenspunkte = 11;
		a_monster(153).f_angriff = 6;
		a_monster(153).f_abwehr = 5;
		a_monster(153).f_staerke = 6;
		a_monster(153).f_ruestung = 2;
		a_monster(153).f_zauberkraft = 0;
		a_monster(153).f_zauber = 0;
		a_monster(153).f_reichweite = 0;
		a_monster(153).f_minlevel = 7;
		a_monster(153).f_eigenschaft1 = 2;
		a_monster(153).f_eigenschaft2 = 4;
		a_monster(153).f_eigenschaft3 = 9;
		a_monster(153).f_eigenschaft4 = 26;
		a_monster(153).f_eigenschaft5 = 29;
		a_monster(154).f_name[2] = "Unhold";
		a_monster(154).f_name[1] = "Unhold";
		a_monster(154).f_name[3] = "Unhold";
		a_monster(154).f_nr = 127;
		a_monster(154).f_art = 10;
		a_monster(154).f_lebenspunkte = 25;
		a_monster(154).f_angriff = 8;
		a_monster(154).f_abwehr = 4;
		a_monster(154).f_staerke = 8;
		a_monster(154).f_ruestung = 1;
		a_monster(154).f_zauberkraft = 10;
		a_monster(154).f_zauber = 5;
		a_monster(154).f_reichweite = 5;
		a_monster(154).f_minlevel = 13;
		a_monster(154).f_eigenschaft1 = 12;
		a_monster(154).f_eigenschaft2 = 17;
		a_monster(154).f_eigenschaft3 = 18;
		a_monster(154).f_eigenschaft4 = 44;
		a_monster(155).f_name[2] = "Vierarmiger Oger";
		a_monster(155).f_name[1] = "Four-Handed Ogre";
		a_monster(155).f_name[3] = "Ogro con cuatro brazos";
		a_monster(155).f_nr = 44;
		a_monster(155).f_art = 2;
		a_monster(155).f_lebenspunkte = 30;
		a_monster(155).f_angriff = 9;
		a_monster(155).f_abwehr = 6;
		a_monster(155).f_staerke = 12;
		a_monster(155).f_ruestung = 3;
		a_monster(155).f_zauberkraft = 0;
		a_monster(155).f_zauber = 0;
		a_monster(155).f_reichweite = 4;
		a_monster(155).f_minlevel = 13;
		a_monster(155).f_eigenschaft1 = 9;
		a_monster(155).f_eigenschaft2 = 26;
		a_monster(155).f_eigenschaft3 = 29;
		a_monster(155).f_eigenschaft4 = 33;
		a_monster(155).f_eigenschaft5 = 16;
		a_monster(155).f_eigenschaft6 = 40;
		a_monster(155).f_eigenschaft7 = 41;
		a_monster(156).f_name[2] = "Troll";
		a_monster(156).f_name[1] = "Troll";
		a_monster(156).f_name[3] = "Troll";
		a_monster(156).f_nr = 49;
		a_monster(156).f_art = 2;
		a_monster(156).f_lebenspunkte = 50;
		a_monster(156).f_angriff = 8;
		a_monster(156).f_abwehr = 5;
		a_monster(156).f_staerke = 11;
		a_monster(156).f_ruestung = 4;
		a_monster(156).f_zauberkraft = 0;
		a_monster(156).f_zauber = 0;
		a_monster(156).f_reichweite = 4;
		a_monster(156).f_minlevel = 15;
		a_monster(156).f_eigenschaft1 = 9;
		a_monster(156).f_eigenschaft2 = 26;
		a_monster(156).f_eigenschaft3 = 29;
		a_monster(156).f_eigenschaft4 = 33;
		a_monster(156).f_eigenschaft5 = 16;
		a_monster(156).f_eigenschaft6 = 18;
		a_monster(156).f_eigenschaft7 = 41;
		a_monster(157).f_name[2] = "Blob";
		a_monster(157).f_name[1] = "Blob";
		a_monster(157).f_name[3] = "Blob";
		a_monster(157).f_nr = 46;
		a_monster(157).f_art = 6;
		a_monster(157).f_lebenspunkte = 20;
		a_monster(157).f_angriff = 1;
		a_monster(157).f_abwehr = 0;
		a_monster(157).f_staerke = 2;
		a_monster(157).f_ruestung = 0;
		a_monster(157).f_zauberkraft = 0;
		a_monster(157).f_zauber = 0;
		a_monster(157).f_reichweite = 0;
		a_monster(157).f_minlevel = 8;
		a_monster(157).f_eigenschaft1 = 16;
		a_monster(157).f_eigenschaft2 = 6;
		a_monster(157).f_eigenschaft3 = 43;
		a_monster(158).f_name[2] = "Meisterdieb";
		a_monster(158).f_name[1] = "Master Thief";
		a_monster(158).f_name[3] = "Ladron maestro";
		a_monster(158).f_nr = 53;
		a_monster(158).f_art = 2;
		a_monster(158).f_lebenspunkte = 12;
		a_monster(158).f_angriff = 7;
		a_monster(158).f_abwehr = 5;
		a_monster(158).f_staerke = 5;
		a_monster(158).f_ruestung = 1;
		a_monster(158).f_zauberkraft = 0;
		a_monster(158).f_zauber = 0;
		a_monster(158).f_reichweite = 0;
		a_monster(158).f_minlevel = 9;
		a_monster(158).f_eigenschaft1 = 8;
		a_monster(158).f_eigenschaft2 = 9;
		a_monster(158).f_eigenschaft3 = 10;
		a_monster(158).f_eigenschaft4 = 27;
		a_monster(158).f_eigenschaft5 = 29;
		a_monster(159).f_name[2] = "Kolossus";
		a_monster(159).f_name[1] = "Colossus";
		a_monster(159).f_name[3] = "Colossus";
		a_monster(159).f_nr = 54;
		a_monster(159).f_art = 6;
		a_monster(159).f_lebenspunkte = 120;
		a_monster(159).f_angriff = 35;
		a_monster(159).f_abwehr = 35;
		a_monster(159).f_staerke = 35;
		a_monster(159).f_ruestung = 10;
		a_monster(159).f_zauberkraft = 0;
		a_monster(159).f_zauber = 0;
		a_monster(159).f_reichweite = 12;
		a_monster(159).f_minlevel = 100;
		a_monster(159).f_eigenschaft1 = 1;
		a_monster(159).f_eigenschaft2 = 12;
		a_monster(159).f_eigenschaft3 = 17;
		a_monster(159).f_eigenschaft4 = 7;
		a_monster(159).f_eigenschaft5 = 13;
		a_monster(159).f_eigenschaft6 = 14;
		a_monster(159).f_eigenschaft7 = 25;
		a_monster(159).f_eigenschaft8 = 15;
		a_monster(160).f_name[2] = "Feuer Magier";
		a_monster(160).f_name[1] = "Fire Magician";
		a_monster(160).f_name[3] = "Mago Fuego";
		a_monster(160).f_nr = 55;
		a_monster(160).f_art = 2;
		a_monster(160).f_lebenspunkte = 10;
		a_monster(160).f_angriff = 4;
		a_monster(160).f_abwehr = 1;
		a_monster(160).f_staerke = 2;
		a_monster(160).f_ruestung = 1;
		a_monster(160).f_zauberkraft = 12;
		a_monster(160).f_zauber = 1;
		a_monster(160).f_reichweite = 9;
		a_monster(160).f_minlevel = 15;
		a_monster(160).f_eigenschaft1 = 4;
		a_monster(160).f_eigenschaft2 = 15;
		a_monster(160).f_eigenschaft3 = 27;
		a_monster(160).f_eigenschaft4 = 29;
		a_monster(160).f_eigenschaft5 = 12;
		a_monster(160).f_eigenschaft6 = 42;
		a_monster(161).f_name[2] = "Wasserd\357\277\275on";
		a_monster(161).f_name[1] = "Water Demon";
		a_monster(161).f_name[3] = "Demonio de Aqua";
		a_monster(161).f_nr = 56;
		a_monster(161).f_art = 7;
		a_monster(161).f_lebenspunkte = 42;
		a_monster(161).f_angriff = 9;
		a_monster(161).f_abwehr = 7;
		a_monster(161).f_staerke = 11;
		a_monster(161).f_ruestung = 5;
		a_monster(161).f_zauberkraft = 0;
		a_monster(161).f_zauber = 0;
		a_monster(161).f_reichweite = 4;
		a_monster(161).f_minlevel = 18;
		a_monster(161).f_eigenschaft1 = 30;
		a_monster(161).f_eigenschaft2 = 23;
		a_monster(161).f_eigenschaft3 = 18;
		a_monster(161).f_eigenschaft4 = 13;
		a_monster(162).f_name[2] = "Riesen Frettchen";
		a_monster(162).f_name[1] = "Giant Frettchen";
		a_monster(162).f_name[3] = "Frettchen gigante";
		a_monster(162).f_nr = 48;
		a_monster(162).f_art = 1;
		a_monster(162).f_lebenspunkte = 10;
		a_monster(162).f_angriff = 6;
		a_monster(162).f_abwehr = 2;
		a_monster(162).f_staerke = 4;
		a_monster(162).f_ruestung = 1;
		a_monster(162).f_zauberkraft = 0;
		a_monster(162).f_zauber = 0;
		a_monster(162).f_reichweite = 0;
		a_monster(162).f_minlevel = 7;
		a_monster(162).f_sound = 45;
		a_monster(162).f_eigenschaft1 = 2;
		a_monster(162).f_eigenschaft2 = 6;
		a_monster(162).f_eigenschaft3 = 8;
		a_monster(162).f_eigenschaft4 = 29;
		a_monster(162).f_eigenschaft5 = 35;
		a_monster(162).f_eigenschaft6 = 44;
		a_monster(163).f_name[2] = "Werewolf";
		a_monster(163).f_name[1] = "Werewolf";
		a_monster(163).f_name[3] = "Hombrelobo";
		a_monster(163).f_nr = 81;
		a_monster(163).f_art = 2;
		a_monster(163).f_lebenspunkte = 15;
		a_monster(163).f_angriff = 7;
		a_monster(163).f_abwehr = 3;
		a_monster(163).f_staerke = 7;
		a_monster(163).f_ruestung = 1;
		a_monster(163).f_zauberkraft = 0;
		a_monster(163).f_zauber = 0;
		a_monster(163).f_reichweite = 0;
		a_monster(163).f_minlevel = 8;
		a_monster(163).f_sound = 36;
		a_monster(163).f_eigenschaft1 = 16;
		a_monster(163).f_eigenschaft2 = 44;
		a_monster(163).f_eigenschaft3 = 29;
		a_monster(163).f_eigenschaft4 = 36;
		a_monster(164).f_name[2] = "Riesenschnecke";
		a_monster(164).f_name[1] = "Giant Slug";
		a_monster(164).f_name[3] = "Caracol Gigante";
		a_monster(164).f_nr = 172;
		a_monster(164).f_art = 1;
		a_monster(164).f_lebenspunkte = 6;
		a_monster(164).f_angriff = 3;
		a_monster(164).f_abwehr = 0;
		a_monster(164).f_staerke = 2;
		a_monster(164).f_ruestung = 0;
		a_monster(164).f_zauberkraft = 0;
		a_monster(164).f_zauber = 0;
		a_monster(164).f_reichweite = 0;
		a_monster(164).f_minlevel = 1;
		a_monster(164).f_eigenschaft1 = 39;
		a_monster(164).f_eigenschaft2 = 29;
		a_monster(165).f_name[2] = "Riesenbremse";
		a_monster(165).f_name[1] = "Giant Horsefly";
		a_monster(165).f_name[3] = "Mosquito Gigante";
		a_monster(165).f_nr = 173;
		a_monster(165).f_art = 1;
		a_monster(165).f_lebenspunkte = 4;
		a_monster(165).f_angriff = 3;
		a_monster(165).f_abwehr = 2;
		a_monster(165).f_staerke = 3;
		a_monster(165).f_ruestung = 0;
		a_monster(165).f_zauberkraft = 0;
		a_monster(165).f_zauber = 0;
		a_monster(165).f_reichweite = 0;
		a_monster(165).f_minlevel = 2;
		a_monster(165).f_eigenschaft1 = 1;
		a_monster(165).f_eigenschaft2 = 8;
		a_monster(165).f_eigenschaft3 = 6;
		a_monster(165).f_eigenschaft4 = 29;
		a_monster(165).f_eigenschaft5 = 44;
		a_monster(166).f_name[2] = "Schuppenechse";
		a_monster(166).f_name[1] = "Scaled Lizard";
		a_monster(166).f_name[3] = "Lagarto Fortificado";
		a_monster(166).f_nr = 174;
		a_monster(166).f_art = 1;
		a_monster(166).f_lebenspunkte = 8;
		a_monster(166).f_angriff = 4;
		a_monster(166).f_abwehr = 1;
		a_monster(166).f_staerke = 3;
		a_monster(166).f_ruestung = 3;
		a_monster(166).f_zauberkraft = 0;
		a_monster(166).f_zauber = 0;
		a_monster(166).f_reichweite = 0;
		a_monster(166).f_minlevel = 5;
		a_monster(166).f_eigenschaft1 = 8;
		a_monster(166).f_eigenschaft2 = 9;
		a_monster(166).f_eigenschaft3 = 29;
		a_monster(167).f_name[2] = "Mykonid";
		a_monster(167).f_name[1] = "Mykonid";
		a_monster(167).f_name[3] = "Mykonid";
		a_monster(167).f_nr = 175;
		a_monster(167).f_art = 4;
		a_monster(167).f_lebenspunkte = 3;
		a_monster(167).f_angriff = 1;
		a_monster(167).f_abwehr = 0;
		a_monster(167).f_staerke = 1;
		a_monster(167).f_ruestung = 0;
		a_monster(167).f_zauberkraft = 0;
		a_monster(167).f_zauber = 0;
		a_monster(167).f_reichweite = 0;
		a_monster(167).f_minlevel = 1;
		a_monster(167).f_eigenschaft1 = 16;
		a_monster(167).f_eigenschaft2 = 43;
		a_monster(168).f_name[2] = "\357\277\275terer Mykonid";
		a_monster(168).f_name[1] = "Elder Mykonid";
		a_monster(168).f_name[3] = "Mykonid Viejo";
		a_monster(168).f_nr = 176;
		a_monster(168).f_art = 4;
		a_monster(168).f_lebenspunkte = 6;
		a_monster(168).f_angriff = 3;
		a_monster(168).f_abwehr = 1;
		a_monster(168).f_staerke = 2;
		a_monster(168).f_ruestung = 0;
		a_monster(168).f_zauberkraft = 0;
		a_monster(168).f_zauber = 0;
		a_monster(168).f_reichweite = 0;
		a_monster(168).f_minlevel = 2;
		a_monster(168).f_eigenschaft1 = 16;
		a_monster(168).f_eigenschaft2 = 43;
		a_monster(169).f_name[2] = "Riesiger Hirschk\357\277\275er";
		a_monster(169).f_name[1] = "Giant Stag Beetle";
		a_monster(169).f_name[3] = "Scarabajo Enorme";
		a_monster(169).f_nr = 171;
		a_monster(169).f_art = 1;
		a_monster(169).f_lebenspunkte = 5;
		a_monster(169).f_angriff = 3;
		a_monster(169).f_abwehr = 1;
		a_monster(169).f_staerke = 3;
		a_monster(169).f_ruestung = 2;
		a_monster(169).f_zauberkraft = 0;
		a_monster(169).f_zauber = 0;
		a_monster(169).f_reichweite = 0;
		a_monster(169).f_minlevel = 4;
		a_monster(169).f_eigenschaft1 = 8;
		a_monster(169).f_eigenschaft2 = 6;
		a_monster(169).f_eigenschaft3 = 29;
		a_monster(170).f_name[2] = "Gargyle";
		a_monster(170).f_name[1] = "Gargoyle";
		a_monster(170).f_name[3] = "Gargyle";
		a_monster(170).f_nr = 177;
		a_monster(170).f_art = 2;
		a_monster(170).f_lebenspunkte = 30;
		a_monster(170).f_angriff = 3;
		a_monster(170).f_abwehr = 2;
		a_monster(170).f_staerke = 6;
		a_monster(170).f_ruestung = 5;
		a_monster(170).f_zauberkraft = 0;
		a_monster(170).f_zauber = 0;
		a_monster(170).f_reichweite = 0;
		a_monster(170).f_minlevel = 11;
		a_monster(170).f_eigenschaft1 = 7;
		a_monster(170).f_eigenschaft2 = 13;
		a_monster(170).f_eigenschaft3 = 25;
		a_monster(170).f_eigenschaft4 = 1;
		g_environment = (p_getenvironmentvariable("HOME") + "/.lostlaby");
		p_createdirectory(g_environment);
		g_yplus = 12;
		g_yplus2 = 10;
		g_akt_zauber_offset = 14;
		g_akt_zauber_offset2 = 13;
		g_anzz = 26;
		if ((p_initsprite() == 0)) {
		}
		p_load_settings();
		if ((g_win_mode == 2)) {
			g_windowsfenster = 1;
		}
		if ((g_win_mode == 1)) {
			if ((p_openscreen(640, 480, 16, "Lost Labyrinth") == 0)) {
			}
			v_screenopen = 1;
		} else {
			if ((p_openwindowedscreen(0, 0, 0, 640, 480, 1, 0, 0) == 0)) {
			}
			v_screenopen = 1;
			p_sdl_wm_setcaption_("Lost Labyrinth - Press Escape to release the mouse", "");
		}
		if (((g_sound == 1) || (g_music == 1))) {
			if ((p_initsound() == 0)) {
			}
			p_load_sounds();
		}
		p_load_graphics();
		p_clipsprite(0, (((a_spieler(g_akt_spieler).f_face * 32) * 2) + (g_frame * 32)), 0, 32, 32);
		p_displaytransparentsprite(0, 160, 160);
		p_setframerate(60);
		if ((p_initkeyboard() == 0)) {
		}
		if ((g_no_mouse == 0)) {
			v_result = p_initmouse();
		}
		p_init_highscores();
		p_read_highscores();
L_again: ;
		g_zw_bild = 0;
		g_nr_of_saves = 0;
		for (v_i = 1; v_i <= 150; v_i += 1) {
			a_raeume(v_i) = 0;
			a_raumx(v_i) = 0;
			a_raumy(v_i) = 0;
			a_ausgangx(v_i) = 0;
			a_ausgangy(v_i) = 0;
			a_sonderlevel(v_i) = 0;
			a_levelmod(v_i) = 0;
			a_groesse(v_i) = 0;
			a_inhalt(v_i) = 0;
			a_mit_was(v_i) = 0;
			a_visionen(v_i) = 0;
		}
		g_mit_was_normal = 1;
		g_inhalt_normal = 4;
		for (v_i = 1; v_i <= 4; v_i += 1) {
			a_spieler(v_i).f_status = 1;
			a_spieler(v_i).f_level = 1;
			a_spieler(v_i).f_maxlevel = 1;
			a_spieler(v_i).f_maennchen = 2;
			a_spieler(v_i).f_lifepoints = 12;
			a_spieler(v_i).f_maxlifepoints = 12;
			a_spieler(v_i).f_lifegain = 3;
			a_spieler(v_i).f_mana = 3;
			a_spieler(v_i).f_maxmana = 3;
			a_spieler(v_i).f_managain = 3;
			a_spieler(v_i).f_attack = 1;
			a_spieler(v_i).f_dexterity = 1;
			a_spieler(v_i).f_strength = 1;
			a_spieler(v_i).f_maxspeed = 7;
			a_spieler(v_i).f_speed = 7;
			a_spieler(v_i).f_perception = 1;
			a_spieler(v_i).f_luck_score = 1;
			a_spieler(v_i).f_power_score = 1;
			a_spieler(v_i).f_circle = 0;
			a_spieler(v_i).f_magieresistenz = 0;
			a_spieler(v_i).f_spellweaving = 1;
			a_spieler(v_i).f_style = 0;
			a_spieler(v_i).f_light = 1;
			a_spieler(v_i).f_hunger = 0;
			a_spieler(v_i).f_durst = 0;
			a_spieler(v_i).f_betrunken = 0;
			a_spieler(v_i).f_mks = 0;
			a_spieler(v_i).f_schleichen = 0;
			a_spieler(v_i).f_fluch = 0;
			a_spieler(v_i).f_fluchdauer = 0;
			a_spieler(v_i).f_krankheit = 0;
			a_spieler(v_i).f_krankheitdauer = 0;
			a_spieler(v_i).f_gift = 0;
			a_spieler(v_i).f_giftdauer = 0;
			a_spieler(v_i).f_verhungern = 0;
			a_spieler(v_i).f_verdursten = 0;
			a_spieler(v_i).f_weisheit = 0;
			a_spieler(v_i).f_lifepointgegenstand = 0;
			a_spieler(v_i).f_managegenstand = 0;
			a_spieler(v_i).f_staerkegegenstand = 0;
			a_spieler(v_i).f_zugweitegegenstand = 0;
			a_spieler(v_i).f_dexteritygegenstand = 0;
			a_spieler(v_i).f_gluecksgegenstand = 0;
			a_spieler(v_i).f_bogentreffergegenstand = 0;
			a_spieler(v_i).f_bogenschadengegenstand = 0;
			a_spieler(v_i).f_powergegenstand = 0;
			a_spieler(v_i).f_perceptiongegenstand = 0;
			a_spieler(v_i).f_attackgegenstand = 0;
			a_spieler(v_i).f_stealthgegenstand = 0;
			a_spieler(v_i).f_damagegegenstand = 0;
			a_spieler(v_i).f_lichtgegenstand = 0;
			a_spieler(v_i).f_diebstahlgegenstand = 0;
			a_spieler(v_i).f_goblinlehre = 0;
			a_spieler(v_i).f_spinnenlehre = 0;
			a_spieler(v_i).f_untotenlehre = 0;
			a_spieler(v_i).f_pflanzenlehre = 0;
			a_spieler(v_i).f_tierkunde = 0;
			a_spieler(v_i).f_fallenlehre = 0;
			a_spieler(v_i).f_giftlehre = 0;
			a_spieler(v_i).f_pos_zaubermenue = 0;
			a_spieler(v_i).f_dumm = 0;
			a_spieler(v_i).f_face = 2;
			a_spieler(v_i).f_hinterhalt = 0;
			a_spieler(v_i).f_portal = 1;
			a_spieler(v_i).f_teleport = 1;
			a_spieler(v_i).f_nexus = 1;
			a_spieler(v_i).f_stehlen = 2;
			a_spieler(v_i).f_armageddon = 1;
			a_spieler(v_i).f_pestilence = 1;
			a_spieler(v_i).f_drachenform = 1;
			a_spieler(v_i).f_macht = 1;
			a_spieler(v_i).f_magic_apple = 2;
			a_spieler(v_i).f_refresh = 2;
			a_spieler(v_i).f_heal = 3;
			a_spieler(v_i).f_schriftrolle = 0;
			a_spieler(v_i).f_zauberbuch = 0;
			a_spieler(v_i).f_kessel = 0;
			a_spieler(v_i).f_udjat_ben = 1;
			a_spieler(v_i).f_akt_zauber = 1;
			a_spieler(v_i).f_schule = "";
			a_spieler(v_i).f_udjat_ben = 1;
			a_spieler(v_i).f_character_x = 1;
			a_spieler(v_i).f_character_y = 1;
			a_spieler(v_i).f_lehrer = 3;
			a_spieler(v_i).f_stabteile = 0;
			a_spieler(v_i).f_moves = 0;
			a_spieler(v_i).f_anker_x = 0;
			a_spieler(v_i).f_anker_y = 0;
			a_spieler(v_i).f_anker_level = 0;
			a_spieler(v_i).f_old_pos_x = a_spieler(v_i).f_character_x;
			a_spieler(v_i).f_old_pos_y = a_spieler(v_i).f_character_y;
			a_spieler(v_i).f_old_lp = a_spieler(v_i).f_lifepoints;
			a_spieler(v_i).f_old_max_lp = a_spieler(v_i).f_maxlifepoints;
			a_spieler(v_i).f_old_mp = a_spieler(v_i).f_mana;
			a_spieler(v_i).f_old_max_mp = a_spieler(v_i).f_maxmana;
			for (v_k = 1; v_k <= 2; v_k += 1) {
				a_spieler(v_i).f_sterbegrund[v_k] = " ";
			}
			a_spieler(v_i).f_creature_typ = 0;
			a_spieler(v_i).f_creature_attack = 0;
			a_spieler(v_i).f_creature_lifepoints = 0;
			a_spieler(v_i).f_creature_speed = 0;
			a_spieler(v_i).f_creature_maxspeed = 0;
			a_spieler(v_i).f_creature_x = 0;
			a_spieler(v_i).f_creature_y = 0;
			a_spieler(v_i).f_creature_heading = 0;
		}
		for (v_j = 1; v_j <= 4; v_j += 1) {
			for (v_i = 1; v_i <= 15; v_i += 1) {
				a_aktive(v_i, v_j).f_nr = 0;
				a_aktive(v_i, v_j).f_dauer = 0;
			}
		}
		for (v_j = 1; v_j <= 10; v_j += 1) {
			for (v_i = 1; v_i <= 4; v_i += 1) {
				a_schnellzauber(v_j, v_i) = "";
			}
		}
		for (v_j = 1; v_j <= 8; v_j += 1) {
			for (v_i = 1; v_i <= 4; v_i += 1) {
				a_schnellzauber2(v_j, v_i) = "";
			}
		}
		for (v_j = 1; v_j <= 4; v_j += 1) {
			for (v_i = 1; v_i <= 50; v_i += 1) {
				a_inventory(v_i, v_j).f_name = 0;
				a_inventory(v_i, v_j).f_art = 0;
				a_inventory(v_i, v_j).f_status = 0;
				a_inventory(v_i, v_j).f_benutzt = 0;
				a_inventory(v_i, v_j).f_anzahl = 0;
				a_inventory(v_i, v_j).f_attri1 = 0;
				a_inventory(v_i, v_j).f_attri2 = 0;
				a_inventory(v_i, v_j).f_attri3 = 0;
				a_inventory(v_i, v_j).f_attri4 = 0;
				a_inventory(v_i, v_j).f_attri5 = 0;
			}
		}
		for (v_i = 1; v_i <= 150; v_i += 1) {
			a_spinnenkoenigin(v_i) = 0;
		}
		for (v_i = 1; v_i <= 150; v_i += 1) {
			a_goblinkoenig(v_i) = 0;
		}
		for (v_i = 1; v_i <= 150; v_i += 1) {
			a_untotenherr(v_i) = 0;
		}
		for (v_i = 1; v_i <= 177; v_i += 1) {
			a_summoning(v_i) = 0;
		}
		p_init_creatures();
		g_anfangszeit = p_formatdate("%yyyy%mm%dd%hh%ii%ss", p_date());
		p_init_spells();
		p_init_traenke();
		p_init_pilze();
		if ((g_music == 1)) {
			p_stopmodule(-1);
			p_playmodule(0);
		}
		p_title();
		p_select_spieler();
		for (g_akt_spieler = 1; g_akt_spieler <= g_anz_spieler; g_akt_spieler += 1) {
			p_maennchen_auswaehlen();
			p_init_skills();
			g_punkte = 14;
			p_select_skills();
			p_advancements();
			a_spieler(g_akt_spieler).f_verifikation = "";
			for (v_i = 1; v_i <= 30; v_i += 1) {
				a_spieler(g_akt_spieler).f_verifikation = (a_spieler(g_akt_spieler).f_verifikation + p_str(p_random(9)));
			}
			p_delay(v_my_delay);
		}
		if ((g_music == 1)) {
			p_stopmodule(-1);
		}
		for (g_akt_spieler = 1; g_akt_spieler <= g_anz_spieler; g_akt_spieler += 1) {
			a_spieler(g_akt_spieler).f_speed = p_maxspeed();
			a_spieler(g_akt_spieler).f_lifepoints = p_maxlife();
		}
		for (v_i = 1; v_i <= 40; v_i += 1) {
			for (v_j = 1; v_j <= 150; v_j += 1) {
				a_haendler_objekte(v_i, v_j) = 0;
				a_haendler_schriftrolle(v_i, v_j) = 0;
				a_haendler_staerke(v_i, v_j) = 0;
			}
		}
		for (v_akt_level = 1; v_akt_level <= 150; v_akt_level += 1) {
			for (v_i = 1; v_i <= 200; v_i += 1) {
				for (v_j = 1; v_j <= 200; v_j += 1) {
					a_automap(v_i, v_j).f_feld[v_akt_level] = 0;
				}
			}
			a_levelmod(v_akt_level) = 0;
			if (((v_akt_level > 25) && (p_random(100) > 90))) {
				a_levelmod(v_akt_level) = (p_random(14) + 1);
			}
			a_sonderlevel(v_akt_level) = 0;
			if (((((v_akt_level > 10) && (p_random(100) > 80)) && (a_levelmod(v_akt_level) == 0)) || (g_test == 1))) {
				a_sonderlevel(v_akt_level) = (p_random(10) + 1);
				if ((g_test == 1)) {
					a_sonderlevel(v_akt_level) = 10;
				}
			}
			a_fluss(v_akt_level) = 0;
			if ((((v_akt_level >= 10) && (p_random(3) == 0)) && (a_sonderlevel(v_akt_level) == 0))) {
				a_fluss(v_akt_level) = 1;
			}
			a_raeume(v_akt_level) = 0;
			if (((((v_akt_level > 3) && (a_fluss(v_akt_level) == 0)) && (a_sonderlevel(v_akt_level) == 0)) || (g_test == 1))) {
				do {
					v_gesetzt = 1;
					a_raeume(v_akt_level) = (p_random(33) + 1);
					if ((g_test == 1)) {
					}
					if (((a_raeume(v_akt_level) == 21) && (v_akt_level < 10))) {
						v_gesetzt = 0;
					}
					if (((a_raeume(v_akt_level) == 8) && (v_akt_level < 6))) {
						v_gesetzt = 0;
					}
					if (((a_raeume(v_akt_level) == 14) && (v_akt_level < 7))) {
						v_gesetzt = 0;
					}
				} while (!(v_gesetzt == 1));
				if ((a_raeume(v_akt_level) == 1)) {
					p_haendler_init1(v_akt_level);
				}
				if ((a_raeume(v_akt_level) == 15)) {
					p_haendler_init2(v_akt_level);
				}
				if ((a_raeume(v_akt_level) == 27)) {
					p_haendler_init3(v_akt_level);
				}
				if ((a_raeume(v_akt_level) == 28)) {
					p_haendler_init4(v_akt_level);
				}
				if ((a_raeume(v_akt_level) == 30)) {
					p_haendler_init5(v_akt_level);
				}
			}
		}
		g_level = 1;
		p_gen_laby(g_level);
		for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
			a_spieler(v_i).f_character_x = a_eingangx(g_level);
			a_spieler(v_i).f_character_y = a_eingangy(g_level);
		}
L_geladen: ;
		for (v_j = 1; v_j <= 4; v_j += 1) {
			for (v_i = 1; v_i <= 25; v_i += 1) {
				a_old_messages(v_i, v_j).f_farbe = 0;
				a_old_messages(v_i, v_j).f_nachricht = " ";
			}
		}
		p_flipbuffers(1);
		g_akt_spieler = 1;
		p_laby_screen();
		if ((g_music == 1)) {
			p_playmodule(1);
		}
		g_akt_spieler = 1;
		do {
			v_starttime = p_elapsedmilliseconds();
			p_fenster(0);
			if ((a_spieler(g_akt_spieler).f_creature_speed > 0)) {
				p_creature_bewegen();
			} else {
				g_xmod = 0;
				g_ymod = 0;
				p_examinekeyboard();
				v_jax = 0;
				v_jay = 0;
				if ((g_joystick_used == 1)) {
					p_examinejoystick();
					v_jax = p_joystickaxisx();
					v_jay = p_joystickaxisy();
					v_jb1 = p_joystickbutton(1);
				}
				if ((g_no_mouse == 0)) {
					v_result = p_examinemouse();
					g_mmouse_x = p_mousex();
					g_mmouse_y = p_mousey();
					g_mmouse_links = p_mousebutton(1);
				}
				if ((p_keyboardpushed(275) || (v_jax == 1))) {
					v_okay = 1;
					a_spieler(g_akt_spieler).f_face = 1;
					g_xmod = 1;
					g_ymod = 0;
				}
				if ((p_keyboardpushed(276) || (v_jax == -1))) {
					v_okay = 1;
					a_spieler(g_akt_spieler).f_face = 3;
					g_xmod = -1;
					g_ymod = 0;
				}
				if ((p_keyboardpushed(273) || (v_jay == -1))) {
					v_okay = 1;
					a_spieler(g_akt_spieler).f_face = 0;
					g_xmod = 0;
					g_ymod = -1;
				}
				if ((p_keyboardpushed(274) || (v_jay == 1))) {
					v_okay = 1;
					a_spieler(g_akt_spieler).f_face = 2;
					g_xmod = 0;
					g_ymod = 1;
				}
				g_aktion = 0;
				if ((g_no_mouse == 0)) {
					if ((g_mmouse_links == 1)) {
						if (((((g_mmouse_x > 160) && (g_mmouse_x < 192)) && (g_mmouse_y >= 160)) && (g_mmouse_y <= 192))) {
							p_autopickup();
						} else {
							if (((((g_mmouse_x > 176) && (g_mmouse_x < 352)) && (g_mmouse_y >= 160)) && (g_mmouse_y <= 192))) {
								v_okay = 1;
								a_spieler(g_akt_spieler).f_face = 1;
								g_xmod = 1;
								g_ymod = 0;
							} else {
								if ((((g_mmouse_x < 176) && (g_mmouse_y >= 160)) && (g_mmouse_y <= 192))) {
									v_okay = 1;
									a_spieler(g_akt_spieler).f_face = 3;
									g_xmod = -1;
									g_ymod = 0;
								} else {
									if (((((g_mmouse_y > 176) && (g_mmouse_y < 352)) && (g_mmouse_x >= 160)) && (g_mmouse_x <= 192))) {
										v_okay = 1;
										a_spieler(g_akt_spieler).f_face = 2;
										g_xmod = 0;
										g_ymod = 1;
									} else {
										if ((((g_mmouse_y < 176) && (g_mmouse_x >= 160)) && (g_mmouse_x <= 192))) {
											v_okay = 1;
											a_spieler(g_akt_spieler).f_face = 0;
											g_xmod = 0;
											g_ymod = -1;
										}
									}
								}
							}
						}
					}
				}
				if (((g_xmod != 0) || (g_ymod != 0))) {
					p_vor_bewegung();
				}
				if (((g_xmod != 0) || (g_ymod != 0))) {
					g_bewegt = 1;
				} else {
					g_bewegt = 0;
				}
				g_spielerwechsel = 0;
				g_schongemalt = 0;
				if (((g_xmod != 0) || (g_ymod != 0))) {
					a_spieler(g_akt_spieler).f_speed = (a_spieler(g_akt_spieler).f_speed - 1);
					for (v_i = 4; v_i <= 32; v_i += 4) {
						v_starttime2 = p_elapsedmilliseconds();
						v_framestep = (v_framestep + 1);
						if ((v_framestep > 3)) {
							v_framestep = 0;
							if ((g_frame == 0)) {
								g_frame = 1;
							} else {
								g_frame = 0;
							}
						}
						p_screen1(v_i);
						if ((g_no_mouse == 0)) {
							v_result = p_examinemouse();
							g_mmouse_x = p_mousex();
							g_mmouse_y = p_mousey();
							g_mmouse_links = p_mousebutton(1);
							g_mmouse_rechts = p_mousebutton(2);
							p_clipsprite(8, 192, 288, 32, 32);
							p_displaytransparentsprite(8, g_mmouse_x, g_mmouse_y);
						}
						v_elapsedtime2 = (p_elapsedmilliseconds() - v_starttime2);
						if ((v_elapsedtime2 < 15)) {
							p_delay((15 - v_elapsedtime2));
						}
						p_flipbuffers(1);
					}
					g_schongemalt = 1;
					a_spieler(g_akt_spieler).f_character_x = (a_spieler(g_akt_spieler).f_character_x + g_xmod);
					a_spieler(g_akt_spieler).f_character_y = (a_spieler(g_akt_spieler).f_character_y + g_ymod);
					p_update_automap();
				}
				p_schnelltasten();
				p_zwischenbild();
				p_ftasten();
				if (((p_keyboardpushed(32) || (v_jb1 != 0)) && (g_autopickup == 0))) {
					p_autopickup();
				}
				if ((g_schongemalt == 0)) {
					p_screen2();
					if ((g_no_mouse == 0)) {
						v_result = p_examinemouse();
						g_mmouse_x = p_mousex();
						g_mmouse_y = p_mousey();
						g_mmouse_links = p_mousebutton(1);
						g_mmouse_rechts = p_mousebutton(2);
						g_over_item = 0;
						if (((((g_mmouse_x > 160) && (g_mmouse_x < 192)) && (g_mmouse_y >= 160)) && (g_mmouse_y <= 192))) {
							if ((a_laby_item(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_name[a_spieler(g_akt_spieler).f_level] > 0)) {
								g_over_item = 1;
							}
							v_testfeld = a_labyrinth(a_spieler(g_akt_spieler).f_character_x, a_spieler(g_akt_spieler).f_character_y).f_feld[a_spieler(g_akt_spieler).f_level];
							if (((((((((((((((((((((((((((((((((((((((v_testfeld >= 58) && (v_testfeld <= 61)) || (v_testfeld > 388)) || (v_testfeld == 68)) || (v_testfeld == 194)) || (v_testfeld == 63)) || (v_testfeld == 161)) || (v_testfeld == 162)) || (v_testfeld == 9)) || (v_testfeld == 118)) || (v_testfeld == 7)) || (v_testfeld == 64)) || (v_testfeld == 82)) || (v_testfeld == 84)) || (v_testfeld == 87)) || (v_testfeld == 120)) || (v_testfeld == 121)) || (v_testfeld == 122)) || (v_testfeld == 123)) || (v_testfeld == 124)) || (v_testfeld == 125)) || (v_testfeld == 126)) || (v_testfeld == 127)) || (v_testfeld == 128)) || (v_testfeld == 129)) || (v_testfeld == 130)) || (v_testfeld == 131)) || (v_testfeld == 202)) || (v_testfeld == 203)) || (v_testfeld == 6)) || (v_testfeld == 192)) || (v_testfeld == 8)) || (v_testfeld == 54)) || (v_testfeld == 119)) || (v_testfeld == 19)) || (v_testfeld == 3)) || (v_testfeld == 2)) || (v_testfeld == 206))) {
								g_over_item = 1;
							}
						}
						if ((g_over_item == 0)) {
							p_clipsprite(8, 192, 288, 32, 32);
						} else {
							p_clipsprite(8, 416, 800, 32, 32);
						}
						p_displaytransparentsprite(8, g_mmouse_x, g_mmouse_y);
					}
					p_flipbuffers(1);
				}
				p_laby_screen2();
				p_falle();
				p_sonderfeld();
				if (((a_spieler(g_akt_spieler).f_speed < 1) || (g_aktion == 1))) {
					g_spielerwechsel = 1;
L_nach_zauber: ;
					p_laby_screen2();
					p_nach_zug();
					if ((a_spieler(g_akt_spieler).f_creature_speed > 0)) {
						p_laby_screen3();
					} else {
						p_laby_screen();
					}
				}
				if ((g_anz_spieler > 1)) {
					v_weitere = 0;
					for (v_i = 1; v_i <= g_anz_spieler; v_i += 1) {
						if ((a_spieler(v_i).f_status == 1)) {
							v_weitere = (v_weitere + 1);
						}
					}
					if ((((g_spielerwechsel == 1) || (g_aktion == 1)) && (v_weitere > 1))) {
						p_nachricht(192, 1);
						p_naechster();
					}
				}
			}
			v_elapsedtime = (p_elapsedmilliseconds() - v_starttime);
			if ((v_elapsedtime < 15)) {
				p_delay((15 - v_elapsedtime));
			}
		} while (!(v_eventid == 1));
		exit(0);
	} catch (enum label l) {
		gotolabel = l;
		goto DISPATCH;
	};
	return 0;
}

